** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** 
** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** 
** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** 
** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** 
** ** ** **                                                          ** 
** ** ** **                                                          ** 
** ** ** **       V A L U E  O F  M E D I C A L  I N N O V A T I O N ** 
** ** ** **       V A L U E  O F  M E D I C A L  I N N O V A T I O N ** 
** ** ** **       V A L U E  O F  M E D I C A L  I N N O V A T I O N ** 
** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** 
** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** 

*SM9

*1_Data Setup

/*
Construct the data set to be used in both reduced-form
and structural estimation.  Export the data set for 
use in MATLAB.  Also estimate transition probabilities
and outcomes that are both results and for use in 
the structural model.  In some cases, these estimates
will only serve as starting values for subsequent 
structural estimation
*/

clear
clear matrix
set more off
set mem 1g
set scheme s2mono

**** HERE, REPLACE cd COMMAND TO NAVIGATE TO FOLDER REPLICATION

cd "~/Dropbox/WORK/VMI/PAPER/REPLICATION/STATA/DATASETS"

**** HERE, REPLACE cd COMMAND TO NAVIGATE TO FOLDER REPLICATION

************
************
*DATA SETUP*
************
************

*********
*STEP 1:*
*********

/*
- Obtain ALL medication (ARV) data from visits 6-41
-- 6-11
-- 12
-- 13-41
-- save as "drugs.dta"
*/

*Visits 6-11, 75
clear
infix caseid 1-5 visit 6-8 /// 
maids 1774 /// Any AIDS med: (Visits 6-11, 15-41, 75)
m1aid 1738-1740 m2aid 1746-1748 m3aid 1754-1756 /// Any drugs to fight HIV (Visits 6-11, 75) [already in sub-vis format]
using "MainDataFile/MACSmen/data/section4.dat"

keep if visit>=60 & visit<=110
rename m1aid med1
rename m2aid med2
rename m3aid med3
tab maids
replace maids=2 if maids==1 & med1!=.
replace maids=2 if maids==. & med1!=.
keep if maids==2 & med1!=.
drop maids
reshape long med, i(caseid visit) j(d)
keep if med!=.
drop d
save "drug6_11_75.dta", replace
clear

*Visit 12
clear
infix caseid 1-5 visit 6-8 /// 
cltrl 596 plct1 2626 ctdr1 770-772 plct2 2627 ctdr2 773-775 plct3 2628 ctdr3 776-778 /// Drugs CTRIAL (Visit 12)
d1nam 800-802 d2nam 833-835 d3nam 866-868 d4nam 899-901 /// Drugs Not CTRIAL (Visit 12)
using "MainDataFile/MACSmen/data/section4.dat"

keep if visit==120
drop if plct1==2 | plct1==3 | plct2==2 | plct2==3
drop plct1 plct2 plct3
rename ctdr1 med1
rename ctdr2 med2
rename ctdr3 med3
rename d1nam med4
rename d2nam med5
rename d3nam med6
rename d4nam med7
reshape long med, i(caseid visit) j(d)
keep if med!=.
drop d cltrl
append using "drug6_11_75.dta"
sort caseid visit
erase "drug6_11_75.dta"
save "drug6_12_75.dta", replace

*Visits 13-41
clear
infix caseid 1-5 visit 6-8 drgav /// 
79-81 resf1 91 plcf1 88 ///
using "MainDataFile/MACSmen/data/drugf1.dat"
sort caseid visit drgav resf1 plcf1
replace plcf1=1 if resf1==1
drop if resf1==2
drop if plcf1==2
drop resf1 plcf1
rename drgav med
append using "drug6_12_75.dta"

*Drop Non ARV's using DGNAV from drugf1 as guide
replace med=1000+med

drop if ///
med==1093 | med==1095 | med==1096 | med==1097 | med==1102 | med==1103 | med==1104 | ///
med==1105 | med==1106 | med==1107 | med==1111 | med==1112 | med==1113 | med==1114 | ///
med==1115 | med==1116 | med==1117 | med==1118 | med==1119 | med==1120 | med==1121 | ///
med==1123 | med==1124 | med==1125 | med==1126 | med==1127 | med==1129 | med==1130 | /// 
med==1131 | med==1132 | med==1133 | med==1134 | med==1135 | med==1136 | med==1137 | ///
med==1138 | med==1139 | med==1140 | med==1141 | med==1143 | med==1144 | med==1145 | ///
med==1148 | med==1149 | med==1150 | med==1151 | med==1152 | med==1153 | med==1154 | ///
med==1155 | med==1156 | med==1157 | med==1158 | med==1160 | med==1161 | med==1162 | ///
med==1164 | med==1165 | med==1166 | med==1168 | med==1169 | med==1170 | med==1170 | ///
med==1173 | med==1174 | med==1175 | med==1176 | med==1177 | med==1178 | med==1181 | ///
med==1182 | med==1183 | med==1184 | med==1188 | med==1189 | med==1190 | med==1196 | ///
med==1197 | med==1199 | med==1200 | med==1203 | med==1207 | med==1225 | med==1226 | ///
med==1228 | med==1232 | med==1235 | med==1236 | med==1241 | med==1245 | med==1246 | ///
med==1196 | med==1197 | med==1198

sort caseid visit med
drop if caseid==caseid[_n-1] & visit==visit[_n-1] & med==med[_n-1]

sort caseid
by caseid: egen minmed=min(visit)

sort caseid visit
erase "drug6_12_75.dta"
save "drugs.dta", replace



*********
*STEP 2:* 
*********
/*
-Call drgav data
-Create a measure of compliance
--Self-reported (medpre) at visit>=290
--Stopping NOT due to doctor's orders at visits 170-410
*/

clear
infix caseid 1-5 visit 6-8 drgav 79-81 mdpre 85 decav 76 ///
stane 131 stbld 133 sthed 144 stvot 166 stabp 130 stmpw 150 stbte 135 ///
stwbc 167 sthos 145 stper 162 stdoc 140 stexp 141 stinc 146 ///
stoth 160-161 stot1 154-155 stot2 156-157 stot3 158-159 ///
using "MainDataFile/MACSmen/data/drugf1.dat"
gen comply=1
replace comply=0 if visit<=280 & decav==2 & stdoc==1
replace comply=0 if mdpre==3 
replace comply=0 if mdpre==4 
replace comply=. if visit<170
replace comply=. if visit>=290 & mdpre==.

keep caseid visit drgav comply
rename drgav med
replace med=med+1000
sort caseid visit med comply
save "comply.dta", replace
clear
use "drugs.dta"
sort caseid visit med
merge caseid visit med using "comply.dta"
drop if _merge==2
drop _merge
sort caseid visit med
drop if caseid==caseid[_n-1] & visit==visit[_n-1] & med==med[_n-1]
erase "comply.dta"

sort caseid visit
by caseid visit: egen min_comply=min(comply)
drop comply
rename min_comply comply
save "drugs.dta", replace

*********
*STEP 3:* 
*********
/*
-Call up 'drugs.dta'
-Reshape (drugs)
*/

clear
use "drugs.dta" 

sort caseid visit med
gen av=1
gen xt=_n
replace xt=xt[_n-1] if caseid==caseid[_n-1] & visit==visit[_n-1] & _n!=1
drop if med==med[_n-1] & visit==visit[_n-1] & caseid==caseid[_n-1]
sort caseid visit med
reshape wide av, i(xt) j(med)

foreach var of varlist av* {
qui replace `var'=0 if `var'==.
}
*
sort caseid visit
drop xt
sort caseid visit

save "drugs", replace
clear

*********
*STEP 4:* 
*********
/*
-Merge with mdf data
*/
clear
use "MainDataFile/stata/datasets/maindatafile_vmi"
*ocpay: total co-payments, outpatient stuff, etc.
*dpay: total payments for prescriptions
*pcost: total premium payments for insurance

keep ///
caseid visit ///
d_sp d_sc d_ng ///
d_nt d_pt cd4 lcd4 dcd4 dyear ///
d_pr d_po ///
white nwhite age bage borny ///
educa college hschool scolleg /// 
bincom incom /// 
ftime ptime emdis /// 
hmoc gpic ipic mcaid mcare vaben champ other dpay ///
dpay ocpay pcost hopay nsmed nseek nmoth ///
minvisit maxvisit  ///  
hope meds sfx ///
fatig diarr heada fever sweat ///
trial placebo ///
expF ///
cesd depress hope

sort caseid visit
merge caseid visit using "drugs"
drop if _merge==2
sort caseid visit

foreach var of varlist av* {
qui replace `var'=0 if `var'==. & visit>=60 & meds==0
}
*

drop if minvisit==75
replace d_pr=0 if d_pr==1 & visit==400
replace d_po=1 if d_po==0 & visit==400
drop minvisit
drop maxvisit
qui by caseid: egen maxvisit=max(visit)
qui by caseid: egen minvisit=min(visit)
gen year=(((visit-10)/20)+1984)
gen maxyear=(((maxvisit-10)/20)+1984)
gen minyear=(((minvisit-10)/20)+1984)
gen dvisit = (20*(dyear-1984)+10)
gen diffvisit=dvisit-maxvisit

drop _merge
drop if visit<60

**DEATH
gen B_it1_neg=0
replace B_it1_neg=1 if visit==maxvisit & dyear!=. & d_pt==0
replace B_it1_neg=. if d_pt!=0
sort visit
by visit: egen meanB1_neg=mean(B_it1_neg)
drop B_it1_neg


**Begin: INCOME NEG
preserve
sort caseid visit
gen incom_1=incom[_n+1] if caseid==caseid[_n+1]
gen IN_it=((incom*10000)-5000)/2
gen IN_it1=((incom_1*10000)-5000)/2

replace IN_it=IN_it*2
replace IN_it1=IN_it1*2
sum IN_it if ftime==2
sum IN_it if ftime==1

sum IN_it if ftime==2 & d_pt==1
sum IN_it if ftime==1 & d_pt==1

sum IN_it if ftime==2 & d_pt==0
sum IN_it if ftime==1 & d_pt==0
tab IN_it if ftime==2 & d_pt==0
tab IN_it if ftime==1 & d_pt==0

sum IN_it if ftime==2 & d_pt==0 & ptime==1
sum IN_it if ftime==1 & d_pt==0 & ptime==1

tab emdis if ftime==1 & d_pt==1
tab emdis if ftime==1 & d_pt==0

keep if d_sc==1
gen NEG_IN=IN_it if d_pt==0
gen POS_IN=IN_it if d_pt==1
gen POS_IN_dis=IN_it if d_pt==1 & ftime==1
by caseid: egen mNEG_IN=mean(NEG_IN)
by caseid: egen mPOS_IN=mean(POS_IN)
by caseid: egen mPOS_IN_dis=mean(POS_IN_dis)
by caseid: keep if _n==1
sum mNEG_IN
sum mPOS_IN
sum mPOS_IN_dis

reg mPOS_IN mNEG_IN
reg mPOS_IN_dis mNEG_IN
restore
**END: INCOME NEG 

drop if d_pt==0
drop if meds==. 					// When we have drug data but no meds data -- due to missing / deleted obs in mdf
drop if trial==1 & av1234==. 		// When I've dropped trial part's in drug file but not in mdf.
drop if placebo==1 & av1234==. 
drop placebo trial

sort caseid visit 
save "drugs", replace

***********
*STEP 4.5:* 
***********
/*
ADD OCCUPATION...
*/

clear
infix caseid 1-5 visit 6-8 occup 58-60 ///
using "MainDataFile/MACSmen/data/section2.dat"
sort caseid visit
merge caseid visit using "drugs"
sort caseid visit
by caseid: egen maxoccup=max(occup)
drop occup
rename maxoccup occup
drop if _merge==1
drop _merge
sort caseid visit
save "drugs", replace

*********
*STEP 5:* 
*********
/*
- Make drug categories
-- HAART
-- NRTI Mono
-- NRTI Combo
-- HAART (PI)
-- HAART (Non-PI)
-- Combo
*/

clear
use "drugs"
sort caseid visit
*HAART

gen totnrti= ///
av1092 + av1094 + av1147 + av1159 + av1194 + /// 
av1204 + av1218 + av1224 + av1234 + av1239 + /// 
av1180 + av1185 + av1186 + av1187 + av1205   
replace totnrti=totnrti+2 if av1227==1  
replace totnrti=totnrti+3 if av1240==1  
gen totnnrti= ///
av1191 + av1220

gen totpi= ///
av1193 + av1210 + av1211 + av1212 + av1216 + av1217 + ///
av1219 + av1219 + av1243 + av1249 

*HAART_1: >=2 NRTI's + 1 NNRTI

gen haart_1=0
replace haart_1=1 if (totnrti>=2 & totnnrti>=1)
replace haart_1=1 if (totnrti>=2 & totpi>=1)
replace haart_1=. if totnrti==. | totnnrti==. | totpi==.

*HAART_2: 1 NNRTI + Ritonavir + PI + >=0 NRTI

gen haart_2=0
gen ritonavir=0
replace ritonavir=1 if av1211==1
replace haart_2=1 if (totnnrti>=1 & ritonavir==1 & totpi==0)

*HAART_3: >=3 NRTI's + Abacavir or Tenofovir & 0 NNRTI & 0 pi

gen haart_3=0
gen aba_teno=0
replace aba_teno=1 if (av1234==1 | av1218==1)
replace haart_3=1 if (aba_teno==1 & totnrti==1 & totnnrti==0 & totpi==0)

*HAART_4: >=2 PI's + Ritonavir
gen haart_4=0
replace haart_4=1 if (totpi>=3 & ritonavir==1)

by caseid visit: egen hhaart_1=max(haart_1)
by caseid visit: egen hhaart_2=max(haart_2)
by caseid visit: egen hhaart_3=max(haart_3)
by caseid visit: egen hhaart_4=max(haart_4)
drop haart_1
drop haart_2
drop haart_3
drop haart_4
rename hhaart_1 haart_1
rename hhaart_2 haart_2
rename hhaart_3 haart_3
rename hhaart_4 haart_4

gen haart=0
replace haart=1 if haart_1==1 | haart_2==1 |haart_3==1 |haart_4==1
drop ritonavir aba_teno
drop haart_1 haart_2 haart_3 haart_4

gen haart_pi=haart
gen haart_npi=haart

replace haart_npi=0 if totpi>0
replace haart_pi=0 if  totpi==0


* * * * * * * * * * * * * * 
* * * * * * * * * * * * * * 
*Make Treatment Categories*
* * * * * * * * * * * * * *
* * * * * * * * * * * * * *

*No ARV treatment at all

*NRTI Mono, No HAART
gen mono=(totnrti==1 & haart==0)

*NRTI Combo, No HAART
gen combo=(totnrti>1 & totnrti!=. & haart==0)

*None of these treatments
gen none=(mono==0 & combo==0 & haart==0)
*drop if meds==1 & none==1 ??? /// Is this kosher?
*Those who are using some ARV, but not HAART and NOT NRTI, etc. etc.

**TREATMENT CHOICE: d_it_m

gen d_it_m=.
replace d_it_m=0 if none==1 & meds==0
replace d_it_m=1 if mono==1
replace d_it_m=2 if combo==1
replace d_it_m=3 if haart==1
replace d_it_m=4 if none==1 & meds==1

** Resolve Ambiguous Treatments
/*
gen sumvar= ///
av1001+ av1002+ av1004+ av1009+ av1031+ av1055+ ///
av1058+ av1090+ av1091+ av1092+ av1094+ av1098+ /// 
av1099+ av1101+ av1108+ av1109+ av1110+ av1122+ /// 
av1128+ av1147+ av1146+ av1159+ av1167+ av1180+ /// 
av1185+ av1186+ av1187+ av1191+ av1193+ av1194+ /// 
av1204+ av1205+ av1210+ av1211+ av1212+ av1213+ /// 
av1215+ av1216+ av1217+ av1218+ av1219+ av1220+ /// 
av1224+ av1227+ av1231+ av1233+ av1234+ av1239+ /// 
av1240+ av1243+ av1249+ av1253+ av1254+ av1997+ /// 
av1998+ av1999

tab sumvar if d_it_m==4
keep if sumvar==1

foreach var of varlist av*{
egen sum_`var'=sum(`var')
} 
*/

gen d_it1_m=d_it_m[_n+1] if caseid[_n+1]==caseid & visit[_n+1]-visit==10

**Ever HAART & Ever MEDS
sort caseid visit
by caseid: gen emeds1=sum(d_it_m==1)
replace emeds1=1 if emeds1>=1 & emeds1!=.

by caseid: gen emeds2=sum(d_it_m==2)
replace emeds2=1 if emeds2>=1 & emeds2!=.
gen emeds=0
replace emeds=1 if emeds1==1 | emeds2==1

by caseid: gen emeds3=sum(d_it_m==3)
replace emeds3=1 if emeds3>=1 & emeds3!=.

drop totnrti totnnrti emeds1 emeds2
save "drugs", replace
clear 


*********
*STEP 6:* 
*********
/*
SET-UP for ANALYSIS
*/

clear
use "drugs"
sort caseid visit 

**AGE: a_it
gen A_it=age
gen A_it2=A_it^2

gen A_it1=age+0.5
gen A_it12=A_it1*A_it1

drop age borny

**INSURANCE: N_it
gen N_it=0
replace N_it=1 if ///
hmoc==1 | gpic==1 | ipic==1 | other==1  
replace N_it=2 if ///
mcaid==1 | mcare==1 | vaben==1 | champ==1 & hmoc==0 & gpic==0 & ipic==0 & other==0 
replace N_it=. if N_it==0 & (hmoc==. | gpic==. | ipic==. | mcaid==. | mcare==. | vaben==. | other==.)

gen N_it1=N_it[_n+1] if caseid[_n+1]==caseid & visit[_n+1]-visit==10

drop hmoc gpic ipic mcaid mcare vaben champ other


**EMPLOYMENT CHOICE: d_it_l
gen d_it_l=.
replace d_it_l=0 if ftime==1
replace d_it_l=1 if ftime==2

gen d_it1_l=d_it_l[_n+1] if caseid[_n+1]==caseid & visit[_n+1]-visit==10

**CD4: H_it
gen H_it=.
replace H_it=1 if cd4>=250 & cd4!=.
replace H_it=0 if cd4<250

gen H_it1=H_it[_n+1] if caseid[_n+1]==caseid & visit[_n+1]-visit==10
gen cd41=cd4[_n+1] if caseid[_n+1]==caseid & visit[_n+1]-visit==10

**SFX: F_it
gen F_it=(1-sfx)

gen F_it1=F_it[_n+1] if caseid[_n+1]==caseid & visit[_n+1]-visit==10

gen fatig1=fatig[_n+1] if caseid[_n+1]==caseid & visit[_n+1]-visit==10
gen diarr1=diarr[_n+1] if caseid[_n+1]==caseid & visit[_n+1]-visit==10
gen heada1=heada[_n+1] if caseid[_n+1]==caseid & visit[_n+1]-visit==10
gen fever1=fever[_n+1] if caseid[_n+1]==caseid & visit[_n+1]-visit==10
gen sweat1=sweat[_n+1] if caseid[_n+1]==caseid & visit[_n+1]-visit==10

drop sfx

**INCOME
gen I_it=incom
replace I_it=I_it[_n+1] if I_it==. & caseid==caseid[_n+1] & visit[_n+1]-visit==10 
replace I_it=I_it[_n-1] if I_it==. & caseid==caseid[_n-1] & visit-visit[_n-1]==10 

gen I_it1=I_it[_n+1] if caseid[_n+1]==caseid & visit[_n+1]-visit==10

drop incom

**DEATH
gen B_it1=0
replace B_it1=1 if visit==maxvisit & dyear!=.

drop dyear dvisit

**PAYMENT
gen p_it=dpay
gen p_it1=dpay[_n+1] if caseid[_n+1]==caseid & visit[_n+1]-visit==10

drop dpay


** EXPERIENCE

gen E_it=.
replace E_it=10 if expF<=15
replace E_it=20 if expF>15 & expF<=25
replace E_it=30 if expF>25 & expF<=35
replace E_it=40 if expF>35 & expF<=45
replace E_it=50 if expF>45 & expF!=.
gen E_it2=E_it*E_it

rename expF AE_it
gen AE_it2=AE_it*AE_it

** EVER HAART & EVER MEDS
rename emeds EM_it
rename emeds3 EH_it
replace EM_it=1 if EH_it==1

gen EM_it1=EM_it[_n+1] if caseid[_n+1]==caseid & visit[_n+1]-visit==10
gen EH_it1=EH_it[_n+1] if caseid[_n+1]==caseid & visit[_n+1]-visit==10


**HOPE DEPRESS CESD
replace hope=0 if hope==1 | hope==2 | hope==3
replace hope=1 if hope==4

rename ocpay p_out 
rename pcost p_pre 
rename hopay p_hos
rename nseek nsmed_fin
rename nmoth nsmed_nfi



keep ///
d_it_m d_it1_m   /// 
EM_it EH_it EM_it1 EH_it1 ///
d_it_l d_it1_l ///
H_it H_it1 F_it F_it1 B_it1 ///
A_it A_it2 A_it1 A_it12 ///
I_it I_it1 N_it N_it1 ///
p_it p_it1 ///
caseid visit meds ///
cd4 cd41 bage ///
fatig diarr heada fever sweat ///
fatig1 diarr1 heada1 fever1 sweat1 ///
E_it E_it2 AE_it AE_it2 ptime ftime emdis occup meanB1_neg ///
p_out p_pre p_hos ///
cesd hope depress

gen cd42=cd4*cd4
gen cd412=cd41*cd41


save "drugs", replace
clear

*********
*STEP 7:* 
*********
/*
-DROP VARS
*/
clear
use "drugs"

*Relevant Full Sample
preserve
tab H_it
tab visit

drop if visit==410
drop if visit<150
count
sort caseid
count if caseid!=caseid[_n+1]
restore

*Relevant Full Sample


drop if d_it_m==.
drop if d_it1_m==. 	& B_it1!=1 

*drop if d_it_m==4
*drop if d_it1_m==4

replace d_it_m=0 if d_it_m==4
replace d_it1_m=0 if d_it1_m==4

drop if d_it_l==.   
drop if d_it1_l==. 	& B_it1!=1   
drop if H_it==.  
drop if H_it1==.  	& B_it1!=1 
drop if F_it==.  
drop if E_it==.
drop if N_it==.
drop if F_it1==. 	& B_it1!=1  
drop if B_it1==.  
drop if A_it==. | A_it2==. | A_it1==. | A_it12==.  & B_it1!=1
drop if I_it==. 
drop if I_it1==.   	& B_it1!=1
drop if p_it==.
drop if A_it>=65
drop if visit<150
drop if visit==410

drop meds
drop if d_it1_m==3 & visit<240
drop if d_it_m==3 & visit<230

drop if A_it<30
drop if p_it1>2500 & p_it1!=.

rename visit v_it 
replace v_it=v_it/10
gen v_it1=v_it+1

sum
xi i.v_it

forvalues i=16(1)40{
rename _Iv_it_`i' vv`i'
}
*
gen d_h=(v_it>=24)
gen ts0=v_it-0
gen ts1=v_it-6
gen ts2=v_it-14
gen ts3=v_it-24

replace ts3=0 if ts3<0
save drugs, replace


*********
*STEP 9:* 
*********
/*
-MAKE INCOME "CONTINUOUS"
-GROSS TO NET INCOME
-DEFLATE INCOME TO 2002 DOLLARS
-DEFLATE OOC TO 2002 DOLLARS
*/

clear
use "drugs"
sort caseid v_it
save "drugs", replace

gen year=(((v_it-1)/2)+1984)
gen IN_it=((I_it*10000)-5000)/2
gen IN_it1=((I_it1*10000)-5000)/2

keep caseid v_it IN_it IN_it1 year
gen mstat=1
rename year year_ACTUAL
gen year=year_ACTUAL
replace year=year-0.5
forvalues i=1990.5(1)2003.5{
replace year=year-0.5 if year==`i'
}
gen IN_it_TAX=IN_it
replace IN_it_TAX=2*IN_it_TAX
rename IN_it_TAX pwages
taxsim9, replace
replace fiitax=0 if fiitax<0
gen IN_it_TAX=pwages-fiitax
replace IN_it_TAX=IN_it_TAX/2
keep caseid v_it mstat year_ACTUAL IN_it IN_it1 IN_it_TAX

gen year=year_ACTUAL
forvalues i=1990.5(1)2003.5{
replace year=year-0.5 if year==`i'
}
gen IN_it1_TAX=IN_it1
replace IN_it1_TAX=2*IN_it1_TAX
rename IN_it1_TAX pwages
replace pwages=0 if pwages==.
taxsim9, replace
replace fiitax=0 if fiitax<0
gen IN_it1_TAX=pwages-fiitax
replace IN_it1_TAX=IN_it1_TAX/2
replace IN_it1_TAX=. if pwages==0

keep caseid v_it IN_it IN_it1 IN_it_TAX IN_it1_TAX
sort caseid v_it
save "drugs_income", replace

clear
use "drugs"
merge caseid v_it using "drugs_income"
drop _merge
drop IN_it IN_it1
rename IN_it_TAX IN_it
rename IN_it1_TAX IN_it1

*Deflate
replace IN_it=1.34*IN_it if v_it==15 //1991
replace IN_it=1.34*IN_it if v_it==16 //1991
replace IN_it=1.30*IN_it if v_it==17 //1992
replace IN_it=1.30*IN_it if v_it==18 //1992
replace IN_it=1.26*IN_it if v_it==19 //1993
replace IN_it=1.26*IN_it if v_it==20 //1993
replace IN_it=1.23*IN_it if v_it==21 //1994
replace IN_it=1.23*IN_it if v_it==22 //1994
replace IN_it=1.20*IN_it if v_it==23 //1995
replace IN_it=1.20*IN_it if v_it==24 //1995
replace IN_it=1.16*IN_it if v_it==25 //1996
replace IN_it=1.16*IN_it if v_it==26 //1996
replace IN_it=1.14*IN_it if v_it==27 //1997
replace IN_it=1.14*IN_it if v_it==28 //1997
replace IN_it=1.13*IN_it if v_it==29 //1998
replace IN_it=1.13*IN_it if v_it==30 //1998
replace IN_it=1.10*IN_it if v_it==31 //1999
replace IN_it=1.10*IN_it if v_it==32 //1999
replace IN_it=1.06*IN_it if v_it==33 //2000
replace IN_it=1.06*IN_it if v_it==34 //2000
replace IN_it=1.04*IN_it if v_it==35 //2001
replace IN_it=1.04*IN_it if v_it==36 //2001
replace IN_it=1.02*IN_it if v_it==37 //2002
replace IN_it=1.02*IN_it if v_it==38 //2002
replace IN_it=1.00*IN_it if v_it==39 //2003
replace IN_it=1.00*IN_it if v_it==40 //2003

replace IN_it1=1.34*IN_it1 if v_it==15 //1991
replace IN_it1=1.34*IN_it1 if v_it==16 //1991
replace IN_it1=1.30*IN_it1 if v_it==17 //1992
replace IN_it1=1.30*IN_it1 if v_it==18 //1992
replace IN_it1=1.26*IN_it1 if v_it==19 //1993
replace IN_it1=1.26*IN_it1 if v_it==20 //1993
replace IN_it1=1.23*IN_it1 if v_it==21 //1994
replace IN_it1=1.23*IN_it1 if v_it==22 //1994
replace IN_it1=1.20*IN_it1 if v_it==23 //1995
replace IN_it1=1.20*IN_it1 if v_it==24 //1995
replace IN_it1=1.16*IN_it1 if v_it==25 //1996
replace IN_it1=1.16*IN_it1 if v_it==26 //1996
replace IN_it1=1.14*IN_it1 if v_it==27 //1997
replace IN_it1=1.14*IN_it1 if v_it==28 //1997
replace IN_it1=1.13*IN_it1 if v_it==29 //1998
replace IN_it1=1.13*IN_it1 if v_it==30 //1998
replace IN_it1=1.10*IN_it1 if v_it==31 //1999
replace IN_it1=1.10*IN_it1 if v_it==32 //1999
replace IN_it1=1.06*IN_it1 if v_it==33 //2000
replace IN_it1=1.06*IN_it1 if v_it==34 //2000
replace IN_it1=1.04*IN_it1 if v_it==35 //2001
replace IN_it1=1.04*IN_it1 if v_it==36 //2001
replace IN_it1=1.02*IN_it1 if v_it==37 //2002
replace IN_it1=1.02*IN_it1 if v_it==38 //2002
replace IN_it1=1.00*IN_it1 if v_it==39 //2003
replace IN_it1=1.00*IN_it1 if v_it==40 //2003

replace p_it=1.34*p_it if v_it==15 //1991
replace p_it=1.34*p_it if v_it==16 //1991
replace p_it=1.30*p_it if v_it==17 //1992
replace p_it=1.30*p_it if v_it==18 //1992
replace p_it=1.26*p_it if v_it==19 //1993
replace p_it=1.26*p_it if v_it==20 //1993
replace p_it=1.23*p_it if v_it==21 //1994
replace p_it=1.23*p_it if v_it==22 //1994
replace p_it=1.20*p_it if v_it==23 //1995
replace p_it=1.20*p_it if v_it==24 //1995
replace p_it=1.16*p_it if v_it==25 //1996
replace p_it=1.16*p_it if v_it==26 //1996
replace p_it=1.14*p_it if v_it==27 //1997
replace p_it=1.14*p_it if v_it==28 //1997
replace p_it=1.13*p_it if v_it==29 //1998
replace p_it=1.13*p_it if v_it==30 //1998
replace p_it=1.10*p_it if v_it==31 //1999
replace p_it=1.10*p_it if v_it==32 //1999
replace p_it=1.06*p_it if v_it==33 //2000
replace p_it=1.06*p_it if v_it==34 //2000
replace p_it=1.04*p_it if v_it==35 //2001
replace p_it=1.04*p_it if v_it==36 //2001
replace p_it=1.02*p_it if v_it==37 //2002
replace p_it=1.02*p_it if v_it==38 //2002
replace p_it=1.00*p_it if v_it==39 //2003
replace p_it=1.00*p_it if v_it==40 //2003

replace p_it1=1.34*p_it1 if v_it==15 //1991
replace p_it1=1.34*p_it1 if v_it==16 //1991
replace p_it1=1.30*p_it1 if v_it==17 //1992
replace p_it1=1.30*p_it1 if v_it==18 //1992
replace p_it1=1.26*p_it1 if v_it==19 //1993
replace p_it1=1.26*p_it1 if v_it==20 //1993
replace p_it1=1.23*p_it1 if v_it==21 //1994
replace p_it1=1.23*p_it1 if v_it==22 //1994
replace p_it1=1.20*p_it1 if v_it==23 //1995
replace p_it1=1.20*p_it1 if v_it==24 //1995
replace p_it1=1.16*p_it1 if v_it==25 //1996
replace p_it1=1.16*p_it1 if v_it==26 //1996
replace p_it1=1.14*p_it1 if v_it==27 //1997
replace p_it1=1.14*p_it1 if v_it==28 //1997
replace p_it1=1.13*p_it1 if v_it==29 //1998
replace p_it1=1.13*p_it1 if v_it==30 //1998
replace p_it1=1.10*p_it1 if v_it==31 //1999
replace p_it1=1.10*p_it1 if v_it==32 //1999
replace p_it1=1.06*p_it1 if v_it==33 //2000
replace p_it1=1.06*p_it1 if v_it==34 //2000
replace p_it1=1.04*p_it1 if v_it==35 //2001
replace p_it1=1.04*p_it1 if v_it==36 //2001
replace p_it1=1.02*p_it1 if v_it==37 //2002
replace p_it1=1.02*p_it1 if v_it==38 //2002
replace p_it1=1.00*p_it1 if v_it==39 //2003
replace p_it1=1.00*p_it1 if v_it==40 //2003
 
save "drugs", replace

**********
*STEP 10:* 
**********
/*
-CREATE INTERACTIONS
-NAME VARS
*/
clear 
use "drugs"

*Generate Dummies

gen d_m0_0=(d_it_m==0)
gen d_m1_0=(d_it_m==1)
gen d_m2_0=(d_it_m==2)
gen d_m3_0=(d_it_m==3)

gen d_m0_1=(d_it1_m==0) if B_it1==0
gen d_m1_1=(d_it1_m==1) if B_it1==0
gen d_m2_1=(d_it1_m==2) if B_it1==0
gen d_m3_1=(d_it1_m==3) if B_it1==0

gen d_l0_0=(d_it_l==0)
gen d_l1_0=(d_it_l==1)
gen d_l0_1=(d_it1_l==0) if B_it1==0
gen d_l1_1=(d_it1_l==1) if B_it1==0

gen N_0_1=N_it1==0
gen N_1_1=N_it1==1
gen N_2_1=N_it1==2

gen N_0_0=N_it==0
gen N_1_0=N_it==1
gen N_2_0=N_it==2


*Generate Interactions

gen AH=A_it*H_it
gen F0H1=(F_it==0 & H_it==1)
gen F0H0=(F_it==0 & H_it==0)

gen H00_m01=(1-H_it)*d_m0_1 if B_it1==0
gen H00_m11=(1-H_it)*d_m1_1 if B_it1==0
gen H00_m21=(1-H_it)*d_m2_1 if B_it1==0
gen H00_m31=(1-H_it)*d_m3_1 if B_it1==0

gen H10_m01=(H_it)*d_m0_1 if B_it1==0
gen H10_m11=(H_it)*d_m1_1 if B_it1==0
gen H10_m21=(H_it)*d_m2_1 if B_it1==0
gen H10_m31=(H_it)*d_m3_1 if B_it1==0

gen H01_m01=(1-H_it1)*d_m0_1 if B_it1==0
gen H01_m11=(1-H_it1)*d_m1_1 if B_it1==0
gen H01_m21=(1-H_it1)*d_m2_1 if B_it1==0
gen H01_m31=(1-H_it1)*d_m3_1 if B_it1==0

gen H11_m01=(H_it1)*d_m0_1 if B_it1==0
gen H11_m11=(H_it1)*d_m1_1 if B_it1==0
gen H11_m21=(H_it1)*d_m2_1 if B_it1==0
gen H11_m31=(H_it1)*d_m3_1 if B_it1==0

gen H00_l11=(1-H_it)*d_l1_1 	if B_it1==0
gen H01_l11=(H_it)*d_l1_1 		if B_it1==0
gen H10_l11=(1-H_it1)*d_l1_1 	if B_it1==0
gen H11_l11=(H_it1)*d_l1_1 		if B_it1==0

gen ts0_m0=ts0*d_m0_1
gen ts1_m1=ts1*d_m1_1
gen ts2_m2=ts2*d_m2_1
gen ts3_m3=ts3*d_m3_1

gen ts0_m0H0=ts0*d_m0_1*(1-H_it)
gen ts1_m1H0=ts1*d_m1_1*(1-H_it)
gen ts2_m2H0=ts2*d_m2_1*(1-H_it)
gen ts3_m3H0=ts3*d_m3_1*(1-H_it)
gen ts0_m0H1=ts0*d_m0_1*(H_it)
gen ts1_m1H1=ts1*d_m1_1*(H_it)
gen ts2_m2H1=ts2*d_m2_1*(H_it)
gen ts3_m3H1=ts3*d_m3_1*(H_it)

gen dm1_1_N1=d_m1_1*N_1_1
gen dm1_1_N2=d_m1_1*N_2_1
gen dm2_1_N1=d_m2_1*N_1_1
gen dm2_1_N2=d_m2_1*N_2_1
gen dm3_1_N1=d_m3_1*N_1_1
gen dm3_1_N2=d_m3_1*N_2_1

gen dm1_0_N1=d_m1_0*N_1_0
gen dm1_0_N2=d_m1_0*N_2_0
gen dm2_0_N1=d_m2_0*N_1_0
gen dm2_0_N2=d_m2_0*N_2_0
gen dm3_0_N1=d_m3_0*N_1_0
gen dm3_0_N2=d_m3_0*N_2_0


gen AE_it_w		=AE_it*d_l1_1
gen AE_it2_w	=AE_it2*d_l1_1
gen E_it_w		=E_it*d_l1_1
gen E_it2_w		=E_it2*d_l1_1
gen ts2_w		=ts2*d_l1_1 
gen A_it_w 		=A_it*d_l1_1
gen A_it2_w		=A_it2*d_l1_1
gen H_it_w		=H_it*d_l1_1
gen F_it_w		=F_it*d_l1_1
gen F0H1_w		=F0H1*d_l1_1
gen F0H0_w		=F0H0*d_l1_1

*Label Variables:
sum

lab var d_it_m	"Treatment Choice"
label define ditm 0 "None" 1 "Mono" 2 "Combo" 3 "HAART"
label values d_it_m ditm	
lab var d_it1_m	"Treatment Choice t+1"
label define dit1m 0 "None" 1 "Mono" 2 "Combo" 3 "HAART"
label values d_it1_m dit1m	
lab var d_it_l	"Employment Choice"
label define ditl 0  "Not full time" 1 "Full Time"
label values d_it_l ditl	
lab var d_it1_l	"Employment Choice t+1"
label define dit1l 0 "Not full time" 1 "Full Time"
label values d_it1_l dit1l

lab var N_it	"Insurance"
label define nit  0 "None" 1 "Private" 2 "Public"
label values N_it nit	
lab var N_it1	"Insurance (t+1)"
label define nit1 0 "None" 1 "Private" 2 "Public"
label values N_it1 nit1	



lab var caseid 	"Identifier"
lab var v_it 	"Study visit"
lab var v_it1	"Next visit"
lab var bage	"Age at Baseline"
lab var A_it 	"Age"
lab var A_it2 	"Age$^2$"
lab var d_it_l	"Labor Choice"
lab var d_it1_l	"Labor Choice (t+1)"
lab var H_it	"High CD4"
lab var H_it1	"High CD4 (t+1)"

lab var F0H1	"Side-Effects (no AIDS)"
lab var F0H0	"Symptoms (AIDS)"

lab var EM_it	"Ever Used Meds"
lab var EH_it	"Ever Used HAART"
lab var EM_it1	"Ever Used Meds (t+1)"
lab var EH_it1	"Ever Used HAART (t+1)"

lab var cd4 	"CD4 count"
lab var cd41	"CD4 count (t+1)"
lab var cd42	"CD4-squared"
lab var cd412	"CD4-squared (t+1)"


lab var F_it	"No Symptoms"
lab var F_it1	"No Symptoms (t+1)"
lab var I_it	"Income/10000"
lab var I_it1	"Income/10000 (t+1)"
lab var IN_it	"Income"
lab var IN_it1	"Income (t+1)"

lab var B_it1	"Death Probability"
lab var p_it1	"Out-of-Pocket Cost"

lab var ts0		"Time trend"
lab var ts1		"Time since mono"
lab var ts2		"Time since combo"
lab var ts3		"Time since HAART"

lab var d_m0_0	"Treatment: None (t)"
lab var d_m1_0	"Treatment: Mono (t)"
lab var d_m2_0	"Treatment: Combo (t)"
lab var d_m3_0	"Treatment: HAART (t)"

lab var d_m0_1	"Treatment: None (t+1)"
lab var d_m1_1	"Treatment: Mono (t+1)"
lab var d_m2_1	"Treatment: Combo (t+1)"
lab var d_m3_1	"Treatment: HAART (t+1)"

lab var d_l0_0	"Not full time (t)"
lab var d_l1_0	"Full time (t)"
lab var d_l0_1	"Not full time (t+1)"
lab var d_l1_1	"Full time (t+1)"
lab var d_it1_l "Full time (t+1)"
lab var d_it_l  "Full time (t)"

lab var N_0_1	"No Insurance (t+1)" 
lab var N_1_1 	"Private Insurance (t+1)"
lab var N_2_1 	"Public Insurance (t+1)"

lab var N_0_0	"No Insurance" 
lab var N_1_0 	"Private Insurance"
lab var N_2_0 	"Public Insurance"

lab var d_h		"HAART Available"
lab var E_it	"Experience"
lab var E_it2	"Exper. Squared"
lab var AE_it	"Experience"
lab var AE_it2	"Exper. Squared"
lab var AE_it_w	 	"Full time (t+1) $\times$ Exper."
lab var AE_it2_w	"Full time (t+1) $\times$ Exper. Squared"


*Label Interactions

lab var H00_m01	"Low CD4 (t) $\times$ none"
lab var H00_m11	"Low CD4 (t) $\times$ mono"
lab var H00_m21	"Low CD4 (t) $\times$ combo"
lab var H00_m31	"Low CD4 (t) $\times$ HAART"

lab var H10_m01	"High CD4 (t) $\times$ none"
lab var H10_m11	"High CD4 (t) $\times$ mono"
lab var H10_m21	"High CD4 (t) $\times$ combo"
lab var H10_m31	"High CD4 (t) $\times$ HAART"

lab var H01_m01	"Low CD4 (t+1) $\times$ none"
lab var H01_m11	"Low CD4 (t+1) $\times$ mono"
lab var H01_m21	"Low CD4 (t+1) $\times$ combo"
lab var H01_m31	"Low CD4 (t+1) $\times$ HAART"

lab var H11_m01	"High CD4 (t+1) $\times$ none"
lab var H11_m11	"High CD4 (t+1) $\times$ mono"
lab var H11_m21	"High CD4 (t+1) $\times$ combo"
lab var H11_m31	"High CD4 (t+1) $\times$ HAART"

lab var H00_l11	"Low CD4 (t) $\times$ Full Time"
lab var H10_l11	"High CD4 (t) $\times$ Full Time"
lab var H01_l11	"Low CD4 (t+1) $\times$ Full Time"
lab var H11_l11	"High CD4 (t+1) $\times$ Full Time"

lab var dm1_1_N1	"Private $\times$ Mono (t+1)" 
lab var dm1_1_N2  	"Public $\times$ Mono (t+1)" 
lab var dm2_1_N1  	"Private $\times$ Combo (t+1)"
lab var dm2_1_N2  	"Public $\times$ Combo (t+1)"  
lab var dm3_1_N1  	"Private $\times$ HAART (t+1)" 
lab var dm3_1_N2  	"Public $\times$ HAART (t+1)"

lab var dm1_0_N1	"Private $\times$ Mono" 
lab var dm1_0_N2  	"Public $\times$ Mono" 
lab var dm2_0_N1  	"Private $\times$ Combo"
lab var dm2_0_N2  	"Public $\times$ Combo"  
lab var dm3_0_N1  	"Private $\times$ HAART" 
lab var dm3_0_N2  	"Public $\times$ HAART"


lab var ts0_m0	"Time trend $\times$ No Treat."
lab var ts1_m1	"Time trend $\times$ mono"
lab var ts2_m2	"Time trend $\times$ combo"
lab var ts3_m3	"Time trend $\times$ HAART"
lab var ts0_m0H0	"Time trend $\times$ No Treat. $\times$ Low CD4"
lab var ts1_m1H0	"Time trend $\times$ mono $\times$ Low CD4"
lab var ts2_m2H0	"Time trend $\times$ combo $\times$ Low CD4"
lab var ts3_m3H0	"Time trend $\times$ HAART $\times$ Low CD4"
lab var ts0_m0H1	"Time trend $\times$ No Treat. $\times$ High CD4"
lab var ts1_m1H1	"Time trend $\times$ mono $\times$ High CD4"
lab var ts2_m2H1	"Time trend $\times$ combo $\times$ High CD4"
lab var ts3_m3H1	"Time trend $\times$ HAART $\times$ High CD4"

lab var E_it_w		"Full time (t+1) $\times$ Exper."	
lab var E_it2_w		"Full time (t+1) $\times$ Exper. squared"
lab var ts2_w		"Full time (t+1) $\times$ Time trend" 	
lab var A_it_w 		"Full time (t+1) $\times$ Age"
lab var A_it2_w		"Full time (t+1) $\times$ Age squared"
lab var H_it_w		"Full time (t+1) $\times$ High CD4"
lab var F_it_w		"Full time (t+1) $\times$ No Sympoms"
lab var F0H1_w			"Full time (t+1) $\times$ Side Effects (No AIDS)"	 
lab var F0H0_w		   	"Full time (t+1) $\times$ Symptoms (AIDS)"

lab var AH			"Age $\times$ High CD4"

lab var p_out 		"Costs: out-patient care"
lab var p_pre 		"Costs: insurance premiums"
lab var p_hos 		"Costs: hospitalization"
lab var cesd		"CESD scale score"
lab var depress		"Depressed"
lab var hope 		"Hopeful"

lab var fatig 		"Fatigue"
lab var fatig1 		"Fatigue (t+1)"
lab var diarr 		"Diarrhea"
lab var diarr1 		"Diarrhea (t+1)"
lab var heada 		"Headaches"
lab var heada1 		"Headaches (t+1)"
lab var sweat 		"Night Sweats"
lab var sweat1 		"Night Sweats (t+1)"
lab var fever 		"Fever"
lab var fever1 		"Fever (t+1)"

save drugs, replace   
clear

**********
*STEP 11:* 
**********
/*
-TRY MODELS, Dstats and PIX
-Note: this work is done on my MAC; this is for practicing
*/

clear
use "drugs"

*TP's & Outcomes - Before creating TP matrices
*1	Death
logit B_it1 H_it AH A_it 

*2	Health
gen DH_it=.
replace DH_it=1 if cd41>=cd4
replace DH_it=0 if cd41<cd4
gen H1_1=H_it*d_h

logit DH_it H_it H00_m11 H00_m21 H00_m31 H10_m11 H10_m21 H10_m31 ts0

qui predict DH
qui gen DH0=DH*(1-H_it)
qui gen DH1=DH*(H_it)

logit H_it1 H_it DH0 DH1

*3	No Symptoms, SFX
logit F_it1 H_it H00_m11 H00_m21 H00_m31 H10_m11 H10_m21 H10_m31 ts0 

*4	Cost
tobit p_it H_it F0H1 F0H0 I_it d_m1_0 d_m2_0 d_m3_0 ///
N_1_0 N_2_0 dm1_0_N1 dm2_0_N1 dm3_0_N1 dm1_0_N2 dm2_0_N2 dm3_0_N2 ts0 if B_it1!=1, ll(0) 

*5	Income
tobit IN_it1  H_it AE_it AE_it2 A_it ts2 d_l1_1 H_it_w AE_it_w AE_it2_w A_it_w ts2_w, ll(2500)

*6	Insurance
mlogit N_it1 d_l1_1 H_it E_it E_it2 A_it A_it2 ts0 ts3, baseoutcome(0) 



**********
*STEP 12:* 
**********
/*
-Subject Identifiers
-TOBIT starting values
-EXPORT TO STATA
-DO NOT save - want Death Prob
*/

clear
use "drugs"

**** 
**********
**************
***  EXPORT  *** 
**************
**********
****

* * * * * * * 
* WITH DEATH *
* * * * * * * 
preserve
sort caseid

summarize caseid
scalar minimum=r(min)
replace caseid=caseid-minimum+1

sort caseid
gen ind=.
by caseid: replace ind=1 if _n==1
replace ind=0 if ind==.
gen ind2=sum(ind)

drop ind
rename ind2 ind

sort ind
by ind: gen T_i=_N

gen obs=_n
by ind:egen start_i=min(obs)
by ind:egen end_i=max(obs)

*Label Identifiers

lab var ind 	"Subject Identifier"
lab var obs 	"Observation Number"
lab var T_i		"Number Obs for i"
lab var start 	"Start of i"
lab var end		"end of i"


keep caseid H_it AH A_it B_it1 ind obs T_i start end
outsheet ///
H_it AH A_it B_it1 ind obs T_i start end ///
using "../../MATLAB/Z_DATASETS/drugs_death.csv", noname nolabel comma replace

gen dead1=0
replace dead1=1 if caseid!=caseid[_n-1] & B_it1==1
save drugs_death, replace
bysort caseid: keep if _n==1
save drugs_death1, replace
outsheet ///
dead1 ///
using "../../MATLAB/Z_DATASETS/drugs_death1.csv", noname nolabel comma replace
restore

* * * * * * * * * * * *
* WITH DEATH FOR SIMS *
* * * * * * * * * * * *
preserve
sort v_it
keep if v_it==15
replace d_it_m=0
keep v_it E_it d_it_m H_it A_it
save drugs_sim15, replace  	  
outsheet /// 
v_it E_it d_it_m H_it A_it ///
using "../../MATLAB/Z_DATASETS/drugs_sim15.csv", noname nolabel comma replace
restore

preserve
sort v_it
keep if v_it==24
replace d_it_m=0
keep v_it E_it d_it_m H_it A_it
save drugs_sim24, replace  	  
outsheet /// 
v_it E_it d_it_m H_it A_it ///
using "../../MATLAB/Z_DATASETS/drugs_sim24.csv", noname nolabel comma replace
restore

clear 
use drugs


*1	Death
logit B_it1 H_it AH A_it 
matrix beta_B=e(b)'
svmat beta_B
replace beta_B=-999 if beta_B==.

drop if B_it1==1

sort caseid

summarize caseid
scalar minimum=r(min)
gen cid=caseid-minimum+1

sort cid
gen ind=.
by cid: replace ind=1 if _n==1
replace ind=0 if ind==.
gen ind2=sum(ind)

drop ind
rename ind2 ind

sort ind
by ind: gen T_i=_N

gen obs=_n
by ind:egen start_i=min(obs)
by ind:egen end_i=max(obs)

*Label Identifiers

lab var ind 	"Subject Identifier"
lab var obs 	"Observation Number"
lab var T_i		"Number Obs for i"
lab var start 	"Start of i"
lab var end		"end of i"
drop cid

* * * * * * * * *
* FOR POSTERIOR *
* * * * * * * * *
preserve
drop if B_it1==1
sort ind v_it
keep caseid v_it ind obs A_it
save drugs_posterior, replace  	  
restore




**** 
**********
**************
***  EXPORT  *** 
**************
**********
****





* * * * * * * * * *
* Treatment Price *
* STARTING VALS   *
* * * * * * * * * *

*2	Health
gen DH_it=.
replace DH_it=1 if cd41>=cd4
replace DH_it=0 if cd41<cd4
gen H1_1=H_it*d_h

logit DH_it H_it H00_m11 H00_m21 H00_m31 H10_m11 H10_m21 H10_m31 ts0

matrix beta_D=e(b)'
svmat beta_D
replace beta_D=-999 if beta_D==.

qui predict DH
qui gen DH0=DH*(1-H_it)
qui gen DH1=DH*(H_it)

logit H_it1 H_it DH0 DH1
matrix beta_H=e(b)'
svmat beta_H
replace beta_H=-999 if beta_H==.

*3	No Symptoms, SFX
logit F_it1 H_it H00_m11 H00_m21 H00_m31 H10_m11 H10_m21 H10_m31 ts0  
matrix beta_F=e(b)'
svmat beta_F
replace beta_F=-999 if beta_F==.

*4	Cost
gen pd=1
replace pd=0 if p_it==0

tobit p_it H_it F0H1 F0H0 I_it d_m1_0 d_m2_0 d_m3_0 ///
N_1_0 N_2_0 dm1_0_N1 dm1_0_N2 dm2_0_N1 dm2_0_N2 dm3_0_N1 dm3_0_N2 ts0 , ll(0) 
matrix beta_p=e(b)'
svmat beta_p
replace beta_p=-999 if beta_p==.

*5	Income
gen INCd=1
replace INCd=0 if IN_it1==2500
tobit IN_it1  H_it AE_it AE_it2 A_it ts2 d_l1_1 H_it_w AE_it_w AE_it2_w A_it_w ts2_w, ll(2500)
matrix beta_I=e(b)'
svmat beta_I
replace beta_I=-999 if beta_I==.

*6	Insurance
mlogit N_it1 d_l1_1 H_it E_it E_it2 A_it A_it2 ts0 ts3, baseoutcome(0) 
matrix beta_N=e(b)'
svmat beta_N
replace beta_N=-999 if beta_N==.


replace N_it1=-999 if N_it1==.


keep /// 
obs ind T_i start_i end_i ///
v_it H_it F_it E_it A_it I_it ///
v_it1 H_it1 F_it1 A_it1 I_it1 /// 
N_it N_1_0 N_2_0 N_it1 ///
d_it1_l d_l0_1 d_l1_1  ///
d_it1_m d_m0_1 d_m1_1 d_m2_1 d_m3_1 /// 
d_it_m  d_m0_0 d_m1_0 d_m2_0 d_m3_0 /// 
p_it pd INCd d_h AE_it IN_it1 DH_it /// 
beta_B beta_p beta_D beta_H beta_F beta_I beta_N

save "drugs_MATLAB", replace

outsheet /// 
obs ind T_i start_i end_i ///
v_it H_it F_it E_it A_it I_it ///
v_it1 H_it1 F_it1 A_it1 I_it1 /// 
N_it N_1_0 N_2_0 N_it1 ///
d_it1_l d_l0_1 d_l1_1  ///
d_it1_m d_m0_1 d_m1_1 d_m2_1 d_m3_1 /// 
d_it_m  d_m0_0 d_m1_0 d_m2_0 d_m3_0 /// 
p_it pd INCd d_h AE_it IN_it1 DH_it /// 
beta_p beta_D beta_H beta_F beta_B beta_I beta_N ///
using "../../MATLAB/Z_DATASETS/drugs.csv", noname nolabel comma replace





**************************
**************************
*Transition Probabilities*
*and					 *
*Starting Values		 *
**************************
**************************

**********
*STEP 14:* 
**********
/*
TRANSITIONS for SM9
*/

set more off
clear 
insheet v_it E_it d_it_m d_it1_l d_it1_m H_it using /// 
"../EXCEL/VMI_BLANK.csv", comma case

sort H_it v_it E_it d_it_m d_it1_m d_it1_l
count
*7060



gen ts0=v_it-0
gen ts1=v_it-6
gen ts2=v_it-14
gen ts3=v_it-24

replace ts3=0 if ts3<0
save "TP_blank.dta", replace
clear

forvalues a=300(5)650{

qui use "TP_blank.dta", replace

qui gen A_it=`a'/10
qui gen A_it2=A_it^2
gen AH=A_it*H_it
qui gen d_h=(v_it>=24)
qui gen E_it2=E_it*E_it

qui gen d_l0_1=(d_it1_l==0)
qui gen d_l1_1=(d_it1_l==1)

qui gen d_m0_1=(d_it1_m==0)
qui gen d_m1_1=(d_it1_m==1)
qui gen d_m2_1=(d_it1_m==2)
qui gen d_m3_1=(d_it1_m==3)

qui gen d_m0_0=(d_it_m==0)
qui gen d_m1_0=(d_it_m==1)
qui gen d_m2_0=(d_it_m==2)
qui gen d_m3_0=(d_it_m==3)

gen ts1_m1=ts1*(d_it1_m==1)
gen ts2_m2=ts2*(d_it1_m==2)
gen ts3_m3=ts3*(d_it1_m==3)

gen E_it_w	=E_it*d_l1_1
gen E_it2_w	=E_it2*d_l1_1
gen ts2_w	=ts2*d_l1_1 
gen A_it_w 	=A_it*d_l1_1
gen A_it2_w	=A_it2*d_l1_1
gen H_it_w	=H_it*d_l1_1

gen H00_m01=(1-H_it)*d_m0_1
gen H00_m11=(1-H_it)*d_m1_1
gen H00_m21=(1-H_it)*d_m2_1
gen H00_m31=(1-H_it)*d_m3_1
gen H00_l11=(1-H_it)*d_l1_1

gen H10_m01=(H_it)*d_m0_1
gen H10_m11=(H_it)*d_m1_1
gen H10_m21=(H_it)*d_m2_1
gen H10_m31=(H_it)*d_m3_1
gen H10_l11=(H_it)*d_l1_1

qui save "TP_a`a'.dta", replace

clear
}
*

* * * * * 
* Death *
* * * * * 
clear
use "drugs"

logit B_it1 H_it AH A_it 

forvalues a=300(5)650{
qui use "TP_a`a'.dta"

qui predict P_B

qui save "TP_a`a'.dta", replace
qui clear
}
*



* * * * * * 
* Health *
* * * * * *
clear
use "drugs"

gen DH_it=.
replace DH_it=1 if cd41>=cd4
replace DH_it=0 if cd41<cd4
gen H1_1=H_it*d_h

logit DH_it H_it H00_m11 H00_m21 H00_m31 H10_m11 H10_m21 H10_m31 ts0

qui predict DH
qui gen DH0=DH*(1-H_it)
qui gen DH1=DH*(H_it)
save drugs, replace

forvalues a=300(5)650{
qui use "TP_a`a'.dta"

gen H1_1=H_it*(d_h)

qui predict DH
qui gen DH0=DH*(1-H_it)
qui gen DH1=DH*(H_it)

qui save "TP_a`a'.dta", replace
clear
}
*
use drugs

logit H_it1 H_it DH0 DH1

drop DH DH_it DH1 DH0
save drugs, replace

forvalues a=300(5)650{
qui use "TP_a`a'.dta"


qui predict P_H

qui save "TP_a`a'.dta", replace
clear
}
*






* * * * 
* SFX *
* * * *
clear
use "drugs"

logit F_it1 H_it H00_m11 H00_m21 H00_m31 H10_m11 H10_m21 H10_m31 ts0  

forvalues a=300(5)650{
qui use "TP_a`a'.dta"

qui predict P_F

qui save "TP_a`a'.dta", replace
qui clear
}
*




* * * * * *
* INCOME *
* * * * * *
clear
use "drugs"
tobit IN_it1  H_it AE_it AE_it2 A_it ts2 d_l1_1 H_it_w AE_it_w AE_it2_w A_it_w ts2_w, ll(2500)

forvalues a=300(5)645{
qui use "TP_a`a'.dta"

rename E_it AE_it
rename E_it2 AE_it2
rename E_it_w AE_it_w
rename E_it2_w AE_it2_w

qui predict E_I, ystar(2500,.) 

rename AE_it E_it
rename AE_it2 E_it2
rename AE_it_w E_it_w
rename AE_it2_w E_it2_w


qui save "TP_a`a'.dta", replace
qui clear
}
*


forvalues a=650(5)650{
qui use "TP_a`a'.dta"

rename E_it AE_it
rename E_it2 AE_it2
rename E_it_w AE_it_w
rename E_it2_w AE_it2_w

replace d_l1_1=0 
replace H_it_w=0 
replace AE_it_w=0 
replace AE_it2_w=0 
replace A_it_w=0 
replace ts2_w =0

qui predict E_I, ystar(2500,.)

rename AE_it E_it
rename AE_it2 E_it2
rename AE_it_w E_it_w
rename AE_it2_w E_it2_w 

qui save "TP_a`a'.dta", replace
qui clear
}
*


* * * * * * *
* INSURANCE *
* * * * * * *
clear
use "drugs"
mlogit N_it1 d_l1_1 H_it E_it E_it2 A_it A_it2 ts0 ts3, baseoutcome(0) 

forvalues a=300(5)650{
qui use "TP_a`a'.dta"

qui predict E_N0, outcome(0) 
qui predict E_N1, outcome(1) 
qui predict E_N2, outcome(2) 

qui save "TP_a`a'.dta", replace
qui clear
}
*


clear
forvalues a=300(5)650{
qui use "TP_a`a'.dta", replace

keep ///
v_it d_h ///
H_it E_it ///
d_l0_1 d_l1_1 ///
d_m0_0 d_m1_0 d_m2_0 d_m3_0 /// 
d_m0_1 d_m1_1 d_m2_1 d_m3_1 /// 
P_B P_H P_F ///
E_I  ///
E_N1 E_N2 ///

qui outsheet ///
v_it d_h ///
H_it E_it ///
d_l0_1 d_l1_1 ///
d_m0_0 d_m1_0 d_m2_0 d_m3_0 /// 
d_m0_1 d_m1_1 d_m2_1 d_m3_1 /// 
P_B P_H P_F ///
E_I  ///
E_N1 E_N2 ///
using "TP_a`a'.csv", nonames comma replace

qui outsheet ///
v_it d_h ///
H_it E_it ///
d_l0_1 d_l1_1 ///
d_m0_0 d_m1_0 d_m2_0 d_m3_0 /// 
d_m0_1 d_m1_1 d_m2_1 d_m3_1 /// 
P_B P_H P_F ///
E_I  ///
E_N1 E_N2 ///
using "../../MATLAB/Z_DATASETS/TP/a`a'.csv", nonames comma replace
qui clear
}
*




clear
forvalues a=305(5)640{
qui erase "TP_a`a'.dta"
qui erase "TP_a`a'.csv"
}
*

clear	
use "TP_a300.dta"
keep ///
v_it H_it E_it ///
d_it_m d_it1_l d_it1_m ///
P_B P_H P_F ///
E_I 

clear
use "TP_a650.dta"
keep ///
v_it H_it E_it ///
d_it_m d_it1_l d_it1_m ///
P_B P_H P_F ///
E_I 









