** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** 
** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** 
** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** 
** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** 
** ** ** **                                                          ** 
** ** ** **                                                          ** 
** ** ** **       V A L U E  O F  M E D I C A L  I N N O V A T I O N ** 
** ** ** **       V A L U E  O F  M E D I C A L  I N N O V A T I O N ** 
** ** ** **       V A L U E  O F  M E D I C A L  I N N O V A T I O N ** 
** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** 
** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** 

*2_Tables & FIGURES

/*
Reduced form work, including estimation,
figures, tables, transitions matrices.
*/

clear
clear matrix
set more off
set mem 1g

**** HERE, REPLACE cd COMMAND TO NAVIGATE TO FOLDER REPLICATION

cd "~/Dropbox/WORK/VMI/PAPER/REPLICATION/"

**** HERE, REPLACE cd COMMAND TO NAVIGATE TO FOLDER REPLICATION

set more off
use "STATA/DATASETS/drugs"
save "STATA/DATASETS/drugs", replace
set scheme s2mono

************
*1	Artwork*
************
preserve
sort v_it

gen year=(v_it-15)/2+1991

by v_it: egen meanB1=mean(B_it1)

gen NEMH_it=(EM_it1==0 & EH_it1==0)
gen EMNH_it=(EM_it1==1 & EH_it1==0)

drop if B_it1==1

by v_it: egen meanm0=mean(d_m0_1)
by v_it: egen meanm1=mean(d_m1_1)
by v_it: egen meanm2=mean(d_m2_1)
by v_it: egen meanm3=mean(d_m3_1)

by v_it: egen meanl0=mean(d_l0_1)
by v_it: egen meanl1=mean(d_l1_1)

by v_it: egen meanEM=mean(EM_it1)
by v_it: egen meanEH=mean(EH_it1)
by v_it: egen meanNEMH=mean(NEMH_it)
by v_it: egen meanEMNH=mean(EMNH_it)

by v_it: egen meanDEP=mean(depress)
by v_it: egen meanCESD=mean(cesd)
by v_it: egen meanHOPE =mean(hope)

*logitlogit d_l1_1 ts1 A_it A_it2   if v_it<=23
logit d_l1_1 ts0 A_it  if v_it<=24
predict dlhat1
by v_it: egen meanhatl1=mean(dlhat1)

reg hope cd4 cd42 A_it A_it2
predict hopeRES, residuals
by v_it: egen meanHOPERES =mean(hopeRES)

by v_it: keep if _n==1

gen totm=meanm0+meanm1+meanm2+meanm3
gen totl=meanl0+meanl1
sum totl
sum totm

tab v_it

*Death Rates (HIV+)

twoway ///
(line meanB1 year), ///
title(Death Probability over Time) ///
ytitle(%) xtitle(Year) ///
xline(1995) ///
note("The vertical line indicates HAART introduction")
graph export "ARTWORK/death1.png", replace

*Death Rates (HIV- & HIV+)

twoway ///
(line meanB1 year) ///
(line meanB1_neg year), ///
title(Death Probability over Time: HIV+ and HIV{&minus}) ///
ytitle(%) xtitle(Year) ///
xline(1995) ///
note("The vertical line indicates HAART introduction") ///
legend(label(1 "HIV+")  label(2 "HIV-"))
graph export "ARTWORK/death2.png", replace

*Treatment Choices

twoway /// 
(line meanm0 year) /// 
(line meanm1 year) ///
(line meanm2 year) ///
(line meanm3 year), ///
ylabel(0(.2)1) /// 
title(Treatment Choice over Time) ///
ytitle(%) xtitle(Year) ///
xline(1995) ///
note("The vertical line indicates HAART introduction") ///
legend(label(1 "None")  label(2 "Mono-Therapy") label(3 "Combo-Therapy") label(4 "HAART"))
graph export "ARTWORK/treat1.png", replace

*Treatment Choices: Persistence

twoway ///
(line meanEH year) ///
(line meanEM year), ///
title(Lifetime Use of HAART and ARVs over Time) ///
ylabel(0(.2)1) ///
ytitle(%) xtitle(Year) ///
xline(1995)  ///
note("The vertical line indicates HAART introduction") ///
legend(col(1) label(1 "Ever Used HAART?") label(2 "Ever Used HIV Meds?"))
graph export "ARTWORK/treat2.png", replace

*Employment

twoway /// 
(line meanl1 year) /// 
(line meanm3 year), ///
ytitle(%) xtitle(Year) ///
xline(1995) ///
note("The vertical line indicates HAART introduction") ///
legend(label(1 "Full Time") label(2 "HAART Use"))
graph export "ARTWORK/employ1.png", replace


twoway /// 
(line meanl1 year) ///
(line meanhatl1 year), ///
title(Observed and Extrapolated Labor Supply over Time) ///
ytitle(%) xtitle(Year) ///
xline(1995) ///
note("The vertical line indicates HAART introduction") ///
legend(label(1 "Full Time") label(2 "Extrapolated Full Time"))
graph export "ARTWORK/employ2.png", replace

twoway /// 
(line meanl1 year) ///
(line meanl0 year) ///
(line meanm3 year) ///
(line meanhatl1 year), ///
ytitle(%) xtitle(Year) ///
xline(1995) ///
note("The vertical line indicates HAART introduction") ///
legend(label(1 "Full Time") label(2 "Not Full Time") label(3 "HAART Use") label(4 "Extrapolated Full Time"))
graph export "ARTWORK/employ3.png", replace

*Depression
twoway /// 
(line meanDEP year), /// 
ytitle(%) xtitle(Year) ///
xline(1995) ///
note("The vertical line indicates HAART introduction") ///
legend(label(1 "Depression"))
graph export "ARTWORK/depression.png", replace

twoway /// 
(line meanCESD year), /// 
ytitle(Score) xtitle(Year) ///
xline(1995) ///
note("The vertical line indicates HAART introduction") ///
legend(label(1 "CESD Score"))
graph export "ARTWORK/CESD.png", replace

twoway /// 
(line meanHOPE year), /// 
ytitle(%) xtitle(Year) ///
xline(1995) ///
title(Hopefulness about the Future) ///
subtitle(Most or All of the Time) ///
note("The vertical line indicates HAART introduction") ///
legend(label(1 "Hopeful"))
graph export "ARTWORK/hope.png", replace

twoway /// 
(line meanHOPERES year), /// 
title(Hopefulness about the Future) ///
subtitle(Residuals after Controlling for Age and Health) ///
ytitle(Residuals) xtitle(Year) ///
xline(1995) ///
note("The vertical line indicates HAART introduction") ///
legend(label(1 "Hopeful"))
graph export "ARTWORK/hopeRES.png", replace


restore 
clear


********************************** 
*2 Descriptive Statistics (Paper)*
**********************************





*1	Summary Stats





clear
set more off
use "STATA/DATASETS/drugs"

gen IN_it_year = IN_it*2
gen p_it_year = p_it*2
gen E_it_years = E_it/2

summarize bage A_it cd4 H_it F_it B_it1 d_m0_1-d_m3_1  ///
IN_it_year p_it_year E_it_years d_l0_1 d_l1_1 N_0_0 N_1_0 N_2_0

summarize bage A_it cd4 H_it F_it B_it1 d_m0_1-d_m3_1  ///
IN_it_year p_it_year E_it_years d_l0_1 d_l1_1 N_0_0 N_1_0 N_2_0 if d_h==0

summarize bage A_it cd4 H_it F_it B_it1 d_m0_1-d_m3_1  ///
IN_it_year p_it_year E_it_years d_l0_1 d_l1_1 N_0_0 N_1_0 N_2_0 if d_h==1

summarize bage A_it cd4 H_it F_it B_it1 d_m0_1-d_m3_1  ///
IN_it_year p_it_year E_it_years d_l0_1 d_l1_1 N_0_0 N_1_0 N_2_0 if H_it==1

summarize bage A_it cd4 H_it F_it B_it1 d_m0_1-d_m3_1  ///
IN_it_year p_it_year E_it_years d_l0_1 d_l1_1 N_0_0 N_1_0 N_2_0 if H_it==0

summarize bage A_it cd4 H_it F_it B_it1 d_m0_1-d_m3_1  ///
IN_it_year p_it_year E_it_years d_l0_1 d_l1_1 N_0_0 N_1_0 N_2_0 if d_l0_0==0

summarize bage A_it cd4 H_it F_it B_it1 d_m0_1-d_m3_1  ///
IN_it_year p_it_year E_it_years d_l0_1 d_l1_1 N_0_0 N_1_0 N_2_0 if d_l0_0==1





*2	Transition Matrix: Drug Choice





clear
set more off
use "STATA/DATASETS/drugs"

*Drug Choice: Pre-HAART, Low CD4
latabstat d_m0_1 d_m1_1 d_m2_1 if d_it_m!=4 & d_it_m!=3 & d_h==0 & H_it==0, ///
by(d_it_m) cap(Transition Matrix: Treatment Choices, Pre-HAART Era) clabel(tm4) f(%9.2f)

*Drug Choice: Pre-HAART, High CD4
latabstat d_m0_1 d_m1_1 d_m2_1 if d_it_m!=4 & d_it_m!=3 & d_h==0 & H_it==1, ///
by(d_it_m) cap(Transition Matrix: Treatment Choices, Pre-HAART Era) clabel(tm5) f(%9.2f)

*Drug Choice: Post-HAART, Low CD4
latabstat d_m0_1 d_m1_1 d_m2_1 d_m3_1 if d_it_m!=4 & d_h==1 & H_it==0, ///
by(d_it_m) cap(Transition Matrix: Treatment Choices, Post-HAART Era) clabel(tm3) f(%9.2f)

*Drug Choice: Post-HAART, High CD4
latabstat d_m0_1 d_m1_1 d_m2_1 d_m3_1 if d_it_m!=4 & d_h==1 & H_it==1, ///
by(d_it_m) cap(Transition Matrix: Treatment Choices, Post-HAART Era) clabel(tm3) f(%9.2f)





*3	Transition Matrix: Employment Decision





clear
set more off
use "STATA/DATASETS/drugs"

*Employment Decisions: Pre-HAART, Low CD4
latabstat d_l0_1  d_l1_1 if d_h==0 & H_it==0, ///
by(d_it_l) cap(Transition Matrix: Employment Decisions, Pre-HAART Era) clabel(tm4) f(%9.2f)

*Employment Decision: Pre-HAART, High CD4
latabstat d_l0_1  d_l1_1 if d_h==0 & H_it==1, ///
by(d_it_l) cap(Transition Matrix: Employment Decisions, Pre-HAART Era) clabel(tm5) f(%9.2f)

*Employment Decision: Post-HAART, Low CD4
latabstat d_l0_1  d_l1_1 if d_h==1 & H_it==0, ///
by(d_it_l) cap(Transition Matrix: Employment Decisions, Post-HAART Era) clabel(tm3) f(%9.2f)

*Employment Decision: Post-HAART, High CD4
latabstat d_l0_1  d_l1_1 if d_h==1 & H_it==1, ///
by(d_it_l) cap(Transition Matrix: Employment Decisions, Post-HAART Era) clabel(tm3) f(%9.2f)





*4 Cycling Evidence*





clear
use "STATA/DATASETS/drugs"
set more off
gen onhaart = (d_it_m==3)

bysort caseid: gen tothaart = sum(onhaart)
bysort caseid: gen firsthaart = (tothaart==1 & tothaart[_n-1]==0)

bysort caseid: egen evhaart = max(onhaart)

gen onoffhaart=onhaart==1 & onhaart[_n+1]==0 & caseid==caseid[_n+1]
gen offonhaart=onhaart==0 & onhaart[_n+1]==1 & caseid==caseid[_n+1] & firsthaart[_n+1]==0

bysort caseid: gen totonoffhaart=sum(onoffhaart)
bysort caseid: gen totoffonhaart=sum(offonhaart)

bysort caseid: egen maxtotonoffhaart=max(totonoffhaart)
bysort caseid: egen maxtotoffonhaart=max(totoffonhaart)

rename maxtotonoffhaart switchoff
rename maxtotoffonhaart switchbackon

gen switch=switchoff+switchbackon

bysort caseid: egen maxvisit = max(v_it)
bysort caseid: gen leavebeforehaart = (maxvisit<=23)
bysort caseid: egen observedie = max(B_it1)

bysort caseid: keep if _n==1

tab evhaart 
tab leavebeforehaart if evhaart==0
tab observedie if leavebeforehaart==1 & evhaart==0
tab observedie if leavebeforehaart==0 & evhaart==0
tab switchoff if evhaart==1
tab switchbackon if evhaart==1
count if evhaart==1 & switchoff==0 & switchbackon==0
count if evhaart==1 & switchoff==1 & switchbackon==0
count if evhaart==1 & switchoff==1 & switchbackon==1
count if evhaart==1 & switchoff==2 & switchbackon==1
count if evhaart==1 & switchoff==2 & switchbackon==2
count if evhaart==1 & switchoff==3 & switchbackon==2
count if evhaart==1 & switchoff==3 & switchbackon==3

count if evhaart==1 & switchoff>=1 & switchbackon>=1


clear
use "STATA/DATASETS/drugs"
set more off
gen onmeds = (d_it_m!=0)

bysort caseid: gen totmeds = sum(onmeds)
bysort caseid: gen firstmeds = (totmeds==1 & totmeds[_n-1]==0)

bysort caseid: egen evmeds = max(onmeds)

gen onoffmeds=onmeds==1 & onmeds[_n+1]==0 & caseid==caseid[_n+1]
gen offonmeds=onmeds==0 & onmeds[_n+1]==1 & caseid==caseid[_n+1] & firstmeds[_n+1]==0

bysort caseid: gen totonoffmeds=sum(onoffmeds)
bysort caseid: gen totoffonmeds=sum(offonmeds)

bysort caseid: egen maxtotonoffmeds=max(totonoffmeds)
bysort caseid: egen maxtotoffonmeds=max(totoffonmeds)

rename maxtotonoffmeds switchoffmeds
rename maxtotoffonmeds switchbackonmeds

gen switchmeds=switchoffmeds+switchbackonmeds

bysort caseid: egen maxvisit = max(v_it)
bysort caseid: gen leavebeforehaart = (maxvisit<=23)
bysort caseid: egen observedie = max(B_it1)

bysort caseid: keep if _n==1

tab evmeds 
tab leavebeforehaart if evmeds==0
tab observedie if leavebeforehaart==1 & evmeds==0
tab observedie if leavebeforehaart==0 & evmeds==0
tab switchoff if evmeds==1
tab switchbackon if evmeds==1
count if evmeds==1 & switchoff==0 & switchbackon==0
count if evmeds==1 & switchoff==1 & switchbackon==0
count if evmeds==1 & switchoff==1 & switchbackon==1
count if evmeds==1 & switchoff==2 & switchbackon==1
count if evmeds==1 & switchoff==2 & switchbackon==2
count if evmeds==1 & switchoff==3 & switchbackon==2
count if evmeds==1 & switchoff==3 & switchbackon==3

count if evmeds==1 & switchoff>=1 & switchbackon>=1


*5 Employment Decision*





clear
use "STATA/DATASETS/drugs"
set more off

logit d_it1_l d_it_l AE_it AE_it2 A_it A_it2
est2vec employtable, ///
vars(d_it_l AE_it AE_it2 A_it A_it2 H_it F_it d_h d_m1_1 d_m2_1 d_m3_1 d_m1_0 d_m2_0 d_m3_0 ) ///
replace name(col1)

logit d_it1_l d_it_l AE_it AE_it2 A_it A_it2 H_it F_it d_h
est2vec employtable, addto(employtable) name(col2)

logit d_it1_l d_it_l AE_it AE_it2 A_it A_it2 H_it F_it d_h d_m1_1 d_m2_1 d_m3_1
est2vec employtable, addto(employtable) name(col3)

logit d_it1_l d_it_l AE_it AE_it2 A_it A_it2 H_it F_it d_m1_1 d_m2_1 d_m1_0 d_m2_0  if d_h==0
est2vec employtable, addto(employtable) name(col4)

logit d_it1_l d_it_l AE_it AE_it2 A_it A_it2 H_it F_it d_m1_1 d_m2_1 d_m3_1 d_m1_0 d_m2_0 d_m3_0 if d_h==1
est2vec employtable, addto(employtable) name(col5)

est2rowlbl d_it_l AE_it AE_it2 A_it A_it2 H_it F_it d_h d_m1_1 d_m2_1 d_m3_1  d_m1_0 d_m2_0 d_m3_0, ///
saving addto(employtable) /// 
path(ARTWORK) replace

est2texOWO employtable, replace preserve mark(starb) levels(90 95 99) digits(2) fancy label ///
 collabels([1] [2] [3] [4] [5]) dots leadzero ///
 negative suppress longnames controlrows notabular path(ARTWORK)




 
*6 Income*





clear
use "Stata/datasets/drugs"
set more off

tobit IN_it1 d_l1_1, ll(2500)

est2vec incometable, ///
vars(_cons d_l1_1 H_it AE_it AE_it2 A_it ts2 H_it_w AE_it_w AE_it2_w A_it_w ts2_w) name(col1) ///
replace

tobit IN_it1 d_l1_1 H_it, ll(2500)
est2vec incometable, addto(incometable) name(col2)

tobit IN_it1 d_l1_1 H_it AE_it AE_it2, ll(2500)
est2vec incometable, addto(incometable) name(col3)

tobit IN_it1 d_l1_1 H_it AE_it AE_it2 A_it ts2, ll(2500)
est2vec incometable, addto(incometable) name(col4)

tobit IN_it1 d_l1_1 H_it AE_it AE_it2 A_it ts2 H_it_w AE_it_w AE_it2_w A_it_w ts2_w, ll(2500)
est2vec incometable, addto(incometable) name(col5)

est2rowlbl  d_l1_1 H_it AE_it AE_it2 A_it ts2 H_it_w AE_it_w AE_it2_w A_it_w ts2_w, ///
saving addto(incometable) /// 
path(ARTWORK) replace

est2texOWO incometable, replace preserve mark(starb) levels(90 95 99) digits(2) fancy label ///
 collabels([1] [2] [3] [4] [5])  dots leadzero ///
 negative suppress longnames controlrows notabular path(ARTWORK)





*7 Income/Price changes for Identification of Alpha





clear
set more off
use "STATA/DATASETS/drugs" 

*NOTE 80 people are only observed once*

bysort caseid: gen switchin 	= d_l1_0[_n+1]>d_l1_0 
bysort caseid: replace switchin = . if d_l1_0[_n+1]==.
replace switchin=1 if d_l1_0==0 & d_l1_1==1

bysort caseid: gen switchout 	= d_l1_0[_n+1]<d_l1_0  
bysort caseid: replace switchout = . if d_l1_0[_n+1]==.
replace switchout=1 if d_l1_0==1 & d_l1_1==0

bysort caseid: egen evswitchout = max(switchout)
bysort caseid: egen evswitchin 	= max(switchin)

gen evswitch 	= (evswitchout==1 | evswitchin==1)  
gen bothswitch 	= (evswitchout==1 & evswitchin==1)

bysort caseid: egen minwork=min(d_l1_0)  
bysort caseid: egen minwork2=min(d_l1_1)  
bysort caseid: gen 	alwayswork 	= (minwork==1 & minwork2!=0)
								
bysort caseid: egen maxwork=max(d_l1_0)  
bysort caseid: egen maxwork2=max(d_l1_1)  
bysort caseid: gen 	neverwork 	= (maxwork==0 & maxwork2!=1) 

replace evswitchout=. 	if caseid[_n+1]!=caseid & caseid[_n-1]!=caseid
replace evswitchin=. 	if caseid[_n+1]!=caseid & caseid[_n-1]!=caseid
replace bothswitch=. 	if caseid[_n+1]!=caseid & caseid[_n-1]!=caseid
replace evswitch=. 		if caseid[_n+1]!=caseid & caseid[_n-1]!=caseid
replace alwayswork=. 	if caseid[_n+1]!=caseid & caseid[_n-1]!=caseid
replace neverwork=. 	if caseid[_n+1]!=caseid & caseid[_n-1]!=caseid

preserve
bysort caseid: keep if _n==1
tab evswitchout
tab evswitchin
tab bothswitch
tab evswitch
tab alwayswork
tab neverwork
replace evswitchout=0 if evswitchout==.
replace evswitchin=0 if evswitchin==.
replace bothswitch=0 if bothswitch==.
replace evswitch=0 if evswitch==.
tab evswitchout
tab evswitchin
tab bothswitch
tab evswitch
restore

count if d_l1_0 != d_l1_1
count if d_l1_0 != d_l1_0[_n+1] & caseid==caseid[_n+1]

count if d_l1_0==0 & d_l1_1==1
count if d_l1_0==0 & d_l1_0[_n+1]==1 & caseid==caseid[_n+1]

count if d_l1_0==1 & d_l1_1==0
count if d_l1_0==1 & d_l1_0[_n+1]==0 & caseid==caseid[_n+1]

gen laborout 	= (d_l1_0==1 & d_l1_1==0) if d_l1_1!=.
gen laborin 	= (d_l1_0==0 & d_l1_1==1) if d_l1_1!=.
gen switchdrug	= (d_it_m!=d_it1_m) if d_it1_m!=.

tab laborout
tab laborin
tab switchdrug

kdensity IN_it if laborout==1
kdensity IN_it if laborin==1
kdensity IN_it if laborin==1 | laborout==1
kdensity IN_it if laborin==0 & laborout==0
kdensity IN_it if switchdrug==1
kdensity IN_it if switchdrug==0

hist IN_it, width(350)
hist IN_it if laborout==1, width(350)
hist IN_it if laborin==1, width(350)
hist IN_it if laborin==1 | laborout==1, width(350)
hist IN_it if laborin==0 & laborout==0, width(350)
hist IN_it if switchdrug==1, width(350)
hist IN_it if switchdrug==0, width(350)

gen absincomechange=abs(IN_it1-IN_it)

kdensity absincomechange
kdensity absincomechange if laborout==1
kdensity absincomechange if laborin==1
kdensity absincomechange if laborin==1 | laborout==1
kdensity absincomechange if laborin==0 & laborout==0

hist absincomechange
hist absincomechange if laborout==1
hist absincomechange if laborin==1

twoway 	(kdensity IN_it), ///
		title(Income Distribution) ///
		ytitle(Density) xtitle(Income)
		graph export "ARTWORK/incomedist1.png", replace

twoway 	(kdensity IN_it) ///
		(kdensity IN_it if laborout==1) ///
		(kdensity IN_it if laborin==1) ///
		(kdensity IN_it if laborin==1 | laborout==1), ///
		title(Income Distribution) ///
		subtitle(By Type of Employment Transition) ///
		ytitle(Density) xtitle(Income) ///
		legend(label(1 "Full Sample")  label(2 "Switch Out of Full Time") label(3 "Switch into Full Time") label(4 "In or Out"))
		graph export "ARTWORK/incomedist2.png", replace

twoway 	(kdensity IN_it) ///
		(kdensity IN_it if switchdrug==1) ///
		(kdensity IN_it if switchdrug==0), /// 
		title(Income Distribution) ///
		subtitle(By Type of Treatment Change) ///
		ytitle(Density) xtitle(Income) ///
		legend(label(1 "Full Sample")  label(2 "Switch Medications") label(3 "Do Not Switch Meds"))
		graph export "ARTWORK/incomedist3.png", replace





*8 Side Effects*





clear
set more off
use "STATA/DATASETS/drugs" 
 
logit F_it H_it d_m1_0 d_m2_0 d_m3_0 
logit fatig H_it d_m1_0 d_m2_0 d_m3_0 
logit diarr H_it d_m1_0 d_m2_0 d_m3_0 
logit heada H_it d_m1_0 d_m2_0 d_m3_0 
logit fever H_it d_m1_0 d_m2_0 d_m3_0 
logit sweat H_it d_m1_0 d_m2_0 d_m3_0 

logit fatig1 H_it H00_m11 H00_m21 H00_m31 H10_m11 H10_m21 H10_m31 ts0  
logit diarr1 H_it H00_m11 H00_m21 H00_m31 H10_m11 H10_m21 H10_m31 ts0  
logit heada1 H_it H00_m11 H00_m21 H00_m31 H10_m11 H10_m21 H10_m31 ts0  
logit fever1 H_it H00_m11 H00_m21 H00_m31 H10_m11 H10_m21 H10_m31 ts0  
logit sweat1 H_it H00_m11 H00_m21 H00_m31 H10_m11 H10_m21 H10_m31 ts0  

logit fatig1 H_it H00_m11 H00_m21 H00_m31 H10_m11 H10_m21 H10_m31 ts0  

gen F_it1_no=1-F_it1

gen H_it0=(1-H_it)
lab var H_it0 "Low CD4"
lab var H10_m11 "\hspace{.3cm}$\times$ Mono"
lab var H10_m21 "\hspace{.3cm}$\times$ Combo"
lab var H10_m31 "\hspace{.3cm}$\times$ HAART"
lab var H00_m11 "\hspace{.3cm}$\times$ Mono"
lab var H00_m21 "\hspace{.3cm}$\times$ Combo"
lab var H00_m31 "\hspace{.3cm}$\times$ HAART"


est2vec sfxtable, ///
vars(H_it H10_m11 H10_m21 H10_m31 H_it0 H00_m11 H00_m21 H00_m31  ts0 _cons) name(col1) ///
replace

logit diarr1 H_it H10_m11 H10_m21 H10_m31 H00_m11 H00_m21 H00_m31 ts0  
est2vec sfxtable, addto(sfxtable) name(col2)

logit heada1 H_it H10_m11 H10_m21 H10_m31 H00_m11 H00_m21 H00_m31 ts0  
est2vec sfxtable, addto(sfxtable) name(col3)

logit fever1 H_it H10_m11 H10_m21 H10_m31 H00_m11 H00_m21 H00_m31 ts0  
est2vec sfxtable, addto(sfxtable) name(col4)

logit sweat1 H_it H10_m11 H10_m21 H10_m31 H00_m11 H00_m21 H00_m31 ts0  
est2vec sfxtable, addto(sfxtable) name(col5)

logit F_it1_no H_it H10_m11 H10_m21 H10_m31 H00_m11 H00_m21 H00_m31 ts0  
est2vec sfxtable, addto(sfxtable) name(col6)

est2rowlbl H_it H10_m11 H10_m21 H10_m31 H_it0 H00_m11 H00_m21 H00_m31 ts0   ts0, ///
saving addto(sfxtable) /// 
path(ARTWORK) replace

est2texOWO sfxtable, replace preserve mark(starb) levels(90 95 99) digits(2) fancy label ///
 collabels([All sfx] [fatigue] [diarrhea] [headaches] [fever] [sweats])  dots leadzero ///
 negative suppress longnames controlrows notabular path(ARTWORK)

/*
est2vec sfxtable, ///
vars(H_it H00_m11 H00_m21 H00_m31 H10_m11 H10_m21 H10_m31 ts0 _cons) name(col1) ///
replace

logit diarr1 H_it H00_m11 H00_m21 H00_m31 H10_m11 H10_m21 H10_m31 ts0  
est2vec sfxtable, addto(sfxtable) name(col2)

logit heada1 H_it H00_m11 H00_m21 H00_m31 H10_m11 H10_m21 H10_m31 ts0  
est2vec sfxtable, addto(sfxtable) name(col3)

logit fever1 H_it H00_m11 H00_m21 H00_m31 H10_m11 H10_m21 H10_m31 ts0  
est2vec sfxtable, addto(sfxtable) name(col4)

logit sweat1 H_it H00_m11 H00_m21 H00_m31 H10_m11 H10_m21 H10_m31 ts0  
est2vec sfxtable, addto(sfxtable) name(col5)

logit F_it1_no H_it H00_m11 H00_m21 H00_m31 H10_m11 H10_m21 H10_m31 ts0  
est2vec sfxtable, addto(sfxtable) name(col6)

est2rowlbl H_it H00_m11 H00_m21 H00_m31 H10_m11 H10_m21 H10_m31 ts0, ///
saving addto(sfxtable) /// 
path(ARTWORK) replace

est2texOWO sfxtable, replace preserve mark(starb) levels(90 95 99) digits(2) fancy label ///
 collabels([All sfx] [fatigue] [diarrhea] [headaches] [fever] [sweats])  dots leadzero ///
 negative suppress longnames controlrows notabular path(ARTWORK)
*/

bysort d_h: tab diarr
bysort d_h: tab heada

ttest fatig, by(d_h)
ttest diarr, by(d_h)
ttest heada, by(d_h)
ttest fever, by(d_h)
ttest sweat, by(d_h)
ttest F_it, by(d_h)

ttest fatig1, by(d_h)
ttest diarr1, by(d_h)
ttest heada1, by(d_h)
ttest fever1, by(d_h)
ttest sweat1, by(d_h)
ttest F_it1, by(d_h)
