%{
** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** 
** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** 
** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** 
** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** 
** ** ** **                                                          ** 
** ** ** **                                                          ** 
** ** ** **       V A L U E  O F  M E D I C A L  I N N O V A T I O N ** 
** ** ** **       V A L U E  O F  M E D I C A L  I N N O V A T I O N ** 
** ** ** **       V A L U E  O F  M E D I C A L  I N N O V A T I O N ** 
** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** 
** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** 

Function Name:  A_ESTIMATE
Created:        6/26/2011 by Nicholas W Papageorge 
Last Modified:  9/10/2015 by Nicholas W Papageorge
Copyright:      Nicholas W Papageorge. All rights reserved.
Project:        How Does Medical Innovation Create Value?
                Health, Human Capital and the Labor Market
Description:    Main estimation file using built-in 
                optimization routines to maximize
                the likelihood function
%}

% HERE, REPLACE cd COMMAND TO NAVIGATE TO FOLDER REPLICATION/MATLAB
cd('~/Dropbox/WORK/VMI/PAPER/REPLICATION/MATLAB')
% HERE, REPLACE cd COMMAND TO NAVIGATE TO FOLDER REPLICATION/MATLAB

clear all
clc

%1  MODEL DESCRIPTION

display 'How Does Medical Innovation Create Value?'
display 'Structural Model' 


%2  GLOBAL OBJECTS

global TP ERRORS_CALC 
global T MODEL
global N I L
global N_H N_E N_v N_A N_dm0 N_dm1 N_dl1 DIM DIM_S N_p
global obsB indB T_iB startIB endIB H_itB A_itB IB NB
global obs ind T_i startI endI 
global v_it  H_it  A_it  I_it  F_it  E_it 
global v_it1 H_it1 A_it1 I_it1 F_it1 N_1_0 N_2_0
global IN_it1 AE_it
global d_it_m  d_m0_0 d_m1_0 d_m2_0 d_m3_0  
global d_it1_l d_l0_1 
global d_it1_m d_m0_1 d_m1_1 d_m2_1 d_m3_1  
global p_it pd INCd d_h cd4I
global N_it1 B_it1 
global beta beta_p beta_D beta_H beta_F beta_B beta_I beta_N
global    LU1 LA1 LP1 LS1 LD1 LH1 LF1 LB1 LI1 LN1
global LT LU2 LA2 LP2 LS2 LD2 LH2 LF2 LB2 LI2 LN2
global death I_death N_death dead1







%3  STATE VARIABLE CARDINALITY, DIMENSIONS, MODEL (MODEL=5 for ERRORS)

N_H=2; 
N_E=5;
N_v=26; 
N_A=71;
N_dm0=4; 
N_dm1=4;
N_dl1=2;

DIM=(N_H)*(N_E)*(9) *(N_dm1-1)*(N_dm0-1)*(N_dl1)+...
    (N_H)*(N_E)*(17)*(N_dm1-0)*(N_dm0-0)*(N_dl1);

DIM_S=(N_H)*(N_E)*(N_v)*(N_dm0);



ERRORS_CALC=0;
MODEL=4; 

if MODEL==5
    display 'This Program [MODEL 5] is only for ERRORS & TABLES'
    display 'MODEL 5 computes full likelihood w/ 1st stage parameters included'
    display 'MODEL 5 ENDS RIGHT AFTER ERRORS/TABLES'
    display 'Use MODEL==4 for SIMULATIONS'
end













%4  LOAD DATA AND TP MATRICES FROM FIRST STEP

cd ('Z_DATASETS/TP')

files=dir('*.csv');
for i=1:length(files)
    eval(['load ' files(i).name ' -ascii' ]);
end





 



















%7  CONSTRUCT TP CUBE

TP=cat(3,TP,...
    a300, a305, a310, a315, a320, a325, a330, a335, a340, a345,...
    a350, a355, a360, a365, a370, a375, a380, a385, a390, a395,...
    a400, a405, a410, a415, a420, a425, a430, a435, a440, a445,...
    a450, a455, a460, a465, a470, a475, a480, a485, a490, a495,...
    a500, a505, a510, a515, a520, a525, a530, a535, a540, a545,...
    a550, a555, a560, a565, a570, a575, a580, a585, a590, a595,...
    a600, a605, a610, a615, a620, a625, a630, a635, a640, a645, a650);

clear   a345 a340 a335 a330 a325 a320 a315 a310 a305 a300...
        a395 a390 a385 a380 a375 a370 a365 a360 a355 a350...
        a445 a440 a435 a430 a425 a420 a415 a410 a405 a400...
        a495 a490 a485 a480 a475 a470 a465 a460 a455 a450...
        a545 a540 a535 a530 a525 a520 a515 a510 a505 a500...
        a595 a590 a585 a580 a575 a570 a565 a560 a555 a550...
        a625 a620 a615 a610 a605 a600 a645 a640 a635 a630...
        a635 a640 a645 a650

 
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
%8  DEFINE DATA VECTORS

cd ..
load 'drugs.csv'
cd ..

clear files i

obs         =drugs(:,1); 
ind         =drugs(:,2); 
T_i         =drugs(:,3);
startI      =drugs(:,4); 
endI        =drugs(:,5);

v_it        =drugs(:,6); 
H_it        =drugs(:,7);
F_it        =drugs(:,8);
E_it        =drugs(:,9);
A_it        =drugs(:,10);
I_it        =drugs(:,11);

v_it1       =drugs(:,12); 
H_it1       =drugs(:,13);
F_it1       =drugs(:,14);
A_it1       =drugs(:,15);
I_it1       =drugs(:,16);

N_it        =drugs(:,17);
N_1_0       =drugs(:,18);
N_2_0       =drugs(:,19);
N_it1       =drugs(:,20);

d_it1_l     =drugs(:,21);
d_l0_1      =drugs(:,22);
d_l1_1      =drugs(:,23);

d_it1_m     =drugs(:,24);
d_m0_1      =drugs(:,25);
d_m1_1      =drugs(:,26);
d_m2_1      =drugs(:,27);
d_m3_1      =drugs(:,28);

d_it_m      =drugs(:,29);
d_m0_0      =drugs(:,30);
d_m1_0      =drugs(:,31);
d_m2_0      =drugs(:,32);
d_m3_0      =drugs(:,33);

p_it        =drugs(:,34);
pd          =drugs(:,35);
INCd        =drugs(:,36);
d_h         =drugs(:,37);

AE_it       =drugs(:,38);
IN_it1      =drugs(:,39);

cd4I        =drugs(:,40);

beta_p      =drugs(:,41);
beta_D      =drugs(:,42);
beta_H      =drugs(:,43);
beta_F      =drugs(:,44);
beta_B      =drugs(:,45);
beta_I      =drugs(:,46);
beta_N      =drugs(:,47);

%8  DEFINE DATA VECTORS

load 'Z_DATASETS/drugs_death.csv'
clear files i

death      =drugs_death;

H_itB      =death(:,1);
A_itB      =death(:,3);
B_it1      =death(:,4);
indB       =death(:,5); 
obsB       =death(:,6);
T_iB       =death(:,7);
startIB    =death(:,8); 
endIB      =death(:,9);

IB         =max(drugs_death(:,5));
NB         =length(drugs_death);

load 'Z_DATASETS/drugs_death1.csv'
clear files i
death1      =drugs_death1;
dead1       =death1(:,1);

%9      MODELS

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%9.1    MODEL 1:  BASIC, NO UH
  
if MODEL==1;
%SV (LL=24049)
%FV (LL=16575)

%9.1.1      Set Starting Values / Record Final Values
      
% theta0_U1=[... 
%        -1
%        -1
%        -1
%        -1
%        -1];
% 
% theta0_A1=2;
% theta0=[theta0_U1;theta0_A1];   
 

theta0_U1=[... 
         -1.14426212997056
         -19.5364403271842
         -12.4688437992223
         -1.41990606302202
           6.1291949199423];

theta0_A1=2.06905168096278;
theta0=[theta0_U1;theta0_A1];  

    
%9.1.2      Set Parameters

N=length(obs);
I=max(ind);
L=1;
beta=sqrt(0.95);

LU1=length(theta0_U1);
LA1=length(theta0_A1);
LP1=0;
LS1=0;
LD1=0;
LH1=0;
LF1=0;
LB1=0;
LI1=0;
LN1=0;

LT=0;

LU2=0;
LA2=0;
LP2=0;
LS2=0;
LD2=0;
LH2=0;
LF2=0;
LB2=0;
LI2=0;
LN2=0;

N_p=length(theta0);
tic
LL_SV=B_LL(theta0)
toc

end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%9.2    MODEL 2:  MODEL 1 + F + H
  
if MODEL==2;
%SV (LL=16575)
%FV (LL=14897)

%9.2.1      Set Starting Values / Record Final Values
 
% theta0_U1=[... 
%          -1.14426212997056
%          -19.5364403271842
%          -1.14426212997056
%          -12.4688437992223
%          -1.41990606302202
%            6.1291949199423
%          -12.4688437992223
%          -1.41990606302202
%            6.1291949199423];
% 
% theta0_A1=[...
%             2.06905168096278;
%             2.06905168096278;];
%     
% theta0=[theta0_U1;theta0_A1];
 
theta0_U1=[...
         -1.39619725831831
         -49.6123017435301
         -7.68046305364361
          11.1759955127952
          -5.4432214515766
         -11.0414647247065
         -38.6382218906791
          3.90754846720546
           32.201691580345];

theta0_A1=[...
          2.11376226706099
         0.912400915223856];
    
theta0=[theta0_U1;theta0_A1];


           
%9.2.2      Set Parameters

N=length(obs);
I=max(ind);
L=1;
beta=sqrt(0.95);

LU1=length(theta0_U1);
LA1=length(theta0_A1);
LP1=0;
LS1=0;
LD1=0;
LH1=0;
LF1=0;
LB1=0;
LI1=0;
LN1=0;

LT=0;

LU2=0;
LA2=0;
LP2=0;
LS2=0;
LD2=0;
LH2=0;
LF2=0;
LB2=0;
LI2=0;
LN2=0;

N_p=length(theta0);
tic
LL_SV=B_LL(theta0)
toc

end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
%9.3    MODEL 3:  MODEL 2 + UH in PREFERENCES ONLY
  
if MODEL==3;
%SV (LL=14897)
%FV (LL=13268)

%9.3.1      Set Starting Values / Record Final Values

% theta0_U1=[...
%          -1.39619725831831
%          -49.6123017435301
%          -7.68046305364361
%           11.1759955127952
%           -5.4432214515766
%          -11.0414647247065
%          -38.6382218906791
%           3.90754846720546
%            32.201691580345];
% 
% theta0_A1=[...
%           2.11376226706099
%          0.912400915223856];
%         
% theta0_TP=3;
% 
% theta0_U2=[... 
%          -1.39619725831831
%          -49.6123017435301
%          -7.68046305364361];
% 
% theta0_A2=[...
%           2.11376226706099
%          0.912400915223856];
%     
% theta0=[theta0_U1;theta0_A1;theta0_TP;theta0_U2;theta0_A2]; 

theta0_U1=[...  
          -2.8332778993032
         -54.6859552676167
          0.88208528554118
          14.4443209398945
         -5.94969022355593
         -11.0514932746873
         -41.9591659602782
          4.47113947947594
          31.8359411927227];

theta0_A1=[...
          2.13809998167956
         0.952012141637101];
    
    
theta0_TP=-0.210052930148649;

theta0_U2=[... 
         -2.50740436838655
         -42.6327186097127
         -7.72659904904983];

theta0_A2=[...
          2.10480407073373
          1.03832947363244];
    
theta0=[theta0_U1;theta0_A1;theta0_TP;theta0_U2;theta0_A2];

      
   
%9.3.2      Set Parameters

N=length(obs);
I=max(ind);
L=2;
beta=sqrt(0.95);

LU1=length(theta0_U1);
LA1=length(theta0_A1);
LP1=0;
LS1=0;
LD1=0;
LH1=0;
LF1=0;
LB1=0;
LI1=0;
LN1=0;

LT=1;

LU2=length(theta0_U2);
LA2=length(theta0_A2);
LP2=0;
LS2=0;
LD2=0;
LH2=0;
LF2=0;
LB2=0;
LI2=0;
LN2=0;

N_p=length(theta0);
tic
LL_SV=B_LL(theta0)
toc

end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%9.4    MODEL 4:  MODEL **2** + UH in PREFERENCES & TRANSITION PROBABILITIES

if MODEL==4;
%SV: U   (LL=13268)
%SV: D   (LL= 5311)
%SV: H   (LL= 2229)
%SV: F   (LL= 5148)
%SV: SUM (LL=25956)

%SV: U   (LL= 7805)
%SV: D   (LL= 5380)
%SV: H   (LL= 2421)
%SV: F   (LL= 5239)
%SV: SUM (LL=20560)

%9.4.1      Set Starting Values / Record Final Values
    
theta0_U1=[... 
       -2.594
      -53.695
      -2.6684
       13.595
      -6.1816
      -12.522
      -42.729
       4.3161
       30.066];

theta0_A1=[...       
       1.4148
       1.0595];
       
theta0_D1=[...        
     -0.40295
     0.060897
     0.085151
         0.17
      0.41996
      0.49661
      0.70726
     0.019088
     -0.69871];
    
theta0_H1=[... 
       5.2554
       3.8944
      0.65728
      -3.7068];
       
theta0_F1=[...        
      0.94106
      0.26461
      0.23692
      0.24863
     -0.18668
     -0.20329
     -0.19308
     0.007729
     -0.44644];
    
theta0_TP=[...     
      -1.1252
     -0.17451
        0.569];
     
theta0_U2=[...      
      -2.3526
      -42.552
        -9.24];
     
theta0_A2=[...      
       1.4193
       1.2108];

theta0_D2(1,1)=2.2039;
theta0_D2(2,1)=0.77051;
     
theta0_H2=[...      
       6.1621
       4.3285
       2.9312
       -3.822];

theta0_F2(1,1)=-1.0447;
theta0_F2(2,1)=-0.20359;    
   
theta0=[theta0_U1;theta0_A1;theta0_D1;theta0_H1;theta0_F1;theta0_TP;...
        theta0_U2;theta0_A2;theta0_D2;theta0_H2;theta0_F2;]; 
           
%9.4.2      Set Parameters

N=length(obs);
I=max(ind);
L=4;
beta=sqrt(0.95);

LU1=length(theta0_U1);
LA1=length(theta0_A1);
LP1=0;
LS1=0;
LD1=length(theta0_D1);
LH1=length(theta0_H1);
LF1=length(theta0_F1);
LB1=0;
LI1=0;
LN1=0;

LT=length(theta0_TP);

LU2=length(theta0_U2);
LA2=length(theta0_A2);
LP2=0;
LS2=0;
LD2=length(theta0_D2);
LH2=length(theta0_H2);
LF2=length(theta0_F2);
LB2=0;
LI2=0;
LN2=0;

N_p=length(theta0);
tic
LL_SV=B_LL(theta0)
toc

end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%9.4    MODEL 5:  MODEL 4 & ERRORS

if MODEL==5;

theta0_U1=[... 
       -2.594
      -53.695
      -2.6684
       13.595
      -6.1816
      -12.522
      -42.729
       4.3161
       30.066];

theta0_A1=[...       
      0.80452
      0.74259];
       
theta0_D1=[...        
     -0.40295
     0.060897
     0.085151
         0.17
      0.41996
      0.49661
      0.70726
     0.019088
     -0.69871];
    
theta0_H1=[... 
       5.2554
       3.8944
      0.65728
      -3.7068];
       
theta0_F1=[...        
      0.94106
      0.26461
      0.23692
      0.24863
     -0.18668
     -0.20329
     -0.19308
     0.007729
     -0.44644];
    
theta0_TP=[...     
      0.24505
      0.34462
      0.26201];
     
theta0_U2=[...      
      -2.3526
      -42.552
        -9.24];
     
theta0_A2=[...      
      0.80523
      0.77044];

theta0_D2(1,1)=2.2039;
theta0_D2(2,1)=0.77051;
     
theta0_H2=[...      
       6.1621
       4.3285
       2.9312
       -3.822];

theta0_F2(1,1)=-1.0447;
theta0_F2(2,1)=-0.20359;     

theta0_P1=beta_p(1:18)  ;        
theta0_B1=beta_B(1:4)   ;           
theta0_I1=beta_I(1:13)  ;           
theta0_N1=beta_N(10:27) ;           

theta0=[theta0_U1
        theta0_A1
        theta0_P1
        theta0_D1
        theta0_H1
        theta0_F1
        theta0_B1
        theta0_I1
        theta0_N1
        theta0_TP
        theta0_U2
        theta0_A2
        theta0_D2
        theta0_H2
        theta0_F2]; 
       

%9.4.2      Set Parameters

N=length(obs);
I=max(ind);
L=4;
beta=sqrt(0.95);

LU1=length(theta0_U1);
LA1=length(theta0_A1);
LP1=length(theta0_P1);
LS1=0;
LD1=length(theta0_D1);
LH1=length(theta0_H1);
LF1=length(theta0_F1);
LB1=length(theta0_B1);
LI1=length(theta0_I1);
LN1=length(theta0_N1);

LT=length(theta0_TP);

LU2=length(theta0_U2);
LA2=length(theta0_A2);
LP2=0;
LS2=0;
LD2=length(theta0_D2);
LH2=length(theta0_H2);
LF2=length(theta0_F2);
LB2=0;
LI2=0;
LN2=0;

N_p=length(theta0);
tic
LL_SV=B_LL(theta0)
toc

end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%10    OPTIMIZATION ROUTINE
% N_p=length(theta0);
% tic
% LL_SV=B_LL(theta0)
% toc

% options  = optimset('MaxIter',10000000,'MaxFunEvals',20000000,'Display', 'iter','Tolfun', 1e-0, 'TolX', 1e-0,'OutputFcn', @H_TEMP, 'PlotFcns', @optimplotfval);
% th_ml=fminsearch(@B_LL,theta0,options);
% LL_FV=B_LL(th_ml);
% theta0=th_ml

% lb=theta0-(100000*abs(theta0));
% ub=theta0+(100000*abs(theta0));
% options  = optimset('Algorithm','interior-point', 'MaxIter',10000,'MaxFunEvals',20000000,'Display', 'iter','Tolfun', 1e-5, 'TolX', 1e-5,'OutputFcn', @H_TEMP, 'PlotFcns', @optimplotfval);
% [th_ml, fval, exitflag, output, lambda, grad, hessian]=fmincon(@B_LL,theta0,[],[],[],[],lb,ub,[],options);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   11    STANDARD ERRORS & RESULTS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

th_ml=theta0;

if MODEL==5
%RESULTS=F_ERRORS(th_ml);
%save('RESULTS','RESULTS')
load 'RESULTS'

% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
% TABLES
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %

RESULTS_U1   =RESULTS(1:LU1,:);      
RESULTS_A1   =RESULTS(LU1+1:LU1+LA1,:);      
RESULTS_P1   =RESULTS(LU1+LA1+1:LU1+LA1+LP1,:);      
RESULTS_S1   =RESULTS(LU1+LA1+LP1+1:LU1+LA1+LP1+LS1,:);      
RESULTS_D1   =RESULTS(LU1+LA1+LP1+LS1+1:LU1+LA1+LP1+LS1+LD1,:);   
RESULTS_H1   =RESULTS(LU1+LA1+LP1+LS1+LD1+1:LU1+LA1+LP1+LS1+LD1+LH1,:);
RESULTS_F1   =RESULTS(LU1+LA1+LP1+LS1+LD1+LH1+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1,:);
RESULTS_B1   =RESULTS(LU1+LA1+LP1+LS1+LD1+LH1+LF1+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1,:);
RESULTS_I1   =RESULTS(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1,:);
RESULTS_N1   =RESULTS(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1,:);

if L~=1
RESULTS_T    =RESULTS(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT,:);     

RESULTS_U2   =RESULTS(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2,:);
RESULTS_A2   =RESULTS(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2,:);      
RESULTS_P2   =RESULTS(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2,:);       
RESULTS_S2   =RESULTS(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2,:);        
RESULTS_D2   =RESULTS(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2,:);        
RESULTS_H2   =RESULTS(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2+LH2,:);   
RESULTS_F2   =RESULTS(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2+LH2+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2+LH2+LF2,:);  
RESULTS_B2   =RESULTS(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2+LH2+LF2+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2+LH2+LF2+LB2,:);  
RESULTS_I2   =RESULTS(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2+LH2+LF2+LB2+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2+LH2+LF2+LB2+LI2,:);  
RESULTS_N2   =RESULTS(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2+LH2+LF2+LB2+LI2+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2+LH2+LF2+LB2+LI2+LN2,:);  
end

% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
% Flow Utility Parameters
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %

opt.resultsfolder = '../ARTWORK';
opt.summstatsfile = 'paramestsutility';
opt.captionstar   = '';
thetexfile     = strcat(opt.resultsfolder,'/',opt.summstatsfile,'.tex');
fid = fopen(thetexfile, 'w');
clear thetexfile 

fprintf(fid, '\\begin{table}[htbp] \n');
fprintf(fid, '\\caption{\\label{paramestsutility}\\textsc{Structural Parameter Estimates: Utility}} \n');
fprintf(fid, '\\vspace{-.4cm} \n');
fprintf(fid, '\\begin{center} \n');
fprintf(fid, '\\small \n');
fprintf(fid, '\\begin{tabular}{l|cc|cc} \n');
fprintf(fid, '\\hline\\hline \n');
fprintf(fid, '& \\multicolumn{2}{c}{Type I} & \\multicolumn{2}{c}{Type II} \\\\ \n');
fprintf(fid, '\\hline \n');
fprintf(fid, '& \\multicolumn{1}{c}{Coefficient} & \\multicolumn{1}{c}{Error} & \\multicolumn{1}{c}{Coefficient}& \\multicolumn{1}{c}{Error} \\\\ \n');
fprintf(fid, '\\hline\\hline \n');
fprintf(fid, '\\multicolumn{1}{l|}{No Ailments} & . & . & . & . \\\\ \n'); 
fprintf(fid, '%s   & %7.2f & %7.2f & %7.2f & %7.2f   \\\\\n',...
    '\hspace{.1cm}$\times$ CRRA',RESULTS_A2(1,1),RESULTS_A2(1,2), RESULTS_A1(1,1), RESULTS_A1(1,2));
fprintf(fid, '%s   & %7.2f & %7.2f & %7.2f & %7.2f   \\\\\n',...
    '\hspace{.1cm}$\times$ Labor Disutility',RESULTS_U2(1,1),RESULTS_U2(1,2), RESULTS_U1(1,1), RESULTS_U1(1,2));
fprintf(fid, '%s   & %7.2f & %7.2f & . & .   \\\\\n',...
    '\hspace{.1cm}$\times$ Begin Treatment' ,RESULTS_U1(4,1),RESULTS_U1(4,2));
fprintf(fid, '%s   & %7.2f & %7.2f & . & .   \\\\\n',...
    '\hspace{.1cm}$\times$ Change Treatment',RESULTS_U1(5,1),RESULTS_U1(5,2));
fprintf(fid, '%s   & %7.2f & %7.2f & . & .   \\\\\n',...
    '\hspace{.1cm}$\times$ End Treatment'   ,RESULTS_U1(6,1),RESULTS_U1(6,2));
fprintf(fid, '\\hline \n');
fprintf(fid, '%s   & %7.2f & %7.2f & %7.2f & %7.2f   \\\\\n',...
    'Ailments',RESULTS_U2(2,1),RESULTS_U2(2,2), RESULTS_U1(2,1), RESULTS_U1(2,2));
fprintf(fid, '%s   & %7.2f & %7.2f & %7.2f & %7.2f   \\\\\n',...
    '\hspace{.1cm}$\times$ CRRA',RESULTS_A2(2,1),RESULTS_A2(2,2), RESULTS_A1(1,1), RESULTS_A1(1,2));
fprintf(fid, '%s   & %7.2f & %7.2f & %7.2f & %7.2f   \\\\\n',...
    '\hspace{.1cm}$\times$ Labor Disutility',RESULTS_U2(3,1)+RESULTS_U2(1,1),RESULTS_U2(3,2), RESULTS_U1(1,1)+RESULTS_U1(3,1), RESULTS_U1(1,2));
fprintf(fid, '%s   & %7.2f & %7.2f & . & .   \\\\\n',...
    '\hspace{.1cm}$\times$ Begin Treatment' ,RESULTS_U1(7,1),RESULTS_U1(7,2));
fprintf(fid, '%s   & %7.2f & %7.2f & . & .   \\\\\n',...
    '\hspace{.1cm}$\times$ Change Treatment',RESULTS_U1(8,1),RESULTS_U1(8,2));
fprintf(fid, '%s   & %7.2f & %7.2f & . & .   \\\\\n',...
    '\hspace{.1cm}$\times$ End Treatment'   ,RESULTS_U1(9,1),RESULTS_U1(9,2));
fprintf(fid, '\\hline\\hline \n');
fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '\\end{center} \n');
fprintf(fid, '\\vspace{-.4cm} \n');
fprintf(fid, ['\\caption*{',opt.captionstar,'Estimated utility parameters $(\\theta^{U})$. Recall that for latent preference Type I, the disutility of work is sensitive to ailments.  For latent health Type I, HAART is more effective, but entails harsher side effects.} \n']);
fprintf(fid, '\\end{table} \n');
fprintf(fid, ' \n');
fclose(fid);

% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
% TYPES
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %

opt.resultsfolder = '../ARTWORK';
opt.summstatsfile = 'parameststypes';
opt.captionstar   = '';
thetexfile     = strcat(opt.resultsfolder,'/',opt.summstatsfile,'.tex');
fid = fopen(thetexfile, 'w');
clear thetexfile 

fprintf(fid, '\\begin{table}[htbp] \n');
fprintf(fid, '\\caption{\\label{parameststypes}\\textsc{Structural Parameter Estimates: Type Probabilities}} \n');
fprintf(fid, '\\vspace{-.4cm} \n');
fprintf(fid, '\\begin{center} \n');
fprintf(fid, '\\small \n');
fprintf(fid, '\\begin{tabular}{l|cc|c} \n');
fprintf(fid, '\\hline\\hline \n');
fprintf(fid, '& \\multicolumn{2}{c|}{Latent Type (Preferences)} & \\\\ \n');
fprintf(fid, '& Type I & Type II & $\\Sigma$ \\\\ \n');
fprintf(fid, '\\hline \n');
fprintf(fid, '\\hline \n');
fprintf(fid, 'Latent Type: & & & \\\\ \n');
fprintf(fid, '(Transitions and Outcomes) & & & \\\\ \n');
fprintf(fid, '%s   & %7.3f  & %7.3f & %7.3f    \\\\\n',...
    'Type I',1-RESULTS_T(1,1)-RESULTS_T(2,1)-RESULTS_T(3,1),RESULTS_T(3,1),1-RESULTS_T(1,1)-RESULTS_T(2,1)-RESULTS_T(3,1)+RESULTS_T(3,1)) ;
fprintf(fid, '%s   & %7.3f  & %7.3f & %7.3f    \\\\\n',...
    'Type II',RESULTS_T(2,1),RESULTS_T(1,1), RESULTS_T(1,1)+RESULTS_T(2,1));
fprintf(fid, '\\hline \n');
fprintf(fid, '%s   & %7.3f  & %7.3f & %7.3f    \\\\\n',...
    '$\Sigma$',1-RESULTS_T(1,1)-RESULTS_T(2,1)-RESULTS_T(3,1)+RESULTS_T(2,1),RESULTS_T(3,1)+RESULTS_T(1,1),'');
fprintf(fid, '\\hline\\hline \n');
fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '\\end{center} \n');
fprintf(fid, '\\vspace{-.4cm} \n');
fprintf(fid, ['\\caption*{',opt.captionstar,'Estimated unconditional latent type probabilities $(\\pi^{K})$. Recall that for latent preference Type I, the disutility of work is sensitive to ailments.  For latent health Type I, HAART is more effective, but entails harsher side effects.} \n']);
fprintf(fid, '\\end{table} \n');
fprintf(fid, ' \n');
fclose(fid);

% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
% CD4 Increase
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %

paramest.table={...
    '\hspace{.1cm}High CD4 '...  
    '\hspace{.2cm}$\times$ Mono '...  
    '\hspace{.2cm}$\times$ Combo '...  
    '\hspace{.2cm}$\times$ HAART [Type I]'...  
    '\hspace{.2cm}$\times$ HAART [Type II]'...  
    '\hspace{.2cm}$\times$ Mono '...  
    '\hspace{.2cm}$\times$ Combo '...  
    '\hspace{.2cm}$\times$ HAART [Type I]'...  
    '\hspace{.2cm}$\times$ HAART [Type II]'...  
    '\hspace{.1cm}Time trend'...    
    '\hspace{.1cm}Constant'...    
    };
paramest1.table.values_1=[RESULTS_D1(1,1) ; RESULTS_D1(5:6,1) ; RESULTS_D2(2,1) ; RESULTS_D1(7,1) ; RESULTS_D1(2:3,1) ; RESULTS_D2(1,1) ; RESULTS_D1(4,1) ; RESULTS_D1(8:9,1) ] ;
paramest1.table.values_2=[RESULTS_D1(1,2) ; RESULTS_D1(5:6,2) ; RESULTS_D2(2,2) ; RESULTS_D1(7,2) ; RESULTS_D1(2:3,2) ; RESULTS_D2(1,2) ; RESULTS_D1(4,2) ; RESULTS_D1(8:9,2) ] ;
opt.resultsfolder = '../ARTWORK';
opt.summstatsfile = 'paramestsincrease';
opt.captionstar   = '';
thetexfile     = strcat(opt.resultsfolder,'/',opt.summstatsfile,'.tex');
fid = fopen(thetexfile, 'w');
clear thetexfile 

fprintf(fid, '\\begin{table}[htbp] \n');
fprintf(fid, '\\caption{\\label{paramestsincrease}\\textsc{Structural Parameter Estimates: CD4 Count Increase}} \n');
fprintf(fid, '\\vspace{-.4cm} \n');
fprintf(fid, '\\begin{center} \n');
fprintf(fid, '\\small \n');
fprintf(fid, '\\begin{tabular}{l|cc} \n');
fprintf(fid, '\\hline\\hline \n');
fprintf(fid, '\\multicolumn{1}{c}{Variables} & \\multicolumn{1}{c}{Coefficient} & \\multicolumn{1}{c}{Error} \\\\ \n');
fprintf(fid, '\\hline \n');
fprintf(fid, '\\hline \n');
fprintf(fid, '%s   & %7.2f  & %7.2f    \\\\\n',char(paramest.table(1)),...
    paramest1.table.values_1(1),...
    paramest1.table.values_2(1));
for var=2:5
fprintf(fid, '%s   & %7.2f & %7.2f    \\\\\n',char(paramest.table(var)),...
    paramest1.table.values_1(var),...
    paramest1.table.values_2(var));
end
fprintf(fid, '\\multicolumn{1}{l|}{\\hspace{.1cm}Low CD4} & \\multicolumn{1}{c}{.} & \\multicolumn{1}{c}{.} \\\\ \n');
for var=6:11
fprintf(fid, '%s   & %7.2f & %7.2f    \\\\\n',char(paramest.table(var)),...
    paramest1.table.values_1(var),...
    paramest1.table.values_2(var));
end
fprintf(fid, '\\hline\\hline \n');
fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '\\end{center} \n');
fprintf(fid, '\\vspace{-.4cm} \n');
fprintf(fid, ['\\caption*{',opt.captionstar,'Estimated coefficients for the process governing period by period CD4 count increasess $(\\theta^{\\Delta H})$. Recall that for latent preference Type I, the disutility of work is sensitive to ailments.  For latent health Type I, HAART is more effective, but entails harsher side effects.} \n']);
fprintf(fid, '\\end{table} \n');
fprintf(fid, ' \n');
fclose(fid);

% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
% Ailments Process
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %

paramest.table={...
    '\hspace{.1cm}High CD4 '...  
    '\hspace{.2cm}$\times$ Mono '...  
    '\hspace{.2cm}$\times$ Combo '...  
    '\hspace{.2cm}$\times$ HAART [Type I]'...  
    '\hspace{.2cm}$\times$ HAART [Type II]'...  
    '\hspace{.2cm}$\times$ Mono '...  
    '\hspace{.2cm}$\times$ Combo '...  
    '\hspace{.2cm}$\times$ HAART [Type I]'...  
    '\hspace{.2cm}$\times$ HAART [Type II]'...  
    '\hspace{.1cm}Time trend'...    
    '\hspace{.1cm}Constant'...    
    };
paramest1.table.values_1=[RESULTS_F1(1,1) ; RESULTS_F1(5:6,1) ; RESULTS_F2(2,1) ; RESULTS_F1(7,1) ; RESULTS_F1(2:3,1) ; RESULTS_F2(1,1) ; RESULTS_F1(4,1) ; RESULTS_F1(8:9,1) ] ;
paramest1.table.values_2=[RESULTS_F1(1,2) ; RESULTS_F1(5:6,2) ; RESULTS_F2(2,2) ; RESULTS_F1(7,2) ; RESULTS_F1(2:3,2) ; RESULTS_F2(1,2) ; RESULTS_F1(4,2) ; RESULTS_F1(8:9,2) ] ;
opt.resultsfolder = '../ARTWORK';
opt.summstatsfile = 'paramestsailments';
opt.captionstar   = '';
thetexfile     = strcat(opt.resultsfolder,'/',opt.summstatsfile,'.tex');
fid = fopen(thetexfile, 'w');
clear thetexfile 

fprintf(fid, '\\begin{table}[htbp] \n');
fprintf(fid, '\\caption{\\label{paramestsailments}\\textsc{Structural Parameter Estimates: Ailments}} \n');
fprintf(fid, '\\vspace{-.4cm} \n');
fprintf(fid, '\\begin{center} \n');
fprintf(fid, '\\small \n');
fprintf(fid, '\\begin{tabular}{l|cc} \n');
fprintf(fid, '\\hline\\hline \n');
fprintf(fid, '\\multicolumn{1}{c}{Variables} & \\multicolumn{1}{c}{Coefficient} & \\multicolumn{1}{c}{Error} \\\\ \n');
fprintf(fid, '\\hline \n');
fprintf(fid, '\\hline \n');
fprintf(fid, '%s   & %7.2f  & %7.2f    \\\\\n',char(paramest.table(1)),...
    paramest1.table.values_1(1),...
    paramest1.table.values_2(1));
for var=2:5
fprintf(fid, '%s   & %7.2f & %7.2f    \\\\\n',char(paramest.table(var)),...
    paramest1.table.values_1(var),...
    paramest1.table.values_2(var));
end
fprintf(fid, '\\multicolumn{1}{l|}{\\hspace{.1cm}Low CD4} & \\multicolumn{1}{c}{.} & \\multicolumn{1}{c}{.} \\\\ \n');
for var=6:11
fprintf(fid, '%s   & %7.2f & %7.2f    \\\\\n',char(paramest.table(var)),...
    paramest1.table.values_1(var),...
    paramest1.table.values_2(var));
end
fprintf(fid, '\\hline\\hline \n');
fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '\\end{center} \n');
fprintf(fid, '\\vspace{-.4cm} \n');
fprintf(fid, ['\\caption*{',opt.captionstar,'Estimated coefficients for the process governing whether the agents suffers ailments in the current period $(\\theta^{F})$. Recall that for latent preference Type I, the disutility of work is sensitive to ailments.  For latent health Type I, HAART is more effective, but entails harsher side effects.} \n']);
fprintf(fid, '\\end{table} \n');
fprintf(fid, ' \n');
fclose(fid);

% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
% CD4 Process
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %

paramest.table={...
    '\hspace{.1cm}High CD4 '...  
    '\hspace{.1cm}Predicted increase $\times$ Low CD4 '...  
    '\hspace{.1cm}Predicted increase $\times$ High CD4 '...  
    '\hspace{.1cm}Constant '...     
    };
paramest1.table.values_1=[RESULTS_H2(1:4,1)] ;
paramest1.table.values_2=[RESULTS_H2(1:4,2)] ;
paramest1.table.values_3=[RESULTS_H1(1:4,1)] ;
paramest1.table.values_4=[RESULTS_H1(1:4,2)] ;
opt.resultsfolder = '../ARTWORK';
opt.summstatsfile = 'paramestscd4';
opt.captionstar   = '';
thetexfile     = strcat(opt.resultsfolder,'/',opt.summstatsfile,'.tex');
fid = fopen(thetexfile, 'w');
clear thetexfile 

fprintf(fid, '\\begin{table}[htbp] \n');
fprintf(fid, '\\caption{\\label{paramestscd4}\\textsc{Structural Parameter Estimates: High CD4 at $t+1$}} \n');
fprintf(fid, '\\vspace{-.4cm} \n');
fprintf(fid, '\\begin{center} \n');
fprintf(fid, '\\small \n');
fprintf(fid, '\\begin{tabular}{l|cccc} \n');
fprintf(fid, '\\hline\\hline \n');
fprintf(fid, '\\multicolumn{1}{c}{} & \\multicolumn{2}{c}{Type I} & \\multicolumn{2}{c}{Type II} \\\\ \n');
fprintf(fid, '\\multicolumn{1}{c}{Variables} & \\multicolumn{1}{c}{Coefficient} & \\multicolumn{1}{c}{Error} & \\multicolumn{1}{c}{Coefficient} & \\multicolumn{1}{c}{Error} \\\\ \n');
fprintf(fid, '\\hline \n');
fprintf(fid, '\\hline \n');
fprintf(fid, '%s   & %7.2f  & %7.2f & %7.2f  & %7.2f    \\\\\n',char(paramest.table(1)),...
    paramest1.table.values_1(1),...
    paramest1.table.values_2(1),...
    paramest1.table.values_3(1),...
    paramest1.table.values_4(1));
for var=2:size(paramest1.table.values_1,1)
fprintf(fid, '%s   & %7.2f & %7.2f & %7.2f & %7.2f     \\\\\n',char(paramest.table(var)),...
    paramest1.table.values_1(var),...
    paramest1.table.values_2(var),...
    paramest1.table.values_3(var),...
    paramest1.table.values_4(var));
end
fprintf(fid, '\\hline\\hline \n');
fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '\\end{center} \n');
fprintf(fid, '\\vspace{-.4cm} \n');
fprintf(fid, ['\\caption*{',opt.captionstar,'Estimated coefficients for the process governing one-period-ahead CD4 count $(\\theta^H)$, where explanatory variables include the predicted likelihood of a CD4 increase as a function of current-period drug choices.  Recall that for latent preference Type I, the disutility of work is sensitive to ailments.  For latent health Type I, HAART is more effective, but entails harsher side effects.} \n']);
    fprintf(fid, '\\end{table} \n');
fprintf(fid, ' \n');
fclose(fid);

% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
% SURVIVAL
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %

paramest.table={...
    '\hspace{.1cm}High CD4 '...  
    '\hspace{.1cm}Age $\times$ high CD4 '...  
    '\hspace{.1cm}Age '...  
    '\hspace{.1cm}Constant '...  
    };
paramest1.table.values_1=RESULTS_B1(1:4,1)   ;      
paramest1.table.values_2=RESULTS_B1(1:4,2)   ;     
opt.resultsfolder = '../ARTWORK';
opt.summstatsfile = 'paramestssurvival';
opt.captionstar   = '';
thetexfile     = strcat(opt.resultsfolder,'/',opt.summstatsfile,'.tex');
fid = fopen(thetexfile, 'w');
clear thetexfile 

fprintf(fid, '\\begin{table}[htbp] \n');
fprintf(fid, '\\caption{\\label{paramestssurvival}\\textsc{Structural Parameter Estimates: Mortality}} \n');
fprintf(fid, '\\vspace{-.4cm} \n');
fprintf(fid, '\\begin{center} \n');
fprintf(fid, '\\small \n');
fprintf(fid, '\\begin{tabular}{l|cc} \n');
fprintf(fid, '\\hline\\hline \n');
fprintf(fid, '\\multicolumn{1}{c}{Variables} & \\multicolumn{1}{c}{Coefficient} & \\multicolumn{1}{c}{Error} \\\\ \n');
fprintf(fid, '\\hline \n');
fprintf(fid, '\\hline \n');
fprintf(fid, '%s   & %7.2f  & %7.2f    \\\\\n',char(paramest.table(1)),...
    paramest1.table.values_1(1),...
    paramest1.table.values_2(1));
for var=2:size(paramest1.table.values_1,1)
fprintf(fid, '%s   & %7.2f & %7.2f    \\\\\n',char(paramest.table(var)),...
    paramest1.table.values_1(var),...
    paramest1.table.values_2(var));
end
fprintf(fid, '\\hline\\hline \n');
fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '\\end{center} \n');
fprintf(fid, '\\vspace{-.4cm} \n');
fprintf(fid, ['\\caption*{',opt.captionstar,'Estimated coefficients of the mortality process $(\\theta^B)$.}\n']);
fprintf(fid, '\\end{table} \n');
fprintf(fid, ' \n');
fclose(fid);

% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
% INCOME
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %

paramest.table={...
    '\hspace{.1cm}High CD4 '...  
    '\hspace{.1cm}Experience '...  
    '\hspace{.1cm}Experience-squared '...  
    '\hspace{.1cm}Age '...  
    '\hspace{.1cm}Time Trend '...  
    '\hspace{.1cm}Full-time employment '...  
    '\hspace{.2cm}$\times$ High CD4 '...  
    '\hspace{.2cm}$\times$ Experience '...  
    '\hspace{.2cm}$\times$ Experience-squared '...  
    '\hspace{.2cm}$\times$ Age '...  
    '\hspace{.2cm}$\times$ Time trend '...      
    '\hspace{.1cm}Constant '...   
    '\hspace{.1cm}$\sigma_{I}^2$ '...       
    };
paramest1.table.values_1=RESULTS_I1(1:13,1)   ;      
paramest1.table.values_2=RESULTS_I1(1:13,2)   ;     
opt.resultsfolder = '../ARTWORK';
opt.summstatsfile = 'paramestsincome';
opt.captionstar   = '';
thetexfile     = strcat(opt.resultsfolder,'/',opt.summstatsfile,'.tex');
fid = fopen(thetexfile, 'w');
clear thetexfile 

fprintf(fid, '\\begin{table}[htbp] \n');
fprintf(fid, '\\caption{\\label{paramestsincome}\\textsc{Structural Parameter Estimates: Income}} \n');
fprintf(fid, '\\vspace{-.4cm} \n');
fprintf(fid, '\\begin{center} \n');
fprintf(fid, '\\small \n');
fprintf(fid, '\\begin{tabular}{l|cc} \n');
fprintf(fid, '\\hline\\hline \n');
fprintf(fid, '\\multicolumn{1}{c}{Variables} & \\multicolumn{1}{c}{Coefficient} & \\multicolumn{1}{c}{Error} \\\\ \n');
fprintf(fid, '\\hline \n');
fprintf(fid, '\\hline \n');
fprintf(fid, '%s   & %7.2f  & %7.2f    \\\\\n',char(paramest.table(1)),...
    paramest1.table.values_1(1),...
    paramest1.table.values_2(1));
for var=2:size(paramest1.table.values_1,1)
fprintf(fid, '%s   & %7.2f & %7.2f    \\\\\n',char(paramest.table(var)),...
    paramest1.table.values_1(var),...
    paramest1.table.values_2(var));
end
fprintf(fid, '\\hline\\hline \n');
fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '\\end{center} \n');
fprintf(fid, '\\vspace{-.4cm} \n');
fprintf(fid, ['\\caption*{',opt.captionstar,'Estimated coefficients of the income process $(\\theta^I)$.}\n']);
fprintf(fid, '\\end{table} \n');
fprintf(fid, ' \n');
fclose(fid);

% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
% Insurance
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %

paramest.table={...
    '\hspace{.1cm}Full-time employment '...  
    '\hspace{.1cm}High CD4 '...  
    '\hspace{.1cm}Experience '...  
    '\hspace{.1cm}Experience-squared '...  
    '\hspace{.1cm}Age '...  
    '\hspace{.1cm}Age-squared '...  
    '\hspace{.1cm}Time trend '...  
    '\hspace{.1cm}Time trend (post-HAART) '...  
    '\hspace{.1cm}Constant '...        
    };
paramest1.table.values_1=RESULTS_N1(1:9,1)   ;      
paramest1.table.values_2=RESULTS_N1(1:9,2)   ;     
paramest1.table.values_3=RESULTS_N1(10:18,1)   ;      
paramest1.table.values_4=RESULTS_N1(10:18,2)   ;     
opt.resultsfolder = '../ARTWORK';
opt.summstatsfile = 'paramestsinsurance';
opt.captionstar   = '';
thetexfile     = strcat(opt.resultsfolder,'/',opt.summstatsfile,'.tex');
fid = fopen(thetexfile, 'w');
clear thetexfile 

fprintf(fid, '\\begin{table}[htbp] \n');
fprintf(fid, '\\caption{\\label{paramestsinsurance}\\textsc{Structural Parameter Estimates: Insurance}} \n');
fprintf(fid, '\\vspace{-.4cm} \n');
fprintf(fid, '\\begin{center} \n');
fprintf(fid, '\\small \n');
fprintf(fid, '\\begin{tabular}{l|cc} \n');
fprintf(fid, '\\hline\\hline \n');
fprintf(fid, '\\multicolumn{1}{c}{Variables} & \\multicolumn{1}{c}{Coefficient} & \\multicolumn{1}{c}{Error} \\\\ \n');
fprintf(fid, '\\hline \n');
fprintf(fid, '\\hline \n');
fprintf(fid, '\\textit{Private Insurance Only} \\\\ \n');
fprintf(fid, '%s   & %7.2f  & %7.2f    \\\\\n',char(paramest.table(1)),...
    paramest1.table.values_1(1),...
    paramest1.table.values_2(1));
for var=2:size(paramest1.table.values_1,1)
fprintf(fid, '%s   & %7.2f & %7.2f    \\\\\n',char(paramest.table(var)),...
    paramest1.table.values_1(var),...
    paramest1.table.values_2(var));
end
fprintf(fid, '\\hline \n');
fprintf(fid, '\\textit{Public Only or Public \\& Private}\\\\ \n');
fprintf(fid, '%s   & %7.2f  & %7.2f    \\\\\n',char(paramest.table(1)),...
    paramest1.table.values_3(1),...
    paramest1.table.values_4(1));
for var=2:size(paramest1.table.values_1,1)
fprintf(fid, '%s   & %7.2f & %7.2f    \\\\\n',char(paramest.table(var)),...
    paramest1.table.values_3(var),...
    paramest1.table.values_4(var));
end
fprintf(fid, '\\hline\\hline \n');
fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '\\end{center} \n');
fprintf(fid, '\\vspace{-.4cm} \n');
fprintf(fid, ['\\caption*{',opt.captionstar,'Estimated coefficients of the insurance provision process $(\\theta^N)$.}\n']);
fprintf(fid, '\\end{table} \n');
fprintf(fid, ' \n');
fclose(fid);

% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
% Out of Pocket Payments
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %

paramest.table={...
    '\hspace{.1cm}High CD4 '...  
    '\hspace{.1cm}High CD4 with Ailments '...  
    '\hspace{.1cm}Low CD4 with Ailments '...  
    '\hspace{.1cm}Income '...  
    '\hspace{.1cm}Mono '...  
    '\hspace{.1cm}Combo '...  
    '\hspace{.1cm}HAART '...  
    '\hspace{.1cm}Private'...  
    '\hspace{.2cm}$\times$ Mono '...  
    '\hspace{.2cm}$\times$ Combo '...  
    '\hspace{.2cm}$\times$ HAART '...  
    '\hspace{.1cm}Public '...  
    '\hspace{.2cm}$\times$ Mono '...  
    '\hspace{.2cm}$\times$ Combo '...  
    '\hspace{.2cm}$\times$ HAART '...  
    '\hspace{.2cm}Time trend '...  
    '\hspace{.2cm}Constant '...  
    '\hspace{.2cm}$\sigma_{p}^2$ '...          
    };
paramest1.table.values_1=RESULTS_P1(1:18,1)   ;      
paramest1.table.values_2=RESULTS_P1(1:18,2)   ;     
opt.resultsfolder = '../ARTWORK';
opt.summstatsfile = 'paramestspayment';
opt.captionstar   = '';
thetexfile     = strcat(opt.resultsfolder,'/',opt.summstatsfile,'.tex');
fid = fopen(thetexfile, 'w');
clear thetexfile 

fprintf(fid, '\\begin{table}[htbp] \n');
fprintf(fid, '\\caption{\\label{paramestspayment}\\textsc{Structural Parameter Estimates: Out-of-Pocket Treatment Costs}} \n');
fprintf(fid, '\\vspace{-.4cm} \n');
fprintf(fid, '\\begin{center} \n');
fprintf(fid, '\\small \n');
fprintf(fid, '\\begin{tabular}{l|cc} \n');
fprintf(fid, '\\hline\\hline \n');
fprintf(fid, '\\multicolumn{1}{c}{Variables} & \\multicolumn{1}{c}{Coefficient} & \\multicolumn{1}{c}{Error} \\\\ \n');
fprintf(fid, '\\hline \n');
fprintf(fid, '\\hline \n');
fprintf(fid, '%s   & %7.2f  & %7.2f    \\\\\n',char(paramest.table(1)),...
    paramest1.table.values_1(1),...
    paramest1.table.values_2(1));
for var=2:size(paramest1.table.values_1,1)
fprintf(fid, '%s   & %7.2f & %7.2f    \\\\\n',char(paramest.table(var)),...
    paramest1.table.values_1(var),...
    paramest1.table.values_2(var));
end
fprintf(fid, '\\hline\\hline \n');
fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '\\end{center} \n');
fprintf(fid, '\\vspace{-.4cm} \n');
fprintf(fid, ['\\caption*{',opt.captionstar,'Estimated coefficients of the out-of-pocket payment process $(\\theta^p)$.}\n']);
fprintf(fid, '\\end{table} \n');
fprintf(fid, ' \n');
fclose(fid);

display 'End Program if MODEL=5, only for ERRORS/TABLES'

return % END THE PROGRAM IF MODEL=5.

end







%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%11.2   POSTERIOR

if L==0
    post_type=ones(I,1);
else
    post_type=G_POSTERIOR(th_ml);
    post_type(isnan(post_type)==1)=0;
    posterior_stata=[obs ind v_it A_it post_type];
    cd ..
    csvwrite('Simulations/SIM_POST/posterior_stata.csv', posterior_stata);
    cd('Matlab')
end
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

 
%12     BASIC MODEL FIT: STATE VARS AS GIVEN & COMPUTE CHOICE PROBABILITIES

%12.1   CREATE "LARGE" DATASET (REPLICATE ORIGINAL) FOR SIMULATION

sim1_data= [drugs(:,6) drugs(:,9) drugs(:,29) drugs(:,7) drugs(:,10)]; 
sim1_data=repmat(sim1_data,10,1);
N_sim=length(sim1_data);


v_it_sim1   =sim1_data(:,1);
E_it_sim1   =sim1_data(:,2);
d_it_m_sim1 =sim1_data(:,3);
H_it_sim1   =sim1_data(:,4);
A_it_sim1   =sim1_data(:,5);
a_sim1=(A_it_sim1-30)*2+1;


rand('state',0)
rand_u=rand(N_sim,1);
type=zeros(N_sim,1);



%12.2   OBTAIN CHOICE PROBABILITIES FROM D_DPP USING th_ml

LL_FV=B_LL(th_ml)
CCP=D_DPP(th_ml);
CCP=CCP(:,1:70,:);
size(CCP)


%12.3   ASSIGN CHOICE PROBABILITIES FOR EACH STATE VAR COMBO IN SIMDATA


sim1_data_L=zeros(N_sim,L);
sim1_data_M=zeros(N_sim,L);

for type=1:L

dM0L0=zeros(N_sim,1);
dM1L0=zeros(N_sim,1);
dM2L0=zeros(N_sim,1);
dM3L0=zeros(N_sim,1);
dM0L1=zeros(N_sim,1);
dM1L1=zeros(N_sim,1);
dM2L1=zeros(N_sim,1);
dM3L1=zeros(N_sim,1);
    
SIM_d_it1_m=zeros(N_sim,1);
SIM_d_it1_l=zeros(N_sim,1);

 for j=1:N_sim

    j
    
    if v_it_sim1(j,1)<=23
    
dM0L0(j,1)=CCP(E_INDSM(v_it_sim1(j,1),E_it_sim1(j,1),d_it_m_sim1(j,1),0,0,H_it_sim1(j,1)),a_sim1(j,1),type);
dM0L1(j,1)=CCP(E_INDSM(v_it_sim1(j,1),E_it_sim1(j,1),d_it_m_sim1(j,1),1,0,H_it_sim1(j,1)),a_sim1(j,1),type)+dM0L0(j,1);

dM1L0(j,1)=CCP(E_INDSM(v_it_sim1(j,1),E_it_sim1(j,1),d_it_m_sim1(j,1),0,1,H_it_sim1(j,1)),a_sim1(j,1),type)+dM0L1(j,1);
dM1L1(j,1)=CCP(E_INDSM(v_it_sim1(j,1),E_it_sim1(j,1),d_it_m_sim1(j,1),1,1,H_it_sim1(j,1)),a_sim1(j,1),type)+dM1L0(j,1);

dM2L0(j,1)=CCP(E_INDSM(v_it_sim1(j,1),E_it_sim1(j,1),d_it_m_sim1(j,1),0,2,H_it_sim1(j,1)),a_sim1(j,1),type)+dM1L1(j,1);
dM2L1(j,1)=CCP(E_INDSM(v_it_sim1(j,1),E_it_sim1(j,1),d_it_m_sim1(j,1),1,2,H_it_sim1(j,1)),a_sim1(j,1),type)+dM2L0(j,1);
        



        if rand_u(j,1)<=dM0L0(j,1)
            SIM_d_it1_m(j,1)=0;
            SIM_d_it1_l(j,1)=0;

        elseif rand_u(j,1)>dM0L0(j,1) && rand_u(j,1)<=dM0L1(j,1)
            SIM_d_it1_m(j,1)=0;
            SIM_d_it1_l(j,1)=1;
            
        elseif rand_u(j,1)>dM0L1(j,1) && rand_u(j,1)<=dM1L0(j,1)
            SIM_d_it1_m(j,1)=1;
            SIM_d_it1_l(j,1)=0;
        
        elseif rand_u(j,1)>dM1L0(j,1) && rand_u(j,1)<=dM1L1(j,1)
            SIM_d_it1_m(j,1)=1;
            SIM_d_it1_l(j,1)=1;

        elseif rand_u(j,1)>dM1L1(j,1) && rand_u(j,1)<=dM2L0(j,1)
            SIM_d_it1_m(j,1)=2;
            SIM_d_it1_l(j,1)=0;
        
        elseif rand_u(j,1)>dM2L0(j,1) && rand_u(j,1)<=dM2L1(j,1)
            SIM_d_it1_m(j,1)=2;
            SIM_d_it1_l(j,1)=1;
            
        end

elseif v_it_sim1(j,1)>23
    
dM0L0(j,1)=CCP(E_INDSM(v_it_sim1(j,1),E_it_sim1(j,1),d_it_m_sim1(j,1),0,0,H_it_sim1(j,1)),a_sim1(j,1),type);
dM0L1(j,1)=CCP(E_INDSM(v_it_sim1(j,1),E_it_sim1(j,1),d_it_m_sim1(j,1),1,0,H_it_sim1(j,1)),a_sim1(j,1),type)+dM0L0(j,1);

dM1L0(j,1)=CCP(E_INDSM(v_it_sim1(j,1),E_it_sim1(j,1),d_it_m_sim1(j,1),0,1,H_it_sim1(j,1)),a_sim1(j,1),type)+dM0L1(j,1);
dM1L1(j,1)=CCP(E_INDSM(v_it_sim1(j,1),E_it_sim1(j,1),d_it_m_sim1(j,1),1,1,H_it_sim1(j,1)),a_sim1(j,1),type)+dM1L0(j,1);

dM2L0(j,1)=CCP(E_INDSM(v_it_sim1(j,1),E_it_sim1(j,1),d_it_m_sim1(j,1),0,2,H_it_sim1(j,1)),a_sim1(j,1),type)+dM1L1(j,1);
dM2L1(j,1)=CCP(E_INDSM(v_it_sim1(j,1),E_it_sim1(j,1),d_it_m_sim1(j,1),1,2,H_it_sim1(j,1)),a_sim1(j,1),type)+dM2L0(j,1);

dM3L0(j,1)=CCP(E_INDSM(v_it_sim1(j,1),E_it_sim1(j,1),d_it_m_sim1(j,1),0,3,H_it_sim1(j,1)),a_sim1(j,1),type)+dM2L1(j,1);
dM3L1(j,1)=CCP(E_INDSM(v_it_sim1(j,1),E_it_sim1(j,1),d_it_m_sim1(j,1),1,3,H_it_sim1(j,1)),a_sim1(j,1),type)+dM3L0(j,1);

        if rand_u(j,1)<=dM0L0(j,1)
            SIM_d_it1_m(j,1)=0;
            SIM_d_it1_l(j,1)=0;

        elseif rand_u(j,1)>dM0L0(j,1) && rand_u(j,1)<=dM0L1(j,1)
            SIM_d_it1_m(j,1)=0;
            SIM_d_it1_l(j,1)=1;
            
        elseif rand_u(j,1)>dM0L1(j,1) && rand_u(j,1)<=dM1L0(j,1)
            SIM_d_it1_m(j,1)=1;
            SIM_d_it1_l(j,1)=0;
        
        elseif rand_u(j,1)>dM1L0(j,1) && rand_u(j,1)<=dM1L1(j,1)
            SIM_d_it1_m(j,1)=1;
            SIM_d_it1_l(j,1)=1;
        
        elseif rand_u(j,1)>dM1L1(j,1) && rand_u(j,1)<=dM2L0(j,1)
            SIM_d_it1_m(j,1)=2;
            SIM_d_it1_l(j,1)=0;

        elseif rand_u(j,1)>dM2L0(j,1) && rand_u(j,1)<=dM2L1(j,1)
            SIM_d_it1_m(j,1)=2;
            SIM_d_it1_l(j,1)=1;
        
        elseif rand_u(j,1)>dM2L1(j,1) && rand_u(j,1)<=dM3L0(j,1)
            SIM_d_it1_m(j,1)=3;
            SIM_d_it1_l(j,1)=0;
            
        elseif rand_u(j,1)>dM3L0(j,1) && rand_u(j,1)<=dM3L1(j,1)
            SIM_d_it1_m(j,1)=3;
            SIM_d_it1_l(j,1)=1;
            
        end
    end
 
 
end


sim1_data_M(:,type) = SIM_d_it1_m;
sim1_data_L(:,type) = SIM_d_it1_l;

 
end

if L==1
    sim1_data = [sim1_data sim1_data_M sim1_data_L];

elseif L==2
    post_type=repmat(post_type,10,1);
sim1_data = [sim1_data sim1_data_M(:,1) sim1_data_L(:,1) sim1_data_M(:,2) sim1_data_L(:,2) post_type]; 

elseif L==4
    post_type=repmat(post_type,10,1);
sim1_data = [sim1_data sim1_data_M(:,1) sim1_data_L(:,1) sim1_data_M(:,2) sim1_data_L(:,2) sim1_data_M(:,3) sim1_data_L(:,3) sim1_data_M(:,4) sim1_data_L(:,4) post_type]; 

end

cd ..
csvwrite('Simulations/SIM1/sim1_stata.csv', sim1_data);
cd ('Matlab')






























%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%       SET PARAMETERS FOR ALL SIMULATION

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% start_visit=15;
start_visit=24;


if MODEL==1 || MODEL==2
    No_SIM_TYPES=1;
elseif MODEL==3    
    No_SIM_TYPES=2;
elseif MODEL==4
    No_SIM_TYPES=4;
end

th_ml_U1   =th_ml(1:LU1,1);      
th_ml_A1   =th_ml(LU1+1:LU1+LA1,1);      
th_ml_P1   =th_ml(LU1+LA1+1:LU1+LA1+LP1,1);      
th_ml_S1   =th_ml(LU1+LA1+LP1+1:LU1+LA1+LP1+LS1,1);      
th_ml_D1   =th_ml(LU1+LA1+LP1+LS1+1:LU1+LA1+LP1+LS1+LD1,1);   
th_ml_H1   =th_ml(LU1+LA1+LP1+LS1+LD1+1:LU1+LA1+LP1+LS1+LD1+LH1,1);
th_ml_F1   =th_ml(LU1+LA1+LP1+LS1+LD1+LH1+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1,1);
th_ml_B1   =th_ml(LU1+LA1+LP1+LS1+LD1+LH1+LF1+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1,1);
th_ml_I1   =th_ml(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1,1);
th_ml_N1   =th_ml(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1,1);

if L~=1

th_ml_T    =th_ml(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LT,1);     
th_T=C_TYPEP(th_ml_T);

th_ml_U2   =th_ml(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2,1);
th_ml_A2   =th_ml(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2,1);      
th_ml_P2   =th_ml(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2,1);       
th_ml_S2   =th_ml(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2,1);        
th_ml_D2   =th_ml(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2,1);        
th_ml_H2   =th_ml(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2+LH2,1);   
th_ml_F2   =th_ml(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2+LH2+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2+LH2+LF2,1);  
th_ml_B2   =th_ml(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2+LH2+LF2+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2+LH2+LF2+LB2,1);  
th_ml_I2   =th_ml(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2+LH2+LF2+LB2+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2+LH2+LF2+LB2+LI2,1);  
th_ml_N2   =th_ml(LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2+LH2+LF2+LB2+LI2+1:LU1+LA1+LP1+LS1+LD1+LH1+LF1+LB1+LI1+LN1+LT+LU2+LA2+LP2+LS2+LD2+LH2+LF2+LB2+LI2+LN2,1);  
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if No_SIM_TYPES==2

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Type I Preferences

theta0_U1=th_ml_U1;
theta0_A1=th_ml_A1;

% Type II Preferences

theta0_U2=th_ml_U1;
theta0_U2(1,1)=th_ml_U2(1,1);
theta0_U2(2,1)=th_ml_U2(2,1);
theta0_U2(3,1)=th_ml_U2(3,1);

theta0_A2=th_ml_A2;

% Type I Transitions

beta_p1      =drugs(:,41);
beta_D1      =drugs(:,42);
beta_H1      =drugs(:,43);
beta_F1      =drugs(:,44);
beta_B1      =drugs(:,45);
beta_I1      =drugs(:,46);
beta_N1      =drugs(:,47);

% Type II Transitions

beta_p2      =drugs(:,41);
beta_D2      =drugs(:,42);
beta_H2      =drugs(:,43);
beta_F2      =drugs(:,44);
beta_B2      =drugs(:,45);
beta_I2      =drugs(:,46);
beta_N2      =drugs(:,47);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

elseif No_SIM_TYPES==4

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        
% Type I Preferences

theta0_U1=th_ml_U1;
theta0_A1=th_ml_A1;

% Type II Preferences

theta0_U2=th_ml_U1;
theta0_U2(1,1)=th_ml_U2(1,1);
theta0_U2(2,1)=th_ml_U2(2,1);
theta0_U2(3,1)=th_ml_U2(3,1);

theta0_A2=th_ml_A2;

% Type I Transitions

beta_p1      =drugs(:,41);
beta_D1      =drugs(:,42);
beta_H1      =drugs(:,43);
beta_F1      =drugs(:,44);
beta_B1      =drugs(:,45);
beta_I1      =drugs(:,46);
beta_N1      =drugs(:,47);

% Type II Transitions

beta_p2      =drugs(:,41);
beta_D2      =drugs(:,42);
beta_H2      =drugs(:,43);
beta_F2      =drugs(:,44);
beta_B2      =drugs(:,45);
beta_I2      =drugs(:,46);
beta_N2      =drugs(:,47);

 
beta_H1(1:4,1)=th_ml_H1(1:4,1);
beta_H2(1:4,1)=th_ml_H2(1:4,1);

beta_D1(1:9,1)=th_ml_D1(1:9,1);
beta_D2(1:9,1)=th_ml_D1(1:9,1);
beta_D2(4,1)=th_ml_D2(1,1);
beta_D2(7,1)=th_ml_D2(2,1);

beta_F1(1:9,1)=th_ml_F1(1:9,1);
beta_F2(1:9,1)=th_ml_F1(1:9,1);
beta_F2(4,1)=th_ml_F2(1,1);
beta_F2(7,1)=th_ml_F2(2,1);

end 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
MODEL=2;
L=1;





LU1=length(theta0_U1);
LA1=length(theta0_A1);
LP1=0;
LS1=0;
LD1=0;
LH1=0;
LF1=0;
LB1=0;
LI1=0;
LN1=0;

LT=0;

LU2=0;
LA2=0;
LP2=0;
LS2=0;
LD2=0;
LH2=0;
LF2=0;
LB2=0;
LI2=0;
LN2=0;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if start_visit==15
display 'START AT VISIT 15'
load 'Z_DATASETS/drugs_sim15.csv'
drugs_sim=drugs_sim15;

elseif start_visit==24
display 'START AT VISIT 24'
load 'Z_DATASETS/drugs_sim24.csv'
drugs_sim=drugs_sim24;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
%14    FULL SIMULATION:     COUNTERFACTUAL T R E A T M N E N T S

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


display 'BEGIN: SIMULATION 2'
display 'NO HAART vs. HAART vs. CURE'
display 'NOTE: USE ALT 2 CODE - 1 TYPE'

%14.1   INITIAL DISTRIBUTION

for SIM_TYPE=1:No_SIM_TYPES
for SIM2=0:3

%SIM2=0: No Change 
%SIM2=1: HAART like Combo   
%SIM2=2: CHOICES: HAART HAART HAAART
%SIM2=3: CHOICES: HAART HAART+H HAART+F

SIM2_data= [drugs_sim(:,1) drugs_sim(:,2) drugs_sim(:,3) drugs_sim(:,4) drugs_sim(:,5)]; 
simstart=sortrows(SIM2_data,1);

N_0=sum(simstart(:,1)==start_visit);

simstart = simstart(1:N_0,:);
simstart = repmat(simstart,10,1);
N_0=length(simstart);
simstart = [simstart zeros(N_0,1)];
    

%Here: Define parameter Values for Different Types
%(Can alter both P and TP's)

if SIM_TYPE==1

th_ml=[theta0_U1;theta0_A1];      

beta_p      =beta_p1;
beta_D      =beta_D1; 
beta_H      =beta_H1; 
beta_F      =beta_F1; 
beta_B      =beta_B1; 
beta_I      =beta_I1; 
beta_N      =beta_N1;

elseif SIM_TYPE==2
    
th_ml=[theta0_U2;theta0_A2];      

beta_p      =beta_p1;
beta_D      =beta_D1; 
beta_H      =beta_H1; 
beta_F      =beta_F1; 
beta_B      =beta_B1; 
beta_I      =beta_I1; 
beta_N      =beta_N1;

elseif SIM_TYPE==3

th_ml=[theta0_U1;theta0_A1];      

beta_p      =beta_p2;
beta_D      =beta_D2; 
beta_H      =beta_H2; 
beta_F      =beta_F2; 
beta_B      =beta_B2; 
beta_I      =beta_I2; 
beta_N      =beta_N2;

elseif SIM_TYPE==4
    
th_ml=[theta0_U2;theta0_A2];      

beta_p      =beta_p2;
beta_D      =beta_D2; 
beta_H      =beta_H2; 
beta_F      =beta_F2; 
beta_B      =beta_B2; 
beta_I      =beta_I2; 
beta_N      =beta_N2;

end     
     
%14.2.1   OBTAIN CHOICE PROBABILITIES FROM D_DPP USING th_ml

if SIM2==0 % HAART (as-is)  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Change Parameters Here for CCP 
    

%No parameter changes


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif SIM2==1   % HAART like COMBO  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Change Parameters Here for CCP 
    
%HAART EFFECTIVE AS COMBO
beta_D(4,1)=beta_D(3,1);
beta_D(7,1)=beta_D(6,1);

%HAART SFX SAME AS COMBO
beta_F(4,1)=beta_F(3,1);
beta_F(7,1)=beta_F(6,1);

%HAART COSTS AS COMBO
beta_p(7,1)=beta_p(6,1);
beta_p(14,1)=beta_p(12,1);
beta_p(15,1)=beta_p(13,1);

%beta_I 
%beta_N
%beta_H 
%beta_B 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif SIM2==2  %Choices: Nothing HAART HAART HAART
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Replace Mono & Combo with HAART [Effectiveness]
beta_D(2,1)=beta_D(4,1);
beta_D(3,1)=beta_D(4,1);
beta_D(5,1)=beta_D(7,1);
beta_D(6,1)=beta_D(7,1);

%Replace Mono & Combo with HAART [SFX]
beta_F(2,1)=beta_F(4,1);
beta_F(3,1)=beta_F(4,1);
beta_F(5,1)=beta_F(7,1);
beta_F(6,1)=beta_F(7,1);

%Replace Mono & Combo with HAART [Costs]
beta_p(5,1)=beta_p(7,1);
beta_p(6,1)=beta_p(7,1);
beta_p(10,1)=beta_p(14,1);
beta_p(11,1)=beta_p(15,1);
beta_p(12,1)=beta_p(14,1);
beta_p(13,1)=beta_p(15,1);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif SIM2==3  %Choices: Nothing HAART HAART+H HAART+F
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Replace Mono & Combo with HAART [Effectiveness]
beta_D(2,1)=beta_D(4,1);
beta_D(3,1)=beta_D(4,1);
beta_D(5,1)=beta_D(7,1);
beta_D(6,1)=beta_D(7,1);

%Replace Mono & Combo with HAART [SFX]
beta_F(2,1)=beta_F(4,1);
beta_F(3,1)=beta_F(4,1);
beta_F(5,1)=beta_F(7,1);
beta_F(6,1)=beta_F(7,1);

%EFFECTIVENESS BOOST w. SFX
beta_D(3,1)=1.5;
beta_D(6,1)=1.5;


%NO SFX BOOST w. SAME EFFECTIVENESS
beta_F(4,1)=0;
beta_F(7,1)=0;

%HAART+ Cost = Cost of HAART
beta_p(5,1)=beta_p(7,1);
beta_p(6,1)=beta_p(7,1);
beta_p(10,1)=beta_p(14,1);
beta_p(11,1)=beta_p(15,1);
beta_p(12,1)=beta_p(14,1);
beta_p(13,1)=beta_p(15,1);

%beta_I 
%beta_N
%beta_H 
%beta_B 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

end

LL_FV=B_LL(th_ml)
CCP=D_DPP(th_ml);
CCP=CCP(:,1:71,:);

%14.3   SIMULATIONS VISITS 15-40

simdata=zeros(N_0,14);

%(create a false "vis -1" to start algorithm)
simdata(:,1)=simstart(:,1)-1;
simdata(:,9:14)=simstart;

clear simstart

sv=start_visit;
for v=sv:39

display 'visit'

        v

    simtemp=simdata((((v-sv)*N_0)+1):((v+1-sv)*N_0),:);    
    simtemp(:,1)=sv;
    simtemp(:,1:6)=simtemp(:,9:14);
    
    v_it_SIM2   =simtemp(:,1);
    E_it_SIM2   =simtemp(:,2);
    d_it_m_SIM2 =simtemp(:,3);
    H_it_SIM2   =simtemp(:,4);
    A_it_SIM2   =simtemp(:,5);
    a_SIM2=(A_it_SIM2-30)*2+1;
    

    
%Columns for simtemp 
%--------------
%1   v_it
%2   E_it
%3   d_it_m
%4   H_it
%5   A_it
%6   B_it1
%--------------
%7   d_it1_L
%8   d_it1_M
%--------------
%9   v_it1
%10  E_it1
%11  d_it_m1
%12  H_it1
%13  A_it1
%14  B_it1
%--------------

%14.3.1   SIMULATE CHOICE: P(d_it+1 | s_it)

for j=1:N_0 

%     j
    
simtemp(j,7)=0;    
simtemp(j,8)=0;   
    
u=rand(1,1);  
 
if v<=23
cccp=zeros(1,6);
    
cccp(1,1)=CCP(E_INDSM(v_it_SIM2(j,1),E_it_SIM2(j,1),d_it_m_SIM2(j,1),0,0,H_it_SIM2(j,1)),a_SIM2(j,1),1);
cccp(1,2)=CCP(E_INDSM(v_it_SIM2(j,1),E_it_SIM2(j,1),d_it_m_SIM2(j,1),0,1,H_it_SIM2(j,1)),a_SIM2(j,1),1)+cccp(1,1);
cccp(1,3)=CCP(E_INDSM(v_it_SIM2(j,1),E_it_SIM2(j,1),d_it_m_SIM2(j,1),0,2,H_it_SIM2(j,1)),a_SIM2(j,1),1)+cccp(1,2);
cccp(1,4)=CCP(E_INDSM(v_it_SIM2(j,1),E_it_SIM2(j,1),d_it_m_SIM2(j,1),1,0,H_it_SIM2(j,1)),a_SIM2(j,1),1)+cccp(1,3);
cccp(1,5)=CCP(E_INDSM(v_it_SIM2(j,1),E_it_SIM2(j,1),d_it_m_SIM2(j,1),1,1,H_it_SIM2(j,1)),a_SIM2(j,1),1)+cccp(1,4);
cccp(1,6)=CCP(E_INDSM(v_it_SIM2(j,1),E_it_SIM2(j,1),d_it_m_SIM2(j,1),1,2,H_it_SIM2(j,1)),a_SIM2(j,1),1)+cccp(1,5);


if u>=0 && u<cccp(1,1)
simtemp(j,7)=0;
simtemp(j,8)=0;
elseif u>=cccp(1,1) && u<cccp(1,2)
simtemp(j,7)=0;
simtemp(j,8)=1;
elseif u>=cccp(1,2) && u<cccp(1,3)
simtemp(j,7)=0;
simtemp(j,8)=2;
elseif u>=cccp(1,3) && u<cccp(1,4)
simtemp(j,7)=1;
simtemp(j,8)=0;
elseif u>=cccp(1,4) && u<cccp(1,5)
simtemp(j,7)=1;
simtemp(j,8)=1;
elseif u>=cccp(1,5) && u<cccp(1,6)
simtemp(j,7)=1;
simtemp(j,8)=2;
end


elseif v>23
cccp=zeros(1,8);

cccp(1,1)=CCP(E_INDSM(v_it_SIM2(j,1),E_it_SIM2(j,1),d_it_m_SIM2(j,1),0,0,H_it_SIM2(j,1)),a_SIM2(j,1),1);
cccp(1,2)=CCP(E_INDSM(v_it_SIM2(j,1),E_it_SIM2(j,1),d_it_m_SIM2(j,1),0,1,H_it_SIM2(j,1)),a_SIM2(j,1),1)+cccp(1,1);
cccp(1,3)=CCP(E_INDSM(v_it_SIM2(j,1),E_it_SIM2(j,1),d_it_m_SIM2(j,1),0,2,H_it_SIM2(j,1)),a_SIM2(j,1),1)+cccp(1,2);
cccp(1,4)=CCP(E_INDSM(v_it_SIM2(j,1),E_it_SIM2(j,1),d_it_m_SIM2(j,1),0,3,H_it_SIM2(j,1)),a_SIM2(j,1),1)+cccp(1,3);
cccp(1,5)=CCP(E_INDSM(v_it_SIM2(j,1),E_it_SIM2(j,1),d_it_m_SIM2(j,1),1,0,H_it_SIM2(j,1)),a_SIM2(j,1),1)+cccp(1,4);
cccp(1,6)=CCP(E_INDSM(v_it_SIM2(j,1),E_it_SIM2(j,1),d_it_m_SIM2(j,1),1,1,H_it_SIM2(j,1)),a_SIM2(j,1),1)+cccp(1,5);
cccp(1,7)=CCP(E_INDSM(v_it_SIM2(j,1),E_it_SIM2(j,1),d_it_m_SIM2(j,1),1,2,H_it_SIM2(j,1)),a_SIM2(j,1),1)+cccp(1,6);
cccp(1,8)=CCP(E_INDSM(v_it_SIM2(j,1),E_it_SIM2(j,1),d_it_m_SIM2(j,1),1,3,H_it_SIM2(j,1)),a_SIM2(j,1),1)+cccp(1,7); 


if u>=0 && u<cccp(1,1)
simtemp(j,7)=0;
simtemp(j,8)=0;
elseif u>=cccp(1,1) && u<cccp(1,2)
simtemp(j,7)=0;
simtemp(j,8)=1;
elseif u>=cccp(1,2) && u<cccp(1,3)
simtemp(j,7)=0;
simtemp(j,8)=2;
elseif u>=cccp(1,3) && u<cccp(1,4)
simtemp(j,7)=0;
simtemp(j,8)=3;
elseif u>=cccp(1,4) && u<cccp(1,5)
simtemp(j,7)=1;
simtemp(j,8)=0;
elseif u>=cccp(1,5) && u<cccp(1,6)
simtemp(j,7)=1;
simtemp(j,8)=1;
elseif u>=cccp(1,6) && u<cccp(1,7)
simtemp(j,7)=1;
simtemp(j,8)=2;
elseif u>=cccp(1,7)
simtemp(j,7)=1;
simtemp(j,8)=3;
end

end
end

%14.3.2   SIMULATE TRANSITION: P(s_i,t+1 | s_it, d_i,t+1)

%Beta's are already changed...
%Need to recalculate P_B and P_H

th_D1=beta_D(1:9,1)
th_H1=beta_H(1:4,1)
th_F1=beta_F(1:9,1)

ttp=zeros(1,3);

for j=1:N_0
    
%     j
    
a_SIM2=(simtemp(j,5)-30)*2+1; 

PB=TP(E_INDSM(v_it_SIM2(j,1),E_it_SIM2(j,1),d_it_m_SIM2(j,1),simtemp(j,7),simtemp(j,8),H_it_SIM2(j,1)),15,a_SIM2(1,1));

%TP for this iteration
TPa=TP(:,:,a_SIM2(1,1));  

TP_v        =TPa(:,1);    
TP_dh       =TPa(:,2);
TP_H        =TPa(:,3);    
TP_E        =TPa(:,4);    
TP_dl0_1    =TPa(:,5);
TP_dl1_1    =TPa(:,6);
TP_dm0_0    =TPa(:,7);
TP_dm1_0    =TPa(:,8);
TP_dm2_0    =TPa(:,9);
TP_dm3_0    =TPa(:,10);
TP_dm0_1    =TPa(:,11);
TP_dm1_1    =TPa(:,12);
TP_dm2_1    =TPa(:,13);
TP_dm3_1    =TPa(:,14);

PP_B        =TPa(:,15);
PP_H        =TPa(:,16);
PP_F        =TPa(:,17);

EE_I         =TPa(:,18);

EE_N1        =TPa(:,19);
EE_N2        =TPa(:,20);

EE_IP    =(EE_I+2500)/5000;


XB_D=...
    th_D1(1,1)*TP_H+...
    th_D1(2,1)*times((1-TP_H),TP_dm1_1)+...
    th_D1(3,1)*times((1-TP_H),TP_dm2_1)+...
    th_D1(4,1)*times((1-TP_H),TP_dm3_1)+...
    th_D1(5,1)*times((TP_H)  ,TP_dm1_1)+...
    th_D1(6,1)*times((TP_H)  ,TP_dm2_1)+...
    th_D1(7,1)*times((TP_H)  ,TP_dm3_1)+...
    th_D1(8,1)*TP_v+...
    th_D1(9,1);

DH=exp(XB_D);
DH=times(DH,power((1+DH),-1));
DH0=times(DH,(1-TP_H));
DH1=times(DH,(TP_H));

XB_H=...
    th_H1(1,1)*TP_H+...
    th_H1(2,1)*DH0+...
    th_H1(3,1)*DH1+...
    th_H1(4,1);

P_H=exp(XB_H);
P_H=times(P_H,power((1+P_H),-1));

ProbH=P_H(E_INDSM(v_it_SIM2(j,1),E_it_SIM2(j,1),d_it_m_SIM2(j,1),simtemp(j,7),simtemp(j,8),H_it_SIM2(j,1)),1);



ttp(1,1)=(1-PB)*ProbH;
ttp(1,2)=(1-PB)*(1-ProbH);
ttp(1,3)=PB;

        u=rand(1,1);
    
if u>=0 && u<ttp(1,1)
simtemp(j,12) =1;
elseif u>=ttp(1,1) && u<ttp(1,1)+ttp(1,2)
simtemp(j,12) =0; 
else
simtemp(j,12)=0;
simtemp(j,14)=1;
end

% Death to Death
if  simtemp(j,6)==1
    simtemp(j,14)=1;
end

%Columns for simtemp 
%--------------
%1   v_it
%2   E_it
%3   d_it_m
%4   H_it
%5   A_it
%6   B_it1
%--------------
%7   d_it1_L
%8   d_it1_M
%--------------
%9   v_it1
%10  E_it1
%11  d_it_m1
%12  H_it1
%13  A_it1
%14  B_it1
%--------------

        u=rand(1,1);
    
%Experience
if simtemp(j,7)==0
simtemp(j,10)=simtemp(j,2);
elseif simtemp(j,7)==1 && simtemp(j,2)==50
simtemp(j,10)=50;
elseif simtemp(j,7)==1 && simtemp(j,2)<50 && u<=0.05
simtemp(j,10)=simtemp(j,2)+10;
elseif simtemp(j,7)==1 && simtemp(j,2)<50 && u>0.05
simtemp(j,10)=simtemp(j,2);
end

%Age
if simtemp(j,5)==65
simtemp(j,13)=65;
elseif simtemp(j,5)<65  
simtemp(j,13)=simtemp(j,5)+0.5;
end

%RETIREMENT
if simtemp(j,5)==65
    simtemp(j,7)=0;
end

%Visit
simtemp(j,9)=simtemp(j,1)+1;

%d_it_m1
simtemp(j,11)=simtemp(j,8);

end

%%%%%%%%%%%%%
    
    simdata=[simdata ; simtemp];

%%%%%%%%%%%%%    

end

%Drop unnecessary items...

clear simtemp
clear simstart
 
%Assign type and compile mixed dataset

N_sim=length(simdata);
SIM2_data=simdata(N_0+1:N_sim,:);


%NOW COMPUTE INCOME!

%Columns for simtemp 
%--------------
%1   v_it
%2   E_it
%3   d_it_m
%4   H_it
%5   A_it
%6   B_it1
%--------------
%7   d_it1_L
%8   d_it1_M
%--------------
%9   v_it1
%10  E_it1
%11  d_it_m1
%12  H_it1
%13  A_it1
%14  B_it1
%--------------

th_I1=beta_I(1:13,1); 
    
XB_I=...
    th_I1(1,1)*SIM2_data(:,4)+...                           %TP_H+...
    th_I1(2,1)*SIM2_data(:,2)+...                           %TP_E
    th_I1(3,1)*times(SIM2_data(:,2),SIM2_data(:,2))+...     %times(TP_E,TP_E)+...
    th_I1(4,1)*SIM2_data(:,5)+...                           %A+...
    th_I1(5,1)*(SIM2_data(:,1)-14)+...                      %(TP_v-14)+...
   (times(SIM2_data(:,7),...                                %TP_dl1_1,
   (th_I1(6,1)+...               
    th_I1(7,1)*SIM2_data(:,4)+...                           %TP_H+... 
    th_I1(8,1)*SIM2_data(:,2)+...                           %TP_E+...
    th_I1(9,1)*times(SIM2_data(:,2),SIM2_data(:,2))+...     %times(TP_E,TP_E)+...
    th_I1(10,1)*SIM2_data(:,5)+...                          %A+...
    th_I1(11,1)*(SIM2_data(:,1)-14))))+...                  %(TP_v-14))))+...
    th_I1(12,1);

sig=th_I1(13,1);

w=times((XB_I-2500),power(sig,-1));
phi_1=normpdf(w,0,1);  
phi_2=normcdf(w,0,1);  
E_I=(2500*(1-phi_2))+(times(phi_2,XB_I)+times(sig,phi_1)); %left censored; See C&T p541 
 
SIM2_data=[SIM2_data E_I];

%NOW COMPUTE AILMENTS!

th_F1=beta_F(1:9,1);


%Columns for simtemp 
%--------------
%1   v_it
%2   E_it
%3   d_it_m
%4   H_it
%5   A_it
%6   B_it1
%--------------
%7   d_it1_L
%8   d_it1_M
%--------------
%9   v_it1
%10  E_it1
%11  d_it_m1
%12  H_it1
%13  A_it1
%14  B_it1
%--------------

dm10=zeros(length(SIM2_data),1);
dm11=zeros(length(SIM2_data),1);
dm12=zeros(length(SIM2_data),1);
dm13=zeros(length(SIM2_data),1);

for j=1:length(SIM2_data)
if SIM2_data(j,8)==0
    dm10(j,1)=1;
elseif SIM2_data(j,8)==1
    dm11(j,1)=1;
elseif SIM2_data(j,8)==2
    dm12(j,1)=1;
elseif SIM2_data(j,8)==3
    dm13(j,1)=1;
end    
end

XB_F=...
    th_F1(1,1)*SIM2_data(:,4)+...  
    th_F1(2,1)*times((1-SIM2_data(:,4)),dm11)+...
    th_F1(3,1)*times((1-SIM2_data(:,4)),dm12)+...
    th_F1(4,1)*times((1-SIM2_data(:,4)),dm13)+...
    th_F1(5,1)*times((SIM2_data(:,4)),dm11)+...
    th_F1(6,1)*times((SIM2_data(:,4)),dm12)+...
    th_F1(7,1)*times((SIM2_data(:,4)),dm13)+...
    th_F1(8,1)*SIM2_data(:,1)+...
    th_F1(9,1);


P_F=exp(XB_F);
P_F=times(P_F,power((1+P_F),-1));

SIM2_data=[SIM2_data P_F];


cd ..    

if start_visit==15

if SIM2==0 && SIM_TYPE==1 
csvwrite('Simulations/SIM2/sim2_15_CF0_0_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_15_CF0_0_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_15_CF0_0_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_15_CF0_0_stata.csv', SIM2_data);
elseif SIM2==1 && SIM_TYPE==1
csvwrite('Simulations/SIM2/sim2_15_CF1_1_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_15_CF1_1_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_15_CF1_1_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_15_CF1_1_stata.csv', SIM2_data);
elseif SIM2==2 && SIM_TYPE==1
csvwrite('Simulations/SIM2/sim2_15_CF2_2_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_15_CF2_2_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_15_CF2_2_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_15_CF2_2_stata.csv', SIM2_data);
elseif SIM2==3 && SIM_TYPE==1
csvwrite('Simulations/SIM2/sim2_15_CF3_3_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_15_CF3_3_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_15_CF3_3_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_15_CF3_3_stata.csv', SIM2_data);
end

if No_SIM_TYPES==2
if SIM2==0 && SIM_TYPE==2
csvwrite('Simulations/SIM2/sim2_15_CF0_2_stata.csv', SIM2_data);
elseif SIM2==1 && SIM_TYPE==2
csvwrite('Simulations/SIM2/sim2_15_CF1_2_stata.csv', SIM2_data);
elseif SIM2==2 && SIM_TYPE==2
csvwrite('Simulations/SIM2/sim2_15_CF2_2_stata.csv', SIM2_data);
elseif SIM2==3 && SIM_TYPE==2
csvwrite('Simulations/SIM2/sim2_15_CF3_2_stata.csv', SIM2_data);
end
end

if No_SIM_TYPES==4
if SIM2==0 && SIM_TYPE==2
csvwrite('Simulations/SIM2/sim2_15_CF0_2_stata.csv', SIM2_data);
elseif SIM2==1 && SIM_TYPE==2
csvwrite('Simulations/SIM2/sim2_15_CF1_2_stata.csv', SIM2_data);
elseif SIM2==2 && SIM_TYPE==2
csvwrite('Simulations/SIM2/sim2_15_CF2_2_stata.csv', SIM2_data);
elseif SIM2==3 && SIM_TYPE==2
csvwrite('Simulations/SIM2/sim2_15_CF3_2_stata.csv', SIM2_data);
end

if SIM2==0 && SIM_TYPE==3
csvwrite('Simulations/SIM2/sim2_15_CF0_3_stata.csv', SIM2_data);
elseif SIM2==1 && SIM_TYPE==3
csvwrite('Simulations/SIM2/sim2_15_CF1_3_stata.csv', SIM2_data);
elseif SIM2==2 && SIM_TYPE==3
csvwrite('Simulations/SIM2/sim2_15_CF2_3_stata.csv', SIM2_data);
elseif SIM2==3 && SIM_TYPE==3
csvwrite('Simulations/SIM2/sim2_15_CF3_3_stata.csv', SIM2_data);
end

if SIM2==0 && SIM_TYPE==4
csvwrite('Simulations/SIM2/sim2_15_CF0_4_stata.csv', SIM2_data);
elseif SIM2==1 && SIM_TYPE==4
csvwrite('Simulations/SIM2/sim2_15_CF1_4_stata.csv', SIM2_data);
elseif SIM2==2 && SIM_TYPE==4
csvwrite('Simulations/SIM2/sim2_15_CF2_4_stata.csv', SIM2_data);
elseif SIM2==3 && SIM_TYPE==4
csvwrite('Simulations/SIM2/sim2_15_CF3_4_stata.csv', SIM2_data);
end
end

elseif start_visit==24

if SIM2==0 && SIM_TYPE==1
csvwrite('Simulations/SIM2/sim2_24_CF0_1_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_24_CF0_2_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_24_CF0_3_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_24_CF0_4_stata.csv', SIM2_data);
elseif SIM2==1 && SIM_TYPE==1
csvwrite('Simulations/SIM2/sim2_24_CF1_1_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_24_CF1_2_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_24_CF1_3_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_24_CF1_4_stata.csv', SIM2_data);
elseif SIM2==2 && SIM_TYPE==1
csvwrite('Simulations/SIM2/sim2_24_CF2_1_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_24_CF2_2_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_24_CF2_3_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_24_CF2_4_stata.csv', SIM2_data);
elseif SIM2==3 && SIM_TYPE==1
csvwrite('Simulations/SIM2/sim2_24_CF3_1_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_24_CF3_2_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_24_CF3_3_stata.csv', SIM2_data);
csvwrite('Simulations/SIM2/sim2_24_CF3_4_stata.csv', SIM2_data);
end

if No_SIM_TYPES==2
if SIM2==0 && SIM_TYPE==2
csvwrite('Simulations/SIM2/sim2_24_CF0_2_stata.csv', SIM2_data);
elseif SIM2==1 && SIM_TYPE==2
csvwrite('Simulations/SIM2/sim2_24_CF1_2_stata.csv', SIM2_data);
elseif SIM2==2 && SIM_TYPE==2
csvwrite('Simulations/SIM2/sim2_24_CF2_2_stata.csv', SIM2_data);
elseif SIM2==3 && SIM_TYPE==2
csvwrite('Simulations/SIM2/sim2_24_CF3_2_stata.csv', SIM2_data);
end
end

if No_SIM_TYPES==4
if SIM2==0 && SIM_TYPE==2
csvwrite('Simulations/SIM2/sim2_24_CF0_2_stata.csv', SIM2_data);
elseif SIM2==1 && SIM_TYPE==2
csvwrite('Simulations/SIM2/sim2_24_CF1_2_stata.csv', SIM2_data);
elseif SIM2==2 && SIM_TYPE==2
csvwrite('Simulations/SIM2/sim2_24_CF2_2_stata.csv', SIM2_data);
elseif SIM2==3 && SIM_TYPE==2
csvwrite('Simulations/SIM2/sim2_24_CF3_2_stata.csv', SIM2_data);
end

if SIM2==0 && SIM_TYPE==3
csvwrite('Simulations/SIM2/sim2_24_CF0_3_stata.csv', SIM2_data);
elseif SIM2==1 && SIM_TYPE==3
csvwrite('Simulations/SIM2/sim2_24_CF1_3_stata.csv', SIM2_data);
elseif SIM2==2 && SIM_TYPE==3
csvwrite('Simulations/SIM2/sim2_24_CF2_3_stata.csv', SIM2_data);
elseif SIM2==3 && SIM_TYPE==3
csvwrite('Simulations/SIM2/sim2_24_CF3_3_stata.csv', SIM2_data);
end

if SIM2==0 && SIM_TYPE==4
csvwrite('Simulations/SIM2/sim2_24_CF0_4_stata.csv', SIM2_data);
elseif SIM2==1 && SIM_TYPE==4
csvwrite('Simulations/SIM2/sim2_24_CF1_4_stata.csv', SIM2_data);
elseif SIM2==2 && SIM_TYPE==4
csvwrite('Simulations/SIM2/sim2_24_CF2_4_stata.csv', SIM2_data);
elseif SIM2==3 && SIM_TYPE==4
csvwrite('Simulations/SIM2/sim2_24_CF3_4_stata.csv', SIM2_data);
end
end

cd ('Matlab')

end

display 'END: Simulation'

end
end








%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
%15    FULL SIMULATION:     COUNTERFACTUAL N O N - W A G E   I N C O M E

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


display 'BEGIN: SIMULATION 3'
display 'LOWER NON-WAGE INCOME'
display 'NOTE: USE ALT 2 CODE - 1 TYPE'

%15.1   INITIAL DISTRIBUTION

for SIM_TYPE=1:No_SIM_TYPES
for SIM3=0:3

%SIM3=0: No Change 
%SIM3=1: LOWER INCOME FOR NON-WORKERS (0.75)   
%SIM3=2: LOWER INCOME FOR NON-WORKERS (0.50)  
%SIM3=3: LOWER INCOME FOR NON-WORKERS (0.25)

SIM3_data= [drugs_sim(:,1) drugs_sim(:,2) drugs_sim(:,3) drugs_sim(:,4) drugs_sim(:,5)]; 
simstart=sortrows(SIM3_data,1);

N_0=sum(simstart(:,1)==start_visit);

simstart = simstart(1:N_0,:);
simstart = repmat(simstart,10,1);
N_0=length(simstart);
simstart = [simstart zeros(N_0,1)];
    

%Here: Define parameter Values for Different Types
%(Can alter both P and TP's)

if SIM_TYPE==1

th_ml=[theta0_U1;theta0_A1];      

beta_p      =beta_p1;
beta_D      =beta_D1; 
beta_H      =beta_H1; 
beta_F      =beta_F1; 
beta_B      =beta_B1; 
beta_I      =beta_I1; 
beta_N      =beta_N1;

elseif SIM_TYPE==2
    
th_ml=[theta0_U2;theta0_A2];      

beta_p      =beta_p1;
beta_D      =beta_D1; 
beta_H      =beta_H1; 
beta_F      =beta_F1; 
beta_B      =beta_B1; 
beta_I      =beta_I1; 
beta_N      =beta_N1;

elseif SIM_TYPE==3

th_ml=[theta0_U1;theta0_A1];      

beta_p      =beta_p2;
beta_D      =beta_D2; 
beta_H      =beta_H2; 
beta_F      =beta_F2; 
beta_B      =beta_B2; 
beta_I      =beta_I2; 
beta_N      =beta_N2;

elseif SIM_TYPE==4
    
th_ml=[theta0_U2;theta0_A2];      

beta_p      =beta_p2;
beta_D      =beta_D2; 
beta_H      =beta_H2; 
beta_F      =beta_F2; 
beta_B      =beta_B2; 
beta_I      =beta_I2; 
beta_N      =beta_N2;

end     
     
%14.2.1   OBTAIN CHOICE PROBABILITIES FROM D_DPP USING th_ml

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if SIM3==0 % HAART (as-is)  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Change Parameters Here for CCP 
    
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif SIM3==1   % LOWER DISABILITY PAYMENTS  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Replace Mono & Combo with HAART [Effectiveness]
 

beta_I(6,1) =beta_I(6,1) +0.25*beta_I(12,1); 
beta_I(7,1) =beta_I(7,1) +0.25*beta_I(1,1); 
beta_I(8,1) =beta_I(8,1) +0.25*beta_I(2,1); 
beta_I(9,1) =beta_I(9,1) +0.25*beta_I(3,1); 
beta_I(10,1)=beta_I(10,1)+0.25*beta_I(4,1); 
beta_I(11,1)=beta_I(11,1)+0.25*beta_I(5,1); 

beta_I(1,1)=0.75*beta_I(1,1); 
beta_I(2,1)=0.75*beta_I(2,1); 
beta_I(3,1)=0.75*beta_I(3,1); 
beta_I(4,1)=0.75*beta_I(4,1); 
beta_I(5,1)=0.75*beta_I(5,1); 
beta_I(12,1)=0.75*beta_I(12,1); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif SIM3==2  %Choices: Nothing HAART HAART HAART
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 

beta_I(6,1) =beta_I(6,1) +0.5*beta_I(12,1); 
beta_I(7,1) =beta_I(7,1) +0.5*beta_I(1,1); 
beta_I(8,1) =beta_I(8,1) +0.5*beta_I(2,1); 
beta_I(9,1) =beta_I(9,1) +0.5*beta_I(3,1); 
beta_I(10,1)=beta_I(10,1)+0.5*beta_I(4,1); 
beta_I(11,1)=beta_I(11,1)+0.5*beta_I(5,1); 

beta_I(1,1)=0.5*beta_I(1,1); 
beta_I(2,1)=0.5*beta_I(2,1); 
beta_I(3,1)=0.5*beta_I(3,1); 
beta_I(4,1)=0.5*beta_I(4,1); 
beta_I(5,1)=0.5*beta_I(5,1); 
beta_I(12,1)=0.5*beta_I(12,1); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif SIM3==3  %Choices: Nothing HAART HAART+H HAART+F
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Replace Mono & Combo with HAART [Effectiveness]
 

beta_I(6,1) =beta_I(6,1) +0.75*beta_I(12,1); 
beta_I(7,1) =beta_I(7,1) +0.75*beta_I(1,1); 
beta_I(8,1) =beta_I(8,1) +0.75*beta_I(2,1); 
beta_I(9,1) =beta_I(9,1) +0.75*beta_I(3,1); 
beta_I(10,1)=beta_I(10,1)+0.75*beta_I(4,1); 
beta_I(11,1)=beta_I(11,1)+0.75*beta_I(5,1); 

beta_I(1,1)=0.25*beta_I(1,1); 
beta_I(2,1)=0.25*beta_I(2,1); 
beta_I(3,1)=0.25*beta_I(3,1); 
beta_I(4,1)=0.25*beta_I(4,1); 
beta_I(5,1)=0.25*beta_I(5,1); 
beta_I(12,1)=0.25*beta_I(12,1); 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

end

LL_FV=B_LL(th_ml)
CCP=D_DPP(th_ml);
CCP=CCP(:,1:71,:);

%14.3   SIMULATIONS VISITS 15-40

simdata=zeros(N_0,14);

%(create a false "vis -1" to start algorithm)
simdata(:,1)=simstart(:,1)-1;
simdata(:,9:14)=simstart;

clear simstart

sv=start_visit;
for v=sv:39

display 'visit'

        v

    simtemp=simdata((((v-sv)*N_0)+1):((v+1-sv)*N_0),:);    
    simtemp(:,1)=sv;
    simtemp(:,1:6)=simtemp(:,9:14);
    
    v_it_SIM3   =simtemp(:,1);
    E_it_SIM3   =simtemp(:,2);
    d_it_m_SIM3 =simtemp(:,3);
    H_it_SIM3   =simtemp(:,4);
    A_it_SIM3   =simtemp(:,5);
    a_SIM3=(A_it_SIM3-30)*2+1;
    

    
%Columns for simtemp 
%--------------
%1   v_it
%2   E_it
%3   d_it_m
%4   H_it
%5   A_it
%6   B_it1
%--------------
%7   d_it1_L
%8   d_it1_M
%--------------
%9   v_it1
%10  E_it1
%11  d_it_m1
%12  H_it1
%13  A_it1
%14  B_it1
%--------------

%14.3.1   SIMULATE CHOICE: P(d_it+1 | s_it)

for j=1:N_0 

%     j
    
simtemp(j,7)=0;    
simtemp(j,8)=0;   
    
u=rand(1,1);  
 
if v<=23
cccp=zeros(1,6);
    
cccp(1,1)=CCP(E_INDSM(v_it_SIM3(j,1),E_it_SIM3(j,1),d_it_m_SIM3(j,1),0,0,H_it_SIM3(j,1)),a_SIM3(j,1),1);
cccp(1,2)=CCP(E_INDSM(v_it_SIM3(j,1),E_it_SIM3(j,1),d_it_m_SIM3(j,1),0,1,H_it_SIM3(j,1)),a_SIM3(j,1),1)+cccp(1,1);
cccp(1,3)=CCP(E_INDSM(v_it_SIM3(j,1),E_it_SIM3(j,1),d_it_m_SIM3(j,1),0,2,H_it_SIM3(j,1)),a_SIM3(j,1),1)+cccp(1,2);
cccp(1,4)=CCP(E_INDSM(v_it_SIM3(j,1),E_it_SIM3(j,1),d_it_m_SIM3(j,1),1,0,H_it_SIM3(j,1)),a_SIM3(j,1),1)+cccp(1,3);
cccp(1,5)=CCP(E_INDSM(v_it_SIM3(j,1),E_it_SIM3(j,1),d_it_m_SIM3(j,1),1,1,H_it_SIM3(j,1)),a_SIM3(j,1),1)+cccp(1,4);
cccp(1,6)=CCP(E_INDSM(v_it_SIM3(j,1),E_it_SIM3(j,1),d_it_m_SIM3(j,1),1,2,H_it_SIM3(j,1)),a_SIM3(j,1),1)+cccp(1,5);


if u>=0 && u<cccp(1,1)
simtemp(j,7)=0;
simtemp(j,8)=0;
elseif u>=cccp(1,1) && u<cccp(1,2)
simtemp(j,7)=0;
simtemp(j,8)=1;
elseif u>=cccp(1,2) && u<cccp(1,3)
simtemp(j,7)=0;
simtemp(j,8)=2;
elseif u>=cccp(1,3) && u<cccp(1,4)
simtemp(j,7)=1;
simtemp(j,8)=0;
elseif u>=cccp(1,4) && u<cccp(1,5)
simtemp(j,7)=1;
simtemp(j,8)=1;
elseif u>=cccp(1,5) && u<cccp(1,6)
simtemp(j,7)=1;
simtemp(j,8)=2;
end


elseif v>23
cccp=zeros(1,8);

cccp(1,1)=CCP(E_INDSM(v_it_SIM3(j,1),E_it_SIM3(j,1),d_it_m_SIM3(j,1),0,0,H_it_SIM3(j,1)),a_SIM3(j,1),1);
cccp(1,2)=CCP(E_INDSM(v_it_SIM3(j,1),E_it_SIM3(j,1),d_it_m_SIM3(j,1),0,1,H_it_SIM3(j,1)),a_SIM3(j,1),1)+cccp(1,1);
cccp(1,3)=CCP(E_INDSM(v_it_SIM3(j,1),E_it_SIM3(j,1),d_it_m_SIM3(j,1),0,2,H_it_SIM3(j,1)),a_SIM3(j,1),1)+cccp(1,2);
cccp(1,4)=CCP(E_INDSM(v_it_SIM3(j,1),E_it_SIM3(j,1),d_it_m_SIM3(j,1),0,3,H_it_SIM3(j,1)),a_SIM3(j,1),1)+cccp(1,3);
cccp(1,5)=CCP(E_INDSM(v_it_SIM3(j,1),E_it_SIM3(j,1),d_it_m_SIM3(j,1),1,0,H_it_SIM3(j,1)),a_SIM3(j,1),1)+cccp(1,4);
cccp(1,6)=CCP(E_INDSM(v_it_SIM3(j,1),E_it_SIM3(j,1),d_it_m_SIM3(j,1),1,1,H_it_SIM3(j,1)),a_SIM3(j,1),1)+cccp(1,5);
cccp(1,7)=CCP(E_INDSM(v_it_SIM3(j,1),E_it_SIM3(j,1),d_it_m_SIM3(j,1),1,2,H_it_SIM3(j,1)),a_SIM3(j,1),1)+cccp(1,6);
cccp(1,8)=CCP(E_INDSM(v_it_SIM3(j,1),E_it_SIM3(j,1),d_it_m_SIM3(j,1),1,3,H_it_SIM3(j,1)),a_SIM3(j,1),1)+cccp(1,7); 


if u>=0 && u<cccp(1,1)
simtemp(j,7)=0;
simtemp(j,8)=0;
elseif u>=cccp(1,1) && u<cccp(1,2)
simtemp(j,7)=0;
simtemp(j,8)=1;
elseif u>=cccp(1,2) && u<cccp(1,3)
simtemp(j,7)=0;
simtemp(j,8)=2;
elseif u>=cccp(1,3) && u<cccp(1,4)
simtemp(j,7)=0;
simtemp(j,8)=3;
elseif u>=cccp(1,4) && u<cccp(1,5)
simtemp(j,7)=1;
simtemp(j,8)=0;
elseif u>=cccp(1,5) && u<cccp(1,6)
simtemp(j,7)=1;
simtemp(j,8)=1;
elseif u>=cccp(1,6) && u<cccp(1,7)
simtemp(j,7)=1;
simtemp(j,8)=2;
elseif u>=cccp(1,7)
simtemp(j,7)=1;
simtemp(j,8)=3;
end

end
end

%14.3.2   SIMULATE TRANSITION: P(s_i,t+1 | s_it, d_i,t+1)

%Beta's are already changed...
%Need to recalculate P_B and P_H

th_D1=beta_D(1:9,1)
th_H1=beta_H(1:4,1)
th_F1=beta_F(1:9,1)

ttp=zeros(1,3);

for j=1:N_0
    
%     j
    
a_SIM3=(simtemp(j,5)-30)*2+1; 

PB=TP(E_INDSM(v_it_SIM3(j,1),E_it_SIM3(j,1),d_it_m_SIM3(j,1),simtemp(j,7),simtemp(j,8),H_it_SIM3(j,1)),15,a_SIM3(1,1));

%TP for this iteration
TPa=TP(:,:,a_SIM3(1,1));  

TP_v        =TPa(:,1);    
TP_dh       =TPa(:,2);
TP_H        =TPa(:,3);    
TP_E        =TPa(:,4);    
TP_dl0_1    =TPa(:,5);
TP_dl1_1    =TPa(:,6);
TP_dm0_0    =TPa(:,7);
TP_dm1_0    =TPa(:,8);
TP_dm2_0    =TPa(:,9);
TP_dm3_0    =TPa(:,10);
TP_dm0_1    =TPa(:,11);
TP_dm1_1    =TPa(:,12);
TP_dm2_1    =TPa(:,13);
TP_dm3_1    =TPa(:,14);

PP_B        =TPa(:,15);
PP_H        =TPa(:,16);
PP_F        =TPa(:,17);

EE_I         =TPa(:,18);

EE_N1        =TPa(:,19);
EE_N2        =TPa(:,20);

EE_IP    =(EE_I+2500)/5000;


XB_D=...
    th_D1(1,1)*TP_H+...
    th_D1(2,1)*times((1-TP_H),TP_dm1_1)+...
    th_D1(3,1)*times((1-TP_H),TP_dm2_1)+...
    th_D1(4,1)*times((1-TP_H),TP_dm3_1)+...
    th_D1(5,1)*times((TP_H)  ,TP_dm1_1)+...
    th_D1(6,1)*times((TP_H)  ,TP_dm2_1)+...
    th_D1(7,1)*times((TP_H)  ,TP_dm3_1)+...
    th_D1(8,1)*TP_v+...
    th_D1(9,1);

DH=exp(XB_D);
DH=times(DH,power((1+DH),-1));
DH0=times(DH,(1-TP_H));
DH1=times(DH,(TP_H));

XB_H=...
    th_H1(1,1)*TP_H+...
    th_H1(2,1)*DH0+...
    th_H1(3,1)*DH1+...
    th_H1(4,1);

P_H=exp(XB_H);
P_H=times(P_H,power((1+P_H),-1));

ProbH=P_H(E_INDSM(v_it_SIM3(j,1),E_it_SIM3(j,1),d_it_m_SIM3(j,1),simtemp(j,7),simtemp(j,8),H_it_SIM3(j,1)),1);



ttp(1,1)=(1-PB)*ProbH;
ttp(1,2)=(1-PB)*(1-ProbH);
ttp(1,3)=PB;

        u=rand(1,1);
    
if u>=0 && u<ttp(1,1)
simtemp(j,12) =1;
elseif u>=ttp(1,1) && u<ttp(1,1)+ttp(1,2)
simtemp(j,12) =0; 
else
simtemp(j,12)=0;
simtemp(j,14)=1;
end

% Death to Death
if  simtemp(j,6)==1
    simtemp(j,14)=1;
end

%Columns for simtemp 
%--------------
%1   v_it
%2   E_it
%3   d_it_m
%4   H_it
%5   A_it
%6   B_it1
%--------------
%7   d_it1_L
%8   d_it1_M
%--------------
%9   v_it1
%10  E_it1
%11  d_it_m1
%12  H_it1
%13  A_it1
%14  B_it1
%--------------

        u=rand(1,1);
    
%Experience
if simtemp(j,7)==0
simtemp(j,10)=simtemp(j,2);
elseif simtemp(j,7)==1 && simtemp(j,2)==50
simtemp(j,10)=50;
elseif simtemp(j,7)==1 && simtemp(j,2)<50 && u<=0.05
simtemp(j,10)=simtemp(j,2)+10;
elseif simtemp(j,7)==1 && simtemp(j,2)<50 && u>0.05
simtemp(j,10)=simtemp(j,2);
end

%Age
if simtemp(j,5)==65
simtemp(j,13)=65;
elseif simtemp(j,5)<65  
simtemp(j,13)=simtemp(j,5)+0.5;
end

%RETIREMENT
if simtemp(j,5)==65
    simtemp(j,7)=0;
end

%Visit
simtemp(j,9)=simtemp(j,1)+1;

%d_it_m1
simtemp(j,11)=simtemp(j,8);

end

%%%%%%%%%%%%%
    
    simdata=[simdata ; simtemp];

%%%%%%%%%%%%%    

end

%Drop unnecessary items...

clear simtemp
clear simstart
 
%Assign type and compile mixed dataset

N_sim=length(simdata);
SIM3_data=simdata(N_0+1:N_sim,:);


%NOW COMPUTE INCOME!

%Columns for simtemp 
%--------------
%1   v_it
%2   E_it
%3   d_it_m
%4   H_it
%5   A_it
%6   B_it1
%--------------
%7   d_it1_L
%8   d_it1_M
%--------------
%9   v_it1
%10  E_it1
%11  d_it_m1
%12  H_it1
%13  A_it1
%14  B_it1
%--------------

th_I1=beta_I(1:13,1); 
    
XB_I=...
    th_I1(1,1)*SIM3_data(:,4)+...                           %TP_H+...
    th_I1(2,1)*SIM3_data(:,2)+...                           %TP_E
    th_I1(3,1)*times(SIM3_data(:,2),SIM3_data(:,2))+...     %times(TP_E,TP_E)+...
    th_I1(4,1)*SIM3_data(:,5)+...                           %A+...
    th_I1(5,1)*(SIM3_data(:,1)-14)+...                      %(TP_v-14)+...
   (times(SIM3_data(:,7),...                                %TP_dl1_1,
   (th_I1(6,1)+...               
    th_I1(7,1)*SIM3_data(:,4)+...                           %TP_H+... 
    th_I1(8,1)*SIM3_data(:,2)+...                           %TP_E+...
    th_I1(9,1)*times(SIM3_data(:,2),SIM3_data(:,2))+...     %times(TP_E,TP_E)+...
    th_I1(10,1)*SIM3_data(:,5)+...                          %A+...
    th_I1(11,1)*(SIM3_data(:,1)-14))))+...                  %(TP_v-14))))+...
    th_I1(12,1);

sig=th_I1(13,1);

w=times((XB_I-2500),power(sig,-1));
phi_1=normpdf(w,0,1);  
phi_2=normcdf(w,0,1);  
E_I=(2500*(1-phi_2))+(times(phi_2,XB_I)+times(sig,phi_1)); %left censored; See C&T p541 
 
SIM3_data=[SIM3_data E_I];

%NOW COMPUTE AILMENTS!

th_F1=beta_F(1:9,1);


%Columns for simtemp 
%--------------
%1   v_it
%2   E_it
%3   d_it_m
%4   H_it
%5   A_it
%6   B_it1
%--------------
%7   d_it1_L
%8   d_it1_M
%--------------
%9   v_it1
%10  E_it1
%11  d_it_m1
%12  H_it1
%13  A_it1
%14  B_it1
%--------------

dm10=zeros(length(SIM3_data),1);
dm11=zeros(length(SIM3_data),1);
dm12=zeros(length(SIM3_data),1);
dm13=zeros(length(SIM3_data),1);

for j=1:length(SIM3_data)
if SIM3_data(j,8)==0
    dm10(j,1)=1;
elseif SIM3_data(j,8)==1
    dm11(j,1)=1;
elseif SIM3_data(j,8)==2
    dm12(j,1)=1;
elseif SIM3_data(j,8)==3
    dm13(j,1)=1;
end    
end

XB_F=...
    th_F1(1,1)*SIM3_data(:,4)+...  
    th_F1(2,1)*times((1-SIM3_data(:,4)),dm11)+...
    th_F1(3,1)*times((1-SIM3_data(:,4)),dm12)+...
    th_F1(4,1)*times((1-SIM3_data(:,4)),dm13)+...
    th_F1(5,1)*times((SIM3_data(:,4)),dm11)+...
    th_F1(6,1)*times((SIM3_data(:,4)),dm12)+...
    th_F1(7,1)*times((SIM3_data(:,4)),dm13)+...
    th_F1(8,1)*SIM3_data(:,1)+...
    th_F1(9,1);


P_F=exp(XB_F);
P_F=times(P_F,power((1+P_F),-1));

SIM3_data=[SIM3_data P_F];

cd ..

if start_visit==15

if SIM3==0 && SIM_TYPE==1 
csvwrite('Simulations/SIM3/sim3_15_CF0_0_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_15_CF0_0_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_15_CF0_0_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_15_CF0_0_stata.csv', SIM3_data);
elseif SIM3==1 && SIM_TYPE==1
csvwrite('Simulations/SIM3/sim3_15_CF1_1_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_15_CF1_1_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_15_CF1_1_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_15_CF1_1_stata.csv', SIM3_data);
elseif SIM3==2 && SIM_TYPE==1
csvwrite('Simulations/SIM3/sim3_15_CF2_2_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_15_CF2_2_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_15_CF2_2_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_15_CF2_2_stata.csv', SIM3_data);
elseif SIM3==3 && SIM_TYPE==1
csvwrite('Simulations/SIM3/sim3_15_CF3_3_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_15_CF3_3_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_15_CF3_3_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_15_CF3_3_stata.csv', SIM3_data);
end

if No_SIM_TYPES==2
if SIM3==0 && SIM_TYPE==2
csvwrite('Simulations/SIM3/sim3_15_CF0_2_stata.csv', SIM3_data);
elseif SIM3==1 && SIM_TYPE==2
csvwrite('Simulations/SIM3/sim3_15_CF1_2_stata.csv', SIM3_data);
elseif SIM3==2 && SIM_TYPE==2
csvwrite('Simulations/SIM3/sim3_15_CF2_2_stata.csv', SIM3_data);
elseif SIM3==3 && SIM_TYPE==2
csvwrite('Simulations/SIM3/sim3_15_CF3_2_stata.csv', SIM3_data);
end
end

if No_SIM_TYPES==4
if SIM3==0 && SIM_TYPE==2
csvwrite('Simulations/SIM3/sim3_15_CF0_2_stata.csv', SIM3_data);
elseif SIM3==1 && SIM_TYPE==2
csvwrite('Simulations/SIM3/sim3_15_CF1_2_stata.csv', SIM3_data);
elseif SIM3==2 && SIM_TYPE==2
csvwrite('Simulations/SIM3/sim3_15_CF2_2_stata.csv', SIM3_data);
elseif SIM3==3 && SIM_TYPE==2
csvwrite('Simulations/SIM3/sim3_15_CF3_2_stata.csv', SIM3_data);
end

if SIM3==0 && SIM_TYPE==3
csvwrite('Simulations/SIM3/sim3_15_CF0_3_stata.csv', SIM3_data);
elseif SIM3==1 && SIM_TYPE==3
csvwrite('Simulations/SIM3/sim3_15_CF1_3_stata.csv', SIM3_data);
elseif SIM3==2 && SIM_TYPE==3
csvwrite('Simulations/SIM3/sim3_15_CF2_3_stata.csv', SIM3_data);
elseif SIM3==3 && SIM_TYPE==3
csvwrite('Simulations/SIM3/sim3_15_CF3_3_stata.csv', SIM3_data);
end

if SIM3==0 && SIM_TYPE==4
csvwrite('Simulations/SIM3/sim3_15_CF0_4_stata.csv', SIM3_data);
elseif SIM3==1 && SIM_TYPE==4
csvwrite('Simulations/SIM3/sim3_15_CF1_4_stata.csv', SIM3_data);
elseif SIM3==2 && SIM_TYPE==4
csvwrite('Simulations/SIM3/sim3_15_CF2_4_stata.csv', SIM3_data);
elseif SIM3==3 && SIM_TYPE==4
csvwrite('Simulations/SIM3/sim3_15_CF3_4_stata.csv', SIM3_data);
end
end

elseif start_visit==24

if SIM3==0 && SIM_TYPE==1
csvwrite('Simulations/SIM3/sim3_24_CF0_1_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_24_CF0_2_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_24_CF0_3_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_24_CF0_4_stata.csv', SIM3_data);
elseif SIM3==1 && SIM_TYPE==1
csvwrite('Simulations/SIM3/sim3_24_CF1_1_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_24_CF1_2_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_24_CF1_3_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_24_CF1_4_stata.csv', SIM3_data);
elseif SIM3==2 && SIM_TYPE==1
csvwrite('Simulations/SIM3/sim3_24_CF2_1_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_24_CF2_2_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_24_CF2_3_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_24_CF2_4_stata.csv', SIM3_data);
elseif SIM3==3 && SIM_TYPE==1
csvwrite('Simulations/SIM3/sim3_24_CF3_1_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_24_CF3_2_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_24_CF3_3_stata.csv', SIM3_data);
csvwrite('Simulations/SIM3/sim3_24_CF3_4_stata.csv', SIM3_data);
end

if No_SIM_TYPES==2
if SIM3==0 && SIM_TYPE==2
csvwrite('Simulations/SIM3/sim3_24_CF0_2_stata.csv', SIM3_data);
elseif SIM3==1 && SIM_TYPE==2
csvwrite('Simulations/SIM3/sim3_24_CF1_2_stata.csv', SIM3_data);
elseif SIM3==2 && SIM_TYPE==2
csvwrite('Simulations/SIM3/sim3_24_CF2_2_stata.csv', SIM3_data);
elseif SIM3==3 && SIM_TYPE==2
csvwrite('Simulations/SIM3/sim3_24_CF3_2_stata.csv', SIM3_data);
end
end

if No_SIM_TYPES==4
if SIM3==0 && SIM_TYPE==2
csvwrite('Simulations/SIM3/sim3_24_CF0_2_stata.csv', SIM3_data);
elseif SIM3==1 && SIM_TYPE==2
csvwrite('Simulations/SIM3/sim3_24_CF1_2_stata.csv', SIM3_data);
elseif SIM3==2 && SIM_TYPE==2
csvwrite('Simulations/SIM3/sim3_24_CF2_2_stata.csv', SIM3_data);
elseif SIM3==3 && SIM_TYPE==2
csvwrite('Simulations/SIM3/sim3_24_CF3_2_stata.csv', SIM3_data);
end

if SIM3==0 && SIM_TYPE==3
csvwrite('Simulations/SIM3/sim3_24_CF0_3_stata.csv', SIM3_data);
elseif SIM3==1 && SIM_TYPE==3
csvwrite('Simulations/SIM3/sim3_24_CF1_3_stata.csv', SIM3_data);
elseif SIM3==2 && SIM_TYPE==3
csvwrite('Simulations/SIM3/sim3_24_CF2_3_stata.csv', SIM3_data);
elseif SIM3==3 && SIM_TYPE==3
csvwrite('Simulations/SIM3/sim3_24_CF3_3_stata.csv', SIM3_data);
end

if SIM3==0 && SIM_TYPE==4
csvwrite('Simulations/SIM3/sim3_24_CF0_4_stata.csv', SIM3_data);
elseif SIM3==1 && SIM_TYPE==4
csvwrite('Simulations/SIM3/sim3_24_CF1_4_stata.csv', SIM3_data);
elseif SIM3==2 && SIM_TYPE==4
csvwrite('Simulations/SIM3/sim3_24_CF2_4_stata.csv', SIM3_data);
elseif SIM3==3 && SIM_TYPE==4
csvwrite('Simulations/SIM3/sim3_24_CF3_4_stata.csv', SIM3_data);
end
end

cd ('Matlab')

end

display 'END: Simulation'

end
end

 
 








%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
%16    FULL SIMULATION:     COUNTERFACTUAL T R E A T M N E N T  C O S T S

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


display 'BEGIN: SIMULATION C'
display 'LOWER TREATMENT SUBSIDIES'
display 'NOTE: USE ALT 2 CODE - 1 TYPE'

%14.1   INITIAL DISTRIBUTION

for SIM_TYPE=1:No_SIM_TYPES
for SIMC=0:3

%SIMC=0: No Change 
%SIMC=1: RAISE PRICE FOR HAART (1000)   
%SIMC=2: RAISE PRICE FOR HAART (3000) 
%SIMC=3: RAISE PRICE FOR HAART (6000)

SIMC_data= [drugs_sim(:,1) drugs_sim(:,2) drugs_sim(:,3) drugs_sim(:,4) drugs_sim(:,5)]; 
simstart=sortrows(SIMC_data,1);

N_0=sum(simstart(:,1)==start_visit);

simstart = simstart(1:N_0,:);
simstart = repmat(simstart,10,1);
N_0=length(simstart);
simstart = [simstart zeros(N_0,1)];
    

%Here: Define parameter Values for Different Types
%(Can alter both P and TP's)

if SIM_TYPE==1

th_ml=[theta0_U1;theta0_A1];      

beta_p      =beta_p1;
beta_D      =beta_D1; 
beta_H      =beta_H1; 
beta_F      =beta_F1; 
beta_B      =beta_B1; 
beta_I      =beta_I1; 
beta_N      =beta_N1;

elseif SIM_TYPE==2
    
th_ml=[theta0_U2;theta0_A2];      

beta_p      =beta_p1;
beta_D      =beta_D1; 
beta_H      =beta_H1; 
beta_F      =beta_F1; 
beta_B      =beta_B1; 
beta_I      =beta_I1; 
beta_N      =beta_N1;

elseif SIM_TYPE==3

th_ml=[theta0_U1;theta0_A1];      

beta_p      =beta_p2;
beta_D      =beta_D2; 
beta_H      =beta_H2; 
beta_F      =beta_F2; 
beta_B      =beta_B2; 
beta_I      =beta_I2; 
beta_N      =beta_N2;

elseif SIM_TYPE==4
    
th_ml=[theta0_U2;theta0_A2];      

beta_p      =beta_p2;
beta_D      =beta_D2; 
beta_H      =beta_H2; 
beta_F      =beta_F2; 
beta_B      =beta_B2; 
beta_I      =beta_I2; 
beta_N      =beta_N2;

end     
     
%14.2.1   OBTAIN CHOICE PROBABILITIES FROM D_DPP USING th_ml

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if SIMC==0          % HAART COSTS $300   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
beta_p(1:17,1)=zeros(17,1);
beta_p(18,1)=1;
beta_p(5,1)=0;
beta_p(6,1)=0;
beta_p(7,1)=0;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif SIMC==1      % HAART COSTS $1000  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

beta_p(10:15,1)=zeros(6,1);
beta_p(5,1)=250;
beta_p(6,1)=500;
beta_p(7,1)=1000;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif SIMC==2  % HAART COSTS $3000 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

beta_p(10:15,1)=zeros(6,1);
beta_p(5,1)=500;
beta_p(6,1)=1000;
beta_p(7,1)=2000;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif SIMC==3  % % HAART COSTS $5000 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

beta_p(10:15,1)=zeros(6,1);
beta_p(5,1)=750;
beta_p(6,1)=1500;
beta_p(7,1)=3000;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

end

LL_FV=B_LL(th_ml)
CCP=D_DPP(th_ml);
CCP=CCP(:,1:71,:);

%14.3   SIMULATIONS VISITS 15-40

simdata=zeros(N_0,14);

%(create a false "vis -1" to start algorithm)
simdata(:,1)=simstart(:,1)-1;
simdata(:,9:14)=simstart;

clear simstart

sv=start_visit;
for v=sv:39

display 'visit'

        v

    simtemp=simdata((((v-sv)*N_0)+1):((v+1-sv)*N_0),:);    
    simtemp(:,1)=sv;
    simtemp(:,1:6)=simtemp(:,9:14);
    
    v_it_SIMC   =simtemp(:,1);
    E_it_SIMC   =simtemp(:,2);
    d_it_m_SIMC =simtemp(:,3);
    H_it_SIMC   =simtemp(:,4);
    A_it_SIMC   =simtemp(:,5);
    a_SIMC=(A_it_SIMC-30)*2+1;
    

    
%Columns for simtemp 
%--------------
%1   v_it
%2   E_it
%3   d_it_m
%4   H_it
%5   A_it
%6   B_it1
%--------------
%7   d_it1_L
%8   d_it1_M
%--------------
%9   v_it1
%10  E_it1
%11  d_it_m1
%12  H_it1
%13  A_it1
%14  B_it1
%--------------

%14.3.1   SIMULATE CHOICE: P(d_it+1 | s_it)

for j=1:N_0 

%     j
    
simtemp(j,7)=0;    
simtemp(j,8)=0;   
    
u=rand(1,1);  
 
if v<=23
cccp=zeros(1,6);
    
cccp(1,1)=CCP(E_INDSM(v_it_SIMC(j,1),E_it_SIMC(j,1),d_it_m_SIMC(j,1),0,0,H_it_SIMC(j,1)),a_SIMC(j,1),1);
cccp(1,2)=CCP(E_INDSM(v_it_SIMC(j,1),E_it_SIMC(j,1),d_it_m_SIMC(j,1),0,1,H_it_SIMC(j,1)),a_SIMC(j,1),1)+cccp(1,1);
cccp(1,3)=CCP(E_INDSM(v_it_SIMC(j,1),E_it_SIMC(j,1),d_it_m_SIMC(j,1),0,2,H_it_SIMC(j,1)),a_SIMC(j,1),1)+cccp(1,2);
cccp(1,4)=CCP(E_INDSM(v_it_SIMC(j,1),E_it_SIMC(j,1),d_it_m_SIMC(j,1),1,0,H_it_SIMC(j,1)),a_SIMC(j,1),1)+cccp(1,3);
cccp(1,5)=CCP(E_INDSM(v_it_SIMC(j,1),E_it_SIMC(j,1),d_it_m_SIMC(j,1),1,1,H_it_SIMC(j,1)),a_SIMC(j,1),1)+cccp(1,4);
cccp(1,6)=CCP(E_INDSM(v_it_SIMC(j,1),E_it_SIMC(j,1),d_it_m_SIMC(j,1),1,2,H_it_SIMC(j,1)),a_SIMC(j,1),1)+cccp(1,5);


if u>=0 && u<cccp(1,1)
simtemp(j,7)=0;
simtemp(j,8)=0;
elseif u>=cccp(1,1) && u<cccp(1,2)
simtemp(j,7)=0;
simtemp(j,8)=1;
elseif u>=cccp(1,2) && u<cccp(1,3)
simtemp(j,7)=0;
simtemp(j,8)=2;
elseif u>=cccp(1,3) && u<cccp(1,4)
simtemp(j,7)=1;
simtemp(j,8)=0;
elseif u>=cccp(1,4) && u<cccp(1,5)
simtemp(j,7)=1;
simtemp(j,8)=1;
elseif u>=cccp(1,5) && u<cccp(1,6)
simtemp(j,7)=1;
simtemp(j,8)=2;
end


elseif v>23
cccp=zeros(1,8);

cccp(1,1)=CCP(E_INDSM(v_it_SIMC(j,1),E_it_SIMC(j,1),d_it_m_SIMC(j,1),0,0,H_it_SIMC(j,1)),a_SIMC(j,1),1);
cccp(1,2)=CCP(E_INDSM(v_it_SIMC(j,1),E_it_SIMC(j,1),d_it_m_SIMC(j,1),0,1,H_it_SIMC(j,1)),a_SIMC(j,1),1)+cccp(1,1);
cccp(1,3)=CCP(E_INDSM(v_it_SIMC(j,1),E_it_SIMC(j,1),d_it_m_SIMC(j,1),0,2,H_it_SIMC(j,1)),a_SIMC(j,1),1)+cccp(1,2);
cccp(1,4)=CCP(E_INDSM(v_it_SIMC(j,1),E_it_SIMC(j,1),d_it_m_SIMC(j,1),0,3,H_it_SIMC(j,1)),a_SIMC(j,1),1)+cccp(1,3);
cccp(1,5)=CCP(E_INDSM(v_it_SIMC(j,1),E_it_SIMC(j,1),d_it_m_SIMC(j,1),1,0,H_it_SIMC(j,1)),a_SIMC(j,1),1)+cccp(1,4);
cccp(1,6)=CCP(E_INDSM(v_it_SIMC(j,1),E_it_SIMC(j,1),d_it_m_SIMC(j,1),1,1,H_it_SIMC(j,1)),a_SIMC(j,1),1)+cccp(1,5);
cccp(1,7)=CCP(E_INDSM(v_it_SIMC(j,1),E_it_SIMC(j,1),d_it_m_SIMC(j,1),1,2,H_it_SIMC(j,1)),a_SIMC(j,1),1)+cccp(1,6);
cccp(1,8)=CCP(E_INDSM(v_it_SIMC(j,1),E_it_SIMC(j,1),d_it_m_SIMC(j,1),1,3,H_it_SIMC(j,1)),a_SIMC(j,1),1)+cccp(1,7); 


if u>=0 && u<cccp(1,1)
simtemp(j,7)=0;
simtemp(j,8)=0;
elseif u>=cccp(1,1) && u<cccp(1,2)
simtemp(j,7)=0;
simtemp(j,8)=1;
elseif u>=cccp(1,2) && u<cccp(1,3)
simtemp(j,7)=0;
simtemp(j,8)=2;
elseif u>=cccp(1,3) && u<cccp(1,4)
simtemp(j,7)=0;
simtemp(j,8)=3;
elseif u>=cccp(1,4) && u<cccp(1,5)
simtemp(j,7)=1;
simtemp(j,8)=0;
elseif u>=cccp(1,5) && u<cccp(1,6)
simtemp(j,7)=1;
simtemp(j,8)=1;
elseif u>=cccp(1,6) && u<cccp(1,7)
simtemp(j,7)=1;
simtemp(j,8)=2;
elseif u>=cccp(1,7)
simtemp(j,7)=1;
simtemp(j,8)=3;
end

end
end

%14.3.2   SIMULATE TRANSITION: P(s_i,t+1 | s_it, d_i,t+1)

%Beta's are already changed...
%Need to recalculate P_B and P_H

th_D1=beta_D(1:9,1)
th_H1=beta_H(1:4,1)
th_F1=beta_F(1:9,1)

ttp=zeros(1,3);

for j=1:N_0
    
%     j
    
a_SIMC=(simtemp(j,5)-30)*2+1; 

PB=TP(E_INDSM(v_it_SIMC(j,1),E_it_SIMC(j,1),d_it_m_SIMC(j,1),simtemp(j,7),simtemp(j,8),H_it_SIMC(j,1)),15,a_SIMC(1,1));

%TP for this iteration
TPa=TP(:,:,a_SIMC(1,1));  

TP_v        =TPa(:,1);    
TP_dh       =TPa(:,2);
TP_H        =TPa(:,3);    
TP_E        =TPa(:,4);    
TP_dl0_1    =TPa(:,5);
TP_dl1_1    =TPa(:,6);
TP_dm0_0    =TPa(:,7);
TP_dm1_0    =TPa(:,8);
TP_dm2_0    =TPa(:,9);
TP_dm3_0    =TPa(:,10);
TP_dm0_1    =TPa(:,11);
TP_dm1_1    =TPa(:,12);
TP_dm2_1    =TPa(:,13);
TP_dm3_1    =TPa(:,14);

PP_B        =TPa(:,15);
PP_H        =TPa(:,16);
PP_F        =TPa(:,17);

EE_I         =TPa(:,18);

EE_N1        =TPa(:,19);
EE_N2        =TPa(:,20);

EE_IP    =(EE_I+2500)/5000;


XB_D=...
    th_D1(1,1)*TP_H+...
    th_D1(2,1)*times((1-TP_H),TP_dm1_1)+...
    th_D1(3,1)*times((1-TP_H),TP_dm2_1)+...
    th_D1(4,1)*times((1-TP_H),TP_dm3_1)+...
    th_D1(5,1)*times((TP_H)  ,TP_dm1_1)+...
    th_D1(6,1)*times((TP_H)  ,TP_dm2_1)+...
    th_D1(7,1)*times((TP_H)  ,TP_dm3_1)+...
    th_D1(8,1)*TP_v+...
    th_D1(9,1);

DH=exp(XB_D);
DH=times(DH,power((1+DH),-1));
DH0=times(DH,(1-TP_H));
DH1=times(DH,(TP_H));

XB_H=...
    th_H1(1,1)*TP_H+...
    th_H1(2,1)*DH0+...
    th_H1(3,1)*DH1+...
    th_H1(4,1);

P_H=exp(XB_H);
P_H=times(P_H,power((1+P_H),-1));

ProbH=P_H(E_INDSM(v_it_SIMC(j,1),E_it_SIMC(j,1),d_it_m_SIMC(j,1),simtemp(j,7),simtemp(j,8),H_it_SIMC(j,1)),1);



ttp(1,1)=(1-PB)*ProbH;
ttp(1,2)=(1-PB)*(1-ProbH);
ttp(1,3)=PB;

        u=rand(1,1);
    
if u>=0 && u<ttp(1,1)
simtemp(j,12) =1;
elseif u>=ttp(1,1) && u<ttp(1,1)+ttp(1,2)
simtemp(j,12) =0; 
else
simtemp(j,12)=0;
simtemp(j,14)=1;
end

% Death to Death
if  simtemp(j,6)==1
    simtemp(j,14)=1;
end

%Columns for simtemp 
%--------------
%1   v_it
%2   E_it
%3   d_it_m
%4   H_it
%5   A_it
%6   B_it1
%--------------
%7   d_it1_L
%8   d_it1_M
%--------------
%9   v_it1
%10  E_it1
%11  d_it_m1
%12  H_it1
%13  A_it1
%14  B_it1
%--------------

        u=rand(1,1);
    
%Experience
if simtemp(j,7)==0
simtemp(j,10)=simtemp(j,2);
elseif simtemp(j,7)==1 && simtemp(j,2)==50
simtemp(j,10)=50;
elseif simtemp(j,7)==1 && simtemp(j,2)<50 && u<=0.05
simtemp(j,10)=simtemp(j,2)+10;
elseif simtemp(j,7)==1 && simtemp(j,2)<50 && u>0.05
simtemp(j,10)=simtemp(j,2);
end

%Age
if simtemp(j,5)==65
simtemp(j,13)=65;
elseif simtemp(j,5)<65  
simtemp(j,13)=simtemp(j,5)+0.5;
end

%RETIREMENT
if simtemp(j,5)==65
    simtemp(j,7)=0;
end

%Visit
simtemp(j,9)=simtemp(j,1)+1;

%d_it_m1
simtemp(j,11)=simtemp(j,8);

end

%%%%%%%%%%%%%
    
    simdata=[simdata ; simtemp];

%%%%%%%%%%%%%    

end

%Drop unnecessary items...

clear simtemp
clear simstart
 
%Assign type and compile mixed dataset

N_sim=length(simdata);
SIMC_data=simdata(N_0+1:N_sim,:);


%NOW COMPUTE INCOME!

%Columns for simtemp 
%--------------
%1   v_it
%2   E_it
%3   d_it_m
%4   H_it
%5   A_it
%6   B_it1
%--------------
%7   d_it1_L
%8   d_it1_M
%--------------
%9   v_it1
%10  E_it1
%11  d_it_m1
%12  H_it1
%13  A_it1
%14  B_it1
%--------------

th_I1=beta_I(1:13,1); 
    
XB_I=...
    th_I1(1,1)*SIMC_data(:,4)+...                           %TP_H+...
    th_I1(2,1)*SIMC_data(:,2)+...                           %TP_E
    th_I1(3,1)*times(SIMC_data(:,2),SIMC_data(:,2))+...     %times(TP_E,TP_E)+...
    th_I1(4,1)*SIMC_data(:,5)+...                           %A+...
    th_I1(5,1)*(SIMC_data(:,1)-14)+...                      %(TP_v-14)+...
   (times(SIMC_data(:,7),...                                %TP_dl1_1,
   (th_I1(6,1)+...               
    th_I1(7,1)*SIMC_data(:,4)+...                           %TP_H+... 
    th_I1(8,1)*SIMC_data(:,2)+...                           %TP_E+...
    th_I1(9,1)*times(SIMC_data(:,2),SIMC_data(:,2))+...     %times(TP_E,TP_E)+...
    th_I1(10,1)*SIMC_data(:,5)+...                          %A+...
    th_I1(11,1)*(SIMC_data(:,1)-14))))+...                  %(TP_v-14))))+...
    th_I1(12,1);

sig=th_I1(13,1);

w=times((XB_I-2500),power(sig,-1));
phi_1=normpdf(w,0,1);  
phi_2=normcdf(w,0,1);  
E_I=(2500*(1-phi_2))+(times(phi_2,XB_I)+times(sig,phi_1)); %left censored; See C&T p541 
 
SIMC_data=[SIMC_data E_I];

%NOW COMPUTE AILMENTS!

th_F1=beta_F(1:9,1);


%Columns for simtemp 
%--------------
%1   v_it
%2   E_it
%3   d_it_m
%4   H_it
%5   A_it
%6   B_it1
%--------------
%7   d_it1_L
%8   d_it1_M
%--------------
%9   v_it1
%10  E_it1
%11  d_it_m1
%12  H_it1
%13  A_it1
%14  B_it1
%--------------

dm10=zeros(length(SIMC_data),1);
dm11=zeros(length(SIMC_data),1);
dm12=zeros(length(SIMC_data),1);
dm13=zeros(length(SIMC_data),1);

for j=1:length(SIMC_data)
if SIMC_data(j,8)==0
    dm10(j,1)=1;
elseif SIMC_data(j,8)==1
    dm11(j,1)=1;
elseif SIMC_data(j,8)==2
    dm12(j,1)=1;
elseif SIMC_data(j,8)==3
    dm13(j,1)=1;
end    
end

XB_F=...
    th_F1(1,1)*SIMC_data(:,4)+...  
    th_F1(2,1)*times((1-SIMC_data(:,4)),dm11)+...
    th_F1(3,1)*times((1-SIMC_data(:,4)),dm12)+...
    th_F1(4,1)*times((1-SIMC_data(:,4)),dm13)+...
    th_F1(5,1)*times((SIMC_data(:,4)),dm11)+...
    th_F1(6,1)*times((SIMC_data(:,4)),dm12)+...
    th_F1(7,1)*times((SIMC_data(:,4)),dm13)+...
    th_F1(8,1)*SIMC_data(:,1)+...
    th_F1(9,1);


P_F=exp(XB_F);
P_F=times(P_F,power((1+P_F),-1));

SIMC_data=[SIMC_data P_F];

cd ..

if start_visit==15

if SIMC==0 && SIM_TYPE==1 
csvwrite('Simulations/SIMC/simC_15_CF0_0_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_15_CF0_0_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_15_CF0_0_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_15_CF0_0_stata.csv', SIMC_data);
elseif SIMC==1 && SIM_TYPE==1
csvwrite('Simulations/SIMC/simC_15_CF1_1_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_15_CF1_1_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_15_CF1_1_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_15_CF1_1_stata.csv', SIMC_data);
elseif SIMC==2 && SIM_TYPE==1
csvwrite('Simulations/SIMC/simC_15_CF2_2_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_15_CF2_2_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_15_CF2_2_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_15_CF2_2_stata.csv', SIMC_data);
elseif SIMC==3 && SIM_TYPE==1
csvwrite('Simulations/SIMC/simC_15_CF3_3_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_15_CF3_3_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_15_CF3_3_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_15_CF3_3_stata.csv', SIMC_data);
end

if No_SIM_TYPES==2
if SIMC==0 && SIM_TYPE==2
csvwrite('Simulations/SIMC/simC_15_CF0_2_stata.csv', SIMC_data);
elseif SIMC==1 && SIM_TYPE==2
csvwrite('Simulations/SIMC/simC_15_CF1_2_stata.csv', SIMC_data);
elseif SIMC==2 && SIM_TYPE==2
csvwrite('Simulations/SIMC/simC_15_CF2_2_stata.csv', SIMC_data);
elseif SIMC==3 && SIM_TYPE==2
csvwrite('Simulations/SIMC/simC_15_CF3_2_stata.csv', SIMC_data);
end
end

if No_SIM_TYPES==4
if SIMC==0 && SIM_TYPE==2
csvwrite('Simulations/SIMC/simC_15_CF0_2_stata.csv', SIMC_data);
elseif SIMC==1 && SIM_TYPE==2
csvwrite('Simulations/SIMC/simC_15_CF1_2_stata.csv', SIMC_data);
elseif SIMC==2 && SIM_TYPE==2
csvwrite('Simulations/SIMC/simC_15_CF2_2_stata.csv', SIMC_data);
elseif SIMC==3 && SIM_TYPE==2
csvwrite('Simulations/SIMC/simC_15_CF3_2_stata.csv', SIMC_data);
end

if SIMC==0 && SIM_TYPE==3
csvwrite('Simulations/SIMC/simC_15_CF0_3_stata.csv', SIMC_data);
elseif SIMC==1 && SIM_TYPE==3
csvwrite('Simulations/SIMC/simC_15_CF1_3_stata.csv', SIMC_data);
elseif SIMC==2 && SIM_TYPE==3
csvwrite('Simulations/SIMC/simC_15_CF2_3_stata.csv', SIMC_data);
elseif SIMC==3 && SIM_TYPE==3
csvwrite('Simulations/SIMC/simC_15_CF3_3_stata.csv', SIMC_data);
end

if SIMC==0 && SIM_TYPE==4
csvwrite('Simulations/SIMC/simC_15_CF0_4_stata.csv', SIMC_data);
elseif SIMC==1 && SIM_TYPE==4
csvwrite('Simulations/SIMC/simC_15_CF1_4_stata.csv', SIMC_data);
elseif SIMC==2 && SIM_TYPE==4
csvwrite('Simulations/SIMC/simC_15_CF2_4_stata.csv', SIMC_data);
elseif SIMC==3 && SIM_TYPE==4
csvwrite('Simulations/SIMC/simC_15_CF3_4_stata.csv', SIMC_data);
end
end

elseif start_visit==24

if SIMC==0 && SIM_TYPE==1
csvwrite('Simulations/SIMC/simC_24_CF0_1_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_24_CF0_2_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_24_CF0_3_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_24_CF0_4_stata.csv', SIMC_data);
elseif SIMC==1 && SIM_TYPE==1
csvwrite('Simulations/SIMC/simC_24_CF1_1_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_24_CF1_2_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_24_CF1_3_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_24_CF1_4_stata.csv', SIMC_data);
elseif SIMC==2 && SIM_TYPE==1
csvwrite('Simulations/SIMC/simC_24_CF2_1_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_24_CF2_2_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_24_CF2_3_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_24_CF2_4_stata.csv', SIMC_data);
elseif SIMC==3 && SIM_TYPE==1
csvwrite('Simulations/SIMC/simC_24_CF3_1_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_24_CF3_2_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_24_CF3_3_stata.csv', SIMC_data);
csvwrite('Simulations/SIMC/simC_24_CF3_4_stata.csv', SIMC_data);
end

if No_SIM_TYPES==2
if SIMC==0 && SIM_TYPE==2
csvwrite('Simulations/SIMC/simC_24_CF0_2_stata.csv', SIMC_data);
elseif SIMC==1 && SIM_TYPE==2
csvwrite('Simulations/SIMC/simC_24_CF1_2_stata.csv', SIMC_data);
elseif SIMC==2 && SIM_TYPE==2
csvwrite('Simulations/SIMC/simC_24_CF2_2_stata.csv', SIMC_data);
elseif SIMC==3 && SIM_TYPE==2
csvwrite('Simulations/SIMC/simC_24_CF3_2_stata.csv', SIMC_data);
end
end

if No_SIM_TYPES==4
if SIMC==0 && SIM_TYPE==2
csvwrite('Simulations/SIMC/simC_24_CF0_2_stata.csv', SIMC_data);
elseif SIMC==1 && SIM_TYPE==2
csvwrite('Simulations/SIMC/simC_24_CF1_2_stata.csv', SIMC_data);
elseif SIMC==2 && SIM_TYPE==2
csvwrite('Simulations/SIMC/simC_24_CF2_2_stata.csv', SIMC_data);
elseif SIMC==3 && SIM_TYPE==2
csvwrite('Simulations/SIMC/simC_24_CF3_2_stata.csv', SIMC_data);
end

if SIMC==0 && SIM_TYPE==3
csvwrite('Simulations/SIMC/simC_24_CF0_3_stata.csv', SIMC_data);
elseif SIMC==1 && SIM_TYPE==3
csvwrite('Simulations/SIMC/simC_24_CF1_3_stata.csv', SIMC_data);
elseif SIMC==2 && SIM_TYPE==3
csvwrite('Simulations/SIMC/simC_24_CF2_3_stata.csv', SIMC_data);
elseif SIMC==3 && SIM_TYPE==3
csvwrite('Simulations/SIMC/simC_24_CF3_3_stata.csv', SIMC_data);
end

if SIMC==0 && SIM_TYPE==4
csvwrite('Simulations/SIMC/simC_24_CF0_4_stata.csv', SIMC_data);
elseif SIMC==1 && SIM_TYPE==4
csvwrite('Simulations/SIMC/simC_24_CF1_4_stata.csv', SIMC_data);
elseif SIMC==2 && SIM_TYPE==4
csvwrite('Simulations/SIMC/simC_24_CF2_4_stata.csv', SIMC_data);
elseif SIMC==3 && SIM_TYPE==4
csvwrite('Simulations/SIMC/simC_24_CF3_4_stata.csv', SIMC_data);
end
end

cd ('Matlab')

end

display 'END: Simulation'

end  
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
%17    V A L U E OF H A A R T BY A G E AND E X P E R I E N C E AND T Y P E

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

display 'BEGIN: SIMULATION VALUE OF HAART'
display 'USE AN ANNUITY'
display 'NOTE: USE ALT 2 CODE - 1 TYPE'

%17.1   SET PARAMETERS

for SIM_TYPE=1:No_SIM_TYPES   

% for SIM_TYPE=1:2    


%Here: Define parameter Values for Different Types
%(Can alter both P and TP's)

if SIM_TYPE==1

th_ml=[theta0_U1;theta0_A1];      

beta_p      =beta_p1;
beta_D      =beta_D1; 
beta_H      =beta_H1; 
beta_F      =beta_F1; 
beta_B      =beta_B1; 
beta_I      =beta_I1; 
beta_N      =beta_N1;

elseif SIM_TYPE==2
    
th_ml=[theta0_U2;theta0_A2];      

beta_p      =beta_p1;
beta_D      =beta_D1; 
beta_H      =beta_H1; 
beta_F      =beta_F1; 
beta_B      =beta_B1; 
beta_I      =beta_I1; 
beta_N      =beta_N1;

elseif SIM_TYPE==3

th_ml=[theta0_U1;theta0_A1];      

beta_p      =beta_p2;
beta_D      =beta_D2; 
beta_H      =beta_H2; 
beta_F      =beta_F2; 
beta_B      =beta_B2; 
beta_I      =beta_I2; 
beta_N      =beta_N2;

elseif SIM_TYPE==4
    
th_ml=[theta0_U2;theta0_A2];      

beta_p      =beta_p2;
beta_D      =beta_D2; 
beta_H      =beta_H2; 
beta_F      =beta_F2; 
beta_B      =beta_B2; 
beta_I      =beta_I2; 
beta_N      =beta_N2;

end  

     

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

INCREMENT=50;
for INC=0:300
for HAART=0:1

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

th_P1=beta_p(1:17,1);
th_S1=ones(4,1)*beta_p(18,1);
th_D1=beta_D(1:9,1);
th_H1=beta_H(1:4,1);
th_F1=beta_F(1:9,1);
th_B1=beta_B(1:4,1);
th_I1=beta_I(1:13,1);
th_N1=beta_N(10:27,1);

th_ml_U1   =th_ml(1:LU1,1);      
th_ml_A1   =th_ml(LU1+1:LU1+LA1,1);
alpha1     =times(exp(th_ml_A1),power(1+exp(th_ml_A1),-1));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if HAART==1

%No Changes    
    
elseif HAART==0  %Turn Off HAART    

%HAART EFFECTIVE AS COMBO

th_D1(4,1)=th_D1(3,1);
th_D1(7,1)=th_D1(6,1);

%HAART SFX SAME AS COMBO
th_F1(4,1)=th_F1(3,1);
th_F1(7,1)=th_F1(6,1);

%HAART COSTS AS COMBO
th_P1(7,1)=th_P1(6,1);
th_P1(14,1)=th_P1(12,1);
th_P1(15,1)=th_P1(13,1);

end

HAART
INC
th_D1
th_F1

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%4  SETUP FOR BACKWARD RECURSION

CCP=zeros(DIM,71,L);

for type=1:L
V_A=zeros(DIM,71);
 
    
%5  BACKWARD RECURSION: BEGIN WITH RETIREMENT AGE (65)

%Start w. Retirement A=65)
    
for A=65 

%TP Cube Layer (Using A_it)
    a=(A-30)*2+1;                                         
%TP for this iteration
    TPa=TP(:,:,a);  

%Extract from TP Components for Flow Utility and Transitions
    
TP_v        =TPa(:,1);    
TP_dh       =TPa(:,2);
TP_H        =TPa(:,3);    
TP_E        =TPa(:,4);    
TP_dl0_1    =TPa(:,5);
TP_dl1_1    =TPa(:,6);
TP_dm0_0    =TPa(:,7);
TP_dm1_0    =TPa(:,8);
TP_dm2_0    =TPa(:,9);
TP_dm3_0    =TPa(:,10);
TP_dm0_1    =TPa(:,11);
TP_dm1_1    =TPa(:,12);
TP_dm2_1    =TPa(:,13);
TP_dm3_1    =TPa(:,14);

PP_B        =TPa(:,15);
PP_H        =TPa(:,16);
PP_F        =TPa(:,17);

EE_I         =TPa(:,18);

EE_N1        =TPa(:,19);
EE_N2        =TPa(:,20);

EE_IP    =(EE_I+2500)/5000;

%OOC ~ Health ~ Symptoms/SFX  

if type==1 || type==2
    
XB_B=...
    th_B1(1,1)*TP_H+...
    th_B1(2,1)*A*TP_H+...
    th_B1(3,1)*A+...
    th_B1(4,1);

P_B=exp(XB_B);
P_B=times(P_B,power((1+P_B),-1));     
    
XB_D=...
    th_D1(1,1)*TP_H+...
    th_D1(2,1)*times((1-TP_H),TP_dm1_1)+...
    th_D1(3,1)*times((1-TP_H),TP_dm2_1)+...
    th_D1(4,1)*times((1-TP_H),TP_dm3_1)+...
    th_D1(5,1)*times((TP_H)  ,TP_dm1_1)+...
    th_D1(6,1)*times((TP_H)  ,TP_dm2_1)+...
    th_D1(7,1)*times((TP_H)  ,TP_dm3_1)+...
    th_D1(8,1)*TP_v+...
    th_D1(9,1);


DH=exp(XB_D);
DH=times(DH,power((1+DH),-1));
DH0=times(DH,(1-TP_H));
DH1=times(DH,(TP_H));

XB_H=...
    th_H1(1,1)*TP_H+...
    th_H1(2,1)*DH0+...
    th_H1(3,1)*DH1+...
    th_H1(4,1);

P_H=exp(XB_H);
P_H=times(P_H,power((1+P_H),-1));



XB_F=...
    th_F1(1,1)*TP_H+...  
    th_F1(2,1)*times((1-TP_H),TP_dm1_1)+...
    th_F1(3,1)*times((1-TP_H),TP_dm2_1)+...
    th_F1(4,1)*times((1-TP_H),TP_dm3_1)+...
    th_F1(5,1)*times((TP_H)  ,TP_dm1_1)+...
    th_F1(6,1)*times((TP_H)  ,TP_dm2_1)+...
    th_F1(7,1)*times((TP_H)  ,TP_dm3_1)+...
    th_F1(8,1)*TP_v+...
    th_F1(9,1);

P_F=exp(XB_F);
P_F=times(P_F,power((1+P_F),-1));

XB_I=...
    th_I1(1,1)*TP_H+...
    th_I1(2,1)*TP_E+...
    th_I1(3,1)*times(TP_E,TP_E)+...
    th_I1(4,1)*A+...
    th_I1(5,1)*(TP_v-14)+...
   (times(TP_dl1_1,...
   (th_I1(6,1)+... 
    th_I1(7,1)*TP_H+...
    th_I1(8,1)*TP_E+...
    th_I1(9,1)*times(TP_E,TP_E)+...
    th_I1(10,1)*A+...
    th_I1(11,1)*(TP_v-14))))+...
    th_I1(12,1);

sig=th_I1(13,1);

w=times((XB_I-2500),power(sig,-1));
phi_1=normpdf(w,0,1);  
phi_2=normcdf(w,0,1);  
E_I=(2500*(1-phi_2))+(times(phi_2,XB_I)+times(sig,phi_1)); %left censored; See C&T p541 
E_IP    =(E_I+2500)/5000;

%%%%%%%%%%%%%%%%%%%%%
E_I=E_I+INC*INCREMENT;
%%%%%%%%%%%%%%%%%%%%%
XB_N_1=...
    th_N1(1,1)*TP_dl1_1+...
    th_N1(2,1)*TP_H+...
    th_N1(3,1)*TP_E+...
    th_N1(4,1)*times(TP_E,TP_E)+...
    th_N1(5,1)*A+...
    th_N1(6,1)*A^2+...
    th_N1(7,1)*(TP_v)+...
    th_N1(8,1)*times(TP_v-24,TP_dh)+...
    th_N1(9,1);

XB_N_2=...
    th_N1(10,1)*TP_dl1_1+...
    th_N1(11,1)*TP_H+...
    th_N1(12,1)*TP_E+...
    th_N1(13,1)*times(TP_E,TP_E)+...
    th_N1(14,1)*A+...
    th_N1(15,1)*A^2+...
    th_N1(16,1)*(TP_v)+...
    th_N1(17,1)*times(TP_v-24,TP_dh)+...
    th_N1(18,1);


XB_N_1=exp(XB_N_1);
XB_N_2=exp(XB_N_2);

E_N1=times(XB_N_1,power((1+XB_N_1+XB_N_2),-1));
E_N2=times(XB_N_2,power((1+XB_N_1+XB_N_2),-1));

XB_P=...
    th_P1(1,1)*P_H+...
    th_P1(2,1)*times((1-P_F),P_H)+...
    th_P1(3,1)*times((1-P_F),(1-P_H))+...
    th_P1(4,1)*E_IP+...
    th_P1(5,1)*TP_dm1_1+...
    th_P1(6,1)*TP_dm2_1+...
    th_P1(7,1)*TP_dm3_1+...
    th_P1(8,1)*E_N1+...
    th_P1(9,1)*E_N2+...
    th_P1(10,1)*times(E_N1,TP_dm1_1)+...
    th_P1(11,1)*times(E_N2,TP_dm1_1)+...    
    th_P1(12,1)*times(E_N1,TP_dm2_1)+...
    th_P1(13,1)*times(E_N2,TP_dm2_1)+...    
    th_P1(14,1)*times(E_N1,TP_dm3_1)+...
    th_P1(15,1)*times(E_N2,TP_dm3_1)+...    
    th_P1(16,1)*(TP_v)+...
    th_P1(17,1);

sig0=  th_S1(1,1)*TP_dm0_1;  
sig1=  th_S1(2,1)*TP_dm1_1;
sig2=  th_S1(3,1)*TP_dm2_1;
sig3=  th_S1(4,1)*TP_dm3_1;
sig=sig0+sig1+sig2+sig3;

w=times(XB_P,power(sig,-1));
phi_1=normpdf(w,0,1);  
phi_2=normcdf(w,0,1);  
E_P=times(phi_2,XB_P)+times(sig,phi_1); %left censored; See C&T p541

elseif type==3 || type==4

XB_B=...
    th_B2(1,1)*TP_H+...
    th_B2(2,1)*A*TP_H+...
    th_B2(3,1)*A+...
    th_B2(4,1);

P_B=exp(XB_B);
P_B=times(P_B,power((1+P_B),-1));    
    
XB_D=...
    th_D2(1,1)*TP_H+...
    th_D2(2,1)*times((1-TP_H),TP_dm1_1)+...
    th_D2(3,1)*times((1-TP_H),TP_dm2_1)+...
    th_D2(4,1)*times((1-TP_H),TP_dm3_1)+...
    th_D2(5,1)*times((TP_H)  ,TP_dm1_1)+...
    th_D2(6,1)*times((TP_H)  ,TP_dm2_1)+...
    th_D2(7,1)*times((TP_H)  ,TP_dm3_1)+...
    th_D2(8,1)*TP_v+...
    th_D2(9,1);


DH=exp(XB_D);
DH=times(DH,power((1+DH),-1));
DH0=times(DH,(1-TP_H));
DH1=times(DH,(TP_H));

XB_H=...
    th_H2(1,1)*TP_H+...
    th_H2(2,1)*DH0+...
    th_H2(3,1)*DH1+...
    th_H2(4,1);


P_H=exp(XB_H);
P_H=times(P_H,power((1+P_H),-1));


XB_F=...
    th_F2(1,1)*TP_H+...  
    th_F2(2,1)*times((1-TP_H),TP_dm1_1)+...
    th_F2(3,1)*times((1-TP_H),TP_dm2_1)+...
    th_F2(4,1)*times((1-TP_H),TP_dm3_1)+...
    th_F2(5,1)*times((TP_H)  ,TP_dm1_1)+...
    th_F2(6,1)*times((TP_H)  ,TP_dm2_1)+...
    th_F2(7,1)*times((TP_H)  ,TP_dm3_1)+...
    th_F2(8,1)*TP_v+...
    th_F2(9,1);

P_F=exp(XB_F);
P_F=times(P_F,power((1+P_F),-1));


XB_I=...
    th_I2(1,1)*TP_H+...
    th_I2(2,1)*TP_E+...
    th_I2(3,1)*times(TP_E,TP_E)+...
    th_I2(4,1)*A+...
    th_I2(5,1)*(TP_v-14)+...
   (times(TP_dl1_1,...
   (th_I2(6,1)+... 
    th_I2(7,1)*TP_H+...
    th_I2(8,1)*TP_E+...
    th_I2(9,1)*times(TP_E,TP_E)+...
    th_I2(10,1)*A+...
    th_I2(11,1)*(TP_v-14))))+...
    th_I2(12,1);

sig=th_I2(13,1);

w=times((XB_I-2500),power(sig,-1));
phi_1=normpdf(w,0,1);  
phi_2=normcdf(w,0,1);  
E_I=(2500*(1-phi_2))+(times(phi_2,XB_I)+times(sig,phi_1)); %left censored; See C&T p541 
E_IP    =(E_I+2500)/5000;


XB_N_1=...
    th_N2(1,1)*TP_dl1_1+...
    th_N2(2,1)*TP_H+...
    th_N2(3,1)*TP_E+...
    th_N2(4,1)*times(TP_E,TP_E)+...
    th_N2(5,1)*A+...
    th_N2(6,1)*A^2+...
    th_N2(7,1)*(TP_v)+...
    th_N2(8,1)*times(TP_v-24,TP_dh)+...
    th_N2(9,1);

XB_N_2=...
    th_N2(10,1)*TP_dl1_1+...
    th_N2(11,1)*TP_H+...
    th_N2(12,1)*TP_E+...
    th_N2(13,1)*times(TP_E,TP_E)+...
    th_N2(14,1)*A+...
    th_N2(15,1)*A^2+...
    th_N2(16,1)*(TP_v)+...
    th_N2(17,1)*times(TP_v-24,TP_dh)+...
    th_N2(18,1);


XB_N_1=exp(XB_N_1);
XB_N_2=exp(XB_N_2);

E_N1=times(XB_N_1,power((1+XB_N_1+XB_N_2),-1));
E_N2=times(XB_N_2,power((1+XB_N_1+XB_N_2),-1));

XB_P=...
    th_P2(1,1)*P_H+...
    th_P2(2,1)*times((1-P_F),P_H)+...
    th_P2(3,1)*times((1-P_F),(1-P_H))+...
    th_P2(4,1)*E_IP+...
    th_P2(5,1)*TP_dm1_1+...
    th_P2(6,1)*TP_dm2_1+...
    th_P2(7,1)*TP_dm3_1+...
    th_P2(8,1)*E_N1+...
    th_P2(9,1)*E_N2+...
    th_P2(10,1)*times(E_N1,TP_dm1_1)+...
    th_P2(11,1)*times(E_N2,TP_dm1_1)+...    
    th_P2(12,1)*times(E_N1,TP_dm2_1)+...
    th_P2(13,1)*times(E_N2,TP_dm2_1)+...    
    th_P2(14,1)*times(E_N1,TP_dm3_1)+...
    th_P2(15,1)*times(E_N2,TP_dm3_1)+...    
    th_P2(16,1)*(TP_v)+...
    th_P2(17,1);

sig0=  th_S2(1,1)*TP_dm0_1;  
sig1=  th_S2(2,1)*TP_dm1_1;
sig2=  th_S2(3,1)*TP_dm2_1;
sig3=  th_S2(4,1)*TP_dm3_1;
sig=sig0+sig1+sig2+sig3;

w=times(XB_P,power(sig,-1));
phi_1=normpdf(w,0,1);  
phi_2=normcdf(w,0,1);  
E_P=times(phi_2,XB_P)+times(sig,phi_1); %left censored; See C&T p541

end


if LA1==1
    
    aE_C=(1/(1-alpha1(1,1)))*power((E_I-E_P),(1-alpha1(1,1)));

elseif LA1==2 && LA2==0

    aE_C11=(1/(1-alpha1(1,1)))*power((E_I-E_P),(1-alpha1(1,1)));
    aE_C12=(1/(1-alpha1(2,1)))*power((E_I-E_P),(1-alpha1(2,1)));
       
elseif LA1==2 && LA2==2

    aE_C11=(1/(1-alpha1(1,1)))*power((E_I-E_P),(1-alpha1(1,1)));
    aE_C12=(1/(1-alpha1(2,1)))*power((E_I-E_P),(1-alpha1(2,1)));
    aE_C21=(1/(1-alpha2(1,1)))*power((E_I-E_P),(1-alpha2(1,1)));
    aE_C22=(1/(1-alpha2(2,1)))*power((E_I-E_P),(1-alpha2(2,1)));
    
end
 



%Construct Expected Flow Utility
                                    
if type==1 || type==3
if MODEL==1   

FU=         aE_C+...
            th_ml_U1(1,1)*TP_dl1_1+...
            th_ml_U1(2,1)*(1-P_F)+...
            th_ml_U1(3,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U1(4,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U1(4,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U1(4,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U1(5,1)*times((1-TP_dm0_0),TP_dm0_1);  
                
elseif MODEL==2
    
FU=         times(P_F,...
           (aE_C11+...
            th_ml_U1(1,1)*TP_dl1_1))+...
            times((1-P_F),...
           (aE_C12+...
            th_ml_U1(2,1)+...
            th_ml_U1(3,1)*TP_dl1_1))+...
            times(times(P_H,P_F),...
           (th_ml_U1(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U1(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
            times(times(P_H,1-P_F),...
           (th_ml_U1(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U1(9,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
            times(times(1-P_H,P_F),...
           (th_ml_U1(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U1(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
            times(times(1-P_H,1-P_F),...
           (th_ml_U1(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U1(9,1)*times((1-TP_dm0_0),TP_dm0_1)));   


elseif MODEL==3 || MODEL==4 
 
    
FU=         times(P_F,...
           (aE_C11+...
            th_ml_U1(1,1)*TP_dl1_1))+...
            times((1-P_F),...
           (aE_C12+...
            th_ml_U1(2,1)+...
            th_ml_U1(3,1)*TP_dl1_1))+...
            times(times(P_H,P_F),...
           (th_ml_U1(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U1(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
            times(times(P_H,1-P_F),...
           (th_ml_U1(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U1(9,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
            times(times(1-P_H,P_F),...
           (th_ml_U1(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U1(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
            times(times(1-P_H,1-P_F),...
           (th_ml_U1(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U1(9,1)*times((1-TP_dm0_0),TP_dm0_1)));   
   

end

elseif type==2 || type==4
if MODEL==3 || MODEL==4  

    
FU=         times(P_F,...
           (aE_C21+...
            th_ml_U1(1,1)*TP_dl1_1))+...
            times((1-P_F),...
           (aE_C22+...
            th_ml_U2(2,1)+...
            th_ml_U2(3,1)*TP_dl1_1))+...
            times(times(P_H,P_F),...
           (th_ml_U2(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U2(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
            times(times(P_H,1-P_F),...
           (th_ml_U2(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U2(9,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
            times(times(1-P_H,P_F),...
           (th_ml_U2(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U2(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
            times(times(1-P_H,1-P_F),...
           (th_ml_U2(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U2(9,1)*times((1-TP_dm0_0),TP_dm0_1)));   


    
end   
end

FU=times((times(1,power((1-(times(beta,(1-P_B)))),-1))),FU);

V_A(:,a)=FU;

end        


















%6  BACKWARD RECURSION: AGE 65 to 30

for A=64.5:(-0.5):30

%TP Cube Layer (Using A_it)
    a=(A-30)*2+1;                                     
%TP for this iteration
    TPa=TP(:,:,a);  

%EXTRACT TP COMPONENTS FOR TRANSITIONS
    
TP_v        =TPa(:,1);    
TP_dh       =TPa(:,2);
TP_H        =TPa(:,3);    
TP_E        =TPa(:,4);    
TP_dl0_1    =TPa(:,5);
TP_dl1_1    =TPa(:,6);
TP_dm0_0    =TPa(:,7);
TP_dm1_0    =TPa(:,8);
TP_dm2_0    =TPa(:,9);
TP_dm3_0    =TPa(:,10);
TP_dm0_1    =TPa(:,11);
TP_dm1_1    =TPa(:,12);
TP_dm2_1    =TPa(:,13);
TP_dm3_1    =TPa(:,14);

PP_B        =TPa(:,15);
PP_H        =TPa(:,16);
PP_F        =TPa(:,17);

EE_I         =TPa(:,18);

EE_N1        =TPa(:,19);
EE_N2        =TPa(:,20);

EE_IP    =(EE_I+2500)/5000;

%OOC ~ Health ~ Symptoms/SFX  

if type==1 || type==2

XB_B=...
    th_B1(1,1)*TP_H+...
    th_B1(2,1)*A*TP_H+...
    th_B1(3,1)*A+...
    th_B1(4,1);

P_B=exp(XB_B);
P_B=times(P_B,power((1+P_B),-1));      
    
XB_D=...
    th_D1(1,1)*TP_H+...
    th_D1(2,1)*times((1-TP_H),TP_dm1_1)+...
    th_D1(3,1)*times((1-TP_H),TP_dm2_1)+...
    th_D1(4,1)*times((1-TP_H),TP_dm3_1)+...
    th_D1(5,1)*times((TP_H)  ,TP_dm1_1)+...
    th_D1(6,1)*times((TP_H)  ,TP_dm2_1)+...
    th_D1(7,1)*times((TP_H)  ,TP_dm3_1)+...
    th_D1(8,1)*TP_v+...
    th_D1(9,1);


DH=exp(XB_D);
DH=times(DH,power((1+DH),-1));
DH0=times(DH,(1-TP_H));
DH1=times(DH,(TP_H));

XB_H=...
    th_H1(1,1)*TP_H+...
    th_H1(2,1)*DH0+...
    th_H1(3,1)*DH1+...
    th_H1(4,1);


P_H=exp(XB_H);
P_H=times(P_H,power((1+P_H),-1));

XB_F=...
    th_F1(1,1)*TP_H+...   
    th_F1(2,1)*times((1-TP_H),TP_dm1_1)+...
    th_F1(3,1)*times((1-TP_H),TP_dm2_1)+...
    th_F1(4,1)*times((1-TP_H),TP_dm3_1)+...
    th_F1(5,1)*times((TP_H)  ,TP_dm1_1)+...
    th_F1(6,1)*times((TP_H)  ,TP_dm2_1)+...
    th_F1(7,1)*times((TP_H)  ,TP_dm3_1)+...
    th_F1(8,1)*TP_v+...
    th_F1(9,1);

P_F=exp(XB_F);
P_F=times(P_F,power((1+P_F),-1));

XB_I=...
    th_I1(1,1)*TP_H+...
    th_I1(2,1)*TP_E+...
    th_I1(3,1)*times(TP_E,TP_E)+...
    th_I1(4,1)*A+...
    th_I1(5,1)*(TP_v-14)+...
   (times(TP_dl1_1,...
   (th_I1(6,1)+... 
    th_I1(7,1)*TP_H+...
    th_I1(8,1)*TP_E+...
    th_I1(9,1)*times(TP_E,TP_E)+...
    th_I1(10,1)*A+...
    th_I1(11,1)*(TP_v-14))))+...
    th_I1(12,1);

sig=th_I1(13,1);

w=times((XB_I-2500),power(sig,-1));
phi_1=normpdf(w,0,1);  
phi_2=normcdf(w,0,1);  
E_I=(2500*(1-phi_2))+(times(phi_2,XB_I)+times(sig,phi_1)); %left censored; See C&T p541 
E_IP    =(E_I+2500)/5000;

%%%%%%%%%%%%%%%%%%%%%%
E_I=E_I+INC*INCREMENT;
%%%%%%%%%%%%%%%%%%%%%%


XB_N_1=...
    th_N1(1,1)*TP_dl1_1+...
    th_N1(2,1)*TP_H+...
    th_N1(3,1)*TP_E+...
    th_N1(4,1)*times(TP_E,TP_E)+...
    th_N1(5,1)*A+...
    th_N1(6,1)*A^2+...
    th_N1(7,1)*(TP_v)+...
    th_N1(8,1)*times(TP_v-24,TP_dh)+...
    th_N1(9,1);

XB_N_2=...
    th_N1(10,1)*TP_dl1_1+...
    th_N1(11,1)*TP_H+...
    th_N1(12,1)*TP_E+...
    th_N1(13,1)*times(TP_E,TP_E)+...
    th_N1(14,1)*A+...
    th_N1(15,1)*A^2+...
    th_N1(16,1)*(TP_v)+...
    th_N1(17,1)*times(TP_v-24,TP_dh)+...
    th_N1(18,1);


XB_N_1=exp(XB_N_1);
XB_N_2=exp(XB_N_2);

E_N1=times(XB_N_1,power((1+XB_N_1+XB_N_2),-1));
E_N2=times(XB_N_2,power((1+XB_N_1+XB_N_2),-1)); 


XB_P=...
    th_P1(1,1)*P_H+...
    th_P1(2,1)*times((1-P_F),P_H)+...
    th_P1(3,1)*times((1-P_F),(1-P_H))+...
    th_P1(4,1)*E_IP+...
    th_P1(5,1)*TP_dm1_1+...
    th_P1(6,1)*TP_dm2_1+...
    th_P1(7,1)*TP_dm3_1+...
    th_P1(8,1)*E_N1+...
    th_P1(9,1)*E_N2+...
    th_P1(10,1)*times(E_N1,TP_dm1_1)+...
    th_P1(11,1)*times(E_N2,TP_dm1_1)+...    
    th_P1(12,1)*times(E_N1,TP_dm2_1)+...
    th_P1(13,1)*times(E_N2,TP_dm2_1)+...    
    th_P1(14,1)*times(E_N1,TP_dm3_1)+...
    th_P1(15,1)*times(E_N2,TP_dm3_1)+...    
    th_P1(16,1)*(TP_v)+...
    th_P1(17,1);

sig0=  th_S1(1,1)*TP_dm0_1;  
sig1=  th_S1(2,1)*TP_dm1_1;
sig2=  th_S1(3,1)*TP_dm2_1;
sig3=  th_S1(4,1)*TP_dm3_1;
sig=sig0+sig1+sig2+sig3;

w=times(XB_P,power(sig,-1));
phi_1=normpdf(w,0,1);  
phi_2=normcdf(w,0,1);  
E_P=times(phi_2,XB_P)+times(sig,phi_1); %left censored; See C&T p541

elseif type==3 || type==4

XB_B=...
    th_B2(1,1)*TP_H+...
    th_B2(2,1)*A*TP_H+...
    th_B2(3,1)*A+...
    th_B2(4,1);

P_B=exp(XB_B);
P_B=times(P_B,power((1+P_B),-1));       
    
XB_D=...
    th_D2(1,1)*TP_H+...
    th_D2(2,1)*times((1-TP_H),TP_dm1_1)+...
    th_D2(3,1)*times((1-TP_H),TP_dm2_1)+...
    th_D2(4,1)*times((1-TP_H),TP_dm3_1)+...
    th_D2(5,1)*times((TP_H)  ,TP_dm1_1)+...
    th_D2(6,1)*times((TP_H)  ,TP_dm2_1)+...
    th_D2(7,1)*times((TP_H)  ,TP_dm3_1)+...
    th_D2(8,1)*TP_v+...
    th_D2(9,1);

DH=exp(XB_D);
DH=times(DH,power((1+DH),-1));
DH0=times(DH,(1-TP_H));
DH1=times(DH,(TP_H));

XB_H=...
    th_H2(1,1)*TP_H+...
    th_H2(2,1)*DH0+...
    th_H2(3,1)*DH1+...
    th_H2(4,1);


P_H=exp(XB_H);
P_H=times(P_H,power((1+P_H),-1));

XB_F=...
    th_F2(1,1)*TP_H+...   
    th_F2(2,1)*times((1-TP_H),TP_dm1_1)+...
    th_F2(3,1)*times((1-TP_H),TP_dm2_1)+...
    th_F2(4,1)*times((1-TP_H),TP_dm3_1)+...
    th_F2(5,1)*times((TP_H)  ,TP_dm1_1)+...
    th_F2(6,1)*times((TP_H)  ,TP_dm2_1)+...
    th_F2(7,1)*times((TP_H)  ,TP_dm3_1)+...
    th_F2(8,1)*TP_v+...
    th_F2(9,1);


P_F=exp(XB_F);
P_F=times(P_F,power((1+P_F),-1));

XB_I=...
    th_I2(1,1)*TP_H+...
    th_I2(2,1)*TP_E+...
    th_I2(3,1)*times(TP_E,TP_E)+...
    th_I2(4,1)*A+...
    th_I2(5,1)*(TP_v-14)+...
   (times(TP_dl1_1,...
   (th_I2(6,1)+... 
    th_I2(7,1)*TP_H+...
    th_I2(8,1)*TP_E+...
    th_I2(9,1)*times(TP_E,TP_E)+...
    th_I2(10,1)*A+...
    th_I2(11,1)*(TP_v-14))))+...
    th_I2(12,1);

sig=th_I2(13,1);

w=times((XB_I-2500),power(sig,-1));
phi_1=normpdf(w,0,1);  
phi_2=normcdf(w,0,1);  
E_I=(2500*(1-phi_2))+(times(phi_2,XB_I)+times(sig,phi_1)); %left censored; See C&T p541 
E_IP    =(E_I+2500)/5000;


XB_N_1=...
    th_N2(1,1)*TP_dl1_1+...
    th_N2(2,1)*TP_H+...
    th_N2(3,1)*TP_E+...
    th_N2(4,1)*times(TP_E,TP_E)+...
    th_N2(5,1)*A+...
    th_N2(6,1)*A^2+...
    th_N2(7,1)*(TP_v)+...
    th_N2(8,1)*times(TP_v-24,TP_dh)+...
    th_N2(9,1);

XB_N_2=...
    th_N2(10,1)*TP_dl1_1+...
    th_N2(11,1)*TP_H+...
    th_N2(12,1)*TP_E+...
    th_N2(13,1)*times(TP_E,TP_E)+...
    th_N2(14,1)*A+...
    th_N2(15,1)*A^2+...
    th_N2(16,1)*(TP_v)+...
    th_N2(17,1)*times(TP_v-24,TP_dh)+...
    th_N2(18,1);


XB_N_1=exp(XB_N_1);
XB_N_2=exp(XB_N_2);

E_N1=times(XB_N_1,power((1+XB_N_1+XB_N_2),-1));
E_N2=times(XB_N_2,power((1+XB_N_1+XB_N_2),-1));


XB_P=...
    th_P2(1,1)*P_H+...
    th_P2(2,1)*times((1-P_F),P_H)+...
    th_P2(3,1)*times((1-P_F),(1-P_H))+...
    th_P2(4,1)*E_IP+...
    th_P2(5,1)*TP_dm1_1+...
    th_P2(6,1)*TP_dm2_1+...
    th_P2(7,1)*TP_dm3_1+...
    th_P2(8,1)*E_N1+...
    th_P2(9,1)*E_N2+...
    th_P2(10,1)*times(E_N1,TP_dm1_1)+...
    th_P2(11,1)*times(E_N2,TP_dm1_1)+...    
    th_P2(12,1)*times(E_N1,TP_dm2_1)+...
    th_P2(13,1)*times(E_N2,TP_dm2_1)+...    
    th_P2(14,1)*times(E_N1,TP_dm3_1)+...
    th_P2(15,1)*times(E_N2,TP_dm3_1)+...    
    th_P2(16,1)*(TP_v)+...
    th_P2(17,1);

sig0=  th_S2(1,1)*TP_dm0_1;  
sig1=  th_S2(2,1)*TP_dm1_1;
sig2=  th_S2(3,1)*TP_dm2_1;
sig3=  th_S2(4,1)*TP_dm3_1;
sig=sig0+sig1+sig2+sig3;

w=times(XB_P,power(sig,-1));
phi_1=normpdf(w,0,1);  
phi_2=normcdf(w,0,1);  
E_P=times(phi_2,XB_P)+times(sig,phi_1); %left censored; See C&T p541

end


if LA1==1
    
    aE_C=(1/(1-alpha1(1,1)))*power((E_I-E_P),(1-alpha1(1,1)));

elseif LA1==2 && LA2==0

    aE_C11=(1/(1-alpha1(1,1)))*power((E_I-E_P),(1-alpha1(1,1)));
    aE_C12=(1/(1-alpha1(2,1)))*power((E_I-E_P),(1-alpha1(2,1)));
       
elseif LA1==2 && LA2==2

    aE_C11=(1/(1-alpha1(1,1)))*power((E_I-E_P),(1-alpha1(1,1)));
    aE_C12=(1/(1-alpha1(2,1)))*power((E_I-E_P),(1-alpha1(2,1)));
    aE_C21=(1/(1-alpha2(1,1)))*power((E_I-E_P),(1-alpha2(1,1)));
    aE_C22=(1/(1-alpha2(2,1)))*power((E_I-E_P),(1-alpha2(2,1)));
    
end



%Construct Expected Flow Utility
                                    
if type==1 || type==3
if MODEL==1   

FU=         aE_C+...
            th_ml_U1(1,1)*TP_dl1_1+...
            th_ml_U1(2,1)*(1-P_F)+...
            th_ml_U1(3,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U1(4,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U1(4,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U1(4,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U1(5,1)*times((1-TP_dm0_0),TP_dm0_1);    
                
elseif MODEL==2
    
FU=         times(P_F,...
           (aE_C11+...
            th_ml_U1(1,1)*TP_dl1_1))+...
            times((1-P_F),...
           (aE_C12+...
            th_ml_U1(2,1)+...
            th_ml_U1(3,1)*TP_dl1_1))+...
            times(times(P_H,P_F),...
           (th_ml_U1(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U1(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
            times(times(P_H,1-P_F),...
           (th_ml_U1(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U1(9,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
            times(times(1-P_H,P_F),...
           (th_ml_U1(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U1(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
            times(times(1-P_H,1-P_F),...
           (th_ml_U1(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U1(9,1)*times((1-TP_dm0_0),TP_dm0_1)));  


  


elseif MODEL==3 || MODEL==4 
 
 
FU=         times(P_F,...
           (aE_C11+...
            th_ml_U1(1,1)*TP_dl1_1))+...
            times((1-P_F),...
           (aE_C12+...
            th_ml_U1(2,1)+...
            th_ml_U1(3,1)*TP_dl1_1))+...
            times(times(P_H,P_F),...
           (th_ml_U1(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U1(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
            times(times(P_H,1-P_F),...
           (th_ml_U1(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U1(9,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
            times(times(1-P_H,P_F),...
           (th_ml_U1(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U1(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
            times(times(1-P_H,1-P_F),...
           (th_ml_U1(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U1(9,1)*times((1-TP_dm0_0),TP_dm0_1)));   
   

end

elseif type==2 || type==4
if MODEL==3 || MODEL==4  

         
FU=         times(P_F,...
           (aE_C21+...
            th_ml_U2(1,1)*TP_dl1_1))+...
            times((1-P_F),...
           (aE_C22+...
            th_ml_U2(2,1)+...
            th_ml_U2(3,1)*TP_dl1_1))+...
            times(times(P_H,P_F),...
           (th_ml_U2(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U2(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
            times(times(P_H,1-P_F),...
           (th_ml_U2(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U2(9,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
            times(times(1-P_H,P_F),...
           (th_ml_U2(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U2(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
            times(times(1-P_H,1-P_F),...
           (th_ml_U2(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
            th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
            th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
            th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
            th_ml_U2(9,1)*times((1-TP_dm0_0),TP_dm0_1)));   

        
end   
end
   

%Obtain Continuation (a+1) Payoffs for each choice/state combo.
%Use error structure to obtain probabilities at next age

% CHOICE SPECIFIC VALUES --> PROBABILITIES

CORRECTION=max(V_A(:,(a+1)));
VA1=V_A(:,(a+1))-CORRECTION;

%HERE: forming {ln[\sum_{d^{'}}(v_t+1(x_{t+1},d^{'}_t+1)]+\gamma}

VA11=VA1(1:810);
VA11=reshape(VA11,6,[]);
% VA11=exp(VA11);
% VA11=sum(VA11);
% VA11=log(VA11);
% V1=transpose(VA11);
% V1=V1+.5772;        
V1=.5772+transpose(log(sum(exp(VA11))))+CORRECTION;

VA11=VA1(811:3530);
VA11=reshape(VA11,8,[]);
% VA11=exp(VA11);
% VA11=sum(VA11);
% VA11=log(VA11);
% V2=transpose(VA11);
% V2=V2+.5772; 
V2=.5772+transpose(log(sum(exp(VA11))))+CORRECTION;

VA11=VA1(3531:4340);
VA11=reshape(VA11,6,[]);
% VA11=exp(VA11);
% VA11=sum(VA11);
% VA11=log(VA11);
% V3=transpose(VA11);
% V3=V3+.5772; 
V3=.5772+transpose(log(sum(exp(VA11))))+CORRECTION;

VA11=VA1(4341:7060);
VA11=reshape(VA11,8,[]);
% VA11=exp(VA11);
% VA11=sum(VA11);
% VA11=log(VA11);
% V4=transpose(VA11);
% V4=V4+.5772;        
V4=.5772+transpose(log(sum(exp(VA11))))+CORRECTION;        

weight1=0.95;
weight2=0.05;
        
for i=1:18:793
for j=((i-1)/18)*3+1
k=(j-1)/3+1;
if mod(k,5)~=0    

V_A(i+0,a) =FU(i+0,1)   +        (beta*(1-P_B(i+0,1))) *(((1-P_H(i+0,1)) *V1(j+0,1))+(P_H(i+0,1) *V3(j+0,1)));
V_A(i+1,a) =FU(i+1,1)   +weight1*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *V1(j+0,1))+(P_H(i+1,1) *V3(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *V1(j+3,1))+(P_H(i+1,1) *V3(j+3,1)));

V_A(i+2,a) =FU(i+2,1)   +        (beta*(1-P_B(i+2,1))) *(((1-P_H(i+2,1)) *V1(j+1,1))+(P_H(i+2,1) *V3(j+1,1)));
V_A(i+3,a) =FU(i+3,1)   +weight1*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *V1(j+1,1))+(P_H(i+3,1) *V3(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *V1(j+4,1))+(P_H(i+3,1) *V3(j+4,1)));

V_A(i+4,a) =FU(i+4,1)   +        (beta*(1-P_B(i+4,1))) *(((1-P_H(i+4,1)) *V1(j+2,1))+(P_H(i+4,1) *V3(j+2,1)));
V_A(i+5,a) =FU(i+5,1)   +weight1*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *V1(j+2,1))+(P_H(i+5,1) *V3(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *V1(j+5,1))+(P_H(i+5,1) *V3(j+5,1)));

V_A(i+6,a) =FU(i+6,1)   +        (beta*(1-P_B(i+6,1))) *(((1-P_H(i+6,1)) *V1(j+0,1))+(P_H(i+6,1) *V3(j+0,1)));
V_A(i+7,a) =FU(i+7,1)   +weight1*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *V1(j+0,1))+(P_H(i+7,1) *V3(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *V1(j+3,1))+(P_H(i+7,1) *V3(j+3,1)));

V_A(i+8,a) =FU(i+8,1)   +        (beta*(1-P_B(i+8,1))) *(((1-P_H(i+8,1)) *V1(j+1,1))+(P_H(i+8,1) *V3(j+1,1)));
V_A(i+9,a) =FU(i+9,1)   +weight1*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *V1(j+1,1))+(P_H(i+9,1) *V3(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *V1(j+4,1))+(P_H(i+9,1) *V3(j+4,1)));

V_A(i+10,a)=FU(i+10,1)  +        (beta*(1-P_B(i+10,1)))*(((1-P_H(i+10,1))*V1(j+2,1))+(P_H(i+10,1)*V3(j+2,1)));
V_A(i+11,a)=FU(i+11,1)  +weight1*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*V1(j+2,1))+(P_H(i+11,1)*V3(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*V1(j+5,1))+(P_H(i+11,1)*V3(j+5,1)));

V_A(i+12,a)=FU(i+12,1)  +        (beta*(1-P_B(i+12,1)))*(((1-P_H(i+12,1))*V1(j+0,1))+(P_H(i+12,1)*V3(j+0,1)));
V_A(i+13,a)=FU(i+13,1)  +weight1*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*V1(j+0,1))+(P_H(i+13,1)*V3(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*V1(j+3,1))+(P_H(i+13,1)*V3(j+3,1)));

V_A(i+14,a)=FU(i+14,1)  +        (beta*(1-P_B(i+14,1)))*(((1-P_H(i+14,1))*V1(j+1,1))+(P_H(i+14,1)*V3(j+1,1)));
V_A(i+15,a)=FU(i+15,1)  +weight1*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*V1(j+1,1))+(P_H(i+15,1)*V3(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*V1(j+4,1))+(P_H(i+15,1)*V3(j+4,1)));

V_A(i+16,a)=FU(i+16,1)  +        (beta*(1-P_B(i+16,1)))*(((1-P_H(i+16,1))*V1(j+2,1))+(P_H(i+16,1)*V3(j+2,1)));
V_A(i+17,a)=FU(i+17,1)  +weight1*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*V1(j+2,1))+(P_H(i+17,1)*V3(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*V1(j+5,1))+(P_H(i+17,1)*V3(j+5,1)));

else
    
V_A(i+0,a) =FU(i+0,1)   +        (beta*(1-P_B(i+0,1))) *(((1-P_H(i+0,1)) *   V1(j+0,1))             +(P_H(i+0,1)   *V3(j+0,1)));
V_A(i+1,a) =FU(i+1,1)   +weight1*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *   V1(j+0,1))             +(P_H(i+1,1)   *V3(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *(2*V1(j+0,1)-V1(j+0-3,1)))+(P_H(i+1,1)*(2*V3(j+0,1)-V3(j+0-3,1))));
    
V_A(i+2,a) =FU(i+2,1)   +        (beta*(1-P_B(i+2,1))) *(((1-P_H(i+2,1)) *   V1(j+1,1))             +(P_H(i+2,1)   *V3(j+1,1)));
V_A(i+3,a) =FU(i+3,1)   +weight1*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *   V1(j+1,1))             +(P_H(i+3,1)   *V3(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *(2*V1(j+1,1)-V1(j+1-3,1)))+(P_H(i+3,1)*(2*V3(j+1,1)-V3(j+1-3,1))));

V_A(i+4,a) =FU(i+4,1)   +        (beta*(1-P_B(i+4,1))) *(((1-P_H(i+4,1)) *   V1(j+2,1))             +(P_H(i+4,1)   *V3(j+2,1)));
V_A(i+5,a) =FU(i+5,1)   +weight1*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *   V1(j+2,1))             +(P_H(i+5,1)   *V3(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *(2*V1(j+2,1)-V1(j+2-3,1)))+(P_H(i+5,1)*(2*V3(j+2,1)-V3(j+2-3,1))));

V_A(i+6,a) =FU(i+6,1)   +        (beta*(1-P_B(i+6,1))) *(((1-P_H(i+6,1)) *   V1(j+0,1))             +(P_H(i+6,1)   *V3(j+0,1)));
V_A(i+7,a) =FU(i+7,1)   +weight1*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *   V1(j+0,1))             +(P_H(i+7,1)   *V3(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *(2*V1(j+0,1)-V1(j+0-3,1)))+(P_H(i+7,1)*(2*V3(j+0,1)-V3(j+0-3,1))));

V_A(i+8,a) =FU(i+8,1)   +        (beta*(1-P_B(i+8,1))) *(((1-P_H(i+8,1)) *   V1(j+1,1))             +(P_H(i+8,1)   *V3(j+1,1)));
V_A(i+9,a) =FU(i+9,1)   +weight1*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *   V1(j+1,1))             +(P_H(i+9,1)   *V3(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *(2*V1(j+1,1)-V1(j+1-3,1)))+(P_H(i+9,1)*(2*V3(j+1,1)-V3(j+1-3,1))));

V_A(i+10,a)=FU(i+10,1)  +        (beta*(1-P_B(i+10,1)))*(((1-P_H(i+10,1))*   V1(j+2,1))             +(P_H(i+10,1)   *V3(j+2,1)));
V_A(i+11,a)=FU(i+11,1)  +weight1*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*   V1(j+2,1))             +(P_H(i+11,1)   *V3(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*(2*V1(j+2,1)-V1(j+2-3,1)))+(P_H(i+11,1)*(2*V3(j+2,1)-V3(j+2-3,1))));

V_A(i+12,a)=FU(i+12,1)  +        (beta*(1-P_B(i+12,1)))*(((1-P_H(i+12,1))*   V1(j+0,1))             +(P_H(i+12,1)   *V3(j+0,1)));
V_A(i+13,a)=FU(i+13,1)  +weight1*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*   V1(j+0,1))             +(P_H(i+13,1)   *V3(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*(2*V1(j+0,1)-V1(j+0-3,1)))+(P_H(i+13,1)*(2*V3(j+0,1)-V3(j+0-3,1))));

V_A(i+14,a)=FU(i+14,1)  +        (beta*(1-P_B(i+14,1)))*(((1-P_H(i+14,1))*   V1(j+1,1))             +(P_H(i+14,1)   *V3(j+1,1)));
V_A(i+15,a)=FU(i+15,1)  +weight1*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*   V1(j+1,1))             +(P_H(i+15,1)   *V3(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*(2*V1(j+1,1)-V1(j+1-3,1)))+(P_H(i+15,1)*(2*V3(j+1,1)-V3(j+1-3,1))));

V_A(i+16,a)=FU(i+16,1)  +        (beta*(1-P_B(i+16,1)))*(((1-P_H(i+16,1))*   V1(j+2,1))             +(P_H(i+16,1)   *V3(j+2,1)));
V_A(i+17,a)=FU(i+17,1)  +weight1*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*   V1(j+2,1))             +(P_H(i+17,1)   *V3(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*(2*V1(j+2,1)-V1(j+2-3,1)))+(P_H(i+17,1)*(2*V3(j+2,1)-V3(j+2-3,1))));

end
end
end

for i=811:32:3499
for j=((i-811)/32)*4+1    
k=(j-1)/4+1;
if mod(k,5)~=0 
           
V_A(i+0,a) =FU(i+0,1)   +        (beta*(1-P_B(i+0,1))) *(((1-P_H(i+0,1)) *V2(j+0,1))+(P_H(i+0,1) *V4(j+0,1)));
V_A(i+1,a) =FU(i+1,1)   +weight1*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *V2(j+0,1))+(P_H(i+1,1) *V4(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *V2(j+4,1))+(P_H(i+1,1) *V4(j+4,1)));

V_A(i+2,a) =FU(i+2,1)   +        (beta*(1-P_B(i+2,1))) *(((1-P_H(i+2,1)) *V2(j+1,1))+(P_H(i+2,1) *V4(j+1,1)));
V_A(i+3,a) =FU(i+3,1)   +weight1*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *V2(j+1,1))+(P_H(i+3,1) *V4(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *V2(j+5,1))+(P_H(i+3,1) *V4(j+5,1)));

V_A(i+4,a) =FU(i+4,1)   +        (beta*(1-P_B(i+4,1))) *(((1-P_H(i+4,1)) *V2(j+2,1))+(P_H(i+4,1) *V4(j+2,1)));
V_A(i+5,a) =FU(i+5,1)   +weight1*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *V2(j+2,1))+(P_H(i+5,1) *V4(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *V2(j+6,1))+(P_H(i+5,1) *V4(j+6,1)));

V_A(i+6,a) =FU(i+6,1)   +        (beta*(1-P_B(i+6,1))) *(((1-P_H(i+6,1)) *V2(j+3,1))+(P_H(i+6,1) *V4(j+3,1)));
V_A(i+7,a) =FU(i+7,1)   +weight1*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *V2(j+3,1))+(P_H(i+7,1) *V4(j+3,1)))+...
                        +weight2*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *V2(j+7,1))+(P_H(i+7,1) *V4(j+7,1)));

V_A(i+8,a) =FU(i+8,1)   +        (beta*(1-P_B(i+8,1))) *(((1-P_H(i+8,1)) *V2(j+0,1))+(P_H(i+8,1) *V4(j+0,1)));
V_A(i+9,a) =FU(i+9,1)   +weight1*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *V2(j+0,1))+(P_H(i+9,1) *V4(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *V2(j+4,1))+(P_H(i+9,1) *V4(j+4,1)));

V_A(i+10,a)=FU(i+10,1)  +        (beta*(1-P_B(i+10,1)))*(((1-P_H(i+10,1))*V2(j+1,1))+(P_H(i+10,1)*V4(j+1,1)));
V_A(i+11,a)=FU(i+11,1)  +weight1*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*V2(j+1,1))+(P_H(i+11,1)*V4(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*V2(j+5,1))+(P_H(i+11,1)*V4(j+5,1)));

V_A(i+12,a)=FU(i+12,1)  +        (beta*(1-P_B(i+12,1)))*(((1-P_H(i+12,1))*V2(j+2,1))+(P_H(i+12,1)*V4(j+2,1)));
V_A(i+13,a)=FU(i+13,1)  +weight1*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*V2(j+2,1))+(P_H(i+13,1)*V4(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*V2(j+6,1))+(P_H(i+13,1)*V4(j+6,1)));

V_A(i+14,a)=FU(i+14,1)  +        (beta*(1-P_B(i+14,1)))*(((1-P_H(i+14,1))*V2(j+3,1))+(P_H(i+14,1)*V4(j+3,1)));
V_A(i+15,a)=FU(i+15,1)  +weight1*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*V2(j+3,1))+(P_H(i+15,1)*V4(j+3,1)))+...
                        +weight2*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*V2(j+7,1))+(P_H(i+15,1)*V4(j+7,1)));

V_A(i+16,a)=FU(i+16,1)  +        (beta*(1-P_B(i+16,1)))*(((1-P_H(i+16,1))*V2(j+0,1))+(P_H(i+16,1)*V4(j+0,1)));
V_A(i+17,a)=FU(i+17,1)  +weight1*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*V2(j+0,1))+(P_H(i+17,1)*V4(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*V2(j+4,1))+(P_H(i+17,1)*V4(j+4,1)));

V_A(i+18,a)=FU(i+18,1)  +        (beta*(1-P_B(i+18,1)))*(((1-P_H(i+18,1))*V2(j+1,1))+(P_H(i+18,1)*V4(j+1,1)));
V_A(i+19,a)=FU(i+19,1)  +weight1*(beta*(1-P_B(i+19,1)))*(((1-P_H(i+19,1))*V2(j+1,1))+(P_H(i+19,1)*V4(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+19,1)))*(((1-P_H(i+19,1))*V2(j+5,1))+(P_H(i+19,1)*V4(j+5,1)));

V_A(i+20,a)=FU(i+20,1)  +        (beta*(1-P_B(i+20,1)))*(((1-P_H(i+20,1))*V2(j+2,1))+(P_H(i+20,1)*V4(j+2,1)));
V_A(i+21,a)=FU(i+21,1)  +weight1*(beta*(1-P_B(i+21,1)))*(((1-P_H(i+21,1))*V2(j+2,1))+(P_H(i+21,1)*V4(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+21,1)))*(((1-P_H(i+21,1))*V2(j+6,1))+(P_H(i+21,1)*V4(j+6,1)));

V_A(i+22,a)=FU(i+22,1)  +        (beta*(1-P_B(i+22,1)))*(((1-P_H(i+22,1))*V2(j+3,1))+(P_H(i+22,1)*V4(j+3,1)));
V_A(i+23,a)=FU(i+23,1)  +weight1*(beta*(1-P_B(i+23,1)))*(((1-P_H(i+23,1))*V2(j+3,1))+(P_H(i+23,1)*V4(j+3,1)))+...
                        +weight2*(beta*(1-P_B(i+23,1)))*(((1-P_H(i+23,1))*V2(j+7,1))+(P_H(i+23,1)*V4(j+7,1)));

V_A(i+24,a)=FU(i+24,1)  +        (beta*(1-P_B(i+24,1)))*(((1-P_H(i+24,1))*V2(j+0,1))+(P_H(i+24,1)*V4(j+0,1)));
V_A(i+25,a)=FU(i+25,1)  +weight1*(beta*(1-P_B(i+25,1)))*(((1-P_H(i+25,1))*V2(j+0,1))+(P_H(i+25,1)*V4(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+25,1)))*(((1-P_H(i+25,1))*V2(j+4,1))+(P_H(i+25,1)*V4(j+4,1)));

V_A(i+26,a)=FU(i+26,1)  +        (beta*(1-P_B(i+26,1)))*(((1-P_H(i+26,1))*V2(j+1,1))+(P_H(i+26,1)*V4(j+1,1)));
V_A(i+27,a)=FU(i+27,1)  +weight1*(beta*(1-P_B(i+27,1)))*(((1-P_H(i+27,1))*V2(j+1,1))+(P_H(i+27,1)*V4(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+27,1)))*(((1-P_H(i+27,1))*V2(j+5,1))+(P_H(i+27,1)*V4(j+5,1)));

V_A(i+28,a)=FU(i+28,1)  +        (beta*(1-P_B(i+28,1)))*(((1-P_H(i+28,1))*V2(j+2,1))+(P_H(i+28,1)*V4(j+2,1)));
V_A(i+29,a)=FU(i+29,1)  +weight1*(beta*(1-P_B(i+29,1)))*(((1-P_H(i+29,1))*V2(j+2,1))+(P_H(i+29,1)*V4(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+29,1)))*(((1-P_H(i+29,1))*V2(j+6,1))+(P_H(i+29,1)*V4(j+6,1)));

V_A(i+30,a)=FU(i+30,1)  +        (beta*(1-P_B(i+30,1)))*(((1-P_H(i+30,1))*V2(j+3,1))+(P_H(i+30,1)*V4(j+3,1)));
V_A(i+31,a)=FU(i+31,1)  +weight1*(beta*(1-P_B(i+31,1)))*(((1-P_H(i+31,1))*V2(j+3,1))+(P_H(i+31,1)*V4(j+3,1)))+...
                        +weight2*(beta*(1-P_B(i+31,1)))*(((1-P_H(i+31,1))*V2(j+7,1))+(P_H(i+31,1)*V4(j+7,1)));    

                    
                    
                    
                    
else
    
V_A(i+0,a) =FU(i+0,1)   +        (beta*(1-P_B(i+0,1))) *(((1-P_H(i+0,1))    *V2(j+0,1))             +(P_H(i+0,1)   *V4(j+0,1)));
V_A(i+1,a) =FU(i+1,1)   +weight1*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1))    *V2(j+0,1))             +(P_H(i+1,1)   *V4(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *(2*V2(j+0,1)-V2(j+0-4,1)))+(P_H(i+1,1)*(2*V4(j+0,1)-V4(j+0-4,1))));                    
                  
V_A(i+2,a) =FU(i+2,1)   +        (beta*(1-P_B(i+2,1))) *(((1-P_H(i+2,1))    *V2(j+1,1))             +(P_H(i+2,1)   *V4(j+1,1)));
V_A(i+3,a) =FU(i+3,1)   +weight1*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1))    *V2(j+1,1))             +(P_H(i+3,1)   *V4(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *(2*V2(j+1,1)-V2(j+1-4,1)))+(P_H(i+3,1)*(2*V4(j+1,1)-V4(j+1-4,1))));                    

V_A(i+4,a) =FU(i+4,1)   +        (beta*(1-P_B(i+4,1))) *(((1-P_H(i+4,1))    *V2(j+2,1))             +(P_H(i+4,1)   *V4(j+2,1)));
V_A(i+5,a) =FU(i+5,1)   +weight1*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1))    *V2(j+2,1))             +(P_H(i+5,1)   *V4(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *(2*V2(j+2,1)-V2(j+2-4,1)))+(P_H(i+5,1)*(2*V4(j+2,1)-V4(j+2-4,1))));                    

V_A(i+6,a) =FU(i+6,1)   +        (beta*(1-P_B(i+6,1))) *(((1-P_H(i+6,1))    *V2(j+3,1))             +(P_H(i+6,1)   *V4(j+3,1)));
V_A(i+7,a) =FU(i+7,1)   +weight1*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1))    *V2(j+3,1))             +(P_H(i+7,1)   *V4(j+3,1)))+...
                        +weight2*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *(2*V2(j+3,1)-V2(j+3-4,1)))+(P_H(i+7,1)*(2*V4(j+3,1)-V4(j+3-4,1))));                    

V_A(i+8,a) =FU(i+8,1)   +        (beta*(1-P_B(i+8,1))) *(((1-P_H(i+8,1))    *V2(j+0,1))             +(P_H(i+8,1)   *V4(j+0,1)));
V_A(i+9,a) =FU(i+9,1)   +weight1*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1))    *V2(j+0,1))             +(P_H(i+9,1)   *V4(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *(2*V2(j+0,1)-V2(j+0-4,1)))+(P_H(i+9,1)*(2*V4(j+0,1)-V4(j+0-4,1))));                    

V_A(i+10,a)=FU(i+10,1)  +        (beta*(1-P_B(i+10,1)))*(((1-P_H(i+10,1))   *V2(j+1,1))             +(P_H(i+10,1)   *V4(j+1,1)));
V_A(i+11,a)=FU(i+11,1)  +weight1*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))   *V2(j+1,1))             +(P_H(i+11,1)   *V4(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*(2*V2(j+1,1)-V2(j+1-4,1)))+(P_H(i+11,1)*(2*V4(j+1,1)-V4(j+1-4,1))));                    
    
V_A(i+12,a)=FU(i+12,1)  +        (beta*(1-P_B(i+12,1)))*(((1-P_H(i+12,1))   *V2(j+2,1))             +(P_H(i+12,1)   *V4(j+2,1)));
V_A(i+13,a)=FU(i+13,1)  +weight1*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))   *V2(j+2,1))             +(P_H(i+13,1)   *V4(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*(2*V2(j+2,1)-V2(j+2-4,1)))+(P_H(i+13,1)*(2*V4(j+2,1)-V4(j+2-4,1))));                    

V_A(i+14,a)=FU(i+14,1)  +        (beta*(1-P_B(i+14,1)))*(((1-P_H(i+14,1))   *V2(j+3,1))             +(P_H(i+14,1)   *V4(j+3,1)));
V_A(i+15,a)=FU(i+15,1)  +weight1*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))   *V2(j+3,1))             +(P_H(i+15,1)   *V4(j+3,1)))+...
                        +weight2*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*(2*V2(j+3,1)-V2(j+3-4,1)))+(P_H(i+15,1)*(2*V4(j+3,1)-V4(j+3-4,1))));                    

V_A(i+16,a)=FU(i+16,1)  +        (beta*(1-P_B(i+16,1)))*(((1-P_H(i+16,1))   *V2(j+0,1))             +(P_H(i+16,1)   *V4(j+0,1)));
V_A(i+17,a)=FU(i+17,1)  +weight1*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))   *V2(j+0,1))             +(P_H(i+17,1)   *V4(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*(2*V2(j+0,1)-V2(j+0-4,1)))+(P_H(i+17,1)*(2*V4(j+0,1)-V4(j+0-4,1))));                    

V_A(i+18,a)=FU(i+18,1)  +        (beta*(1-P_B(i+18,1)))*(((1-P_H(i+18,1))   *V2(j+1,1))             +(P_H(i+18,1)   *V4(j+1,1)));
V_A(i+19,a)=FU(i+19,1)  +weight1*(beta*(1-P_B(i+19,1)))*(((1-P_H(i+19,1))   *V2(j+1,1))             +(P_H(i+19,1)   *V4(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+19,1)))*(((1-P_H(i+19,1))*(2*V2(j+1,1)-V2(j+1-4,1)))+(P_H(i+19,1)*(2*V4(j+1,1)-V4(j+1-4,1))));                    

V_A(i+20,a)=FU(i+20,1)  +        (beta*(1-P_B(i+20,1)))*(((1-P_H(i+20,1))   *V2(j+2,1))             +(P_H(i+20,1)   *V4(j+2,1)));
V_A(i+21,a)=FU(i+21,1)  +weight1*(beta*(1-P_B(i+21,1)))*(((1-P_H(i+21,1))   *V2(j+2,1))             +(P_H(i+21,1)   *V4(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+21,1)))*(((1-P_H(i+21,1))*(2*V2(j+2,1)-V2(j+2-4,1)))+(P_H(i+21,1)*(2*V4(j+2,1)-V4(j+2-4,1))));                    

V_A(i+22,a)=FU(i+22,1)  +        (beta*(1-P_B(i+22,1)))*(((1-P_H(i+22,1))   *V2(j+3,1))             +(P_H(i+22,1)   *V4(j+3,1)));
V_A(i+23,a)=FU(i+23,1)  +weight1*(beta*(1-P_B(i+23,1)))*(((1-P_H(i+23,1))   *V2(j+3,1))             +(P_H(i+23,1)   *V4(j+3,1)))+...
                        +weight2*(beta*(1-P_B(i+23,1)))*(((1-P_H(i+23,1))*(2*V2(j+3,1)-V2(j+3-4,1)))+(P_H(i+23,1)*(2*V4(j+3,1)-V4(j+3-4,1))));                    

V_A(i+24,a)=FU(i+24,1)  +        (beta*(1-P_B(i+24,1)))*(((1-P_H(i+24,1))   *V2(j+0,1))             +(P_H(i+24,1)   *V4(j+0,1)));
V_A(i+25,a)=FU(i+25,1)  +weight1*(beta*(1-P_B(i+25,1)))*(((1-P_H(i+25,1))   *V2(j+0,1))             +(P_H(i+25,1)   *V4(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+25,1)))*(((1-P_H(i+25,1))*(2*V2(j+0,1)-V2(j+0-4,1)))+(P_H(i+25,1)*(2*V4(j+0,1)-V4(j+0-4,1))));                    

V_A(i+26,a)=FU(i+26,1)  +        (beta*(1-P_B(i+26,1)))*(((1-P_H(i+26,1))   *V2(j+1,1))             +(P_H(i+26,1)   *V4(j+1,1)));
V_A(i+27,a)=FU(i+27,1)  +weight1*(beta*(1-P_B(i+27,1)))*(((1-P_H(i+27,1))   *V2(j+1,1))             +(P_H(i+27,1)   *V4(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+27,1)))*(((1-P_H(i+27,1))*(2*V2(j+1,1)-V2(j+1-4,1)))+(P_H(i+27,1)*(2*V4(j+1,1)-V4(j+1-4,1))));                    

V_A(i+28,a)=FU(i+28,1)  +        (beta*(1-P_B(i+28,1)))*(((1-P_H(i+28,1))   *V2(j+2,1))             +(P_H(i+28,1)   *V4(j+2,1)));
V_A(i+29,a)=FU(i+29,1)  +weight1*(beta*(1-P_B(i+29,1)))*(((1-P_H(i+29,1))   *V2(j+2,1))             +(P_H(i+29,1)   *V4(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+29,1)))*(((1-P_H(i+29,1))*(2*V2(j+2,1)-V2(j+2-4,1)))+(P_H(i+29,1)*(2*V4(j+2,1)-V4(j+2-4,1))));                    

V_A(i+30,a)=FU(i+30,1)  +        (beta*(1-P_B(i+30,1)))*(((1-P_H(i+30,1))   *V2(j+3,1))             +(P_H(i+30,1)   *V4(j+3,1)));
V_A(i+31,a)=FU(i+31,1)  +weight1*(beta*(1-P_B(i+31,1)))*(((1-P_H(i+31,1))   *V2(j+3,1))             +(P_H(i+31,1)   *V4(j+3,1)))+...
                        +weight2*(beta*(1-P_B(i+31,1)))*(((1-P_H(i+31,1))*(2*V2(j+3,1)-V2(j+3-4,1)))+(P_H(i+31,1)*(2*V4(j+3,1)-V4(j+3-4,1))));            
end                    
end
end

for i=3531:18:4323
for j=((i-3531)/18)*3+1
k=(j-1)/3+1;
if mod(k,5)~=0    

V_A(i+0,a) =FU(i+0,1)   +        (beta*(1-P_B(i+0,1))) *(((1-P_H(i+0,1)) *V1(j+0,1))+(P_H(i+0,1) *V3(j+0,1)));
V_A(i+1,a) =FU(i+1,1)   +weight1*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *V1(j+0,1))+(P_H(i+1,1) *V3(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *V1(j+3,1))+(P_H(i+1,1) *V3(j+3,1)));

V_A(i+2,a) =FU(i+2,1)   +        (beta*(1-P_B(i+2,1))) *(((1-P_H(i+2,1)) *V1(j+1,1))+(P_H(i+2,1) *V3(j+1,1)));
V_A(i+3,a) =FU(i+3,1)   +weight1*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *V1(j+1,1))+(P_H(i+3,1) *V3(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *V1(j+4,1))+(P_H(i+3,1) *V3(j+4,1)));

V_A(i+4,a) =FU(i+4,1)   +        (beta*(1-P_B(i+4,1))) *(((1-P_H(i+4,1)) *V1(j+2,1))+(P_H(i+4,1) *V3(j+2,1)));
V_A(i+5,a) =FU(i+5,1)   +weight1*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *V1(j+2,1))+(P_H(i+5,1) *V3(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *V1(j+5,1))+(P_H(i+5,1) *V3(j+5,1)));

V_A(i+6,a) =FU(i+6,1)   +        (beta*(1-P_B(i+6,1))) *(((1-P_H(i+6,1)) *V1(j+0,1))+(P_H(i+6,1) *V3(j+0,1)));
V_A(i+7,a) =FU(i+7,1)   +weight1*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *V1(j+0,1))+(P_H(i+7,1) *V3(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *V1(j+3,1))+(P_H(i+7,1) *V3(j+3,1)));

V_A(i+8,a) =FU(i+8,1)   +        (beta*(1-P_B(i+8,1))) *(((1-P_H(i+8,1)) *V1(j+1,1))+(P_H(i+8,1) *V3(j+1,1)));
V_A(i+9,a) =FU(i+9,1)   +weight1*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *V1(j+1,1))+(P_H(i+9,1) *V3(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *V1(j+4,1))+(P_H(i+9,1) *V3(j+4,1)));

V_A(i+10,a)=FU(i+10,1)  +        (beta*(1-P_B(i+10,1)))*(((1-P_H(i+10,1))*V1(j+2,1))+(P_H(i+10,1)*V3(j+2,1)));
V_A(i+11,a)=FU(i+11,1)  +weight1*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*V1(j+2,1))+(P_H(i+11,1)*V3(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*V1(j+5,1))+(P_H(i+11,1)*V3(j+5,1)));

V_A(i+12,a)=FU(i+12,1)  +        (beta*(1-P_B(i+12,1)))*(((1-P_H(i+12,1))*V1(j+0,1))+(P_H(i+12,1)*V3(j+0,1)));
V_A(i+13,a)=FU(i+13,1)  +weight1*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*V1(j+0,1))+(P_H(i+13,1)*V3(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*V1(j+3,1))+(P_H(i+13,1)*V3(j+3,1)));

V_A(i+14,a)=FU(i+14,1)  +        (beta*(1-P_B(i+14,1)))*(((1-P_H(i+14,1))*V1(j+1,1))+(P_H(i+14,1)*V3(j+1,1)));
V_A(i+15,a)=FU(i+15,1)  +weight1*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*V1(j+1,1))+(P_H(i+15,1)*V3(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*V1(j+4,1))+(P_H(i+15,1)*V3(j+4,1)));

V_A(i+16,a)=FU(i+16,1)  +        (beta*(1-P_B(i+16,1)))*(((1-P_H(i+16,1))*V1(j+2,1))+(P_H(i+16,1)*V3(j+2,1)));
V_A(i+17,a)=FU(i+17,1)  +weight1*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*V1(j+2,1))+(P_H(i+17,1)*V3(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*V1(j+5,1))+(P_H(i+17,1)*V3(j+5,1)));


else
    
V_A(i+0,a) =FU(i+0,1)   +        (beta*(1-P_B(i+0,1))) *(((1-P_H(i+0,1)) *   V1(j+0,1))             +(P_H(i+0,1)   *V3(j+0,1)));
V_A(i+1,a) =FU(i+1,1)   +weight1*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *   V1(j+0,1))             +(P_H(i+1,1)   *V3(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *(2*V1(j+0,1)-V1(j+0-3,1)))+(P_H(i+1,1)*(2*V3(j+0,1)-V3(j+0-3,1))));
    
V_A(i+2,a) =FU(i+2,1)   +        (beta*(1-P_B(i+2,1))) *(((1-P_H(i+2,1)) *   V1(j+1,1))             +(P_H(i+2,1)   *V3(j+1,1)));
V_A(i+3,a) =FU(i+3,1)   +weight1*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *   V1(j+1,1))             +(P_H(i+3,1)   *V3(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *(2*V1(j+1,1)-V1(j+1-3,1)))+(P_H(i+3,1)*(2*V3(j+1,1)-V3(j+1-3,1))));

V_A(i+4,a) =FU(i+4,1)   +        (beta*(1-P_B(i+4,1))) *(((1-P_H(i+4,1)) *   V1(j+2,1))             +(P_H(i+4,1)   *V3(j+2,1)));
V_A(i+5,a) =FU(i+5,1)   +weight1*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *   V1(j+2,1))             +(P_H(i+5,1)   *V3(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *(2*V1(j+2,1)-V1(j+2-3,1)))+(P_H(i+5,1)*(2*V3(j+2,1)-V3(j+2-3,1))));

V_A(i+6,a) =FU(i+6,1)   +        (beta*(1-P_B(i+6,1))) *(((1-P_H(i+6,1)) *   V1(j+0,1))             +(P_H(i+6,1)   *V3(j+0,1)));
V_A(i+7,a) =FU(i+7,1)   +weight1*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *   V1(j+0,1))             +(P_H(i+7,1)   *V3(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *(2*V1(j+0,1)-V1(j+0-3,1)))+(P_H(i+7,1)*(2*V3(j+0,1)-V3(j+0-3,1))));

V_A(i+8,a) =FU(i+8,1)   +        (beta*(1-P_B(i+8,1))) *(((1-P_H(i+8,1)) *   V1(j+1,1))             +(P_H(i+8,1)   *V3(j+1,1)));
V_A(i+9,a) =FU(i+9,1)   +weight1*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *   V1(j+1,1))             +(P_H(i+9,1)   *V3(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *(2*V1(j+1,1)-V1(j+1-3,1)))+(P_H(i+9,1)*(2*V3(j+1,1)-V3(j+1-3,1))));

V_A(i+10,a)=FU(i+10,1)  +        (beta*(1-P_B(i+10,1)))*(((1-P_H(i+10,1))*   V1(j+2,1))             +(P_H(i+10,1)   *V3(j+2,1)));
V_A(i+11,a)=FU(i+11,1)  +weight1*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*   V1(j+2,1))             +(P_H(i+11,1)   *V3(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*(2*V1(j+2,1)-V1(j+2-3,1)))+(P_H(i+11,1)*(2*V3(j+2,1)-V3(j+2-3,1))));

V_A(i+12,a)=FU(i+12,1)  +        (beta*(1-P_B(i+12,1)))*(((1-P_H(i+12,1))*   V1(j+0,1))             +(P_H(i+12,1)   *V3(j+0,1)));
V_A(i+13,a)=FU(i+13,1)  +weight1*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*   V1(j+0,1))             +(P_H(i+13,1)   *V3(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*(2*V1(j+0,1)-V1(j+0-3,1)))+(P_H(i+13,1)*(2*V3(j+0,1)-V3(j+0-3,1))));

V_A(i+14,a)=FU(i+14,1)  +        (beta*(1-P_B(i+14,1)))*(((1-P_H(i+14,1))*   V1(j+1,1))             +(P_H(i+14,1)   *V3(j+1,1)));
V_A(i+15,a)=FU(i+15,1)  +weight1*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*   V1(j+1,1))             +(P_H(i+15,1)   *V3(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*(2*V1(j+1,1)-V1(j+1-3,1)))+(P_H(i+15,1)*(2*V3(j+1,1)-V3(j+1-3,1))));

V_A(i+16,a)=FU(i+16,1)  +        (beta*(1-P_B(i+16,1)))*(((1-P_H(i+16,1))*   V1(j+2,1))             +(P_H(i+16,1)   *V3(j+2,1)));
V_A(i+17,a)=FU(i+17,1)  +weight1*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*   V1(j+2,1))             +(P_H(i+17,1)   *V3(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*(2*V1(j+2,1)-V1(j+2-3,1)))+(P_H(i+17,1)*(2*V3(j+2,1)-V3(j+2-3,1))));


end
end
end


for i=4341:32:7029
for j=((i-4341)/32)*4+1      
k=(j-1)/4+1;
if mod(k,5)~=0 
           
V_A(i+0,a) =FU(i+0,1)   +        (beta*(1-P_B(i+0,1))) *(((1-P_H(i+0,1)) *V2(j+0,1))+(P_H(i+0,1) *V4(j+0,1)));
V_A(i+1,a) =FU(i+1,1)   +weight1*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *V2(j+0,1))+(P_H(i+1,1) *V4(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *V2(j+4,1))+(P_H(i+1,1) *V4(j+4,1)));

V_A(i+2,a) =FU(i+2,1)   +        (beta*(1-P_B(i+2,1))) *(((1-P_H(i+2,1)) *V2(j+1,1))+(P_H(i+2,1) *V4(j+1,1)));
V_A(i+3,a) =FU(i+3,1)   +weight1*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *V2(j+1,1))+(P_H(i+3,1) *V4(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *V2(j+5,1))+(P_H(i+3,1) *V4(j+5,1)));

V_A(i+4,a) =FU(i+4,1)   +        (beta*(1-P_B(i+4,1))) *(((1-P_H(i+4,1)) *V2(j+2,1))+(P_H(i+4,1) *V4(j+2,1)));
V_A(i+5,a) =FU(i+5,1)   +weight1*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *V2(j+2,1))+(P_H(i+5,1) *V4(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *V2(j+6,1))+(P_H(i+5,1) *V4(j+6,1)));

V_A(i+6,a) =FU(i+6,1)   +        (beta*(1-P_B(i+6,1))) *(((1-P_H(i+6,1)) *V2(j+3,1))+(P_H(i+6,1) *V4(j+3,1)));
V_A(i+7,a) =FU(i+7,1)   +weight1*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *V2(j+3,1))+(P_H(i+7,1) *V4(j+3,1)))+...
                        +weight2*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *V2(j+7,1))+(P_H(i+7,1) *V4(j+7,1)));

V_A(i+8,a) =FU(i+8,1)   +        (beta*(1-P_B(i+8,1))) *(((1-P_H(i+8,1)) *V2(j+0,1))+(P_H(i+8,1) *V4(j+0,1)));
V_A(i+9,a) =FU(i+9,1)   +weight1*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *V2(j+0,1))+(P_H(i+9,1) *V4(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *V2(j+4,1))+(P_H(i+9,1) *V4(j+4,1)));

V_A(i+10,a)=FU(i+10,1)  +        (beta*(1-P_B(i+10,1)))*(((1-P_H(i+10,1))*V2(j+1,1))+(P_H(i+10,1)*V4(j+1,1)));
V_A(i+11,a)=FU(i+11,1)  +weight1*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*V2(j+1,1))+(P_H(i+11,1)*V4(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*V2(j+5,1))+(P_H(i+11,1)*V4(j+5,1)));

V_A(i+12,a)=FU(i+12,1)  +        (beta*(1-P_B(i+12,1)))*(((1-P_H(i+12,1))*V2(j+2,1))+(P_H(i+12,1)*V4(j+2,1)));
V_A(i+13,a)=FU(i+13,1)  +weight1*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*V2(j+2,1))+(P_H(i+13,1)*V4(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*V2(j+6,1))+(P_H(i+13,1)*V4(j+6,1)));

V_A(i+14,a)=FU(i+14,1)  +        (beta*(1-P_B(i+14,1)))*(((1-P_H(i+14,1))*V2(j+3,1))+(P_H(i+14,1)*V4(j+3,1)));
V_A(i+15,a)=FU(i+15,1)  +weight1*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*V2(j+3,1))+(P_H(i+15,1)*V4(j+3,1)))+...
                        +weight2*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*V2(j+7,1))+(P_H(i+15,1)*V4(j+7,1)));

V_A(i+16,a)=FU(i+16,1)  +        (beta*(1-P_B(i+16,1)))*(((1-P_H(i+16,1))*V2(j+0,1))+(P_H(i+16,1)*V4(j+0,1)));
V_A(i+17,a)=FU(i+17,1)  +weight1*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*V2(j+0,1))+(P_H(i+17,1)*V4(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*V2(j+4,1))+(P_H(i+17,1)*V4(j+4,1)));

V_A(i+18,a)=FU(i+18,1)  +        (beta*(1-P_B(i+18,1)))*(((1-P_H(i+18,1))*V2(j+1,1))+(P_H(i+18,1)*V4(j+1,1)));
V_A(i+19,a)=FU(i+19,1)  +weight1*(beta*(1-P_B(i+19,1)))*(((1-P_H(i+19,1))*V2(j+1,1))+(P_H(i+19,1)*V4(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+19,1)))*(((1-P_H(i+19,1))*V2(j+5,1))+(P_H(i+19,1)*V4(j+5,1)));

V_A(i+20,a)=FU(i+20,1)  +        (beta*(1-P_B(i+20,1)))*(((1-P_H(i+20,1))*V2(j+2,1))+(P_H(i+20,1)*V4(j+2,1)));
V_A(i+21,a)=FU(i+21,1)  +weight1*(beta*(1-P_B(i+21,1)))*(((1-P_H(i+21,1))*V2(j+2,1))+(P_H(i+21,1)*V4(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+21,1)))*(((1-P_H(i+21,1))*V2(j+6,1))+(P_H(i+21,1)*V4(j+6,1)));

V_A(i+22,a)=FU(i+22,1)  +        (beta*(1-P_B(i+22,1)))*(((1-P_H(i+22,1))*V2(j+3,1))+(P_H(i+22,1)*V4(j+3,1)));
V_A(i+23,a)=FU(i+23,1)  +weight1*(beta*(1-P_B(i+23,1)))*(((1-P_H(i+23,1))*V2(j+3,1))+(P_H(i+23,1)*V4(j+3,1)))+...
                        +weight2*(beta*(1-P_B(i+23,1)))*(((1-P_H(i+23,1))*V2(j+7,1))+(P_H(i+23,1)*V4(j+7,1)));

V_A(i+24,a)=FU(i+24,1)  +        (beta*(1-P_B(i+24,1)))*(((1-P_H(i+24,1))*V2(j+0,1))+(P_H(i+24,1)*V4(j+0,1)));
V_A(i+25,a)=FU(i+25,1)  +weight1*(beta*(1-P_B(i+25,1)))*(((1-P_H(i+25,1))*V2(j+0,1))+(P_H(i+25,1)*V4(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+25,1)))*(((1-P_H(i+25,1))*V2(j+4,1))+(P_H(i+25,1)*V4(j+4,1)));

V_A(i+26,a)=FU(i+26,1)  +        (beta*(1-P_B(i+26,1)))*(((1-P_H(i+26,1))*V2(j+1,1))+(P_H(i+26,1)*V4(j+1,1)));
V_A(i+27,a)=FU(i+27,1)  +weight1*(beta*(1-P_B(i+27,1)))*(((1-P_H(i+27,1))*V2(j+1,1))+(P_H(i+27,1)*V4(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+27,1)))*(((1-P_H(i+27,1))*V2(j+5,1))+(P_H(i+27,1)*V4(j+5,1)));

V_A(i+28,a)=FU(i+28,1)  +        (beta*(1-P_B(i+28,1)))*(((1-P_H(i+28,1))*V2(j+2,1))+(P_H(i+28,1)*V4(j+2,1)));
V_A(i+29,a)=FU(i+29,1)  +weight1*(beta*(1-P_B(i+29,1)))*(((1-P_H(i+29,1))*V2(j+2,1))+(P_H(i+29,1)*V4(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+29,1)))*(((1-P_H(i+29,1))*V2(j+6,1))+(P_H(i+29,1)*V4(j+6,1)));

V_A(i+30,a)=FU(i+30,1)  +        (beta*(1-P_B(i+30,1)))*(((1-P_H(i+30,1))*V2(j+3,1))+(P_H(i+30,1)*V4(j+3,1)));
V_A(i+31,a)=FU(i+31,1)  +weight1*(beta*(1-P_B(i+31,1)))*(((1-P_H(i+31,1))*V2(j+3,1))+(P_H(i+31,1)*V4(j+3,1)))+...
                        +weight2*(beta*(1-P_B(i+31,1)))*(((1-P_H(i+31,1))*V2(j+7,1))+(P_H(i+31,1)*V4(j+7,1)));    

                    
                    
                    
                    
else
    
V_A(i+0,a) =FU(i+0,1)   +        (beta*(1-P_B(i+0,1))) *(((1-P_H(i+0,1))    *V2(j+0,1))             +(P_H(i+0,1)   *V4(j+0,1)));
V_A(i+1,a) =FU(i+1,1)   +weight1*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1))    *V2(j+0,1))             +(P_H(i+1,1)   *V4(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *(2*V2(j+0,1)-V2(j+0-4,1)))+(P_H(i+1,1)*(2*V4(j+0,1)-V4(j+0-4,1))));                    
                    
V_A(i+2,a) =FU(i+2,1)   +        (beta*(1-P_B(i+2,1))) *(((1-P_H(i+2,1))    *V2(j+1,1))             +(P_H(i+2,1)   *V4(j+1,1)));
V_A(i+3,a) =FU(i+3,1)   +weight1*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1))    *V2(j+1,1))             +(P_H(i+3,1)   *V4(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *(2*V2(j+1,1)-V2(j+1-4,1)))+(P_H(i+3,1)*(2*V4(j+1,1)-V4(j+1-4,1))));                    

V_A(i+4,a) =FU(i+4,1)   +        (beta*(1-P_B(i+4,1))) *(((1-P_H(i+4,1))    *V2(j+2,1))             +(P_H(i+4,1)   *V4(j+2,1)));
V_A(i+5,a) =FU(i+5,1)   +weight1*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1))    *V2(j+2,1))             +(P_H(i+5,1)   *V4(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *(2*V2(j+2,1)-V2(j+2-4,1)))+(P_H(i+5,1)*(2*V4(j+2,1)-V4(j+2-4,1))));                    

V_A(i+6,a) =FU(i+6,1)   +        (beta*(1-P_B(i+6,1))) *(((1-P_H(i+6,1))    *V2(j+3,1))             +(P_H(i+6,1)   *V4(j+3,1)));
V_A(i+7,a) =FU(i+7,1)   +weight1*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1))    *V2(j+3,1))             +(P_H(i+7,1)   *V4(j+3,1)))+...
                        +weight2*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *(2*V2(j+3,1)-V2(j+3-4,1)))+(P_H(i+7,1)*(2*V4(j+3,1)-V4(j+3-4,1))));                    

V_A(i+8,a) =FU(i+8,1)   +        (beta*(1-P_B(i+8,1))) *(((1-P_H(i+8,1))    *V2(j+0,1))             +(P_H(i+8,1)   *V4(j+0,1)));
V_A(i+9,a) =FU(i+9,1)   +weight1*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1))    *V2(j+0,1))             +(P_H(i+9,1)   *V4(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *(2*V2(j+0,1)-V2(j+0-4,1)))+(P_H(i+9,1)*(2*V4(j+0,1)-V4(j+0-4,1))));                    

V_A(i+10,a)=FU(i+10,1)  +        (beta*(1-P_B(i+10,1)))*(((1-P_H(i+10,1))   *V2(j+1,1))             +(P_H(i+10,1)   *V4(j+1,1)));
V_A(i+11,a)=FU(i+11,1)  +weight1*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))   *V2(j+1,1))             +(P_H(i+11,1)   *V4(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*(2*V2(j+1,1)-V2(j+1-4,1)))+(P_H(i+11,1)*(2*V4(j+1,1)-V4(j+1-4,1))));                    

V_A(i+12,a)=FU(i+12,1)  +        (beta*(1-P_B(i+12,1)))*(((1-P_H(i+12,1))   *V2(j+2,1))             +(P_H(i+12,1)   *V4(j+2,1)));
V_A(i+13,a)=FU(i+13,1)  +weight1*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))   *V2(j+2,1))             +(P_H(i+13,1)   *V4(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*(2*V2(j+2,1)-V2(j+2-4,1)))+(P_H(i+13,1)*(2*V4(j+2,1)-V4(j+2-4,1))));                    

V_A(i+14,a)=FU(i+14,1)  +        (beta*(1-P_B(i+14,1)))*(((1-P_H(i+14,1))   *V2(j+3,1))             +(P_H(i+14,1)   *V4(j+3,1)));
V_A(i+15,a)=FU(i+15,1)  +weight1*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))   *V2(j+3,1))             +(P_H(i+15,1)   *V4(j+3,1)))+...
                        +weight2*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*(2*V2(j+3,1)-V2(j+3-4,1)))+(P_H(i+15,1)*(2*V4(j+3,1)-V4(j+3-4,1))));                    

V_A(i+16,a)=FU(i+16,1)  +        (beta*(1-P_B(i+16,1)))*(((1-P_H(i+16,1))   *V2(j+0,1))             +(P_H(i+16,1)   *V4(j+0,1)));
V_A(i+17,a)=FU(i+17,1)  +weight1*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))   *V2(j+0,1))             +(P_H(i+17,1)   *V4(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*(2*V2(j+0,1)-V2(j+0-4,1)))+(P_H(i+17,1)*(2*V4(j+0,1)-V4(j+0-4,1))));                    

V_A(i+18,a)=FU(i+18,1)  +        (beta*(1-P_B(i+18,1)))*(((1-P_H(i+18,1))   *V2(j+1,1))             +(P_H(i+18,1)   *V4(j+1,1)));
V_A(i+19,a)=FU(i+19,1)  +weight1*(beta*(1-P_B(i+19,1)))*(((1-P_H(i+19,1))   *V2(j+1,1))             +(P_H(i+19,1)   *V4(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+19,1)))*(((1-P_H(i+19,1))*(2*V2(j+1,1)-V2(j+1-4,1)))+(P_H(i+19,1)*(2*V4(j+1,1)-V4(j+1-4,1))));                    

V_A(i+20,a)=FU(i+20,1)  +        (beta*(1-P_B(i+20,1)))*(((1-P_H(i+20,1))   *V2(j+2,1))             +(P_H(i+20,1)   *V4(j+2,1)));
V_A(i+21,a)=FU(i+21,1)  +weight1*(beta*(1-P_B(i+21,1)))*(((1-P_H(i+21,1))   *V2(j+2,1))             +(P_H(i+21,1)   *V4(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+21,1)))*(((1-P_H(i+21,1))*(2*V2(j+2,1)-V2(j+2-4,1)))+(P_H(i+21,1)*(2*V4(j+2,1)-V4(j+2-4,1))));                    

V_A(i+22,a)=FU(i+22,1)  +        (beta*(1-P_B(i+22,1)))*(((1-P_H(i+22,1))   *V2(j+3,1))             +(P_H(i+22,1)   *V4(j+3,1)));
V_A(i+23,a)=FU(i+23,1)  +weight1*(beta*(1-P_B(i+23,1)))*(((1-P_H(i+23,1))   *V2(j+3,1))             +(P_H(i+23,1)   *V4(j+3,1)))+...
                        +weight2*(beta*(1-P_B(i+23,1)))*(((1-P_H(i+23,1))*(2*V2(j+3,1)-V2(j+3-4,1)))+(P_H(i+23,1)*(2*V4(j+3,1)-V4(j+3-4,1))));                    

V_A(i+24,a)=FU(i+24,1)  +        (beta*(1-P_B(i+24,1)))*(((1-P_H(i+24,1))   *V2(j+0,1))             +(P_H(i+24,1)   *V4(j+0,1)));
V_A(i+25,a)=FU(i+25,1)  +weight1*(beta*(1-P_B(i+25,1)))*(((1-P_H(i+25,1))   *V2(j+0,1))             +(P_H(i+25,1)   *V4(j+0,1)))+...
                        +weight2*(beta*(1-P_B(i+25,1)))*(((1-P_H(i+25,1))*(2*V2(j+0,1)-V2(j+0-4,1)))+(P_H(i+25,1)*(2*V4(j+0,1)-V4(j+0-4,1))));                    

V_A(i+26,a)=FU(i+26,1)  +        (beta*(1-P_B(i+26,1)))*(((1-P_H(i+26,1))   *V2(j+1,1))             +(P_H(i+26,1)   *V4(j+1,1)));
V_A(i+27,a)=FU(i+27,1)  +weight1*(beta*(1-P_B(i+27,1)))*(((1-P_H(i+27,1))   *V2(j+1,1))             +(P_H(i+27,1)   *V4(j+1,1)))+...
                        +weight2*(beta*(1-P_B(i+27,1)))*(((1-P_H(i+27,1))*(2*V2(j+1,1)-V2(j+1-4,1)))+(P_H(i+27,1)*(2*V4(j+1,1)-V4(j+1-4,1))));                    

V_A(i+28,a)=FU(i+28,1)  +        (beta*(1-P_B(i+28,1)))*(((1-P_H(i+28,1))   *V2(j+2,1))             +(P_H(i+28,1)   *V4(j+2,1)));
V_A(i+29,a)=FU(i+29,1)  +weight1*(beta*(1-P_B(i+29,1)))*(((1-P_H(i+29,1))   *V2(j+2,1))             +(P_H(i+29,1)   *V4(j+2,1)))+...
                        +weight2*(beta*(1-P_B(i+29,1)))*(((1-P_H(i+29,1))*(2*V2(j+2,1)-V2(j+2-4,1)))+(P_H(i+29,1)*(2*V4(j+2,1)-V4(j+2-4,1))));                    

V_A(i+30,a)=FU(i+30,1)  +        (beta*(1-P_B(i+30,1)))*(((1-P_H(i+30,1))   *V2(j+3,1))             +(P_H(i+30,1)   *V4(j+3,1)));
V_A(i+31,a)=FU(i+31,1)  +weight1*(beta*(1-P_B(i+31,1)))*(((1-P_H(i+31,1))   *V2(j+3,1))             +(P_H(i+31,1)   *V4(j+3,1)))+...
                        +weight2*(beta*(1-P_B(i+31,1)))*(((1-P_H(i+31,1))*(2*V2(j+3,1)-V2(j+3-4,1)))+(P_H(i+31,1)*(2*V4(j+3,1)-V4(j+3-4,1))));            
end                    
end
end

% V_A(:,a)

end




%7  USE V_A TO CREATE CCPS (EXPLOIT EV TYPE I ERROR ASSUMPTIONS)

exp_VA=exp(V_A-(max(transpose(max(V_A)))));

ccp=zeros(size(V_A));

for d0=1:6:805
    d1=d0+5;
    for x=d0:d1
        
    ccp(x,:)=times(exp_VA(x,:),power((sum(exp_VA(d0:d1,:))),-1));
    
    end
end

for d0=811:8:3523 
    d1=d0+7; 
    for x=d0:d1

    ccp(x,:)=times(exp_VA(x,:),power((sum(exp_VA(d0:d1,:))),-1));
    
    end
end

for d0=3531:6:4335 
    d1=d0+5;
    for x=d0:d1
        
    ccp(x,:)=times(exp_VA(x,:),power((sum(exp_VA(d0:d1,:))),-1));
    
    end
end

for d0=4341:8:7053 
    d1=d0+7; 
    for x=d0:d1

    ccp(x,:)=times(exp_VA(x,:),power((sum(exp_VA(d0:d1,:))),-1));
    
    end
end

CCP(:,:,type)=[ccp(:,1:70) sig];

end


 



% VALUES
% E_INDSM  = E_INDSM(v_it,E_it,d_m0,d_l1,d_m1,H_it)

for E=10:10:50
for A=30:3:60

a=(A-30)*2+1;
v=24;
dm0=0;
H=1;

V_sim(:,1)=  V_A(E_INDSM(v,E,dm0,0,0,H):E_INDSM(v,E,dm0,1,3,H),a);
CCP_sim(:,1)=CCP(E_INDSM(v,E,dm0,0,0,H):E_INDSM(v,E,dm0,1,3,H),a);
r=((a-1)/6)+1+(((E-10)/10)*11);

%VALUE Decomposition for HAART
if     HAART==1 && INC==0
V1_sim(r,1)=sum(times(V_sim(:,1),CCP_sim(:,1)));
elseif HAART==0 && INC==0
V1_sim(r,2)=sum(times(V_sim(:,1),CCP_sim(:,1)));
end
if HAART==0
g=INC+2;
V1_sim(r,g)=sum(times(V_sim(:,1),CCP_sim(:,1)));
end





a=(A-30)*2+1;
v=24;
dm0=0;
H=0;

V_sim(:,1)=  V_A(E_INDSM(v,E,dm0,0,0,H):E_INDSM(v,E,dm0,1,3,H),a);
CCP_sim(:,1)=CCP(E_INDSM(v,E,dm0,0,0,H):E_INDSM(v,E,dm0,1,3,H),a);

r=((a-1)/6)+1+(((E-10)/10)*11);

%VALUE Decomposition for HAART
if     HAART==1 && INC==0
V0_sim(r,1)=sum(times(V_sim(:,1),CCP_sim(:,1)));
elseif HAART==0 && INC==0
V0_sim(r,2)=sum(times(V_sim(:,1),CCP_sim(:,1)));
end

if HAART==0
g=INC+2;
V0_sim(r,g)=sum(times(V_sim(:,1),CCP_sim(:,1)));
end




end
end
end
end

%HIGH CD4

g=size(V1_sim,2)+1;
for x=1:size(V1_sim,1)
i=1;
while i<=size(V1_sim,2);
if V1_sim(x,i+2)>=V1_sim(x,1)
    V1_sim(x,g)=INCREMENT*(i); 
    i=size(V1_sim,2)+1;
else
    i=i+1;
end
end
end


ANNU(:,1)=[...
    10*ones(11,1);
    20*ones(11,1);
    30*ones(11,1);
    40*ones(11,1);
    50*ones(11,1);];

ANNU(:,2)=[...
    30;33;36;39;42;45;48;51;54;57;60;
    30;33;36;39;42;45;48;51;54;57;60;
    30;33;36;39;42;45;48;51;54;57;60;
    30;33;36;39;42;45;48;51;54;57;60;
    30;33;36;39;42;45;48;51;54;57;60;];


% ANNU(:,3)=2*[...
% 8;8;8;7;7;7;6;6;5;5;5;
% 8;8;8;7;7;7;6;6;5;5;5;
% 8;8;8;7;7;7;6;6;5;5;5;
% 8;8;8;7;7;7;6;6;5;5;5;
% 8;8;8;7;7;7;6;6;5;5;5;];

ANNU(:,3)=2*[...
12;12;12;11;11;11;10;10;9;9;9;
12;12;12;11;11;11;10;10;9;9;9;
12;12;12;11;11;11;10;10;9;9;9;
12;12;12;11;11;11;10;10;9;9;9;
12;12;12;11;11;11;10;10;9;9;9;];

ANNU(:,4)=V1_sim(:,size(V1_sim,2));

%GROSS
ANNU(:,4)=ANNU(:,4)/(2/3);
%GROSS

ANNU(:,5)=((times((((1-power(1.03,-ANNU(:,3)))/0.03)*1.03),ANNU(:,4))))/1000;

if SIM_TYPE==1

EXP101=[ANNU(1:11,2)    ANNU(1:11,5)];
EXP201=[ANNU(12+1:22,2) ANNU(12+1:22,5)];
EXP301=[ANNU(23+2:33,2) ANNU(23+2:33,5)];
EXP401=[ANNU(34+4:44,2) ANNU(34+4:44,5)];
EXP501=[ANNU(45+5:55,2) ANNU(45+5:55,5)];
    
elseif SIM_TYPE==2
    
EXP102=[ANNU(1:11,2)    ANNU(1:11,5)];
EXP202=[ANNU(12+1:22,2) ANNU(12+1:22,5)];
EXP302=[ANNU(23+2:33,2) ANNU(23+2:33,5)];
EXP402=[ANNU(34+4:44,2) ANNU(34+4:44,5)];
EXP502=[ANNU(45+5:55,2) ANNU(45+5:55,5)];
    
elseif SIM_TYPE==3
    
EXP103=[ANNU(1:11,2)    ANNU(1:11,5)];
EXP203=[ANNU(12+1:22,2) ANNU(12+1:22,5)];
EXP303=[ANNU(23+2:33,2) ANNU(23+2:33,5)];
EXP403=[ANNU(34+4:44,2) ANNU(34+4:44,5)];
EXP503=[ANNU(45+5:55,2) ANNU(45+5:55,5)];
    
else
    
EXP104=[ANNU(1:11,2)    ANNU(1:11,5)];
EXP204=[ANNU(12+1:22,2) ANNU(12+1:22,5)];
EXP304=[ANNU(23+2:33,2) ANNU(23+2:33,5)];
EXP404=[ANNU(34+4:44,2) ANNU(34+4:44,5)];
EXP504=[ANNU(45+5:55,2) ANNU(45+5:55,5)];
    
end


end

cd ..

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clf reset

set(0,'DefaultAxesColorOrder',[0 0 0],...
      'DefaultAxesLineStyleOrder','-');
a = get(gca,'XTickLabel');
set(gca,'XTickLabel',a,'fontsize',15)
a = get(gca,'XTickLabel');
set(gca,'YTickLabel',a,'fontsize',15)
 
plot(...
    EXP101(:,1),EXP101(:,2),...
    EXP201(:,1),EXP201(:,2),...
    EXP301(:,1),EXP301(:,2),...
    EXP401(:,1),EXP401(:,2),...
    EXP501(:,1),EXP501(:,2),...
    'LineWidth', 1.5)
 
xlabel('Age','FontSize',25)
ylabel('Payment (X $1,000)','FontSize',25)

text(34,10,'\leftarrow Exp=5',...
     'HorizontalAlignment','left','FontSize', 12)
text(38.0,12,'\leftarrow Exp=10',...
     'HorizontalAlignment','left','FontSize', 12)
text(42.0,13.5,'\leftarrow Exp=15',...
     'HorizontalAlignment','left','FontSize', 12)
text(46.0,15,'\leftarrow Exp=20',...
     'HorizontalAlignment','left','FontSize', 12)
text(51,17,'\leftarrow Exp=25',...
     'HorizontalAlignment','left','FontSize', 12)
print('-dpng' , 'Artwork/sim5_plot_1')
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if No_SIM_TYPES>1

clf reset

set(0,'DefaultAxesColorOrder',[0 0 0],...
      'DefaultAxesLineStyleOrder','-');
a = get(gca,'XTickLabel');
set(gca,'XTickLabel',a,'fontsize',15)
a = get(gca,'XTickLabel');
set(gca,'YTickLabel',a,'fontsize',15)
 
plot(...
    EXP102(:,1),EXP102(:,2),...
    EXP202(:,1),EXP202(:,2),...
    EXP302(:,1),EXP302(:,2),...
    EXP402(:,1),EXP402(:,2),...
    EXP502(:,1),EXP502(:,2),...
    'LineWidth', 1.5)
 
xlabel('Age','FontSize',25)
ylabel('Payment (X $1,000)','FontSize',25)

text(35,8,'\leftarrow Exp=5',...
     'HorizontalAlignment','left','FontSize', 12)
text(39,9.5,'\leftarrow Exp=10',...
     'HorizontalAlignment','left','FontSize', 12)
text(43.0,11.0,'\leftarrow Exp=15',...
     'HorizontalAlignment','left','FontSize', 12)
text(47,12.5,'\leftarrow Exp=20',...
     'HorizontalAlignment','left','FontSize', 12)
text(51,14,'\leftarrow Exp=25',...
     'HorizontalAlignment','left','FontSize', 12)
print('-dpng' , 'Artwork/sim5_plot_2')

end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if No_SIM_TYPES>2

clf reset

set(0,'DefaultAxesColorOrder',[0 0 0],...
      'DefaultAxesLineStyleOrder','-');
a = get(gca,'XTickLabel');
set(gca,'XTickLabel',a,'fontsize',15)
a = get(gca,'XTickLabel');
set(gca,'YTickLabel',a,'fontsize',15)
 
plot(...
    EXP103(:,1),EXP103(:,2),...
    EXP203(:,1),EXP203(:,2),...
    EXP303(:,1),EXP303(:,2),...
    EXP403(:,1),EXP403(:,2),...
    EXP503(:,1),EXP503(:,2),...
    'LineWidth', 1.5)
 
xlabel('Age','FontSize',25)
ylabel('Payment (X $1,000)','FontSize',25)

text(32.5,100,'\leftarrow Exp=5',...
     'HorizontalAlignment','left','FontSize', 12)
text(36.25,115,'\leftarrow Exp=10',...
     'HorizontalAlignment','left','FontSize', 12)
text(40,125,'\leftarrow Exp=15',...
     'HorizontalAlignment','left','FontSize', 12)
text(43.3,137,'\leftarrow Exp=20',...
     'HorizontalAlignment','left','FontSize', 12)
text(46.95,150,'\leftarrow Exp=25',...
     'HorizontalAlignment','left','FontSize', 12)
print('-dpng' , 'Artwork/sim5_plot_3')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


clf reset

set(0,'DefaultAxesColorOrder',[0 0 0],...
      'DefaultAxesLineStyleOrder','-');
a = get(gca,'XTickLabel');
set(gca,'XTickLabel',a,'fontsize',15)
a = get(gca,'XTickLabel');
set(gca,'YTickLabel',a,'fontsize',15)
 
plot(...
    EXP104(:,1),EXP104(:,2),...
    EXP204(:,1),EXP204(:,2),...
    EXP304(:,1),EXP304(:,2),...
    EXP404(:,1),EXP404(:,2),...
    EXP504(:,1),EXP504(:,2),...
    'LineWidth', 1.5)
 
xlabel('Age','FontSize',25)
ylabel('Payment (X $1,000)','FontSize',25)

text(34.5,80,'\leftarrow Exp=5',...
     'HorizontalAlignment','left','FontSize', 12)
text(38.15,90,'\leftarrow Exp=10',...
     'HorizontalAlignment','left','FontSize', 12)
text(41.55,100,'\leftarrow Exp=15',...
     'HorizontalAlignment','left','FontSize', 12)
text(42.34,130,'\leftarrow Exp=20',...
     'HorizontalAlignment','left','FontSize', 12)
text(45.5,140,'\leftarrow Exp=25',...
     'HorizontalAlignment','left','FontSize', 12)
print('-dpng' , 'Artwork/sim5_plot_4')

end

cd ('Matlab')



























% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  
% %18    V A L U E OF C O U N T E R F A C T U A L D R U G S
% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% display 'BEGIN: SIMULATION COUNTERFACTUAL DRUGS'
% display 'USE AN ANNUITY'
% display 'NOTE: USE ALT 2 CODE - 1 TYPE'
% 
% %18.1   SET PARAMETERS
% 
% for SIM_TYPE=1:No_SIM_TYPES   
% 
% % for SIM_TYPE=4:4    
% 
% 
% %Here: Define parameter Values for Different Types
% %(Can alter both P and TP's)
% 
% if SIM_TYPE==1
% 
% th_ml=[theta0_U1;theta0_A1];      
% 
% beta_p      =beta_p1;
% beta_D      =beta_D1; 
% beta_H      =beta_H1; 
% beta_F      =beta_F1; 
% beta_B      =beta_B1; 
% beta_I      =beta_I1; 
% beta_N      =beta_N1;
% 
% elseif SIM_TYPE==2
%     
% th_ml=[theta0_U2;theta0_A2];      
% 
% beta_p      =beta_p1;
% beta_D      =beta_D1; 
% beta_H      =beta_H1; 
% beta_F      =beta_F1; 
% beta_B      =beta_B1; 
% beta_I      =beta_I1; 
% beta_N      =beta_N1;
% 
% elseif SIM_TYPE==3
% 
% th_ml=[theta0_U1;theta0_A1];      
% 
% beta_p      =beta_p2;
% beta_D      =beta_D2; 
% beta_H      =beta_H2; 
% beta_F      =beta_F2; 
% beta_B      =beta_B2; 
% beta_I      =beta_I2; 
% beta_N      =beta_N2;
% 
% elseif SIM_TYPE==4
%     
% th_ml=[theta0_U2;theta0_A2];      
% 
% beta_p      =beta_p2;
% beta_D      =beta_D2; 
% beta_H      =beta_H2; 
% beta_F      =beta_F2; 
% beta_B      =beta_B2; 
% beta_I      =beta_I2; 
% beta_N      =beta_N2;
% 
% end  
% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% N_CFDRUG=8;
% 
% INCREMENT=250;
% 
% for CFDRUG=1:N_CFDRUG
% for INC=0:600    
%     
%     CFDRUG
%     INC
% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% th_P1=beta_p(1:17,1);
% th_S1=ones(4,1)*beta_p(18,1);
% th_D1=beta_D(1:9,1);
% th_H1=beta_H(1:4,1);
% th_F1=beta_F(1:9,1);
% th_B1=beta_B(1:4,1);
% th_I1=beta_I(1:13,1);
% th_N1=beta_N(10:27,1);
% 
% th_ml_U1   =th_ml(1:LU1,1);      
% th_ml_A1   =th_ml(LU1+1:LU1+LA1,1);      
% alpha1     =times(exp(th_ml_A1),power(1+exp(th_ml_A1),-1));
% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % 1 HAART AS COMBO
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% if CFDRUG==1
% 
% %HAART EFFECTIVE AS COMBO
% th_D1(4,1)=beta_D(3,1);
% th_D1(7,1)=beta_D(6,1);
% 
% %HAART HAS NO INFLUENCE ON SFX
% th_F1(4,1)=beta_F(3,1);
% th_F1(7,1)=beta_F(6,1);
% 
% %HAART COSTS AS COMBO
% th_P1(7,1)=beta_p(6,1);
% th_P1(14,1)=beta_p(12,1);
% th_P1(15,1)=beta_p(13,1);
% 
% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % 2 HAART AS IS
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% elseif CFDRUG==2
%     
% %No Change    
% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % 3 HAART HAART HAART
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% elseif CFDRUG==3
%     
% %Replace Mono & Combo with HAART [Effectiveness]
% th_D1(2,1)=beta_D(4,1);
% th_D1(3,1)=beta_D(4,1);
% th_D1(5,1)=beta_D(7,1);
% th_D1(6,1)=beta_D(7,1);
% 
% %Replace Mono & Combo with HAART [SFX]
% th_F1(2,1)=beta_F(4,1);
% th_F1(3,1)=beta_F(4,1);
% th_F1(5,1)=beta_F(7,1);
% th_F1(6,1)=beta_F(7,1);
% 
% %HAART+ Cost = Cost of HAART
% th_P1(5,1)=beta_p(7,1);
% th_P1(6,1)=beta_p(7,1);
% th_P1(10,1)=beta_p(14,1);
% th_P1(11,1)=beta_p(15,1);
% th_P1(12,1)=beta_p(14,1);
% th_P1(13,1)=beta_p(15,1);
% 
% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % 4 HAART HAART H+F
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% elseif CFDRUG==4
%     
% %Replace Mono & Combo with HAART [Effectiveness]
% th_D1(2,1)=beta_D(4,1);
% th_D1(3,1)=beta_D(4,1);
% th_D1(5,1)=beta_D(7,1);
% th_D1(6,1)=beta_D(7,1);
% 
% %Replace Mono & Combo with HAART [SFX]
% th_F1(2,1)=beta_F(4,1);
% th_F1(3,1)=beta_F(4,1);
% th_F1(5,1)=beta_F(7,1);
% th_F1(6,1)=beta_F(7,1);
% 
% %HAART+ Cost = Cost of HAART
% th_P1(5,1)=beta_p(7,1);
% th_P1(6,1)=beta_p(7,1);
% th_P1(10,1)=beta_p(14,1);
% th_P1(11,1)=beta_p(15,1);
% th_P1(12,1)=beta_p(14,1);
% th_P1(13,1)=beta_p(15,1);
% 
% %NO SFX BOOST
% th_F1(4,1)=0;
% th_F1(7,1)=0;
% 
% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % 5 HAART Setback F Innovation H
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% elseif CFDRUG==5
%     
% %Replace Mono & Combo with HAART [Effectiveness]
% th_D1(2,1)=beta_D(4,1);
% th_D1(3,1)=beta_D(4,1);
% th_D1(5,1)=beta_D(7,1);
% th_D1(6,1)=beta_D(7,1);
% 
% %Replace Mono & Combo with HAART [SFX]
% th_F1(2,1)=beta_F(4,1);
% th_F1(3,1)=beta_F(4,1);
% th_F1(5,1)=beta_F(7,1);
% th_F1(6,1)=beta_F(7,1);
% 
% %HAART+ Cost = Cost of HAART
% th_P1(5,1)=beta_p(7,1);
% th_P1(6,1)=beta_p(7,1);
% th_P1(10,1)=beta_p(14,1);
% th_P1(11,1)=beta_p(15,1);
% th_P1(12,1)=beta_p(14,1);
% th_P1(13,1)=beta_p(15,1);
% 
% %EFFECTIVENESS BOOST
% th_D1(4,1)=12;
% th_D1(7,1)=12;
% 
% %NO SFX BOOST
% th_F1(4,1)=-12;
% th_F1(7,1)=-12;
% 
% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % 6 HAART HAART H+H
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% elseif CFDRUG==6
%     
% %Replace Mono & Combo with HAART [Effectiveness]
% th_D1(2,1)=beta_D(4,1);
% th_D1(3,1)=beta_D(4,1);
% th_D1(5,1)=beta_D(7,1);
% th_D1(6,1)=beta_D(7,1);
% 
% %Replace Mono & Combo with HAART [SFX]
% th_F1(2,1)=beta_F(4,1);
% th_F1(3,1)=beta_F(4,1);
% th_F1(5,1)=beta_F(7,1);
% th_F1(6,1)=beta_F(7,1);
% 
% %HAART+ Cost = Cost of HAART
% th_P1(5,1)=beta_p(7,1);
% th_P1(6,1)=beta_p(7,1);
% th_P1(10,1)=beta_p(14,1);
% th_P1(11,1)=beta_p(15,1);
% th_P1(12,1)=beta_p(14,1);
% th_P1(13,1)=beta_p(15,1);
% 
% %NO SFX BOOST
% th_D1(4,1)=12;
% th_D1(7,1)=12;
% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % 6 HAART H+H H+F
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% elseif CFDRUG==7
%     
% %Replace Mono & Combo with HAART [Effectiveness]
% th_D1(2,1)=beta_D(4,1);
% th_D1(3,1)=beta_D(4,1);
% th_D1(5,1)=beta_D(7,1);
% th_D1(6,1)=beta_D(7,1);
% 
% %Replace Mono & Combo with HAART [SFX]
% th_F1(2,1)=beta_F(4,1);
% th_F1(3,1)=beta_F(4,1);
% th_F1(5,1)=beta_F(7,1);
% th_F1(6,1)=beta_F(7,1);
% 
% %HAART+ Cost = Cost of HAART
% th_P1(5,1)=beta_p(7,1);
% th_P1(6,1)=beta_p(7,1);
% th_P1(10,1)=beta_p(14,1);
% th_P1(11,1)=beta_p(15,1);
% th_P1(12,1)=beta_p(14,1);
% th_P1(13,1)=beta_p(15,1);
% 
% %EFFECTIVENESS BOOST
% th_D1(3,1)=12;
% th_D1(6,1)=12;
% 
% %NO SFX BOOST
% th_F1(4,1)=0;
% th_F1(7,1)=0;
% 
% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % 7  HAART HAART HHF
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% elseif CFDRUG==8
%     
% %Replace Mono & Combo with HAART [Effectiveness]
% th_D1(2,1)=beta_D(4,1);
% th_D1(3,1)=beta_D(4,1);
% th_D1(5,1)=beta_D(7,1);
% th_D1(6,1)=beta_D(7,1);
% 
% %Replace Mono & Combo with HAART [SFX]
% th_F1(2,1)=beta_F(4,1);
% th_F1(3,1)=beta_F(4,1);
% th_F1(5,1)=beta_F(7,1);
% th_F1(6,1)=beta_F(7,1);
% 
% %HAART+ Cost = Cost of HAART
% th_P1(5,1)=beta_p(7,1);
% th_P1(6,1)=beta_p(7,1);
% th_P1(10,1)=beta_p(14,1);
% th_P1(11,1)=beta_p(15,1);
% th_P1(12,1)=beta_p(14,1);
% th_P1(13,1)=beta_p(15,1);
% 
% %EFFECTIVENESS BOOST
% th_D1(4,1)=12;
% th_D1(7,1)=12;
% 
% %NO SFX BOOST
% th_F1(4,1)=0;
% th_F1(7,1)=0;
% 
% end
% 
% CFDRUG
% INC
% th_D1
% th_F1
% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %4  SETUP FOR BACKWARD RECURSION
% 
% CCP=zeros(DIM,71,L);
% 
% for type=1:L
% V_A=zeros(DIM,71);
%  
%     
% %5  BACKWARD RECURSION: BEGIN WITH RETIREMENT AGE (65)
% 
% %Start w. Retirement A=65)
%     
% for A=65 
% 
% %TP Cube Layer (Using A_it)
%     a=(A-30)*2+1;                                         
% %TP for this iteration
%     TPa=TP(:,:,a);  
% 
% %Extract from TP Components for Flow Utility and Transitions
%     
% TP_v        =TPa(:,1);    
% TP_dh       =TPa(:,2);
% TP_H        =TPa(:,3);    
% TP_E        =TPa(:,4);    
% TP_dl0_1    =TPa(:,5);
% TP_dl1_1    =TPa(:,6);
% TP_dm0_0    =TPa(:,7);
% TP_dm1_0    =TPa(:,8);
% TP_dm2_0    =TPa(:,9);
% TP_dm3_0    =TPa(:,10);
% TP_dm0_1    =TPa(:,11);
% TP_dm1_1    =TPa(:,12);
% TP_dm2_1    =TPa(:,13);
% TP_dm3_1    =TPa(:,14);
% 
% PP_B        =TPa(:,15);
% PP_H        =TPa(:,16);
% PP_F        =TPa(:,17);
% 
% EE_I         =TPa(:,18);
% 
% EE_N1        =TPa(:,19);
% EE_N2        =TPa(:,20);
% 
% EE_IP    =(EE_I+2500)/5000;
% 
% %OOC ~ Health ~ Symptoms/SFX  
% 
% if type==1 || type==2
%     
% XB_B=...
%     th_B1(1,1)*TP_H+...
%     th_B1(2,1)*A*TP_H+...
%     th_B1(3,1)*A+...
%     th_B1(4,1);
% 
% P_B=exp(XB_B);
% P_B=times(P_B,power((1+P_B),-1));     
%     
% XB_D=...
%     th_D1(1,1)*TP_H+...
%     th_D1(2,1)*times((1-TP_H),TP_dm1_1)+...
%     th_D1(3,1)*times((1-TP_H),TP_dm2_1)+...
%     th_D1(4,1)*times((1-TP_H),TP_dm3_1)+...
%     th_D1(5,1)*times((TP_H)  ,TP_dm1_1)+...
%     th_D1(6,1)*times((TP_H)  ,TP_dm2_1)+...
%     th_D1(7,1)*times((TP_H)  ,TP_dm3_1)+...
%     th_D1(8,1)*TP_v+...
%     th_D1(9,1);
% 
% 
% DH=exp(XB_D);
% DH=times(DH,power((1+DH),-1));
% DH0=times(DH,(1-TP_H));
% DH1=times(DH,(TP_H));
% 
% XB_H=...
%     th_H1(1,1)*TP_H+...
%     th_H1(2,1)*DH0+...
%     th_H1(3,1)*DH1+...
%     th_H1(4,1);
% 
% P_H=exp(XB_H);
% P_H=times(P_H,power((1+P_H),-1));
% 
% 
% 
% XB_F=...
%     th_F1(1,1)*TP_H+...  
%     th_F1(2,1)*times((1-TP_H),TP_dm1_1)+...
%     th_F1(3,1)*times((1-TP_H),TP_dm2_1)+...
%     th_F1(4,1)*times((1-TP_H),TP_dm3_1)+...
%     th_F1(5,1)*times((TP_H)  ,TP_dm1_1)+...
%     th_F1(6,1)*times((TP_H)  ,TP_dm2_1)+...
%     th_F1(7,1)*times((TP_H)  ,TP_dm3_1)+...
%     th_F1(8,1)*TP_v+...
%     th_F1(9,1);
% 
% P_F=exp(XB_F);
% P_F=times(P_F,power((1+P_F),-1));
% 
% XB_I=...
%     th_I1(1,1)*TP_H+...
%     th_I1(2,1)*TP_E+...
%     th_I1(3,1)*times(TP_E,TP_E)+...
%     th_I1(4,1)*A+...
%     th_I1(5,1)*(TP_v-14)+...
%    (times(TP_dl1_1,...
%    (th_I1(6,1)+... 
%     th_I1(7,1)*TP_H+...
%     th_I1(8,1)*TP_E+...
%     th_I1(9,1)*times(TP_E,TP_E)+...
%     th_I1(10,1)*A+...
%     th_I1(11,1)*(TP_v-14))))+...
%     th_I1(12,1);
% 
% sig=th_I1(13,1);
% 
% w=times((XB_I-2500),power(sig,-1));
% phi_1=normpdf(w,0,1);  
% phi_2=normcdf(w,0,1);  
% E_I=(2500*(1-phi_2))+(times(phi_2,XB_I)+times(sig,phi_1)); %left censored; See C&T p541 
% E_IP    =(E_I+2500)/5000;
% 
% %%%%%%%%%%%%%%%%%%%%%%
% E_I=E_I+INC*INCREMENT;
% %%%%%%%%%%%%%%%%%%%%%%
% 
% XB_N_1=...
%     th_N1(1,1)*TP_dl1_1+...
%     th_N1(2,1)*TP_H+...
%     th_N1(3,1)*TP_E+...
%     th_N1(4,1)*times(TP_E,TP_E)+...
%     th_N1(5,1)*A+...
%     th_N1(6,1)*A^2+...
%     th_N1(7,1)*(TP_v)+...
%     th_N1(8,1)*times(TP_v-24,TP_dh)+...
%     th_N1(9,1);
% 
% XB_N_2=...
%     th_N1(10,1)*TP_dl1_1+...
%     th_N1(11,1)*TP_H+...
%     th_N1(12,1)*TP_E+...
%     th_N1(13,1)*times(TP_E,TP_E)+...
%     th_N1(14,1)*A+...
%     th_N1(15,1)*A^2+...
%     th_N1(16,1)*(TP_v)+...
%     th_N1(17,1)*times(TP_v-24,TP_dh)+...
%     th_N1(18,1);
% 
% 
% XB_N_1=exp(XB_N_1);
% XB_N_2=exp(XB_N_2);
% 
% E_N1=times(XB_N_1,power((1+XB_N_1+XB_N_2),-1));
% E_N2=times(XB_N_2,power((1+XB_N_1+XB_N_2),-1));
% 
% XB_P=...
%     th_P1(1,1)*P_H+...
%     th_P1(2,1)*times((1-P_F),P_H)+...
%     th_P1(3,1)*times((1-P_F),(1-P_H))+...
%     th_P1(4,1)*E_IP+...
%     th_P1(5,1)*TP_dm1_1+...
%     th_P1(6,1)*TP_dm2_1+...
%     th_P1(7,1)*TP_dm3_1+...
%     th_P1(8,1)*E_N1+...
%     th_P1(9,1)*E_N2+...
%     th_P1(10,1)*times(E_N1,TP_dm1_1)+...
%     th_P1(11,1)*times(E_N2,TP_dm1_1)+...    
%     th_P1(12,1)*times(E_N1,TP_dm2_1)+...
%     th_P1(13,1)*times(E_N2,TP_dm2_1)+...    
%     th_P1(14,1)*times(E_N1,TP_dm3_1)+...
%     th_P1(15,1)*times(E_N2,TP_dm3_1)+...    
%     th_P1(16,1)*(TP_v)+...
%     th_P1(17,1);
% 
% sig0=  th_S1(1,1)*TP_dm0_1;  
% sig1=  th_S1(2,1)*TP_dm1_1;
% sig2=  th_S1(3,1)*TP_dm2_1;
% sig3=  th_S1(4,1)*TP_dm3_1;
% sig=sig0+sig1+sig2+sig3;
% 
% w=times(XB_P,power(sig,-1));
% phi_1=normpdf(w,0,1);  
% phi_2=normcdf(w,0,1);  
% E_P=times(phi_2,XB_P)+times(sig,phi_1); %left censored; See C&T p541
% 
% elseif type==3 || type==4
% 
% XB_B=...
%     th_B2(1,1)*TP_H+...
%     th_B2(2,1)*A*TP_H+...
%     th_B2(3,1)*A+...
%     th_B2(4,1);
% 
% P_B=exp(XB_B);
% P_B=times(P_B,power((1+P_B),-1));    
%     
% XB_D=...
%     th_D2(1,1)*TP_H+...
%     th_D2(2,1)*times((1-TP_H),TP_dm1_1)+...
%     th_D2(3,1)*times((1-TP_H),TP_dm2_1)+...
%     th_D2(4,1)*times((1-TP_H),TP_dm3_1)+...
%     th_D2(5,1)*times((TP_H)  ,TP_dm1_1)+...
%     th_D2(6,1)*times((TP_H)  ,TP_dm2_1)+...
%     th_D2(7,1)*times((TP_H)  ,TP_dm3_1)+...
%     th_D2(8,1)*TP_v+...
%     th_D2(9,1);
% 
% 
% DH=exp(XB_D);
% DH=times(DH,power((1+DH),-1));
% DH0=times(DH,(1-TP_H));
% DH1=times(DH,(TP_H));
% 
% XB_H=...
%     th_H2(1,1)*TP_H+...
%     th_H2(2,1)*DH0+...
%     th_H2(3,1)*DH1+...
%     th_H2(4,1);
% 
% 
% P_H=exp(XB_H);
% P_H=times(P_H,power((1+P_H),-1));
% 
% 
% XB_F=...
%     th_F2(1,1)*TP_H+...  
%     th_F2(2,1)*times((1-TP_H),TP_dm1_1)+...
%     th_F2(3,1)*times((1-TP_H),TP_dm2_1)+...
%     th_F2(4,1)*times((1-TP_H),TP_dm3_1)+...
%     th_F2(5,1)*times((TP_H)  ,TP_dm1_1)+...
%     th_F2(6,1)*times((TP_H)  ,TP_dm2_1)+...
%     th_F2(7,1)*times((TP_H)  ,TP_dm3_1)+...
%     th_F2(8,1)*TP_v+...
%     th_F2(9,1);
% 
% P_F=exp(XB_F);
% P_F=times(P_F,power((1+P_F),-1));
% 
% 
% XB_I=...
%     th_I2(1,1)*TP_H+...
%     th_I2(2,1)*TP_E+...
%     th_I2(3,1)*times(TP_E,TP_E)+...
%     th_I2(4,1)*A+...
%     th_I2(5,1)*(TP_v-14)+...
%    (times(TP_dl1_1,...
%    (th_I2(6,1)+... 
%     th_I2(7,1)*TP_H+...
%     th_I2(8,1)*TP_E+...
%     th_I2(9,1)*times(TP_E,TP_E)+...
%     th_I2(10,1)*A+...
%     th_I2(11,1)*(TP_v-14))))+...
%     th_I2(12,1);
% 
% sig=th_I2(13,1);
% 
% w=times((XB_I-2500),power(sig,-1));
% phi_1=normpdf(w,0,1);  
% phi_2=normcdf(w,0,1);  
% E_I=(2500*(1-phi_2))+(times(phi_2,XB_I)+times(sig,phi_1)); %left censored; See C&T p541 
% E_IP    =(E_I+2500)/5000;
% 
% 
% XB_N_1=...
%     th_N2(1,1)*TP_dl1_1+...
%     th_N2(2,1)*TP_H+...
%     th_N2(3,1)*TP_E+...
%     th_N2(4,1)*times(TP_E,TP_E)+...
%     th_N2(5,1)*A+...
%     th_N2(6,1)*A^2+...
%     th_N2(7,1)*(TP_v)+...
%     th_N2(8,1)*times(TP_v-24,TP_dh)+...
%     th_N2(9,1);
% 
% XB_N_2=...
%     th_N2(10,1)*TP_dl1_1+...
%     th_N2(11,1)*TP_H+...
%     th_N2(12,1)*TP_E+...
%     th_N2(13,1)*times(TP_E,TP_E)+...
%     th_N2(14,1)*A+...
%     th_N2(15,1)*A^2+...
%     th_N2(16,1)*(TP_v)+...
%     th_N2(17,1)*times(TP_v-24,TP_dh)+...
%     th_N2(18,1);
% 
% 
% XB_N_1=exp(XB_N_1);
% XB_N_2=exp(XB_N_2);
% 
% E_N1=times(XB_N_1,power((1+XB_N_1+XB_N_2),-1));
% E_N2=times(XB_N_2,power((1+XB_N_1+XB_N_2),-1));
% 
% XB_P=...
%     th_P2(1,1)*P_H+...
%     th_P2(2,1)*times((1-P_F),P_H)+...
%     th_P2(3,1)*times((1-P_F),(1-P_H))+...
%     th_P2(4,1)*E_IP+...
%     th_P2(5,1)*TP_dm1_1+...
%     th_P2(6,1)*TP_dm2_1+...
%     th_P2(7,1)*TP_dm3_1+...
%     th_P2(8,1)*E_N1+...
%     th_P2(9,1)*E_N2+...
%     th_P2(10,1)*times(E_N1,TP_dm1_1)+...
%     th_P2(11,1)*times(E_N2,TP_dm1_1)+...    
%     th_P2(12,1)*times(E_N1,TP_dm2_1)+...
%     th_P2(13,1)*times(E_N2,TP_dm2_1)+...    
%     th_P2(14,1)*times(E_N1,TP_dm3_1)+...
%     th_P2(15,1)*times(E_N2,TP_dm3_1)+...    
%     th_P2(16,1)*(TP_v)+...
%     th_P2(17,1);
% 
% sig0=  th_S2(1,1)*TP_dm0_1;  
% sig1=  th_S2(2,1)*TP_dm1_1;
% sig2=  th_S2(3,1)*TP_dm2_1;
% sig3=  th_S2(4,1)*TP_dm3_1;
% sig=sig0+sig1+sig2+sig3;
% 
% w=times(XB_P,power(sig,-1));
% phi_1=normpdf(w,0,1);  
% phi_2=normcdf(w,0,1);  
% E_P=times(phi_2,XB_P)+times(sig,phi_1); %left censored; See C&T p541
% 
% end
% 
% 
% if LA1==1
%     
%     aE_C=(1/(1-alpha1(1,1)))*power((E_I-E_P),(1-alpha1(1,1)));
% 
% elseif LA1==2 && LA2==0
% 
%     aE_C11=(1/(1-alpha1(1,1)))*power((E_I-E_P),(1-alpha1(1,1)));
%     aE_C12=(1/(1-alpha1(2,1)))*power((E_I-E_P),(1-alpha1(2,1)));
%        
% elseif LA1==2 && LA2==2
% 
%     aE_C11=(1/(1-alpha1(1,1)))*power((E_I-E_P),(1-alpha1(1,1)));
%     aE_C12=(1/(1-alpha1(2,1)))*power((E_I-E_P),(1-alpha1(2,1)));
%     aE_C21=(1/(1-alpha2(1,1)))*power((E_I-E_P),(1-alpha2(1,1)));
%     aE_C22=(1/(1-alpha2(2,1)))*power((E_I-E_P),(1-alpha2(2,1)));
%     
% end
%  
% 
% 
% 
% %Construct Expected Flow Utility
%                                     
% if type==1 || type==3
% if MODEL==1   
% 
% FU=         aE_C+...
%             th_ml_U1(1,1)*TP_dl1_1+...
%             th_ml_U1(2,1)*(1-P_F)+...
%             th_ml_U1(3,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U1(4,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U1(4,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U1(4,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U1(5,1)*times((1-TP_dm0_0),TP_dm0_1);  
%                 
% elseif MODEL==2
%     
% FU=         times(P_F,...
%            (aE_C11+...
%             th_ml_U1(1,1)*TP_dl1_1))+...
%             times((1-P_F),...
%            (aE_C12+...
%             th_ml_U1(2,1)+...
%             th_ml_U1(3,1)*TP_dl1_1))+...
%             times(times(P_H,P_F),...
%            (th_ml_U1(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U1(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
%             times(times(P_H,1-P_F),...
%            (th_ml_U1(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U1(9,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
%             times(times(1-P_H,P_F),...
%            (th_ml_U1(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U1(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
%             times(times(1-P_H,1-P_F),...
%            (th_ml_U1(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U1(9,1)*times((1-TP_dm0_0),TP_dm0_1)));   
% 
% 
% elseif MODEL==3 || MODEL==4 
%  
%     
% FU=         times(P_F,...
%            (aE_C11+...
%             th_ml_U1(1,1)*TP_dl1_1))+...
%             times((1-P_F),...
%            (aE_C12+...
%             th_ml_U1(2,1)+...
%             th_ml_U1(3,1)*TP_dl1_1))+...
%             times(times(P_H,P_F),...
%            (th_ml_U1(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U1(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
%             times(times(P_H,1-P_F),...
%            (th_ml_U1(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U1(9,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
%             times(times(1-P_H,P_F),...
%            (th_ml_U1(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U1(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
%             times(times(1-P_H,1-P_F),...
%            (th_ml_U1(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U1(9,1)*times((1-TP_dm0_0),TP_dm0_1)));   
%    
% 
% end
% 
% elseif type==2 || type==4
% if MODEL==3 || MODEL==4  
% 
%     
% FU=         times(P_F,...
%            (aE_C21+...
%             th_ml_U2(1,1)*TP_dl1_1))+...
%             times((1-P_F),...
%            (aE_C22+...
%             th_ml_U2(2,1)+...
%             th_ml_U2(3,1)*TP_dl1_1))+...
%             times(times(P_H,P_F),...
%            (th_ml_U2(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U2(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
%             times(times(P_H,1-P_F),...
%            (th_ml_U2(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U2(9,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
%             times(times(1-P_H,P_F),...
%            (th_ml_U2(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U2(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
%             times(times(1-P_H,1-P_F),...
%            (th_ml_U2(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U2(9,1)*times((1-TP_dm0_0),TP_dm0_1)));   
% 
% 
%     
% end   
% end
% 
% FU=times((times(1,power((1-(times(beta,(1-P_B)))),-1))),FU);
% 
% V_A(:,a)=FU;
% 
% end        
% 
% 
% 
% 
% 
% 
% 
% 
% 
% 
% 
% 
% 
% 
% 
% 
% 
% 
% %6  BACKWARD RECURSION: AGE 65 to 30
% 
% for A=64.5:(-0.5):30
% 
% %TP Cube Layer (Using A_it)
%     a=(A-30)*2+1;                                     
% %TP for this iteration
%     TPa=TP(:,:,a);  
% 
% %EXTRACT TP COMPONENTS FOR TRANSITIONS
%     
% TP_v        =TPa(:,1);    
% TP_dh       =TPa(:,2);
% TP_H        =TPa(:,3);    
% TP_E        =TPa(:,4);    
% TP_dl0_1    =TPa(:,5);
% TP_dl1_1    =TPa(:,6);
% TP_dm0_0    =TPa(:,7);
% TP_dm1_0    =TPa(:,8);
% TP_dm2_0    =TPa(:,9);
% TP_dm3_0    =TPa(:,10);
% TP_dm0_1    =TPa(:,11);
% TP_dm1_1    =TPa(:,12);
% TP_dm2_1    =TPa(:,13);
% TP_dm3_1    =TPa(:,14);
% 
% PP_B        =TPa(:,15);
% PP_H        =TPa(:,16);
% PP_F        =TPa(:,17);
% 
% EE_I         =TPa(:,18);
% 
% EE_N1        =TPa(:,19);
% EE_N2        =TPa(:,20);
% 
% EE_IP    =(EE_I+2500)/5000;
% 
% %OOC ~ Health ~ Symptoms/SFX  
% 
% if type==1 || type==2
% 
% XB_B=...
%     th_B1(1,1)*TP_H+...
%     th_B1(2,1)*A*TP_H+...
%     th_B1(3,1)*A+...
%     th_B1(4,1);
% 
% P_B=exp(XB_B);
% P_B=times(P_B,power((1+P_B),-1));      
%     
% XB_D=...
%     th_D1(1,1)*TP_H+...
%     th_D1(2,1)*times((1-TP_H),TP_dm1_1)+...
%     th_D1(3,1)*times((1-TP_H),TP_dm2_1)+...
%     th_D1(4,1)*times((1-TP_H),TP_dm3_1)+...
%     th_D1(5,1)*times((TP_H)  ,TP_dm1_1)+...
%     th_D1(6,1)*times((TP_H)  ,TP_dm2_1)+...
%     th_D1(7,1)*times((TP_H)  ,TP_dm3_1)+...
%     th_D1(8,1)*TP_v+...
%     th_D1(9,1);
% 
% 
% DH=exp(XB_D);
% DH=times(DH,power((1+DH),-1));
% DH0=times(DH,(1-TP_H));
% DH1=times(DH,(TP_H));
% 
% XB_H=...
%     th_H1(1,1)*TP_H+...
%     th_H1(2,1)*DH0+...
%     th_H1(3,1)*DH1+...
%     th_H1(4,1);
% 
% 
% P_H=exp(XB_H);
% P_H=times(P_H,power((1+P_H),-1));
% 
% XB_F=...
%     th_F1(1,1)*TP_H+...   
%     th_F1(2,1)*times((1-TP_H),TP_dm1_1)+...
%     th_F1(3,1)*times((1-TP_H),TP_dm2_1)+...
%     th_F1(4,1)*times((1-TP_H),TP_dm3_1)+...
%     th_F1(5,1)*times((TP_H)  ,TP_dm1_1)+...
%     th_F1(6,1)*times((TP_H)  ,TP_dm2_1)+...
%     th_F1(7,1)*times((TP_H)  ,TP_dm3_1)+...
%     th_F1(8,1)*TP_v+...
%     th_F1(9,1);
% 
% P_F=exp(XB_F);
% P_F=times(P_F,power((1+P_F),-1));
% 
% XB_I=...
%     th_I1(1,1)*TP_H+...
%     th_I1(2,1)*TP_E+...
%     th_I1(3,1)*times(TP_E,TP_E)+...
%     th_I1(4,1)*A+...
%     th_I1(5,1)*(TP_v-14)+...
%    (times(TP_dl1_1,...
%    (th_I1(6,1)+... 
%     th_I1(7,1)*TP_H+...
%     th_I1(8,1)*TP_E+...
%     th_I1(9,1)*times(TP_E,TP_E)+...
%     th_I1(10,1)*A+...
%     th_I1(11,1)*(TP_v-14))))+...
%     th_I1(12,1);
% 
% sig=th_I1(13,1);
% 
% w=times((XB_I-2500),power(sig,-1));
% phi_1=normpdf(w,0,1);  
% phi_2=normcdf(w,0,1);  
% E_I=(2500*(1-phi_2))+(times(phi_2,XB_I)+times(sig,phi_1)); %left censored; See C&T p541 
% E_IP    =(E_I+2500)/5000;
% 
% %%%%%%%%%%%%%%%%%%%%%%
% E_I=E_I+INC*INCREMENT;
% %%%%%%%%%%%%%%%%%%%%%%
% 
% XB_N_1=...
%     th_N1(1,1)*TP_dl1_1+...
%     th_N1(2,1)*TP_H+...
%     th_N1(3,1)*TP_E+...
%     th_N1(4,1)*times(TP_E,TP_E)+...
%     th_N1(5,1)*A+...
%     th_N1(6,1)*A^2+...
%     th_N1(7,1)*(TP_v)+...
%     th_N1(8,1)*times(TP_v-24,TP_dh)+...
%     th_N1(9,1);
% 
% XB_N_2=...
%     th_N1(10,1)*TP_dl1_1+...
%     th_N1(11,1)*TP_H+...
%     th_N1(12,1)*TP_E+...
%     th_N1(13,1)*times(TP_E,TP_E)+...
%     th_N1(14,1)*A+...
%     th_N1(15,1)*A^2+...
%     th_N1(16,1)*(TP_v)+...
%     th_N1(17,1)*times(TP_v-24,TP_dh)+...
%     th_N1(18,1);
% 
% 
% XB_N_1=exp(XB_N_1);
% XB_N_2=exp(XB_N_2);
% 
% E_N1=times(XB_N_1,power((1+XB_N_1+XB_N_2),-1));
% E_N2=times(XB_N_2,power((1+XB_N_1+XB_N_2),-1)); 
% 
% 
% XB_P=...
%     th_P1(1,1)*P_H+...
%     th_P1(2,1)*times((1-P_F),P_H)+...
%     th_P1(3,1)*times((1-P_F),(1-P_H))+...
%     th_P1(4,1)*E_IP+...
%     th_P1(5,1)*TP_dm1_1+...
%     th_P1(6,1)*TP_dm2_1+...
%     th_P1(7,1)*TP_dm3_1+...
%     th_P1(8,1)*E_N1+...
%     th_P1(9,1)*E_N2+...
%     th_P1(10,1)*times(E_N1,TP_dm1_1)+...
%     th_P1(11,1)*times(E_N2,TP_dm1_1)+...    
%     th_P1(12,1)*times(E_N1,TP_dm2_1)+...
%     th_P1(13,1)*times(E_N2,TP_dm2_1)+...    
%     th_P1(14,1)*times(E_N1,TP_dm3_1)+...
%     th_P1(15,1)*times(E_N2,TP_dm3_1)+...    
%     th_P1(16,1)*(TP_v)+...
%     th_P1(17,1);
% 
% sig0=  th_S1(1,1)*TP_dm0_1;  
% sig1=  th_S1(2,1)*TP_dm1_1;
% sig2=  th_S1(3,1)*TP_dm2_1;
% sig3=  th_S1(4,1)*TP_dm3_1;
% sig=sig0+sig1+sig2+sig3;
% 
% w=times(XB_P,power(sig,-1));
% phi_1=normpdf(w,0,1);  
% phi_2=normcdf(w,0,1);  
% E_P=times(phi_2,XB_P)+times(sig,phi_1); %left censored; See C&T p541
% 
% elseif type==3 || type==4
% 
% XB_B=...
%     th_B2(1,1)*TP_H+...
%     th_B2(2,1)*A*TP_H+...
%     th_B2(3,1)*A+...
%     th_B2(4,1);
% 
% P_B=exp(XB_B);
% P_B=times(P_B,power((1+P_B),-1));       
%     
% XB_D=...
%     th_D2(1,1)*TP_H+...
%     th_D2(2,1)*times((1-TP_H),TP_dm1_1)+...
%     th_D2(3,1)*times((1-TP_H),TP_dm2_1)+...
%     th_D2(4,1)*times((1-TP_H),TP_dm3_1)+...
%     th_D2(5,1)*times((TP_H)  ,TP_dm1_1)+...
%     th_D2(6,1)*times((TP_H)  ,TP_dm2_1)+...
%     th_D2(7,1)*times((TP_H)  ,TP_dm3_1)+...
%     th_D2(8,1)*TP_v+...
%     th_D2(9,1);
% 
% DH=exp(XB_D);
% DH=times(DH,power((1+DH),-1));
% DH0=times(DH,(1-TP_H));
% DH1=times(DH,(TP_H));
% 
% XB_H=...
%     th_H2(1,1)*TP_H+...
%     th_H2(2,1)*DH0+...
%     th_H2(3,1)*DH1+...
%     th_H2(4,1);
% 
% 
% P_H=exp(XB_H);
% P_H=times(P_H,power((1+P_H),-1));
% 
% XB_F=...
%     th_F2(1,1)*TP_H+...   
%     th_F2(2,1)*times((1-TP_H),TP_dm1_1)+...
%     th_F2(3,1)*times((1-TP_H),TP_dm2_1)+...
%     th_F2(4,1)*times((1-TP_H),TP_dm3_1)+...
%     th_F2(5,1)*times((TP_H)  ,TP_dm1_1)+...
%     th_F2(6,1)*times((TP_H)  ,TP_dm2_1)+...
%     th_F2(7,1)*times((TP_H)  ,TP_dm3_1)+...
%     th_F2(8,1)*TP_v+...
%     th_F2(9,1);
% 
% 
% P_F=exp(XB_F);
% P_F=times(P_F,power((1+P_F),-1));
% 
% XB_I=...
%     th_I2(1,1)*TP_H+...
%     th_I2(2,1)*TP_E+...
%     th_I2(3,1)*times(TP_E,TP_E)+...
%     th_I2(4,1)*A+...
%     th_I2(5,1)*(TP_v-14)+...
%    (times(TP_dl1_1,...
%    (th_I2(6,1)+... 
%     th_I2(7,1)*TP_H+...
%     th_I2(8,1)*TP_E+...
%     th_I2(9,1)*times(TP_E,TP_E)+...
%     th_I2(10,1)*A+...
%     th_I2(11,1)*(TP_v-14))))+...
%     th_I2(12,1);
% 
% sig=th_I2(13,1);
% 
% w=times((XB_I-2500),power(sig,-1));
% phi_1=normpdf(w,0,1);  
% phi_2=normcdf(w,0,1);  
% E_I=(2500*(1-phi_2))+(times(phi_2,XB_I)+times(sig,phi_1)); %left censored; See C&T p541 
% E_IP    =(E_I+2500)/5000;
% 
% 
% XB_N_1=...
%     th_N2(1,1)*TP_dl1_1+...
%     th_N2(2,1)*TP_H+...
%     th_N2(3,1)*TP_E+...
%     th_N2(4,1)*times(TP_E,TP_E)+...
%     th_N2(5,1)*A+...
%     th_N2(6,1)*A^2+...
%     th_N2(7,1)*(TP_v)+...
%     th_N2(8,1)*times(TP_v-24,TP_dh)+...
%     th_N2(9,1);
% 
% XB_N_2=...
%     th_N2(10,1)*TP_dl1_1+...
%     th_N2(11,1)*TP_H+...
%     th_N2(12,1)*TP_E+...
%     th_N2(13,1)*times(TP_E,TP_E)+...
%     th_N2(14,1)*A+...
%     th_N2(15,1)*A^2+...
%     th_N2(16,1)*(TP_v)+...
%     th_N2(17,1)*times(TP_v-24,TP_dh)+...
%     th_N2(18,1);
% 
% 
% XB_N_1=exp(XB_N_1);
% XB_N_2=exp(XB_N_2);
% 
% E_N1=times(XB_N_1,power((1+XB_N_1+XB_N_2),-1));
% E_N2=times(XB_N_2,power((1+XB_N_1+XB_N_2),-1));
% 
% 
% XB_P=...
%     th_P2(1,1)*P_H+...
%     th_P2(2,1)*times((1-P_F),P_H)+...
%     th_P2(3,1)*times((1-P_F),(1-P_H))+...
%     th_P2(4,1)*E_IP+...
%     th_P2(5,1)*TP_dm1_1+...
%     th_P2(6,1)*TP_dm2_1+...
%     th_P2(7,1)*TP_dm3_1+...
%     th_P2(8,1)*E_N1+...
%     th_P2(9,1)*E_N2+...
%     th_P2(10,1)*times(E_N1,TP_dm1_1)+...
%     th_P2(11,1)*times(E_N2,TP_dm1_1)+...    
%     th_P2(12,1)*times(E_N1,TP_dm2_1)+...
%     th_P2(13,1)*times(E_N2,TP_dm2_1)+...    
%     th_P2(14,1)*times(E_N1,TP_dm3_1)+...
%     th_P2(15,1)*times(E_N2,TP_dm3_1)+...    
%     th_P2(16,1)*(TP_v)+...
%     th_P2(17,1);
% 
% sig0=  th_S2(1,1)*TP_dm0_1;  
% sig1=  th_S2(2,1)*TP_dm1_1;
% sig2=  th_S2(3,1)*TP_dm2_1;
% sig3=  th_S2(4,1)*TP_dm3_1;
% sig=sig0+sig1+sig2+sig3;
% 
% w=times(XB_P,power(sig,-1));
% phi_1=normpdf(w,0,1);  
% phi_2=normcdf(w,0,1);  
% E_P=times(phi_2,XB_P)+times(sig,phi_1); %left censored; See C&T p541
% 
% end
% 
% 
% if LA1==1
%     
%     aE_C=(1/(1-alpha1(1,1)))*power((E_I-E_P),(1-alpha1(1,1)));
% 
% elseif LA1==2 && LA2==0
% 
%     aE_C11=(1/(1-alpha1(1,1)))*power((E_I-E_P),(1-alpha1(1,1)));
%     aE_C12=(1/(1-alpha1(2,1)))*power((E_I-E_P),(1-alpha1(2,1)));
%        
% elseif LA1==2 && LA2==2
% 
%     aE_C11=(1/(1-alpha1(1,1)))*power((E_I-E_P),(1-alpha1(1,1)));
%     aE_C12=(1/(1-alpha1(2,1)))*power((E_I-E_P),(1-alpha1(2,1)));
%     aE_C21=(1/(1-alpha2(1,1)))*power((E_I-E_P),(1-alpha2(1,1)));
%     aE_C22=(1/(1-alpha2(2,1)))*power((E_I-E_P),(1-alpha2(2,1)));
%     
% end
% 
% 
% 
% %Construct Expected Flow Utility
%                                     
% if type==1 || type==3
% if MODEL==1   
% 
% FU=         aE_C+...
%             th_ml_U1(1,1)*TP_dl1_1+...
%             th_ml_U1(2,1)*(1-P_F)+...
%             th_ml_U1(3,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U1(4,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U1(4,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U1(4,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U1(5,1)*times((1-TP_dm0_0),TP_dm0_1);    
%                 
% elseif MODEL==2
%     
% FU=         times(P_F,...
%            (aE_C11+...
%             th_ml_U1(1,1)*TP_dl1_1))+...
%             times((1-P_F),...
%            (aE_C12+...
%             th_ml_U1(2,1)+...
%             th_ml_U1(3,1)*TP_dl1_1))+...
%             times(times(P_H,P_F),...
%            (th_ml_U1(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U1(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
%             times(times(P_H,1-P_F),...
%            (th_ml_U1(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U1(9,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
%             times(times(1-P_H,P_F),...
%            (th_ml_U1(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U1(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
%             times(times(1-P_H,1-P_F),...
%            (th_ml_U1(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U1(9,1)*times((1-TP_dm0_0),TP_dm0_1)));  
% 
% 
%   
% 
% 
% elseif MODEL==3 || MODEL==4 
%  
%  
% FU=         times(P_F,...
%            (aE_C11+...
%             th_ml_U1(1,1)*TP_dl1_1))+...
%             times((1-P_F),...
%            (aE_C12+...
%             th_ml_U1(2,1)+...
%             th_ml_U1(3,1)*TP_dl1_1))+...
%             times(times(P_H,P_F),...
%            (th_ml_U1(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U1(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
%             times(times(P_H,1-P_F),...
%            (th_ml_U1(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U1(9,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
%             times(times(1-P_H,P_F),...
%            (th_ml_U1(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U1(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U1(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
%             times(times(1-P_H,1-P_F),...
%            (th_ml_U1(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U1(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U1(9,1)*times((1-TP_dm0_0),TP_dm0_1)));   
%    
% 
% end
% 
% elseif type==2 || type==4
% if MODEL==3 || MODEL==4  
% 
%     
% FU=         times(P_F,...
%            (aE_C21+...
%             th_ml_U2(1,1)*TP_dl1_1))+...
%             times((1-P_F),...
%            (aE_C22+...
%             th_ml_U2(2,1)+...
%             th_ml_U2(3,1)*TP_dl1_1))+...
%             times(times(P_H,P_F),...
%            (th_ml_U2(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U2(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
%             times(times(P_H,1-P_F),...
%            (th_ml_U2(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U2(9,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
%             times(times(1-P_H,P_F),...
%            (th_ml_U2(4,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U2(5,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U2(6,1)*times((1-TP_dm0_0),TP_dm0_1)))+...  
%             times(times(1-P_H,1-P_F),...
%            (th_ml_U2(7,1)*times(TP_dm0_0,(1-TP_dm0_1))+...                   
%             th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm1_0,(1-TP_dm1_1))))+...                  
%             th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm2_0,(1-TP_dm2_1))))+...                  
%             th_ml_U2(8,1)*times((1-TP_dm0_1),(times(TP_dm3_0,(1-TP_dm3_1))))+...                  
%             th_ml_U2(9,1)*times((1-TP_dm0_0),TP_dm0_1)));   
% 
%         
% end   
% end
%    
% 
% %Obtain Continuation (a+1) Payoffs for each choice/state combo.
% %Use error structure to obtain probabilities at next age
% 
% % CHOICE SPECIFIC VALUES --> PROBABILITIES
% 
% CORRECTION=max(V_A(:,(a+1)));
% VA1=V_A(:,(a+1))-CORRECTION;
% 
% %HERE: forming {ln[\sum_{d^{'}}(v_t+1(x_{t+1},d^{'}_t+1)]+\gamma}
% 
% VA11=VA1(1:810);
% VA11=reshape(VA11,6,[]);
% % VA11=exp(VA11);
% % VA11=sum(VA11);
% % VA11=log(VA11);
% % V1=transpose(VA11);
% % V1=V1+.5772;        
% V1=.5772+transpose(log(sum(exp(VA11))))+CORRECTION;
% 
% VA11=VA1(811:3530);
% VA11=reshape(VA11,8,[]);
% % VA11=exp(VA11);
% % VA11=sum(VA11);
% % VA11=log(VA11);
% % V2=transpose(VA11);
% % V2=V2+.5772; 
% V2=.5772+transpose(log(sum(exp(VA11))))+CORRECTION;
% 
% VA11=VA1(3531:4340);
% VA11=reshape(VA11,6,[]);
% % VA11=exp(VA11);
% % VA11=sum(VA11);
% % VA11=log(VA11);
% % V3=transpose(VA11);
% % V3=V3+.5772; 
% V3=.5772+transpose(log(sum(exp(VA11))))+CORRECTION;
% 
% VA11=VA1(4341:7060);
% VA11=reshape(VA11,8,[]);
% % VA11=exp(VA11);
% % VA11=sum(VA11);
% % VA11=log(VA11);
% % V4=transpose(VA11);
% % V4=V4+.5772;        
% V4=.5772+transpose(log(sum(exp(VA11))))+CORRECTION;        
% 
% weight1=0.95;
% weight2=0.05;
%         
% for i=1:18:793
% for j=((i-1)/18)*3+1
% k=(j-1)/3+1;
% if mod(k,5)~=0    
% 
% V_A(i+0,a) =FU(i+0,1)   +        (beta*(1-P_B(i+0,1))) *(((1-P_H(i+0,1)) *V1(j+0,1))+(P_H(i+0,1) *V3(j+0,1)));
% V_A(i+1,a) =FU(i+1,1)   +weight1*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *V1(j+0,1))+(P_H(i+1,1) *V3(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *V1(j+3,1))+(P_H(i+1,1) *V3(j+3,1)));
% 
% V_A(i+2,a) =FU(i+2,1)   +        (beta*(1-P_B(i+2,1))) *(((1-P_H(i+2,1)) *V1(j+1,1))+(P_H(i+2,1) *V3(j+1,1)));
% V_A(i+3,a) =FU(i+3,1)   +weight1*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *V1(j+1,1))+(P_H(i+3,1) *V3(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *V1(j+4,1))+(P_H(i+3,1) *V3(j+4,1)));
% 
% V_A(i+4,a) =FU(i+4,1)   +        (beta*(1-P_B(i+4,1))) *(((1-P_H(i+4,1)) *V1(j+2,1))+(P_H(i+4,1) *V3(j+2,1)));
% V_A(i+5,a) =FU(i+5,1)   +weight1*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *V1(j+2,1))+(P_H(i+5,1) *V3(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *V1(j+5,1))+(P_H(i+5,1) *V3(j+5,1)));
% 
% V_A(i+6,a) =FU(i+6,1)   +        (beta*(1-P_B(i+6,1))) *(((1-P_H(i+6,1)) *V1(j+0,1))+(P_H(i+6,1) *V3(j+0,1)));
% V_A(i+7,a) =FU(i+7,1)   +weight1*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *V1(j+0,1))+(P_H(i+7,1) *V3(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *V1(j+3,1))+(P_H(i+7,1) *V3(j+3,1)));
% 
% V_A(i+8,a) =FU(i+8,1)   +        (beta*(1-P_B(i+8,1))) *(((1-P_H(i+8,1)) *V1(j+1,1))+(P_H(i+8,1) *V3(j+1,1)));
% V_A(i+9,a) =FU(i+9,1)   +weight1*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *V1(j+1,1))+(P_H(i+9,1) *V3(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *V1(j+4,1))+(P_H(i+9,1) *V3(j+4,1)));
% 
% V_A(i+10,a)=FU(i+10,1)  +        (beta*(1-P_B(i+10,1)))*(((1-P_H(i+10,1))*V1(j+2,1))+(P_H(i+10,1)*V3(j+2,1)));
% V_A(i+11,a)=FU(i+11,1)  +weight1*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*V1(j+2,1))+(P_H(i+11,1)*V3(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*V1(j+5,1))+(P_H(i+11,1)*V3(j+5,1)));
% 
% V_A(i+12,a)=FU(i+12,1)  +        (beta*(1-P_B(i+12,1)))*(((1-P_H(i+12,1))*V1(j+0,1))+(P_H(i+12,1)*V3(j+0,1)));
% V_A(i+13,a)=FU(i+13,1)  +weight1*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*V1(j+0,1))+(P_H(i+13,1)*V3(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*V1(j+3,1))+(P_H(i+13,1)*V3(j+3,1)));
% 
% V_A(i+14,a)=FU(i+14,1)  +        (beta*(1-P_B(i+14,1)))*(((1-P_H(i+14,1))*V1(j+1,1))+(P_H(i+14,1)*V3(j+1,1)));
% V_A(i+15,a)=FU(i+15,1)  +weight1*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*V1(j+1,1))+(P_H(i+15,1)*V3(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*V1(j+4,1))+(P_H(i+15,1)*V3(j+4,1)));
% 
% V_A(i+16,a)=FU(i+16,1)  +        (beta*(1-P_B(i+16,1)))*(((1-P_H(i+16,1))*V1(j+2,1))+(P_H(i+16,1)*V3(j+2,1)));
% V_A(i+17,a)=FU(i+17,1)  +weight1*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*V1(j+2,1))+(P_H(i+17,1)*V3(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*V1(j+5,1))+(P_H(i+17,1)*V3(j+5,1)));
% 
% else
%     
% V_A(i+0,a) =FU(i+0,1)   +        (beta*(1-P_B(i+0,1))) *(((1-P_H(i+0,1)) *   V1(j+0,1))             +(P_H(i+0,1)   *V3(j+0,1)));
% V_A(i+1,a) =FU(i+1,1)   +weight1*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *   V1(j+0,1))             +(P_H(i+1,1)   *V3(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *(2*V1(j+0,1)-V1(j+0-3,1)))+(P_H(i+1,1)*(2*V3(j+0,1)-V3(j+0-3,1))));
%     
% V_A(i+2,a) =FU(i+2,1)   +        (beta*(1-P_B(i+2,1))) *(((1-P_H(i+2,1)) *   V1(j+1,1))             +(P_H(i+2,1)   *V3(j+1,1)));
% V_A(i+3,a) =FU(i+3,1)   +weight1*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *   V1(j+1,1))             +(P_H(i+3,1)   *V3(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *(2*V1(j+1,1)-V1(j+1-3,1)))+(P_H(i+3,1)*(2*V3(j+1,1)-V3(j+1-3,1))));
% 
% V_A(i+4,a) =FU(i+4,1)   +        (beta*(1-P_B(i+4,1))) *(((1-P_H(i+4,1)) *   V1(j+2,1))             +(P_H(i+4,1)   *V3(j+2,1)));
% V_A(i+5,a) =FU(i+5,1)   +weight1*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *   V1(j+2,1))             +(P_H(i+5,1)   *V3(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *(2*V1(j+2,1)-V1(j+2-3,1)))+(P_H(i+5,1)*(2*V3(j+2,1)-V3(j+2-3,1))));
% 
% V_A(i+6,a) =FU(i+6,1)   +        (beta*(1-P_B(i+6,1))) *(((1-P_H(i+6,1)) *   V1(j+0,1))             +(P_H(i+6,1)   *V3(j+0,1)));
% V_A(i+7,a) =FU(i+7,1)   +weight1*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *   V1(j+0,1))             +(P_H(i+7,1)   *V3(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *(2*V1(j+0,1)-V1(j+0-3,1)))+(P_H(i+7,1)*(2*V3(j+0,1)-V3(j+0-3,1))));
% 
% V_A(i+8,a) =FU(i+8,1)   +        (beta*(1-P_B(i+8,1))) *(((1-P_H(i+8,1)) *   V1(j+1,1))             +(P_H(i+8,1)   *V3(j+1,1)));
% V_A(i+9,a) =FU(i+9,1)   +weight1*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *   V1(j+1,1))             +(P_H(i+9,1)   *V3(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *(2*V1(j+1,1)-V1(j+1-3,1)))+(P_H(i+9,1)*(2*V3(j+1,1)-V3(j+1-3,1))));
% 
% V_A(i+10,a)=FU(i+10,1)  +        (beta*(1-P_B(i+10,1)))*(((1-P_H(i+10,1))*   V1(j+2,1))             +(P_H(i+10,1)   *V3(j+2,1)));
% V_A(i+11,a)=FU(i+11,1)  +weight1*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*   V1(j+2,1))             +(P_H(i+11,1)   *V3(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*(2*V1(j+2,1)-V1(j+2-3,1)))+(P_H(i+11,1)*(2*V3(j+2,1)-V3(j+2-3,1))));
% 
% V_A(i+12,a)=FU(i+12,1)  +        (beta*(1-P_B(i+12,1)))*(((1-P_H(i+12,1))*   V1(j+0,1))             +(P_H(i+12,1)   *V3(j+0,1)));
% V_A(i+13,a)=FU(i+13,1)  +weight1*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*   V1(j+0,1))             +(P_H(i+13,1)   *V3(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*(2*V1(j+0,1)-V1(j+0-3,1)))+(P_H(i+13,1)*(2*V3(j+0,1)-V3(j+0-3,1))));
% 
% V_A(i+14,a)=FU(i+14,1)  +        (beta*(1-P_B(i+14,1)))*(((1-P_H(i+14,1))*   V1(j+1,1))             +(P_H(i+14,1)   *V3(j+1,1)));
% V_A(i+15,a)=FU(i+15,1)  +weight1*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*   V1(j+1,1))             +(P_H(i+15,1)   *V3(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*(2*V1(j+1,1)-V1(j+1-3,1)))+(P_H(i+15,1)*(2*V3(j+1,1)-V3(j+1-3,1))));
% 
% V_A(i+16,a)=FU(i+16,1)  +        (beta*(1-P_B(i+16,1)))*(((1-P_H(i+16,1))*   V1(j+2,1))             +(P_H(i+16,1)   *V3(j+2,1)));
% V_A(i+17,a)=FU(i+17,1)  +weight1*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*   V1(j+2,1))             +(P_H(i+17,1)   *V3(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*(2*V1(j+2,1)-V1(j+2-3,1)))+(P_H(i+17,1)*(2*V3(j+2,1)-V3(j+2-3,1))));
% 
% end
% end
% end
% 
% for i=811:32:3499
% for j=((i-811)/32)*4+1    
% k=(j-1)/4+1;
% if mod(k,5)~=0 
%            
% V_A(i+0,a) =FU(i+0,1)   +        (beta*(1-P_B(i+0,1))) *(((1-P_H(i+0,1)) *V2(j+0,1))+(P_H(i+0,1) *V4(j+0,1)));
% V_A(i+1,a) =FU(i+1,1)   +weight1*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *V2(j+0,1))+(P_H(i+1,1) *V4(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *V2(j+4,1))+(P_H(i+1,1) *V4(j+4,1)));
% 
% V_A(i+2,a) =FU(i+2,1)   +        (beta*(1-P_B(i+2,1))) *(((1-P_H(i+2,1)) *V2(j+1,1))+(P_H(i+2,1) *V4(j+1,1)));
% V_A(i+3,a) =FU(i+3,1)   +weight1*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *V2(j+1,1))+(P_H(i+3,1) *V4(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *V2(j+5,1))+(P_H(i+3,1) *V4(j+5,1)));
% 
% V_A(i+4,a) =FU(i+4,1)   +        (beta*(1-P_B(i+4,1))) *(((1-P_H(i+4,1)) *V2(j+2,1))+(P_H(i+4,1) *V4(j+2,1)));
% V_A(i+5,a) =FU(i+5,1)   +weight1*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *V2(j+2,1))+(P_H(i+5,1) *V4(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *V2(j+6,1))+(P_H(i+5,1) *V4(j+6,1)));
% 
% V_A(i+6,a) =FU(i+6,1)   +        (beta*(1-P_B(i+6,1))) *(((1-P_H(i+6,1)) *V2(j+3,1))+(P_H(i+6,1) *V4(j+3,1)));
% V_A(i+7,a) =FU(i+7,1)   +weight1*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *V2(j+3,1))+(P_H(i+7,1) *V4(j+3,1)))+...
%                         +weight2*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *V2(j+7,1))+(P_H(i+7,1) *V4(j+7,1)));
% 
% V_A(i+8,a) =FU(i+8,1)   +        (beta*(1-P_B(i+8,1))) *(((1-P_H(i+8,1)) *V2(j+0,1))+(P_H(i+8,1) *V4(j+0,1)));
% V_A(i+9,a) =FU(i+9,1)   +weight1*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *V2(j+0,1))+(P_H(i+9,1) *V4(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *V2(j+4,1))+(P_H(i+9,1) *V4(j+4,1)));
% 
% V_A(i+10,a)=FU(i+10,1)  +        (beta*(1-P_B(i+10,1)))*(((1-P_H(i+10,1))*V2(j+1,1))+(P_H(i+10,1)*V4(j+1,1)));
% V_A(i+11,a)=FU(i+11,1)  +weight1*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*V2(j+1,1))+(P_H(i+11,1)*V4(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*V2(j+5,1))+(P_H(i+11,1)*V4(j+5,1)));
% 
% V_A(i+12,a)=FU(i+12,1)  +        (beta*(1-P_B(i+12,1)))*(((1-P_H(i+12,1))*V2(j+2,1))+(P_H(i+12,1)*V4(j+2,1)));
% V_A(i+13,a)=FU(i+13,1)  +weight1*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*V2(j+2,1))+(P_H(i+13,1)*V4(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*V2(j+6,1))+(P_H(i+13,1)*V4(j+6,1)));
% 
% V_A(i+14,a)=FU(i+14,1)  +        (beta*(1-P_B(i+14,1)))*(((1-P_H(i+14,1))*V2(j+3,1))+(P_H(i+14,1)*V4(j+3,1)));
% V_A(i+15,a)=FU(i+15,1)  +weight1*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*V2(j+3,1))+(P_H(i+15,1)*V4(j+3,1)))+...
%                         +weight2*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*V2(j+7,1))+(P_H(i+15,1)*V4(j+7,1)));
% 
% V_A(i+16,a)=FU(i+16,1)  +        (beta*(1-P_B(i+16,1)))*(((1-P_H(i+16,1))*V2(j+0,1))+(P_H(i+16,1)*V4(j+0,1)));
% V_A(i+17,a)=FU(i+17,1)  +weight1*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*V2(j+0,1))+(P_H(i+17,1)*V4(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*V2(j+4,1))+(P_H(i+17,1)*V4(j+4,1)));
% 
% V_A(i+18,a)=FU(i+18,1)  +        (beta*(1-P_B(i+18,1)))*(((1-P_H(i+18,1))*V2(j+1,1))+(P_H(i+18,1)*V4(j+1,1)));
% V_A(i+19,a)=FU(i+19,1)  +weight1*(beta*(1-P_B(i+19,1)))*(((1-P_H(i+19,1))*V2(j+1,1))+(P_H(i+19,1)*V4(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+19,1)))*(((1-P_H(i+19,1))*V2(j+5,1))+(P_H(i+19,1)*V4(j+5,1)));
% 
% V_A(i+20,a)=FU(i+20,1)  +        (beta*(1-P_B(i+20,1)))*(((1-P_H(i+20,1))*V2(j+2,1))+(P_H(i+20,1)*V4(j+2,1)));
% V_A(i+21,a)=FU(i+21,1)  +weight1*(beta*(1-P_B(i+21,1)))*(((1-P_H(i+21,1))*V2(j+2,1))+(P_H(i+21,1)*V4(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+21,1)))*(((1-P_H(i+21,1))*V2(j+6,1))+(P_H(i+21,1)*V4(j+6,1)));
% 
% V_A(i+22,a)=FU(i+22,1)  +        (beta*(1-P_B(i+22,1)))*(((1-P_H(i+22,1))*V2(j+3,1))+(P_H(i+22,1)*V4(j+3,1)));
% V_A(i+23,a)=FU(i+23,1)  +weight1*(beta*(1-P_B(i+23,1)))*(((1-P_H(i+23,1))*V2(j+3,1))+(P_H(i+23,1)*V4(j+3,1)))+...
%                         +weight2*(beta*(1-P_B(i+23,1)))*(((1-P_H(i+23,1))*V2(j+7,1))+(P_H(i+23,1)*V4(j+7,1)));
% 
% V_A(i+24,a)=FU(i+24,1)  +        (beta*(1-P_B(i+24,1)))*(((1-P_H(i+24,1))*V2(j+0,1))+(P_H(i+24,1)*V4(j+0,1)));
% V_A(i+25,a)=FU(i+25,1)  +weight1*(beta*(1-P_B(i+25,1)))*(((1-P_H(i+25,1))*V2(j+0,1))+(P_H(i+25,1)*V4(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+25,1)))*(((1-P_H(i+25,1))*V2(j+4,1))+(P_H(i+25,1)*V4(j+4,1)));
% 
% V_A(i+26,a)=FU(i+26,1)  +        (beta*(1-P_B(i+26,1)))*(((1-P_H(i+26,1))*V2(j+1,1))+(P_H(i+26,1)*V4(j+1,1)));
% V_A(i+27,a)=FU(i+27,1)  +weight1*(beta*(1-P_B(i+27,1)))*(((1-P_H(i+27,1))*V2(j+1,1))+(P_H(i+27,1)*V4(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+27,1)))*(((1-P_H(i+27,1))*V2(j+5,1))+(P_H(i+27,1)*V4(j+5,1)));
% 
% V_A(i+28,a)=FU(i+28,1)  +        (beta*(1-P_B(i+28,1)))*(((1-P_H(i+28,1))*V2(j+2,1))+(P_H(i+28,1)*V4(j+2,1)));
% V_A(i+29,a)=FU(i+29,1)  +weight1*(beta*(1-P_B(i+29,1)))*(((1-P_H(i+29,1))*V2(j+2,1))+(P_H(i+29,1)*V4(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+29,1)))*(((1-P_H(i+29,1))*V2(j+6,1))+(P_H(i+29,1)*V4(j+6,1)));
% 
% V_A(i+30,a)=FU(i+30,1)  +        (beta*(1-P_B(i+30,1)))*(((1-P_H(i+30,1))*V2(j+3,1))+(P_H(i+30,1)*V4(j+3,1)));
% V_A(i+31,a)=FU(i+31,1)  +weight1*(beta*(1-P_B(i+31,1)))*(((1-P_H(i+31,1))*V2(j+3,1))+(P_H(i+31,1)*V4(j+3,1)))+...
%                         +weight2*(beta*(1-P_B(i+31,1)))*(((1-P_H(i+31,1))*V2(j+7,1))+(P_H(i+31,1)*V4(j+7,1)));    
% 
%                     
%                     
%                     
%                     
% else
%     
% V_A(i+0,a) =FU(i+0,1)   +        (beta*(1-P_B(i+0,1))) *(((1-P_H(i+0,1))    *V2(j+0,1))             +(P_H(i+0,1)   *V4(j+0,1)));
% V_A(i+1,a) =FU(i+1,1)   +weight1*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1))    *V2(j+0,1))             +(P_H(i+1,1)   *V4(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *(2*V2(j+0,1)-V2(j+0-4,1)))+(P_H(i+1,1)*(2*V4(j+0,1)-V4(j+0-4,1))));                    
%                   
% V_A(i+2,a) =FU(i+2,1)   +        (beta*(1-P_B(i+2,1))) *(((1-P_H(i+2,1))    *V2(j+1,1))             +(P_H(i+2,1)   *V4(j+1,1)));
% V_A(i+3,a) =FU(i+3,1)   +weight1*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1))    *V2(j+1,1))             +(P_H(i+3,1)   *V4(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *(2*V2(j+1,1)-V2(j+1-4,1)))+(P_H(i+3,1)*(2*V4(j+1,1)-V4(j+1-4,1))));                    
% 
% V_A(i+4,a) =FU(i+4,1)   +        (beta*(1-P_B(i+4,1))) *(((1-P_H(i+4,1))    *V2(j+2,1))             +(P_H(i+4,1)   *V4(j+2,1)));
% V_A(i+5,a) =FU(i+5,1)   +weight1*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1))    *V2(j+2,1))             +(P_H(i+5,1)   *V4(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *(2*V2(j+2,1)-V2(j+2-4,1)))+(P_H(i+5,1)*(2*V4(j+2,1)-V4(j+2-4,1))));                    
% 
% V_A(i+6,a) =FU(i+6,1)   +        (beta*(1-P_B(i+6,1))) *(((1-P_H(i+6,1))    *V2(j+3,1))             +(P_H(i+6,1)   *V4(j+3,1)));
% V_A(i+7,a) =FU(i+7,1)   +weight1*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1))    *V2(j+3,1))             +(P_H(i+7,1)   *V4(j+3,1)))+...
%                         +weight2*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *(2*V2(j+3,1)-V2(j+3-4,1)))+(P_H(i+7,1)*(2*V4(j+3,1)-V4(j+3-4,1))));                    
% 
% V_A(i+8,a) =FU(i+8,1)   +        (beta*(1-P_B(i+8,1))) *(((1-P_H(i+8,1))    *V2(j+0,1))             +(P_H(i+8,1)   *V4(j+0,1)));
% V_A(i+9,a) =FU(i+9,1)   +weight1*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1))    *V2(j+0,1))             +(P_H(i+9,1)   *V4(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *(2*V2(j+0,1)-V2(j+0-4,1)))+(P_H(i+9,1)*(2*V4(j+0,1)-V4(j+0-4,1))));                    
% 
% V_A(i+10,a)=FU(i+10,1)  +        (beta*(1-P_B(i+10,1)))*(((1-P_H(i+10,1))   *V2(j+1,1))             +(P_H(i+10,1)   *V4(j+1,1)));
% V_A(i+11,a)=FU(i+11,1)  +weight1*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))   *V2(j+1,1))             +(P_H(i+11,1)   *V4(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*(2*V2(j+1,1)-V2(j+1-4,1)))+(P_H(i+11,1)*(2*V4(j+1,1)-V4(j+1-4,1))));                    
%     
% V_A(i+12,a)=FU(i+12,1)  +        (beta*(1-P_B(i+12,1)))*(((1-P_H(i+12,1))   *V2(j+2,1))             +(P_H(i+12,1)   *V4(j+2,1)));
% V_A(i+13,a)=FU(i+13,1)  +weight1*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))   *V2(j+2,1))             +(P_H(i+13,1)   *V4(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*(2*V2(j+2,1)-V2(j+2-4,1)))+(P_H(i+13,1)*(2*V4(j+2,1)-V4(j+2-4,1))));                    
% 
% V_A(i+14,a)=FU(i+14,1)  +        (beta*(1-P_B(i+14,1)))*(((1-P_H(i+14,1))   *V2(j+3,1))             +(P_H(i+14,1)   *V4(j+3,1)));
% V_A(i+15,a)=FU(i+15,1)  +weight1*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))   *V2(j+3,1))             +(P_H(i+15,1)   *V4(j+3,1)))+...
%                         +weight2*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*(2*V2(j+3,1)-V2(j+3-4,1)))+(P_H(i+15,1)*(2*V4(j+3,1)-V4(j+3-4,1))));                    
% 
% V_A(i+16,a)=FU(i+16,1)  +        (beta*(1-P_B(i+16,1)))*(((1-P_H(i+16,1))   *V2(j+0,1))             +(P_H(i+16,1)   *V4(j+0,1)));
% V_A(i+17,a)=FU(i+17,1)  +weight1*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))   *V2(j+0,1))             +(P_H(i+17,1)   *V4(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*(2*V2(j+0,1)-V2(j+0-4,1)))+(P_H(i+17,1)*(2*V4(j+0,1)-V4(j+0-4,1))));                    
% 
% V_A(i+18,a)=FU(i+18,1)  +        (beta*(1-P_B(i+18,1)))*(((1-P_H(i+18,1))   *V2(j+1,1))             +(P_H(i+18,1)   *V4(j+1,1)));
% V_A(i+19,a)=FU(i+19,1)  +weight1*(beta*(1-P_B(i+19,1)))*(((1-P_H(i+19,1))   *V2(j+1,1))             +(P_H(i+19,1)   *V4(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+19,1)))*(((1-P_H(i+19,1))*(2*V2(j+1,1)-V2(j+1-4,1)))+(P_H(i+19,1)*(2*V4(j+1,1)-V4(j+1-4,1))));                    
% 
% V_A(i+20,a)=FU(i+20,1)  +        (beta*(1-P_B(i+20,1)))*(((1-P_H(i+20,1))   *V2(j+2,1))             +(P_H(i+20,1)   *V4(j+2,1)));
% V_A(i+21,a)=FU(i+21,1)  +weight1*(beta*(1-P_B(i+21,1)))*(((1-P_H(i+21,1))   *V2(j+2,1))             +(P_H(i+21,1)   *V4(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+21,1)))*(((1-P_H(i+21,1))*(2*V2(j+2,1)-V2(j+2-4,1)))+(P_H(i+21,1)*(2*V4(j+2,1)-V4(j+2-4,1))));                    
% 
% V_A(i+22,a)=FU(i+22,1)  +        (beta*(1-P_B(i+22,1)))*(((1-P_H(i+22,1))   *V2(j+3,1))             +(P_H(i+22,1)   *V4(j+3,1)));
% V_A(i+23,a)=FU(i+23,1)  +weight1*(beta*(1-P_B(i+23,1)))*(((1-P_H(i+23,1))   *V2(j+3,1))             +(P_H(i+23,1)   *V4(j+3,1)))+...
%                         +weight2*(beta*(1-P_B(i+23,1)))*(((1-P_H(i+23,1))*(2*V2(j+3,1)-V2(j+3-4,1)))+(P_H(i+23,1)*(2*V4(j+3,1)-V4(j+3-4,1))));                    
% 
% V_A(i+24,a)=FU(i+24,1)  +        (beta*(1-P_B(i+24,1)))*(((1-P_H(i+24,1))   *V2(j+0,1))             +(P_H(i+24,1)   *V4(j+0,1)));
% V_A(i+25,a)=FU(i+25,1)  +weight1*(beta*(1-P_B(i+25,1)))*(((1-P_H(i+25,1))   *V2(j+0,1))             +(P_H(i+25,1)   *V4(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+25,1)))*(((1-P_H(i+25,1))*(2*V2(j+0,1)-V2(j+0-4,1)))+(P_H(i+25,1)*(2*V4(j+0,1)-V4(j+0-4,1))));                    
% 
% V_A(i+26,a)=FU(i+26,1)  +        (beta*(1-P_B(i+26,1)))*(((1-P_H(i+26,1))   *V2(j+1,1))             +(P_H(i+26,1)   *V4(j+1,1)));
% V_A(i+27,a)=FU(i+27,1)  +weight1*(beta*(1-P_B(i+27,1)))*(((1-P_H(i+27,1))   *V2(j+1,1))             +(P_H(i+27,1)   *V4(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+27,1)))*(((1-P_H(i+27,1))*(2*V2(j+1,1)-V2(j+1-4,1)))+(P_H(i+27,1)*(2*V4(j+1,1)-V4(j+1-4,1))));                    
% 
% V_A(i+28,a)=FU(i+28,1)  +        (beta*(1-P_B(i+28,1)))*(((1-P_H(i+28,1))   *V2(j+2,1))             +(P_H(i+28,1)   *V4(j+2,1)));
% V_A(i+29,a)=FU(i+29,1)  +weight1*(beta*(1-P_B(i+29,1)))*(((1-P_H(i+29,1))   *V2(j+2,1))             +(P_H(i+29,1)   *V4(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+29,1)))*(((1-P_H(i+29,1))*(2*V2(j+2,1)-V2(j+2-4,1)))+(P_H(i+29,1)*(2*V4(j+2,1)-V4(j+2-4,1))));                    
% 
% V_A(i+30,a)=FU(i+30,1)  +        (beta*(1-P_B(i+30,1)))*(((1-P_H(i+30,1))   *V2(j+3,1))             +(P_H(i+30,1)   *V4(j+3,1)));
% V_A(i+31,a)=FU(i+31,1)  +weight1*(beta*(1-P_B(i+31,1)))*(((1-P_H(i+31,1))   *V2(j+3,1))             +(P_H(i+31,1)   *V4(j+3,1)))+...
%                         +weight2*(beta*(1-P_B(i+31,1)))*(((1-P_H(i+31,1))*(2*V2(j+3,1)-V2(j+3-4,1)))+(P_H(i+31,1)*(2*V4(j+3,1)-V4(j+3-4,1))));            
% end                    
% end
% end
% 
% for i=3531:18:4323
% for j=((i-3531)/18)*3+1
% k=(j-1)/3+1;
% if mod(k,5)~=0    
% 
% V_A(i+0,a) =FU(i+0,1)   +        (beta*(1-P_B(i+0,1))) *(((1-P_H(i+0,1)) *V1(j+0,1))+(P_H(i+0,1) *V3(j+0,1)));
% V_A(i+1,a) =FU(i+1,1)   +weight1*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *V1(j+0,1))+(P_H(i+1,1) *V3(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *V1(j+3,1))+(P_H(i+1,1) *V3(j+3,1)));
% 
% V_A(i+2,a) =FU(i+2,1)   +        (beta*(1-P_B(i+2,1))) *(((1-P_H(i+2,1)) *V1(j+1,1))+(P_H(i+2,1) *V3(j+1,1)));
% V_A(i+3,a) =FU(i+3,1)   +weight1*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *V1(j+1,1))+(P_H(i+3,1) *V3(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *V1(j+4,1))+(P_H(i+3,1) *V3(j+4,1)));
% 
% V_A(i+4,a) =FU(i+4,1)   +        (beta*(1-P_B(i+4,1))) *(((1-P_H(i+4,1)) *V1(j+2,1))+(P_H(i+4,1) *V3(j+2,1)));
% V_A(i+5,a) =FU(i+5,1)   +weight1*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *V1(j+2,1))+(P_H(i+5,1) *V3(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *V1(j+5,1))+(P_H(i+5,1) *V3(j+5,1)));
% 
% V_A(i+6,a) =FU(i+6,1)   +        (beta*(1-P_B(i+6,1))) *(((1-P_H(i+6,1)) *V1(j+0,1))+(P_H(i+6,1) *V3(j+0,1)));
% V_A(i+7,a) =FU(i+7,1)   +weight1*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *V1(j+0,1))+(P_H(i+7,1) *V3(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *V1(j+3,1))+(P_H(i+7,1) *V3(j+3,1)));
% 
% V_A(i+8,a) =FU(i+8,1)   +        (beta*(1-P_B(i+8,1))) *(((1-P_H(i+8,1)) *V1(j+1,1))+(P_H(i+8,1) *V3(j+1,1)));
% V_A(i+9,a) =FU(i+9,1)   +weight1*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *V1(j+1,1))+(P_H(i+9,1) *V3(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *V1(j+4,1))+(P_H(i+9,1) *V3(j+4,1)));
% 
% V_A(i+10,a)=FU(i+10,1)  +        (beta*(1-P_B(i+10,1)))*(((1-P_H(i+10,1))*V1(j+2,1))+(P_H(i+10,1)*V3(j+2,1)));
% V_A(i+11,a)=FU(i+11,1)  +weight1*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*V1(j+2,1))+(P_H(i+11,1)*V3(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*V1(j+5,1))+(P_H(i+11,1)*V3(j+5,1)));
% 
% V_A(i+12,a)=FU(i+12,1)  +        (beta*(1-P_B(i+12,1)))*(((1-P_H(i+12,1))*V1(j+0,1))+(P_H(i+12,1)*V3(j+0,1)));
% V_A(i+13,a)=FU(i+13,1)  +weight1*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*V1(j+0,1))+(P_H(i+13,1)*V3(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*V1(j+3,1))+(P_H(i+13,1)*V3(j+3,1)));
% 
% V_A(i+14,a)=FU(i+14,1)  +        (beta*(1-P_B(i+14,1)))*(((1-P_H(i+14,1))*V1(j+1,1))+(P_H(i+14,1)*V3(j+1,1)));
% V_A(i+15,a)=FU(i+15,1)  +weight1*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*V1(j+1,1))+(P_H(i+15,1)*V3(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*V1(j+4,1))+(P_H(i+15,1)*V3(j+4,1)));
% 
% V_A(i+16,a)=FU(i+16,1)  +        (beta*(1-P_B(i+16,1)))*(((1-P_H(i+16,1))*V1(j+2,1))+(P_H(i+16,1)*V3(j+2,1)));
% V_A(i+17,a)=FU(i+17,1)  +weight1*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*V1(j+2,1))+(P_H(i+17,1)*V3(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*V1(j+5,1))+(P_H(i+17,1)*V3(j+5,1)));
% 
% 
% else
%     
% V_A(i+0,a) =FU(i+0,1)   +        (beta*(1-P_B(i+0,1))) *(((1-P_H(i+0,1)) *   V1(j+0,1))             +(P_H(i+0,1)   *V3(j+0,1)));
% V_A(i+1,a) =FU(i+1,1)   +weight1*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *   V1(j+0,1))             +(P_H(i+1,1)   *V3(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *(2*V1(j+0,1)-V1(j+0-3,1)))+(P_H(i+1,1)*(2*V3(j+0,1)-V3(j+0-3,1))));
%     
% V_A(i+2,a) =FU(i+2,1)   +        (beta*(1-P_B(i+2,1))) *(((1-P_H(i+2,1)) *   V1(j+1,1))             +(P_H(i+2,1)   *V3(j+1,1)));
% V_A(i+3,a) =FU(i+3,1)   +weight1*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *   V1(j+1,1))             +(P_H(i+3,1)   *V3(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *(2*V1(j+1,1)-V1(j+1-3,1)))+(P_H(i+3,1)*(2*V3(j+1,1)-V3(j+1-3,1))));
% 
% V_A(i+4,a) =FU(i+4,1)   +        (beta*(1-P_B(i+4,1))) *(((1-P_H(i+4,1)) *   V1(j+2,1))             +(P_H(i+4,1)   *V3(j+2,1)));
% V_A(i+5,a) =FU(i+5,1)   +weight1*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *   V1(j+2,1))             +(P_H(i+5,1)   *V3(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *(2*V1(j+2,1)-V1(j+2-3,1)))+(P_H(i+5,1)*(2*V3(j+2,1)-V3(j+2-3,1))));
% 
% V_A(i+6,a) =FU(i+6,1)   +        (beta*(1-P_B(i+6,1))) *(((1-P_H(i+6,1)) *   V1(j+0,1))             +(P_H(i+6,1)   *V3(j+0,1)));
% V_A(i+7,a) =FU(i+7,1)   +weight1*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *   V1(j+0,1))             +(P_H(i+7,1)   *V3(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *(2*V1(j+0,1)-V1(j+0-3,1)))+(P_H(i+7,1)*(2*V3(j+0,1)-V3(j+0-3,1))));
% 
% V_A(i+8,a) =FU(i+8,1)   +        (beta*(1-P_B(i+8,1))) *(((1-P_H(i+8,1)) *   V1(j+1,1))             +(P_H(i+8,1)   *V3(j+1,1)));
% V_A(i+9,a) =FU(i+9,1)   +weight1*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *   V1(j+1,1))             +(P_H(i+9,1)   *V3(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *(2*V1(j+1,1)-V1(j+1-3,1)))+(P_H(i+9,1)*(2*V3(j+1,1)-V3(j+1-3,1))));
% 
% V_A(i+10,a)=FU(i+10,1)  +        (beta*(1-P_B(i+10,1)))*(((1-P_H(i+10,1))*   V1(j+2,1))             +(P_H(i+10,1)   *V3(j+2,1)));
% V_A(i+11,a)=FU(i+11,1)  +weight1*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*   V1(j+2,1))             +(P_H(i+11,1)   *V3(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*(2*V1(j+2,1)-V1(j+2-3,1)))+(P_H(i+11,1)*(2*V3(j+2,1)-V3(j+2-3,1))));
% 
% V_A(i+12,a)=FU(i+12,1)  +        (beta*(1-P_B(i+12,1)))*(((1-P_H(i+12,1))*   V1(j+0,1))             +(P_H(i+12,1)   *V3(j+0,1)));
% V_A(i+13,a)=FU(i+13,1)  +weight1*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*   V1(j+0,1))             +(P_H(i+13,1)   *V3(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*(2*V1(j+0,1)-V1(j+0-3,1)))+(P_H(i+13,1)*(2*V3(j+0,1)-V3(j+0-3,1))));
% 
% V_A(i+14,a)=FU(i+14,1)  +        (beta*(1-P_B(i+14,1)))*(((1-P_H(i+14,1))*   V1(j+1,1))             +(P_H(i+14,1)   *V3(j+1,1)));
% V_A(i+15,a)=FU(i+15,1)  +weight1*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*   V1(j+1,1))             +(P_H(i+15,1)   *V3(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*(2*V1(j+1,1)-V1(j+1-3,1)))+(P_H(i+15,1)*(2*V3(j+1,1)-V3(j+1-3,1))));
% 
% V_A(i+16,a)=FU(i+16,1)  +        (beta*(1-P_B(i+16,1)))*(((1-P_H(i+16,1))*   V1(j+2,1))             +(P_H(i+16,1)   *V3(j+2,1)));
% V_A(i+17,a)=FU(i+17,1)  +weight1*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*   V1(j+2,1))             +(P_H(i+17,1)   *V3(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*(2*V1(j+2,1)-V1(j+2-3,1)))+(P_H(i+17,1)*(2*V3(j+2,1)-V3(j+2-3,1))));
% 
% 
% end
% end
% end
% 
% 
% for i=4341:32:7029
% for j=((i-4341)/32)*4+1      
% k=(j-1)/4+1;
% if mod(k,5)~=0 
%            
% V_A(i+0,a) =FU(i+0,1)   +        (beta*(1-P_B(i+0,1))) *(((1-P_H(i+0,1)) *V2(j+0,1))+(P_H(i+0,1) *V4(j+0,1)));
% V_A(i+1,a) =FU(i+1,1)   +weight1*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *V2(j+0,1))+(P_H(i+1,1) *V4(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *V2(j+4,1))+(P_H(i+1,1) *V4(j+4,1)));
% 
% V_A(i+2,a) =FU(i+2,1)   +        (beta*(1-P_B(i+2,1))) *(((1-P_H(i+2,1)) *V2(j+1,1))+(P_H(i+2,1) *V4(j+1,1)));
% V_A(i+3,a) =FU(i+3,1)   +weight1*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *V2(j+1,1))+(P_H(i+3,1) *V4(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *V2(j+5,1))+(P_H(i+3,1) *V4(j+5,1)));
% 
% V_A(i+4,a) =FU(i+4,1)   +        (beta*(1-P_B(i+4,1))) *(((1-P_H(i+4,1)) *V2(j+2,1))+(P_H(i+4,1) *V4(j+2,1)));
% V_A(i+5,a) =FU(i+5,1)   +weight1*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *V2(j+2,1))+(P_H(i+5,1) *V4(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *V2(j+6,1))+(P_H(i+5,1) *V4(j+6,1)));
% 
% V_A(i+6,a) =FU(i+6,1)   +        (beta*(1-P_B(i+6,1))) *(((1-P_H(i+6,1)) *V2(j+3,1))+(P_H(i+6,1) *V4(j+3,1)));
% V_A(i+7,a) =FU(i+7,1)   +weight1*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *V2(j+3,1))+(P_H(i+7,1) *V4(j+3,1)))+...
%                         +weight2*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *V2(j+7,1))+(P_H(i+7,1) *V4(j+7,1)));
% 
% V_A(i+8,a) =FU(i+8,1)   +        (beta*(1-P_B(i+8,1))) *(((1-P_H(i+8,1)) *V2(j+0,1))+(P_H(i+8,1) *V4(j+0,1)));
% V_A(i+9,a) =FU(i+9,1)   +weight1*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *V2(j+0,1))+(P_H(i+9,1) *V4(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *V2(j+4,1))+(P_H(i+9,1) *V4(j+4,1)));
% 
% V_A(i+10,a)=FU(i+10,1)  +        (beta*(1-P_B(i+10,1)))*(((1-P_H(i+10,1))*V2(j+1,1))+(P_H(i+10,1)*V4(j+1,1)));
% V_A(i+11,a)=FU(i+11,1)  +weight1*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*V2(j+1,1))+(P_H(i+11,1)*V4(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*V2(j+5,1))+(P_H(i+11,1)*V4(j+5,1)));
% 
% V_A(i+12,a)=FU(i+12,1)  +        (beta*(1-P_B(i+12,1)))*(((1-P_H(i+12,1))*V2(j+2,1))+(P_H(i+12,1)*V4(j+2,1)));
% V_A(i+13,a)=FU(i+13,1)  +weight1*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*V2(j+2,1))+(P_H(i+13,1)*V4(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*V2(j+6,1))+(P_H(i+13,1)*V4(j+6,1)));
% 
% V_A(i+14,a)=FU(i+14,1)  +        (beta*(1-P_B(i+14,1)))*(((1-P_H(i+14,1))*V2(j+3,1))+(P_H(i+14,1)*V4(j+3,1)));
% V_A(i+15,a)=FU(i+15,1)  +weight1*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*V2(j+3,1))+(P_H(i+15,1)*V4(j+3,1)))+...
%                         +weight2*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*V2(j+7,1))+(P_H(i+15,1)*V4(j+7,1)));
% 
% V_A(i+16,a)=FU(i+16,1)  +        (beta*(1-P_B(i+16,1)))*(((1-P_H(i+16,1))*V2(j+0,1))+(P_H(i+16,1)*V4(j+0,1)));
% V_A(i+17,a)=FU(i+17,1)  +weight1*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*V2(j+0,1))+(P_H(i+17,1)*V4(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*V2(j+4,1))+(P_H(i+17,1)*V4(j+4,1)));
% 
% V_A(i+18,a)=FU(i+18,1)  +        (beta*(1-P_B(i+18,1)))*(((1-P_H(i+18,1))*V2(j+1,1))+(P_H(i+18,1)*V4(j+1,1)));
% V_A(i+19,a)=FU(i+19,1)  +weight1*(beta*(1-P_B(i+19,1)))*(((1-P_H(i+19,1))*V2(j+1,1))+(P_H(i+19,1)*V4(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+19,1)))*(((1-P_H(i+19,1))*V2(j+5,1))+(P_H(i+19,1)*V4(j+5,1)));
% 
% V_A(i+20,a)=FU(i+20,1)  +        (beta*(1-P_B(i+20,1)))*(((1-P_H(i+20,1))*V2(j+2,1))+(P_H(i+20,1)*V4(j+2,1)));
% V_A(i+21,a)=FU(i+21,1)  +weight1*(beta*(1-P_B(i+21,1)))*(((1-P_H(i+21,1))*V2(j+2,1))+(P_H(i+21,1)*V4(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+21,1)))*(((1-P_H(i+21,1))*V2(j+6,1))+(P_H(i+21,1)*V4(j+6,1)));
% 
% V_A(i+22,a)=FU(i+22,1)  +        (beta*(1-P_B(i+22,1)))*(((1-P_H(i+22,1))*V2(j+3,1))+(P_H(i+22,1)*V4(j+3,1)));
% V_A(i+23,a)=FU(i+23,1)  +weight1*(beta*(1-P_B(i+23,1)))*(((1-P_H(i+23,1))*V2(j+3,1))+(P_H(i+23,1)*V4(j+3,1)))+...
%                         +weight2*(beta*(1-P_B(i+23,1)))*(((1-P_H(i+23,1))*V2(j+7,1))+(P_H(i+23,1)*V4(j+7,1)));
% 
% V_A(i+24,a)=FU(i+24,1)  +        (beta*(1-P_B(i+24,1)))*(((1-P_H(i+24,1))*V2(j+0,1))+(P_H(i+24,1)*V4(j+0,1)));
% V_A(i+25,a)=FU(i+25,1)  +weight1*(beta*(1-P_B(i+25,1)))*(((1-P_H(i+25,1))*V2(j+0,1))+(P_H(i+25,1)*V4(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+25,1)))*(((1-P_H(i+25,1))*V2(j+4,1))+(P_H(i+25,1)*V4(j+4,1)));
% 
% V_A(i+26,a)=FU(i+26,1)  +        (beta*(1-P_B(i+26,1)))*(((1-P_H(i+26,1))*V2(j+1,1))+(P_H(i+26,1)*V4(j+1,1)));
% V_A(i+27,a)=FU(i+27,1)  +weight1*(beta*(1-P_B(i+27,1)))*(((1-P_H(i+27,1))*V2(j+1,1))+(P_H(i+27,1)*V4(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+27,1)))*(((1-P_H(i+27,1))*V2(j+5,1))+(P_H(i+27,1)*V4(j+5,1)));
% 
% V_A(i+28,a)=FU(i+28,1)  +        (beta*(1-P_B(i+28,1)))*(((1-P_H(i+28,1))*V2(j+2,1))+(P_H(i+28,1)*V4(j+2,1)));
% V_A(i+29,a)=FU(i+29,1)  +weight1*(beta*(1-P_B(i+29,1)))*(((1-P_H(i+29,1))*V2(j+2,1))+(P_H(i+29,1)*V4(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+29,1)))*(((1-P_H(i+29,1))*V2(j+6,1))+(P_H(i+29,1)*V4(j+6,1)));
% 
% V_A(i+30,a)=FU(i+30,1)  +        (beta*(1-P_B(i+30,1)))*(((1-P_H(i+30,1))*V2(j+3,1))+(P_H(i+30,1)*V4(j+3,1)));
% V_A(i+31,a)=FU(i+31,1)  +weight1*(beta*(1-P_B(i+31,1)))*(((1-P_H(i+31,1))*V2(j+3,1))+(P_H(i+31,1)*V4(j+3,1)))+...
%                         +weight2*(beta*(1-P_B(i+31,1)))*(((1-P_H(i+31,1))*V2(j+7,1))+(P_H(i+31,1)*V4(j+7,1)));    
% 
%                     
%                     
%                     
%                     
% else
%     
% V_A(i+0,a) =FU(i+0,1)   +        (beta*(1-P_B(i+0,1))) *(((1-P_H(i+0,1))    *V2(j+0,1))             +(P_H(i+0,1)   *V4(j+0,1)));
% V_A(i+1,a) =FU(i+1,1)   +weight1*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1))    *V2(j+0,1))             +(P_H(i+1,1)   *V4(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+1,1))) *(((1-P_H(i+1,1)) *(2*V2(j+0,1)-V2(j+0-4,1)))+(P_H(i+1,1)*(2*V4(j+0,1)-V4(j+0-4,1))));                    
%                     
% V_A(i+2,a) =FU(i+2,1)   +        (beta*(1-P_B(i+2,1))) *(((1-P_H(i+2,1))    *V2(j+1,1))             +(P_H(i+2,1)   *V4(j+1,1)));
% V_A(i+3,a) =FU(i+3,1)   +weight1*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1))    *V2(j+1,1))             +(P_H(i+3,1)   *V4(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+3,1))) *(((1-P_H(i+3,1)) *(2*V2(j+1,1)-V2(j+1-4,1)))+(P_H(i+3,1)*(2*V4(j+1,1)-V4(j+1-4,1))));                    
% 
% V_A(i+4,a) =FU(i+4,1)   +        (beta*(1-P_B(i+4,1))) *(((1-P_H(i+4,1))    *V2(j+2,1))             +(P_H(i+4,1)   *V4(j+2,1)));
% V_A(i+5,a) =FU(i+5,1)   +weight1*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1))    *V2(j+2,1))             +(P_H(i+5,1)   *V4(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+5,1))) *(((1-P_H(i+5,1)) *(2*V2(j+2,1)-V2(j+2-4,1)))+(P_H(i+5,1)*(2*V4(j+2,1)-V4(j+2-4,1))));                    
% 
% V_A(i+6,a) =FU(i+6,1)   +        (beta*(1-P_B(i+6,1))) *(((1-P_H(i+6,1))    *V2(j+3,1))             +(P_H(i+6,1)   *V4(j+3,1)));
% V_A(i+7,a) =FU(i+7,1)   +weight1*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1))    *V2(j+3,1))             +(P_H(i+7,1)   *V4(j+3,1)))+...
%                         +weight2*(beta*(1-P_B(i+7,1))) *(((1-P_H(i+7,1)) *(2*V2(j+3,1)-V2(j+3-4,1)))+(P_H(i+7,1)*(2*V4(j+3,1)-V4(j+3-4,1))));                    
% 
% V_A(i+8,a) =FU(i+8,1)   +        (beta*(1-P_B(i+8,1))) *(((1-P_H(i+8,1))    *V2(j+0,1))             +(P_H(i+8,1)   *V4(j+0,1)));
% V_A(i+9,a) =FU(i+9,1)   +weight1*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1))    *V2(j+0,1))             +(P_H(i+9,1)   *V4(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+9,1))) *(((1-P_H(i+9,1)) *(2*V2(j+0,1)-V2(j+0-4,1)))+(P_H(i+9,1)*(2*V4(j+0,1)-V4(j+0-4,1))));                    
% 
% V_A(i+10,a)=FU(i+10,1)  +        (beta*(1-P_B(i+10,1)))*(((1-P_H(i+10,1))   *V2(j+1,1))             +(P_H(i+10,1)   *V4(j+1,1)));
% V_A(i+11,a)=FU(i+11,1)  +weight1*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))   *V2(j+1,1))             +(P_H(i+11,1)   *V4(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+11,1)))*(((1-P_H(i+11,1))*(2*V2(j+1,1)-V2(j+1-4,1)))+(P_H(i+11,1)*(2*V4(j+1,1)-V4(j+1-4,1))));                    
% 
% V_A(i+12,a)=FU(i+12,1)  +        (beta*(1-P_B(i+12,1)))*(((1-P_H(i+12,1))   *V2(j+2,1))             +(P_H(i+12,1)   *V4(j+2,1)));
% V_A(i+13,a)=FU(i+13,1)  +weight1*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))   *V2(j+2,1))             +(P_H(i+13,1)   *V4(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+13,1)))*(((1-P_H(i+13,1))*(2*V2(j+2,1)-V2(j+2-4,1)))+(P_H(i+13,1)*(2*V4(j+2,1)-V4(j+2-4,1))));                    
% 
% V_A(i+14,a)=FU(i+14,1)  +        (beta*(1-P_B(i+14,1)))*(((1-P_H(i+14,1))   *V2(j+3,1))             +(P_H(i+14,1)   *V4(j+3,1)));
% V_A(i+15,a)=FU(i+15,1)  +weight1*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))   *V2(j+3,1))             +(P_H(i+15,1)   *V4(j+3,1)))+...
%                         +weight2*(beta*(1-P_B(i+15,1)))*(((1-P_H(i+15,1))*(2*V2(j+3,1)-V2(j+3-4,1)))+(P_H(i+15,1)*(2*V4(j+3,1)-V4(j+3-4,1))));                    
% 
% V_A(i+16,a)=FU(i+16,1)  +        (beta*(1-P_B(i+16,1)))*(((1-P_H(i+16,1))   *V2(j+0,1))             +(P_H(i+16,1)   *V4(j+0,1)));
% V_A(i+17,a)=FU(i+17,1)  +weight1*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))   *V2(j+0,1))             +(P_H(i+17,1)   *V4(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+17,1)))*(((1-P_H(i+17,1))*(2*V2(j+0,1)-V2(j+0-4,1)))+(P_H(i+17,1)*(2*V4(j+0,1)-V4(j+0-4,1))));                    
% 
% V_A(i+18,a)=FU(i+18,1)  +        (beta*(1-P_B(i+18,1)))*(((1-P_H(i+18,1))   *V2(j+1,1))             +(P_H(i+18,1)   *V4(j+1,1)));
% V_A(i+19,a)=FU(i+19,1)  +weight1*(beta*(1-P_B(i+19,1)))*(((1-P_H(i+19,1))   *V2(j+1,1))             +(P_H(i+19,1)   *V4(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+19,1)))*(((1-P_H(i+19,1))*(2*V2(j+1,1)-V2(j+1-4,1)))+(P_H(i+19,1)*(2*V4(j+1,1)-V4(j+1-4,1))));                    
% 
% V_A(i+20,a)=FU(i+20,1)  +        (beta*(1-P_B(i+20,1)))*(((1-P_H(i+20,1))   *V2(j+2,1))             +(P_H(i+20,1)   *V4(j+2,1)));
% V_A(i+21,a)=FU(i+21,1)  +weight1*(beta*(1-P_B(i+21,1)))*(((1-P_H(i+21,1))   *V2(j+2,1))             +(P_H(i+21,1)   *V4(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+21,1)))*(((1-P_H(i+21,1))*(2*V2(j+2,1)-V2(j+2-4,1)))+(P_H(i+21,1)*(2*V4(j+2,1)-V4(j+2-4,1))));                    
% 
% V_A(i+22,a)=FU(i+22,1)  +        (beta*(1-P_B(i+22,1)))*(((1-P_H(i+22,1))   *V2(j+3,1))             +(P_H(i+22,1)   *V4(j+3,1)));
% V_A(i+23,a)=FU(i+23,1)  +weight1*(beta*(1-P_B(i+23,1)))*(((1-P_H(i+23,1))   *V2(j+3,1))             +(P_H(i+23,1)   *V4(j+3,1)))+...
%                         +weight2*(beta*(1-P_B(i+23,1)))*(((1-P_H(i+23,1))*(2*V2(j+3,1)-V2(j+3-4,1)))+(P_H(i+23,1)*(2*V4(j+3,1)-V4(j+3-4,1))));                    
% 
% V_A(i+24,a)=FU(i+24,1)  +        (beta*(1-P_B(i+24,1)))*(((1-P_H(i+24,1))   *V2(j+0,1))             +(P_H(i+24,1)   *V4(j+0,1)));
% V_A(i+25,a)=FU(i+25,1)  +weight1*(beta*(1-P_B(i+25,1)))*(((1-P_H(i+25,1))   *V2(j+0,1))             +(P_H(i+25,1)   *V4(j+0,1)))+...
%                         +weight2*(beta*(1-P_B(i+25,1)))*(((1-P_H(i+25,1))*(2*V2(j+0,1)-V2(j+0-4,1)))+(P_H(i+25,1)*(2*V4(j+0,1)-V4(j+0-4,1))));                    
% 
% V_A(i+26,a)=FU(i+26,1)  +        (beta*(1-P_B(i+26,1)))*(((1-P_H(i+26,1))   *V2(j+1,1))             +(P_H(i+26,1)   *V4(j+1,1)));
% V_A(i+27,a)=FU(i+27,1)  +weight1*(beta*(1-P_B(i+27,1)))*(((1-P_H(i+27,1))   *V2(j+1,1))             +(P_H(i+27,1)   *V4(j+1,1)))+...
%                         +weight2*(beta*(1-P_B(i+27,1)))*(((1-P_H(i+27,1))*(2*V2(j+1,1)-V2(j+1-4,1)))+(P_H(i+27,1)*(2*V4(j+1,1)-V4(j+1-4,1))));                    
% 
% V_A(i+28,a)=FU(i+28,1)  +        (beta*(1-P_B(i+28,1)))*(((1-P_H(i+28,1))   *V2(j+2,1))             +(P_H(i+28,1)   *V4(j+2,1)));
% V_A(i+29,a)=FU(i+29,1)  +weight1*(beta*(1-P_B(i+29,1)))*(((1-P_H(i+29,1))   *V2(j+2,1))             +(P_H(i+29,1)   *V4(j+2,1)))+...
%                         +weight2*(beta*(1-P_B(i+29,1)))*(((1-P_H(i+29,1))*(2*V2(j+2,1)-V2(j+2-4,1)))+(P_H(i+29,1)*(2*V4(j+2,1)-V4(j+2-4,1))));                    
% 
% V_A(i+30,a)=FU(i+30,1)  +        (beta*(1-P_B(i+30,1)))*(((1-P_H(i+30,1))   *V2(j+3,1))             +(P_H(i+30,1)   *V4(j+3,1)));
% V_A(i+31,a)=FU(i+31,1)  +weight1*(beta*(1-P_B(i+31,1)))*(((1-P_H(i+31,1))   *V2(j+3,1))             +(P_H(i+31,1)   *V4(j+3,1)))+...
%                         +weight2*(beta*(1-P_B(i+31,1)))*(((1-P_H(i+31,1))*(2*V2(j+3,1)-V2(j+3-4,1)))+(P_H(i+31,1)*(2*V4(j+3,1)-V4(j+3-4,1))));            
% end                    
% end
% end
% 
% % V_A(:,a)
% 
% end
% 
% 
% 
% 
% %7  USE V_A TO CREATE CCPS (EXPLOIT EV TYPE I ERROR ASSUMPTIONS)
% 
% exp_VA=exp(V_A-(max(transpose(max(V_A)))));
% 
% ccp=zeros(size(V_A));
% 
% for d0=1:6:805
%     d1=d0+5;
%     for x=d0:d1
%         
%     ccp(x,:)=times(exp_VA(x,:),power((sum(exp_VA(d0:d1,:))),-1));
%     
%     end
% end
% 
% for d0=811:8:3523 
%     d1=d0+7; 
%     for x=d0:d1
% 
%     ccp(x,:)=times(exp_VA(x,:),power((sum(exp_VA(d0:d1,:))),-1));
%     
%     end
% end
% 
% for d0=3531:6:4335 
%     d1=d0+5;
%     for x=d0:d1
%         
%     ccp(x,:)=times(exp_VA(x,:),power((sum(exp_VA(d0:d1,:))),-1));
%     
%     end
% end
% 
% for d0=4341:8:7053 
%     d1=d0+7; 
%     for x=d0:d1
% 
%     ccp(x,:)=times(exp_VA(x,:),power((sum(exp_VA(d0:d1,:))),-1));
%     
%     end
% end
% 
% CCP(:,:,type)=[ccp(:,1:70) sig];
% 
% end
%  
% 
% 
% 
% % VALUES
% % E_INDSM  = E_INDSM(v_it,E_it,d_m0,d_l1,d_m1,H_it)
% 
% for E=10:10:50
% for A=30:3:60
% 
% a=(A-30)*2+1;
% v=24;
% dm0=0;
% H=1;
% 
% V_sim(:,1)=  V_A(E_INDSM(v,E,dm0,0,0,H):E_INDSM(v,E,dm0,1,3,H),a);
% CCP_sim(:,1)=CCP(E_INDSM(v,E,dm0,0,0,H):E_INDSM(v,E,dm0,1,3,H),a);
% r=((a-1)/6)+1+(((E-10)/10)*11);
% 
% %VALUE CHANGE for COUNTERFACTUAL DRUGS
% if     CFDRUG==1 && INC==0  
% V1_sim(r,1)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% elseif CFDRUG==2 && INC==0  
% V1_sim(r,2)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% elseif CFDRUG==3 && INC==0  
% V1_sim(r,3)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% elseif CFDRUG==4 && INC==0  
% V1_sim(r,4)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% elseif CFDRUG==5 && INC==0  
% V1_sim(r,5)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% elseif CFDRUG==6 && INC==0  
% V1_sim(r,6)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% elseif CFDRUG==7 && INC==0  
% V1_sim(r,7)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% elseif CFDRUG==8 && INC==0  
% V1_sim(r,8)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% end
% 
% 
% if     CFDRUG==2 && INC==0
% V1_sim2(r,1)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% elseif CFDRUG==1 && INC==0
% V1_sim2(r,2)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% end
% if CFDRUG==1
% g=INC+2;
% V1_sim2(r,g)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% end
% 
% if     CFDRUG==4 && INC==0
% V1_sim4(r,1)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% elseif CFDRUG==3 && INC==0
% V1_sim4(r,2)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% end
% if CFDRUG==3
% g=INC+2;
% V1_sim4(r,g)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% end
% 
% if     CFDRUG==5 && INC==0
% V1_sim5(r,1)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% elseif CFDRUG==3 && INC==0
% V1_sim5(r,2)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% end
% if CFDRUG==3
% g=INC+2;
% V1_sim5(r,g)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% end
% 
% if     CFDRUG==6 && INC==0
% V1_sim6(r,1)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% elseif CFDRUG==3 && INC==0
% V1_sim6(r,2)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% end
% if CFDRUG==3
% g=INC+2;
% V1_sim6(r,g)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% end
% 
% if     CFDRUG==7 && INC==0
% V1_sim7(r,1)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% elseif CFDRUG==3 && INC==0
% V1_sim7(r,2)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% end
% if CFDRUG==3
% g=INC+2;
% V1_sim7(r,g)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% end
% 
% if     CFDRUG==8 && INC==0
% V1_sim8(r,1)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% if isinf(V1_sim8(r,1))==1
%     V1_sim8(r,1)=V1_sim8(r-1,1)-(V1_sim8(r-1,1)-V1_sim8(r-1,1));
% end
% elseif CFDRUG==6 && INC==0
% V1_sim8(r,2)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% end
% if CFDRUG==6
% g=INC+2;
% V1_sim8(r,g)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% if isnan(V1_sim8(r,g))==1;
% V1_sim8(r,g)=V1_sim8(r,g-1)+(V1_sim8(r,g-1)-V1_sim8(r,g-2))*.9;
% end
% end
% 
% 
% if     CFDRUG==8 && INC==0
% V1_sim83(r,1)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% if isinf(V1_sim83(r,1))==1
%     V1_sim83(r,1)=V1_sim83(r-1,1)-(V1_sim83(r-1,1)-V1_sim83(r-1,1));
% end
% elseif CFDRUG==3 && INC==0
% V1_sim83(r,2)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% end
% if CFDRUG==3
% g=INC+2;
% V1_sim83(r,g)=sum(times(V_sim(:,1),CCP_sim(:,1)));
% if isnan(V1_sim83(r,g))==1;
% V1_sim83(r,g)=V1_sim83(r,g-1)+(V1_sim83(r,g-1)-V1_sim83(r,g-2))*.9;
% end
% end
% 
% end
% end
% end
% end
% 
% g=size(V1_sim2,2)+1;
% for x=1:size(V1_sim2,1)
% i=1;
% while i<=size(V1_sim2,2)-1;
% if V1_sim2(x,i+2)>=V1_sim2(x,1)
%     V1_sim2(x,g)=INCREMENT*(i-1);
%     i=size(V1_sim2,2)+1;
% else
%     i=i+1;
% end
% end
% end
% 
% g=size(V1_sim4,2)+1;
% for x=1:size(V1_sim4,1)
% i=1;
% while i<=size(V1_sim4,2)-1;
% if V1_sim4(x,i+2)>=V1_sim4(x,1)
%     V1_sim4(x,g)=INCREMENT*(i-1);  
%     i=size(V1_sim4,2)+1;
% else
%     i=i+1;
% end
% end
% end
% 
% 
% g=size(V1_sim5,2)+1;
% for x=1:size(V1_sim5,1)
% i=1;
% while i<=size(V1_sim5,2)-1;
% if V1_sim5(x,i+2)>=V1_sim5(x,1)
%     V1_sim5(x,g)=INCREMENT*(i-1);  
%     i=size(V1_sim5,2)+1;
% else
%     i=i+1;
% end
% end
% end
% 
% 
% g=size(V1_sim6,2)+1;
% for x=1:size(V1_sim6,1)
% i=1;
% while i<=size(V1_sim6,2)-1;
% if V1_sim6(x,i+2)>=V1_sim6(x,1)
%     V1_sim6(x,g)=INCREMENT*(i-1); 
%     i=size(V1_sim6,2)+1;
% else
%     i=i+1;
% end
% end
% end
% 
% g=size(V1_sim7,2)+1;
% for x=1:size(V1_sim7,1)
% i=1;
% while i<=size(V1_sim7,2)-1;
% if V1_sim7(x,i+2)>=V1_sim7(x,1)
%     V1_sim7(x,g)=INCREMENT*(i-1);
%     i=size(V1_sim7,2)+1;
% else
%     i=i+1;
% end
% end
% end
% 
% 
% g=size(V1_sim8,2)+1;
% for x=1:size(V1_sim8,1)
% i=1;
% while i<=size(V1_sim8,2)-1;
% if V1_sim8(x,i+2)>=V1_sim8(x,1)
%     V1_sim8(x,g)=INCREMENT*(i-1);  
%     i=size(V1_sim8,2)+1;
% else
%     i=i+1;
% end
% end
% end
% 
% 
% g=size(V1_sim83,2)+1;
% for x=1:size(V1_sim83,1)
% i=1;
% while i<=size(V1_sim83,2)-1;
% if V1_sim83(x,i+2)>=V1_sim83(x,1)
%     V1_sim83(x,g)=INCREMENT*(i-1);  
%     i=size(V1_sim83,2)+1;
% else
%     i=i+1;
% end
% end
% end
% 
% clear ANNU ANNUAGE ANNUEXP GraphAGE GraphEXP
% clear str1 str2 str3 str4 str5 str6
% 
% ANNU(:,1)=[...
%     10*ones(11,1);
%     20*ones(11,1);
%     30*ones(11,1);
%     40*ones(11,1);
%     50*ones(11,1);];
% 
% ANNU(:,2)=[...
%     30;33;36;39;42;45;48;51;54;57;60;
%     30;33;36;39;42;45;48;51;54;57;60;
%     30;33;36;39;42;45;48;51;54;57;60;
%     30;33;36;39;42;45;48;51;54;57;60;
%     30;33;36;39;42;45;48;51;54;57;60;];
% 
% ANNU(:,3)=2*[...
% 12;12;12;11;11;11;10;10;9;9;9;
% 12;12;12;11;11;11;10;10;9;9;9;
% 12;12;12;11;11;11;10;10;9;9;9;
% 12;12;12;11;11;11;10;10;9;9;9;
% 12;12;12;11;11;11;10;10;9;9;9;];
% 
% ANNU(:,4)=2*[...
% 30;30;27;27;25;22;22;20;20;20;20;
% 30;30;27;27;25;22;22;20;20;20;20;
% 30;30;27;27;25;22;22;20;20;20;20;
% 30;30;27;27;25;22;22;20;20;20;20;
% 30;30;27;27;25;22;22;20;20;20;20;];
% 
% RawANNU(:,1)=(3/2)*V1_sim2(:,size(V1_sim2,2));
% RawANNU(:,2)=(3/2)*V1_sim4(:,size(V1_sim4,2));
% RawANNU(:,3)=(3/2)*V1_sim5(:,size(V1_sim5,2));
% RawANNU(:,4)=(3/2)*V1_sim6(:,size(V1_sim6,2));
% RawANNU(:,5)=(3/2)*V1_sim7(:,size(V1_sim7,2));
% RawANNU(:,6)=(3/2)*V1_sim83(:,size(V1_sim83,2));
% % RawANNU(:,6)=(3/2)*V1_sim8(:,size(V1_sim8,2))+V1_sim6(:,size(V1_sim6,2));
% 
% 
% ANNU(:,5)=((times((((1-power(1.03,-ANNU(:,3)))/0.03)*1.03),RawANNU(:,1))))/1000;
% ANNU(:,6)=((times((((1-power(1.03,-ANNU(:,4)))/0.03)*1.03),RawANNU(:,2))))/1000+ANNU(:,5);
% ANNU(:,7)=((times((((1-power(1.03,-ANNU(:,4)))/0.03)*1.03),RawANNU(:,3))))/1000+ANNU(:,5);
% ANNU(:,8)=((times((((1-power(1.03,-ANNU(:,4)))/0.03)*1.03),RawANNU(:,4))))/1000+ANNU(:,5);
% ANNU(:,9)=((times((((1-power(1.03,-ANNU(:,4)))/0.03)*1.03),RawANNU(:,5))))/1000+ANNU(:,5);
% ANNU(:,10)=((times((((1-power(1.03,-ANNU(:,4)))/0.03)*1.03),RawANNU(:,6))))/1000+ANNU(:,5);
% 
% beep=1;
% boop=11;
% 
% 
%   a=ANNU(beep:boop,2)
% y1= ANNU(beep:boop,5) % HAART
% y2=[ANNU(beep:boop,5) ANNU(beep:boop,6)]% HAART, H+F
% y3=[ANNU(beep:boop,5) ANNU(beep:boop,6) ANNU(beep:boop,7)]% HAART, H+F, H+E-F
% y4=[ANNU(beep:boop,5) ANNU(beep:boop,6) ANNU(beep:boop,8)]% HAART, H+F, H+E
% y5=[ANNU(beep:boop,5) ANNU(beep:boop,6) ANNU(beep:boop,8) ANNU(beep:boop,9)]% HAART, H+F, H+E, H+E & H+F
% y6=[ANNU(beep:boop,5) ANNU(beep:boop,6) ANNU(beep:boop,8) ANNU(beep:boop,9) ANNU(beep:boop,10)]% HAART, CURE
% 
% 
% cd ..
% 
% clf reset
% colormap gray 
% 
% b = get(gca,'XTickLabel');
% set(gca,'XTickLabel',b,'fontsize',14)
% b = get(gca,'XTickLabel');
% set(gca,'YTickLabel',b,'fontsize',14)
% 
% bar(a,y2);
% leg1 = legend('HAART','Side-Effects Innovation');
% xlabel('Age','FontSize',25)
% ylabel('Payment (X $1,000)','FontSize',25)
% xlim([27 63])
% if SIM_TYPE==1
% print('-dpng' , 'Artwork/sim6_plot1_1')
% elseif SIM_TYPE==2
% print('-dpng' , 'Artwork/sim6_plot1_2')
% elseif SIM_TYPE==3
% print('-dpng' , 'Artwork/sim6_plot1_3')
% elseif SIM_TYPE==4
% print('-dpng' , 'Artwork/sim6_plot1_4')
% end
% 
% 
% bar(a,y4);
% leg2 = legend('HAART','Side-Effects Innovation','Efficacy Innovation');
% xlabel('Age','FontSize',25)
% ylabel('Payment (X $1,000)','FontSize',25)
% xlim([27 63])
% if SIM_TYPE==1
% print('-dpng' , 'Artwork/sim6_plot2_1')
% elseif SIM_TYPE==2
% print('-dpng' , 'Artwork/sim6_plot2_2')
% elseif SIM_TYPE==3
% print('-dpng' , 'Artwork/sim6_plot2_3')
% elseif SIM_TYPE==4
% print('-dpng' , 'Artwork/sim6_plot2_4')
% end
% 
% bar(a,y5);
% leg3 = legend('HAART','Side-Effects Innovation',...
%     'Efficacy Innovation','Efficacy & Side-Effects Innov. (Two Treatments)');
% xlabel('Age','FontSize',25)
% ylabel('Payment (X $1,000)','FontSize',25)
% xlim([27 63])
% if SIM_TYPE==1
% print('-dpng' , 'Artwork/sim6_plot3_1')
% elseif SIM_TYPE==2
% print('-dpng' , 'Artwork/sim6_plot3_2')
% elseif SIM_TYPE==3
% print('-dpng' , 'Artwork/sim6_plot3_3')
% elseif SIM_TYPE==4
% print('-dpng' , 'Artwork/sim6_plot3_4')
% end
% 
% bar(a,y6);
% leg4 = legend('HAART','Side-Effects Innovation',...
%     'Efficacy Innovation',...
%     'Efficacy & Side-Effects Innov. (Two Treatments)',...
%     'Efficacy & Side-Effects Innov. (One Treatment)');
% xlabel('Age','FontSize',25)
% ylabel('Payment (X $1,000)','FontSize',25)
% xlim([27 63])
% if SIM_TYPE==1
% print('-dpng' , 'Artwork/sim6_plot4_1')
% elseif SIM_TYPE==2
% print('-dpng' , 'Artwork/sim6_plot4_2')
% elseif SIM_TYPE==3
% print('-dpng' , 'Artwork/sim6_plot4_3')
% elseif SIM_TYPE==4
% print('-dpng' , 'Artwork/sim6_plot4_4')
% end
% 
% 
% ANNUB=sortrows(ANNU,2)
% a=ANNUB(36:40,1)
% a=a/2
% 
% y1=ANNUB(36:40,5) % HAART
% y2=[ANNUB(36:40,5) ANNUB(36:40,6)] % HAART, H+F
% y3=[ANNUB(36:40,5) ANNUB(36:40,6) ANNUB(36:40,7)] % HAART, H+F, H+E-F
% y4=[ANNUB(36:40,5) ANNUB(36:40,6) ANNUB(36:40,8)] % HAART, H+F, H+E
% y5=[ANNUB(36:40,5) ANNUB(36:40,6) ANNUB(36:40,8) ANNUB(36:40,9)] % HAART, H+F, H+E, H+E & H+F
% y6=[ANNUB(36:40,5) ANNUB(36:40,6) ANNUB(36:40,8) ANNUB(36:40,9) ANNUB(36:40,10)] % HAART, CURE
% 
% 
% clf reset
% colormap gray 
% 
% b = get(gca,'XTickLabel');
% set(gca,'XTickLabel',b,'fontsize',14)
% b = get(gca,'XTickLabel');
% set(gca,'YTickLabel',b,'fontsize',14)
% 
% bar(a,y2);
% leg1 = legend('HAART','Side-Effects Innovation','Location','NorthWest');
% xlabel('Experience (Years)','FontSize',25)
% ylabel('Payment (X $1,000)','FontSize',25)
% xlim([2 28])
% if SIM_TYPE==1
% print('-dpng' , 'Artwork/sim6_plot5_1')
% elseif SIM_TYPE==2
% print('-dpng' , 'Artwork/sim6_plot5_2')
% elseif SIM_TYPE==3
% print('-dpng' , 'Artwork/sim6_plot5_3')
% elseif SIM_TYPE==4
% print('-dpng' , 'Artwork/sim6_plot5_4')
% end
% 
% 
% bar(a,y4);
% leg2 = legend('HAART','Side-Effects Innovation','Efficacy Innovation','Location','NorthWest');
% xlabel('Experience (Years)','FontSize',25)
% ylabel('Payment (X $1,000)','FontSize',25)
% xlim([2 28])
% if SIM_TYPE==1
% print('-dpng' , 'Artwork/sim6_plot6_1')
% elseif SIM_TYPE==2
% print('-dpng' , 'Artwork/sim6_plot6_2')
% elseif SIM_TYPE==3
% print('-dpng' , 'Artwork/sim6_plot6_3')
% elseif SIM_TYPE==4
% print('-dpng' , 'Artwork/sim6_plot6_4')
% end
% 
% bar(a,y5);
% leg3 = legend('HAART','Side-Effects Innovation',...
%     'Efficacy Innovation','Efficacy & Side-Effects Innov. (Two Treatments)','Location','NorthWest');
% xlabel('Experience (Years)','FontSize',25)
% ylabel('Payment (X $1,000)','FontSize',25)
% xlim([2 28])
% if SIM_TYPE==1
% print('-dpng' , 'Artwork/sim6_plot7_1')
% elseif SIM_TYPE==2
% print('-dpng' , 'Artwork/sim6_plot7_2')
% elseif SIM_TYPE==3
% print('-dpng' , 'Artwork/sim6_plot7_3')
% elseif SIM_TYPE==4
% print('-dpng' , 'Artwork/sim6_plot7_4')
% end
% 
% bar(a,y6);
% leg4 = legend('HAART','Side-Effects Innovation',...
%     'Efficacy Innovation',...
%     'Efficacy & Side-Effects Innov. (Two Treatments)',...
%     'Efficacy & Side-Effects Innov. (One Treatment)','Location','NorthWest');
% xlabel('Experience (Years)','FontSize',25)
% ylabel('Payment (X $1,000)','FontSize',25)
% xlim([2 28])
% if SIM_TYPE==1
% print('-dpng' , 'Artwork/sim6_plot8_1')
% elseif SIM_TYPE==2
% print('-dpng' , 'Artwork/sim6_plot8_2')
% elseif SIM_TYPE==3
% print('-dpng' , 'Artwork/sim6_plot8_3')
% elseif SIM_TYPE==4
% print('-dpng' , 'Artwork/sim6_plot8_4')
% end
% 
% cd ('Matlab')
% 
% end
